<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns="http://www.w3.org/1999/xhtml" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:mml="http://www.w3.org/1998/Math/MathML">

<!--
Hermes document rendering stylesheet version 1.0.11, 2005-12-24.
License: GNU GPL
Author: Romeo Anghelache, http://romeo.roua.org
-->

<xsl:output method="xml" indent="yes" encoding="utf-8"/>

<xsl:template match="document">

<!--
<xsl:text disable-output-escaping="yes">
&lt;!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1 plus MathML 2.0//EN" 
               "http://www.w3.org/Math/DTD/mathml2/xhtml-math11-f.dtd" &gt;
</xsl:text>
-->
<xsl:text disable-output-escaping="yes">
&lt;?xml-stylesheet type="text/xsl" href="mathml.xsl"?&gt;
</xsl:text>
<html>
	<head><xsl:text>
	</xsl:text>
		<title><xsl:value-of select="//title[1]"/>, 
		<xsl:for-each select="section[type='envelope']//author">
		<xsl:value-of select="name"/>, 
		</xsl:for-each>
		<xsl:text> published in LivingReviews in Relativity on </xsl:text>
		<xsl:value-of select="section[type='envelope']//date"/>
		</title>
		<meta content="text/xml; charset=utf-8" http-equiv="Content-Type" /><xsl:text>
		</xsl:text>
		<xsl:for-each select="section[type='envelope']//author">
		<meta name="author">
		<xsl:attribute name="content">
		<xsl:choose>
		<xsl:when test="name">
			<xsl:value-of select="name"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="normalize-space(string(.))"/>
		</xsl:otherwise>
		</xsl:choose>
		</xsl:attribute>
		</meta><xsl:text>
		</xsl:text>
		</xsl:for-each>
		<meta name="keywords">
		<xsl:attribute name="content">
		<xsl:value-of select="normalize-space(string(section[type='envelope']//keywords))"/>
		</xsl:attribute>
		</meta><xsl:text>
		</xsl:text>
		<meta name="description">
		<xsl:attribute name="content">
		<xsl:value-of select="normalize-space(string(section[type='envelope']//abstract))"/>
		</xsl:attribute>
		</meta><xsl:text>
		</xsl:text>
		<meta name="generator">
		<xsl:attribute name="content">
		<xsl:value-of select="concat(string(generator/name),
		', version ',string(generator/version),' ', string(generator/date),
		', license ',string(generator/license),
		', description ', string(generator/description))"/>
		</xsl:attribute>
		</meta><xsl:text>
		</xsl:text>
	<style type="text/css">
	a:link {text-decoration:none;}
	a:hover {text-decoration:none;background-color:navy;color:yellow;}
	a:visited {text-decoration:none;}
	a.cref:hover {text-decoration:none;background-color:green;color:black;}
	
	h2,h3 {text-align:center;margin:0 5% 0 5%;}
	
	.abstract {margin:0 10% 0 10%;text-align:justify;}
 	.footnote {margin:0 0 0 5%;border-left:1px dashed blue;padding-left:1em;}
	.theorem,.definition,.lemma {margin:0 5% 0 5%;}
	

 	.title {color:maroon;font-weight:bolder;}
	.label {color:green;font-weight:bolder;}
	.ftt {font-family:monospace;}
	.fbtt {font-weight:bolder;font-family:monospace;}
	.fttsl {text-color: maroon;font-family:monospace;}
	.fttsc {text-color: maroon;font-variant:small-caps;font-family:monospace;}
	.fi {text-color: maroon;}
	.fb {text-color: maroon;font-weight:bolder;}
	.fs {font-family:cursive;}
	.fss {font-family:sans-serif;}
	.fsc {font-variant:small-caps;}
	.fsssc {font-variant:small-caps;font-family:sans-serif;}
	.fsssl {text-color: maroon;font-family:sans-serif;}
	.fbsc {font-variant:small-caps;font-weight:bolder;}
	.fbi {text-color: maroon;font-weight:bolder;}
	.fbsl {font-style:oblique;font-weight:bolder;}
	.fbss {font-weight:bolder;font-family:sans-serif;}
	.fsl {text-color: maroon;}
	.fn {font-weight:normal;color:black;}
	.affiliation {text-align:center;margin:0 15% 0 15%;}

	
 	table.normal {align:center;border-style:ridge;align:center;width=100%;}
	table.figure {border-style:ridge;align:center;width=100%;}
	td {text-align:center;}
	
	.bib {text-indent:-4em;}
	</style>
	</head>
	<body style="text-align:justify;margin:0 15% 0 15%;">
	<xsl:text>
	</xsl:text>
	
	<xsl:apply-templates/>
<xsl:text>
</xsl:text>
</body>
<xsl:text>
</xsl:text>
</html>
</xsl:template>


<xsl:template match="mml:mtable/mml:mtr">
<table width="100%">
	<xsl:if test="@id">
	<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
	</xsl:if>
		<tr>
			<td align="left" width="90%">
				<math xmlns="http://www.w3.org/1998/Math/MathML">
					<xsl:attribute name="display">block</xsl:attribute>
					<xsl:element name="mtable">
						<xsl:element name="mtr">
							<xsl:apply-templates/>
						</xsl:element>
					</xsl:element>
				</math>
			</td>
			<td align="right" valign="top"/>
		</tr>
		</table>
</xsl:template>

<xsl:template match="mml:mtable/mml:mlabeledtr">
		<table width="100%">
		<xsl:if test="@id">
		<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
		</xsl:if>
		<tr>
			<td align="left" width="90%">
				<math xmlns="http://www.w3.org/1998/Math/MathML">
					<xsl:attribute name="display">block</xsl:attribute>
					<xsl:element name="mtable">
						<xsl:element name="mtr">
							<xsl:apply-templates select="mml:mtd[position()>1]"/>
						</xsl:element>
					</xsl:element>
				</math>
			</td>
			<td align="right" valign="top">
			<xsl:value-of select="mml:mtd[position()=1]"/>
			</td>
		</tr>
		</table>
</xsl:template>

<xsl:template match="mml:mtable"><xsl:apply-templates/></xsl:template>

<xsl:template match="mml:math">
<xsl:choose>
	<xsl:when test="mml:mtable"><xsl:apply-templates/></xsl:when>
	<xsl:otherwise>
		<math xmlns="http://www.w3.org/1998/Math/MathML">
			<xsl:if test="@display"><xsl:attribute name="display">block</xsl:attribute></xsl:if>
			<xsl:if test="@id"><xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute></xsl:if>
			<xsl:apply-templates/>
		</math>
	</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="env">
<p>
<xsl:attribute name="class"><xsl:value-of select="type"/></xsl:attribute>
<xsl:if test="@id">
	<xsl:attribute name="id"><xsl:value-of select="@id"/>
</xsl:attribute></xsl:if>
</p>
<xsl:apply-templates/>
</xsl:template>
<xsl:template match="option"/>

<xsl:template match="*">
<xsl:copy-of select="."/>
</xsl:template>


<xsl:template match="cite">
<xsl:text>[</xsl:text>
<xsl:for-each select="sref">
<xsl:variable name="curRefNum" select="position()"/>
<a class="cref">
<xsl:attribute name="href">#<xsl:value-of select="."/></xsl:attribute>
<xsl:value-of select="substring-before(substring-after(string(../pref[$curRefNum]),'['),']')"/></a>
<xsl:if test='position()&lt;last()'><xsl:text>, </xsl:text></xsl:if>
</xsl:for-each>
<xsl:text>]</xsl:text>
</xsl:template>

<xsl:template match="ref">
<xsl:text> </xsl:text><xsl:element name="a">
<xsl:attribute name="href">#<xsl:value-of select="sref"/></xsl:attribute>
<xsl:value-of select="pref"/>
</xsl:element>
<xsl:text> </xsl:text>
</xsl:template>


<xsl:template match="env[type='table']">
<table class="normal">
<xsl:if test="id">
<xsl:attribute name="id"><xsl:value-of select="id"/></xsl:attribute>
</xsl:if>
<tr>
	<td>
		<xsl:apply-templates select=".//env[type='tabular']"/>
	</td>
</tr>
<xsl:if test="caption">
<tr>
	<td>
		<xsl:apply-templates select="caption/node()"/>
	</td>
</tr>
</xsl:if>
</table>
</xsl:template>

<xsl:template match="env[type='tabular']">
<table><xsl:apply-templates/>	</table>
</xsl:template>

<xsl:template match="tr">
<tr><xsl:apply-templates/></tr>
</xsl:template>

<xsl:template match="td">
<td><xsl:apply-templates/></td>
</xsl:template>

<xsl:template match="page"/>

<xsl:template match="author">
<h3>
<xsl:choose>
<xsl:when test="string-length(string(.//vaddress)) != 0">
<a>
<xsl:attribute name="href"><xsl:value-of select=".//vaddress"/></xsl:attribute>
	<xsl:value-of select=".//name"/>
</a>
</xsl:when>
<xsl:when test="string-length(string(.//email)) != 0">
<a>
<xsl:attribute name="href">mailto:<xsl:value-of select=".//email"/></xsl:attribute>
	<xsl:value-of select=".//name"/>
	</a>
</xsl:when>
<xsl:otherwise>
<xsl:choose>
<xsl:when test="name">
<xsl:value-of select=".//name"/>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="."/>
</xsl:otherwise>
</xsl:choose>

</xsl:otherwise>
</xsl:choose>
</h3>
<p class="affiliation"><xsl:value-of select=".//affiliation"/></p>
</xsl:template>
<xsl:template match="date">
<h3><xsl:value-of select="."/></h3>
</xsl:template>
<xsl:template match="abstract">
<p class="abstract">
<xsl:apply-templates/>
</p>
</xsl:template>

<xsl:template match="footnote">
	<xsl:for-each select="par">
		<p class="footnote"><xsl:apply-templates/></p>
	</xsl:for-each>
</xsl:template>

<xsl:template match="fnmark">
<sup><xsl:apply-templates/></sup>
</xsl:template>


<xsl:template match="subsection|subsubsection|section">
<xsl:choose>
<xsl:when test="type='bibliography'">
<p class="bib"><xsl:apply-templates/></p>
</xsl:when>
<xsl:otherwise>
<p>
<xsl:attribute name="class"><xsl:value-of select="type"/></xsl:attribute>
<xsl:attribute name="id"><xsl:value-of select=".//id[1]"/></xsl:attribute>
	<xsl:apply-templates/>
</p>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="title">
<span class="title">
<xsl:apply-templates/>
</span>
</xsl:template>

<xsl:template match="section[type='envelope']//title">
<h2 class="title"><xsl:value-of select="."/></h2>
</xsl:template>

<xsl:template match="env/par/head">
<xsl:value-of select="type"/>
<xsl:value-of select="counter"/>
</xsl:template>

<xsl:template match="type"/>
<xsl:template match="id"/>

<xsl:template match="label">
<xsl:choose>
	<xsl:when test="../id">
		<a class="label" id="{../id}">
		<xsl:apply-templates/>
		</a>
	</xsl:when>
	<xsl:otherwise>
		<span class="label">
			<xsl:apply-templates/>
		</span>
	</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="sref"/>

<xsl:template match="list|description">
<ul>
<xsl:attribute name="class"><xsl:value-of select="local-name(.)"/></xsl:attribute>
<xsl:apply-templates/>
</ul>
</xsl:template>

<xsl:template match="item">
<div class="bib">
<xsl:if test="id">
<xsl:attribute name="id"><xsl:value-of select="id"/></xsl:attribute>
</xsl:if>
	<xsl:apply-templates/>
</div>
</xsl:template>


<xsl:template match="head|foot">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="vaddress">
<a>
<xsl:attribute name="href"><xsl:value-of select="."/></xsl:attribute>
<xsl:value-of select="."/>
</a>
</xsl:template>

<xsl:template match="par">
<p>
<xsl:apply-templates/>
</p>
</xsl:template>

<xsl:template match="ph">
<xsl:if test="string-length()">
<xsl:choose>
	<xsl:when test="contains(@f,'cmmib') 
		or contains(@f,'cmbxti')
		or contains(@f,'ecbi')
		or contains(@f,'lassdc')
		or contains(@f,'zppleb7m')
		or contains(@f,'pxbi')
		or contains(@f,'txbi')
		or contains(@f,'pxbmi')
		or contains(@f,'txbmi')
		or contains(@f,'p1xbi')
		or contains(@f,'t1xbi')">
	<span class="fbi"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmssdc')
		or contains(@f,'pplb8t')">
	<span class="fbss"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmbx') 
		or contains(@f,'cmbsy')
		or contains(@f,'cmb')
		or contains(@f,'zppleb7y')
		or contains(@f,'zppleb7t')
		or contains(@f,'ecbx')
		or contains(@f,'ecb')
		or contains(@f,'pplb8t') 
		or contains(@f,'pxb')
		or contains(@f,'txb')
		or contains(@f,'pxbsy')
		or contains(@f,'txbsy')
		or contains(@f,'p1xb')
		or contains(@f,'t1xb')">
	<span class="fb"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'pxbsl')
		or contains(@f,'txbsl')
		or contains(@f,'p1xbsl')
		or contains(@f,'t1xbsl')">
	<span class="fbsl"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'pxbsc')
		or contains(@f,'txbsc')">
	<span class="fbsc"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmttsl')
		or contains(@f,'pxttsl') 
		or contains(@f,'txttsl') 
		or contains(@f,'p1xttsl') 
		or contains(@f,'t1xttsl')">
	<span class="fttsl"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmtt')
		or contains(@f,'pxtt') 
		or contains(@f,'txtt') 
		or contains(@f,'p1xtt') 
		or contains(@f,'t1xtt')">
	<span class="ftt"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmtcsc')
		or contains(@f,'pxttsc') 
		or contains(@f,'txttsc') 
		or contains(@f,'p1xttsc') 
		or contains(@f,'t1xttsc')">
	<span class="fttsc"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'pxbtt') 
		or contains(@f,'txbtt')">
	<span class="fbtt"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmmi') 
		or contains(@f,'cmti') 
		or contains(@f,'wncyi') 
		or contains(@f,'ecti') 
		or contains(@f,'pplri8t') 
		or contains(@f,'zppler7m') 
		or contains(@f,'pxi') 
		or contains(@f,'txi') 
		or contains(@f,'pxmi') 
		or contains(@f,'txmi') 
		or contains(@f,'pplri')">
	<span class="fi"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmsssc')  
		or contains(@f,'pxsssc') 
		or contains(@f,'txsssc') 
		or contains(@f,'p1xsssc') 
		or contains(@f,'t1xsssc')">
	<span class="fsssc"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmsc')  
		or contains(@f,'ecsc') 
		or contains(@f,'pxsc') 
		or contains(@f,'txsc') 
		or contains(@f,'p1xsc') 
		or contains(@f,'t1xsc')">
	<span class="fsc"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmsssl')  
		or contains(@f,'pxsssl') 
		or contains(@f,'txsssl')">
	<span class="fsssl"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmss')  
		or contains(@f,'pplr8t') 
		or contains(@f,'pxss') 
		or contains(@f,'txss') 
		or contains(@f,'p1xss') 
		or contains(@f,'t1xss')">
	<span class="fss"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'cmsl')  
		or contains(@f,'ecsl') 
		or contains(@f,'pxsl') 
		or contains(@f,'txsl')">
	<span class="fsl"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:when test="contains(@f,'rsfs')
		or contains(@f,'zppler7y')">
	<span class="fs"><xsl:apply-templates/></span>
	</xsl:when>
	<xsl:otherwise>
	<span class="fn"><xsl:apply-templates/></span>
	</xsl:otherwise>
</xsl:choose>
</xsl:if>
</xsl:template>

<xsl:template match="dviy"/>

<xsl:template match="figure">
<table class="figure">
<xsl:if test="id">
<xsl:attribute name="id"><xsl:value-of select="id"/></xsl:attribute>
</xsl:if>
<tr>
	<td>
		<img>
			<xsl:attribute name="src"><xsl:value-of select="concat(source/text(),'.png')"/></xsl:attribute>
			<xsl:attribute name="alt"><xsl:value-of select="source"/></xsl:attribute>
		</img>
	</td>
</tr>
<xsl:if test="caption">
<tr>
	<td>
		<xsl:apply-templates select="caption/node()"/>
	</td>
</tr>
</xsl:if>
</table>
</xsl:template>

<xsl:template match="keywords"/>
<xsl:template match="generator"/>
</xsl:stylesheet>
