/*
Hermes bison grammar version 0.9.4, 2005-12-24
author Romeo Anghelache http://romeo.roua.org
released under GNU GPL
*/

%{

#include <stdlib.h>
#include <stdio.h>
#include <assert.h>
#include <string.h>
#include <ctype.h>
const char * VERSION="0.9.5";
const char * DATE="2005-12-24";
const char * DESCRIPTION="http://hermes.roua.org/";
extern char* yytext;
extern FILE* yyin;
extern FILE* yyout;
extern int yylex();
int yyerror(char*msg);
void showcontext();
int BigEndian=0; 
#define LIMIT 100000
void p(char*s);
struct{
	unsigned int mag;
	unsigned int num;
	unsigned int den;
}scale;

int DEBUG=0;
int INFER_CONTENT=0;
int maxFontNr=0;
int fakesp=1;
int inhibitspace=0;
char *doc_math;
char *doc_text;
int mathText=0;
int mathOp=0;
int pHints=1;
int inBibliography=0;
int inCitation=0;
int length=0;
extern char currentFont[512];
char fname[512];
extern char lastToken[512];//last token received before an error happens
extern void empty();
extern int inputlines;
int mathmode=0;//if in text it's 0
int mathblock=0;//display mode flag
int mathBox=0;//set if inside a math box
int infhp=0;//inside footer or header
unsigned int blockthis=0;//use this to stop TeX construction of big delimiters
int canbreak=1;
int noDVIY=0;
int inTable=0;
char id[512]="";
char label[512]="";
char* content(char*from,char*what, char*bas, char*eas);
void InferContent();
void printFigureFileName();
void printEPSFigureFileName();
void printEnvType();
void printId();
void printRef();
void printSectType();
void printCiteSRef();

char* Insert(char*at,char*what);
char* MatchCloseLeft(char*where, char*from, char*what);
char* MatchTagLeft(char*from, char*what);
char* MatchTagRight(char*from);
char* SkipBracketsLeft(char*from);
char* SkipBracketsRight(char*from);
char* MoveLeft(char*where,char*temp);
char* IndentContainer(char*pos,int* spaces,int start);
int IsMMLContainerEnd(char*at);
int IsMMLContainerStart(char*at);
int IsMMLConstant(char*at);
void flushMath();
void flushText();
void AddPHint(int StartOrEnd);
void Clean(char*from,char*what,int how);
void pretty(char*s,int eraseBrackets);
void die(char* text);
void fixIds();
void fixLabels();
void fixBackParsedPrimitive(const char* what);
void mapp_char();
unsigned long combiningUnicode=0;
void saveAccent(char accent);
void saveAccentUnder(char accent);
int AccentBelow=0;
char* ul2utf8(unsigned long unicode);
void pmt(unsigned long unicode);
void precomposedNegative(unsigned long single, unsigned long composed);
enum{mi, //presentation math identifier -> <mi> default variant
	mib, 		//bold variant
	mibi, 		//bold-italic
	mif, 		//fraktur
	mis, 		//script
	mibs, 		//bold script
	mids,		//double struck
	mitt, 		//monospace
	miss,		//sans-serif
	mibss,		//bold sans-serif
	missi,		//sans-serif-italic
	mo,			////presentation math operatorr -> <mo> normal variant
	mob,
	moi,	//italic variant
	mobi,
	mof,
	mos,
	mobs,
	mods,
	mott,
	moss,
	mossi,
	mobss,
	mn,			//<mn>
	mnb,		//bold <mn>
	mni,
	mnbi,
	mnf,
	mns,
	mnbs,
	mnds,
	mntt,
	mnss,
	mnssi,
	mnbss,
	ld,			//left delimiter
	ldb,		//...bold
	ldi,		//...italic
	lds,		//...script
	ldbi,		//...bold-italic
	ldtt,		//...monospace
	ldss,		//...sans-serif
	ldssi,		//...sans-serif-italic
	rd,			//right delimiter
	rdb,
	rdi,
	rds,
	rdbi,
	rdtt,
	rdss,
	rdssi,
	ld_b,		//left delimiter begin (bigg  delimiters)
	rd_b,
	ld_x,		//left delimiter extend (bigg)
	rd_x,
	ld_e,		//left delimiter end	(bigg)
	rd_e
	}pmath;

void beginSuperScript();
void beginSubScript();
void endSubScript();
void endSuperScript();
void endover();
void endMAccent();
void fixDigits();
void contractTextAccent();
int hbrace=0;
%}

%token		ANY SET END

%token		DVIY PAR FontChange 

%token		CR Left Right LeftNull RightNull
%token 		BTBOX ETBOX BMBOX EMBOX BFBOX EFBOX BPUBLISHED	EPUBLISHED 
%token		BMATHICS	EMATHICS BICSIDX	EICSIDX	BICSDESC	EICSDESC BMATVERW EMATVERW	BMATHICSSUB	EMATHICSSUB 

%token		POST_POST
%token		BENTRY EENTRY 
%token 		BTITLE ETITLE BAUTHOR EAUTHOR BName EName BDATE EDATE BTHANKS ETHANKS MAKETITLE
%token		BComment EComment BCAuthor ECAuthor
%token 		BURL EURL BEMAIL EEMAIL BAFFIL EAFFIL
%token 		BKeywords EKeywords
%token 		BEQTAG EEQTAG
%token 		BBINOM EBINOM BBINOMUP EBINOMUP	BBINOMDOWN EBINOMDOWN
%token		BHEADLINE EHEADLINE BFOOTLINE EFOOTLINE
%token		BEnvDocument EEnvDocument BAbstract EAbstract 
%token		BTheorem ETheorem BDefinition EDefinition BLemma ELemma
%token		BEnumerate EEnumerate BItemize EItemize BDescription EDescription ITEM LIST
%token		BBibliography EBibliography BBibLabel EBibLabel 
%token		BSectMark ESectMark SectType BSectLabel ESectLabel BSectTitle ESectTitle
%token		BCaption ECaption BFigureTag EFigureTag FigureFileName EPSFigureFileName
%token		Id BRef Ref ERef BCite ECite BCiteLabel ECiteLabel CiteSRef
%token		BFootnoteMark EFootnoteMark BFootnote EFootnote
%token		BTabular ETabular BTable ETable BFigure EFigure BLTable ELTable TABCR SPAN
%token		TACCENT TACCENTU MACCENT 
%token		BIGSQCUP BIGSQCAP
%token		IMATHB IMATHE DMATHB DMATHE 
%token		Bfile Efile
%token		EQNO LEQNO REQNO BEqNum EEqNum BFoot EFoot BHead EHead BPage EPage
%token		ALIGN BMTABLE EMTABLE BARRAY EARRAY BEqnArray EEqnArray BEQALIGN EEQALIGN 
%token		BSplit ESplit

%token		BSP ESP BPower Power EPower
%token		BSB ESB SBCHAR

%token		LT GT NEQ

%token		ARCCOS ARCSIN ARCTAN ARG COS COSH COT COTH CSC DEG
%token		DET DIM EXP GCD HOM INF KER LG LIM LIMINF LIMSUP LN LOG
%token		MAX MIN PR SEC SIN SINH SUP TAN TANH
%token		CDOTS DDOTS LDOTS VDOTS
%token		BFRAC FRACN FRACD EFRAC OVER CHOOSE ATOP BBUILDREL BUILDREL EBUILDREL
%token		MAPSTO LMAPSTO MODELS HLARROW HRARROW lLARROW LLARROW lRARROW LRARROW lLRARROW LLRARROW BOWTIE
%token		BOVERLARROW EOVERLARROW BOVERRARROW EOVERRARROW 
%token		BUNDERLARROW EUNDERLARROW BUNDERRARROW EUNDERRARROW 
%token		BOVERBRACE EOVERBRACE BUNDERBRACE EUNDERBRACE 
%token		BWIDEHAT EWIDEHAT BWIDETILDE EWIDETILDE 
%token		BDOT EDOT BOVERLINE EOVERLINE BUNDERLINE EUNDERLINE 
%token		BMO EMO
%token		BSQRT SQRT ESQRT BROOT ROOT EROOT BRoot Root ERoot BSqrt ESqrt

/****** MathML content TeX macros ******/

/* arbitrary functions */
%token		Bfunc Bfarg Efarg Efunc

/* basic elements */
%token		BInterval Interval EInterval	BCompose Compose ECompose BInverse Inverse EInverse Ident
%token		BDomain EDomain	BCodomain ECodomain	BImage EImage
%token		BAmsCases EAmsCases BLaCases ELaCases

/*new elements*/
%token		BBra EBra BKet EKet NOTIN

/*	arithmetic, algebra, logic	*/
%token		BPlus Plus EPlus BMinus Minus EMinus BTimes Times ETimes

%token 	BQuotient Quotient EQuotient
%token 	BFactorial Factorial EFactorial
%token 	BFrac Fracn Fracd EFrac
%token 	BMaxl BMaxc EMaxl EMaxc BVar EVar BCond ECond	BExpr EExpr BMinl BMinc EMinl EMinc
%token	BRem Rem ERem REM BPMOD EPMOD BGcd EGcd BLcm ELcm LCM BRe ERe BIm EIm
%token	AND BLand Land ELand OR BLor Lor ELor XOR BXor Xor EXor BNot ENot BImplies Implies EImplies


%token	BForall EForall	BAssert EAssert BExists EExists

%token	Babs Eabs
%token	Bconjugate Econjugate BArg EArg	Bfloor Efloor Bceil Eceil
%token	BFactor Factor EFactor

/* relations */
%token		BEqual Equal EEqual BNequal Nequal ENequal BLequal Lequal ELequal BGequal Gequal EGequal
%token		BEquiv Equiv EEquiv BApprox Approx EApprox BGthan Gthan EGthan BLthan Lthan ELthan

/* 	calculus and vector calculus 	*/
%token BInt EInt BIntll EIntll BIntul EIntul BIntarg EIntarg BIntbe EIntbe
%token BDiff EDiff BDiffbe EDiffbe BDiffdeg EDiffdeg BDiffarg EDiffarg
%token BDivs BDivt EDiv BGradt BGrads EGrad BCurlt BCurls ECurl BLaplacian ELaplacian

/*	sequences and series	*/
%token BSum ESum BSumll ESumll BSumul ESumul BSumarg ESumarg
%token BProd EProd BProdll EProdll BProdul EProdul BProdarg EProdarg
%token BLimit ELimit BLimitarg ELimitarg BTendsto Tendsto ETendsto

/* set theory	*/
%token BSetl ESetl BSetc ESetc
%token BSubset Subset ESubset BSubseteq Subseteq ESubseteq
%token BNotsubset Notsubset ENotsubset BNotsubseteq Notsubseteq ENotsubseteq
%token BListl EListl BListcarg EListcarg BListc EListc
%token BUnion Union EUnion BIntersect Intersect EIntersect BIn In EIn BNotin Notin ENotin
%token BSetdiff Setdiff ESetdiff BCard ECard BCartesian Cartesian ECartesian

/* elementary functions	*/
%token BSin ESin BCos ECos BTan ETan BSec ESec BCsc ECsc BCot ECot
%token BSinh ESinh BCosh ECosh	BTanh ETanh BSech Sech ESech BCsch Csch ECsch BCoth ECoth

%token BArccos EArccos BArccosh Arccosh EArccosh BArcsin EArcsin BArctan EArctan
%token BArccot Arccot EArccot BArccoth Arccoth EArccoth
%token BArccsc Arccsc EArccsc BArccsch Arccsch EArccsch BArcsec Arcsec EArcsec
%token BArcsech Arcsech EArcsech BArcsinh Arcsinh EArcsinh BArctanh Arctanh EArctanh
%token BLn ELn BLog ELog BLg ELg BExp EExp


/* statistics	*/

%token BMean EMean BSDev ESDev BVariance Variance EVariance
%token BMedian Median EMedian BMode Mode EMode
%token BMoment EMoment BMomentDeg EMomentDeg BMomentArg EMomentArg BMomenta EMomenta BMabout EMabout

/*	linear algebra	*/
%token BMATRIX EMATRIX BVector EVector BMatrix EMatrix BTranspose ETranspose BDet EDet
%token BSelector SelectorMatrix ESelector
%token BVectorProduct VectorProduct EVectorProduct
%token BScalarProduct ScalarProduct EScalarProduct
%token BOuterProduct OuterProduct EOuterProduct


/*	constants	*/
%token Integers Naturals Rationals Reals Complexes Primes EPrimes
%token ExponentialE ImaginaryI NotANumber True False Emptyset PiCst EulerGamma Infty

/*	extras	*/
%token Trace

%left CR ALIGN

%%

Document: document END {flushText();};

document: |	document input ;


input: 	
	BAbstract {
	 	AddPHint(0);
	 	p("\n</par>\n<abstract>\n<par>\n");
	 	AddPHint(1);
	 	} 
	 	document {
	 	AddPHint(0);
	 	p("\n</par>\n</abstract>\n<par>\n");
	 	AddPHint(1);
	 	} 
 	EAbstract
	|
	BTheorem {
	 	AddPHint(0);
	 	p("\n</par>\n<theorem>\n<par>\n");
	 	AddPHint(1);
	 	} 
	 	document {
	 	AddPHint(0);
	 	p("\n</par>\n</theorem>\n<par>\n");
	 	AddPHint(1);
	 	} 
 	ETheorem
	|
	BDefinition {
	 	AddPHint(0);
	 	p("\n</par>\n<definition>\n<par>\n");
	 	AddPHint(1);
	 	} 
	 	document {
	 	AddPHint(0);
	 	p("\n</par>\n</definition>\n<par>\n");
	 	AddPHint(1);
	 	} 
 	EDefinition
	|
	BLemma {
	 	AddPHint(0);
	 	p("\n</par>\n<lemma>\n<par>\n");
	 	AddPHint(1);
	 	} 
	 	document {
	 	AddPHint(0);
	 	p("\n</par>\n</lemma>\n<par>\n");
	 	AddPHint(1);
	 	} 
 	ELemma
	| 
	BRef {pHints=0;noDVIY=1;p("<ref>");} Ref  {printRef();p("<pref>");} document ERef {p("</pref></ref>");noDVIY=0;pHints=1;}
	|
	BEqNum {p("<label>");mathText=1;}
		document
	EEqNum {mathText=0;p("</label>");}
	|
	BCite
		{pHints=0;p("<cite>");}
		CiteSRef {printCiteSRef();}
		BCiteLabel 
			{inCitation=1;AddPHint(0);pHints=0;p("<pref>");} 
			citation 
		ECiteLabel 
			{p("</pref></cite>");inCitation=0;pHints=1;}
	ECite
	| 
	BSectMark 
		{
			AddPHint(0);noDVIY=1;
			p("</par>\n</section>\n<section>\n");
		} 
	sectionmark 
	ESectMark 
		{
			p("<par>");	
			noDVIY=0;AddPHint(1);
		} 
	|
	BEnumerate
		{
			AddPHint(0);noDVIY=1;
			p("</par>\n<list>\n<item>\n<par>\n");
			AddPHint(1);
		} 
	document 
	EEnumerate
		{
			AddPHint(0);
			p("</par>\n</item>\n</list>\n<par>\n");	
			noDVIY=0;AddPHint(1);
		} 
	|
	BItemize
		{
			AddPHint(0);noDVIY=1;
			p("</par>\n<list>\n<item>\n<par>\n");
			AddPHint(1);
		} 
	document 
	EItemize
		{
			AddPHint(0);
			p("</par>\n</item>\n</list>\n<par>\n");	
			noDVIY=0;AddPHint(1);
		} 
	|
	BDescription
		{
			AddPHint(0);noDVIY=1;
			p("</par>\n<description>\n<item>\n<par>\n");
			AddPHint(1);
		} 
	document 
	EDescription
		{
			AddPHint(0);
			p("</par>\n</item>\n</description>\n<par>\n");	
			noDVIY=0;AddPHint(1);
		} 
	|
	Id {
			if (inBibliography) {
				AddPHint(0);pHints=0;
				p("\n</item>\n<item>\n");
			}
			printId();
		} 
	| 
	BBibliography 
		{
		AddPHint(0);
		p("</par>\n<section>\n<type>bibliography</type>\n<item>\n");
		AddPHint(1);
		inBibliography=1;} 
		document 
	EBibliography 
		{
		AddPHint(0);
		p("</item>\n</section>\n<par>");
		AddPHint(1);
		inBibliography=0;
		}
	| ITEM {AddPHint(0);p("</par>\n</item>\n<item>\n<par>\n");AddPHint(1);}
	| LIST ITEM 
	| 
	BBibLabel 
		{p("\n<label>");} 
		document 
		{p("</label>\n");pHints=1;AddPHint(1);} 
	EBibLabel
	| BMBOX document EMBOX
	| fhp  
	| text
	| math  {flushText();if(!mathBox) flushMath();} 
	| caption
	| IMATHB {mathmode=0;mathText=0;} IMATHE
	| Bfile {pHints=0;p("<file>");} document Efile {p("</file>");pHints=1;} 
	| BUNDERLINE IMATHB {mathmode=0;mathText=0;p("<underline>");} document IMATHE EUNDERLINE {p("</underline>");} 
	| table 
	| ltable
	| tabular
	| IMATHB mathmode_off tabular document IMATHE
	| footnote 
	| figureTag
	| FigureFileName {printFigureFileName();}
	| EPSFigureFileName {printEPSFigureFileName();}
;

sectionmark:
	SectType	{printSectType();}
	BSectLabel	{p("<label>");AddPHint(1);noDVIY=1;} 
	document
	ESectLabel	{AddPHint(0);p("</label>");AddPHint(1);noDVIY=1;} 
	BSectTitle	{AddPHint(0);p("<title>");AddPHint(1);} 
	document
	ESectTitle	{AddPHint(0);p("</title>");noDVIY=1;} 
;


figure: BFigure {p("</ph>\n<figure>\n<ph>\n");} document EFigure {p("</ph>\n</figure>\n<ph>\n");}
;

footnote:	
	BFootnoteMark  
		{canbreak=0; AddPHint(0);pHints=0;p("<fnmark>");} 
		IMATHB mathmode_off
	document 
		IMATHE
	EFootnoteMark 
		{p("</fnmark>\n");pHints=1;AddPHint(1);canbreak=1;} 
	|
	BFootnote mathmode_off 
		{canbreak=0;AddPHint(0);p("<footnote>\n<par>\n");AddPHint(1);}  
	document 
	EFootnote 
		{AddPHint(0);p("</par>\n</footnote>\n");AddPHint(1);canbreak=1;} 
;


caption: 
	BCaption
	{pHints=1;AddPHint(0);canbreak=0;noDVIY=1;p("\n<caption>\n");AddPHint(1);} 
	document 
	ECaption 
	{AddPHint(0);p("\n</caption>\n");noDVIY=0;canbreak=1;AddPHint(1);}
;

figureTag: 
	BFigureTag 
	document 
	EFigureTag
;

ltable: 
	BLTable mathmode_off 
	{AddPHint(0);p("<table><tr><td>");AddPHint(1);} 
	tcore 
	ELTable
	{p("</table>");AddPHint(1);}
;

table: 
	BTable {inTable=1;p("<table>");AddPHint(1);}  
	document 
	ETable {AddPHint(0);p("</table>");inTable=0;} ;


tabular:	BTabular mathmode_off  
	{AddPHint(0);inTable=1;p("<tabbed><tr><td>");AddPHint(1);} 
	IMATHB  mathmode_off tcore IMATHE 
	ETabular mathmode_off 
	{p("</tabbed>");AddPHint(1);inTable=0;} 
;


tcore: 
	row {AddPHint(0);p("</td></tr>");}mathmode_off
	| 
	tcore mathmode_off {p("<tr><td>");AddPHint(1);} TABCR row {AddPHint(0);p("</td></tr>");} 
;

row: 
	ecell mathmode_off
	| 
	cells mathmode_off ecell mathmode_off
;

cells:
	mcell mathmode_off
	|
	cells mathmode_off mcell mathmode_off
;
	
ecell:	document mathmode_off 
;


mcell:document align_or_span mathmode_off {AddPHint(0);p("</td><td>");AddPHint(1);}
;

align_or_span: 
	ALIGN 
	|
	SPAN 
;

text:
	accent
	| ANY {mapp_char();}
	| SBCHAR {p("_");inhibitspace=1;}
	| DVIY {fakesp=0;p("<dviy/>");}
	| headline
	|	SET ANY {mapp_char();}
	| 
	BMATHICS document 
		BICSIDX 
			{p("<ics>\n<index>");} document {p("</index><description><par>");} 
		EICSIDX 
		BICSDESC 
			document {p("</par></description>");} 
		EICSDESC 
		document {p("</ics>\n");}
	EMATHICS
	| 
	BMATVERW 
		{AddPHint(0);p("<matverw><par>\n");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par></matverw>\n");AddPHint(1);}
	EMATVERW 
	| 
	BMATHICSSUB 
		{AddPHint(0);p("<zwigeb><par>\n");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par></zwigeb>\n");AddPHint(1);}
	EMATHICSSUB 
	| 
	BAUTHOR {
		canbreak=0;	mathmode=0;AddPHint(0);
		p("</par>\n<author>\n<par>\n");
		AddPHint(1);
		} 
		document {
		AddPHint(0);
		p("</par>\n</author>\n<par>\n");canbreak=1;
		AddPHint(1);
		} 
	EAUTHOR 
	| 
	BCAuthor {mathmode=0;
		canbreak=0;	AddPHint(0);
		p("</par><cauthor><par>\n");
		AddPHint(1);
		} 
		document {
		AddPHint(0);
		p("</par></cauthor><par>\n");canbreak=1;
		AddPHint(1);
		}
	ECAuthor
	| 
	BENTRY 
		{AddPHint(0);canbreak=0;p("</par><number><par>\n");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par></number><par>\n");canbreak=1;AddPHint(1);} 
	EENTRY
	| 
	BTBOX 
		{AddPHint(0);p("</par>\n<par>\n");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par>\n<par>\n");AddPHint(1);} 
	ETBOX 
	| 
	BPUBLISHED 
		{mathmode=0;AddPHint(0);p("<published>\n<par>\n");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par></published>\n");AddPHint(1);} 
	EPUBLISHED 
	| 
	BComment 
		{AddPHint(0);p("<comment><par>\n");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par></comment>\n");AddPHint(1);} 
	EComment
	| 
	PAR 
		{AddPHint(0);p("</par>\n<par>\n");AddPHint(1);}
	| 
	BTITLE 
		{mathmode=0;canbreak=0;AddPHint(0);p("</par>\n<title>");AddPHint(1);} 
		document 
		{AddPHint(0);p("</title><par>\n");canbreak=1;AddPHint(1);}
	ETITLE 
	| 
	BDATE {mathmode=0;
		AddPHint(0);p("</par>\n<date>");AddPHint(1);} 
		document 
		{AddPHint(0);p("</date>\n<par>\n");	AddPHint(1);} 
	EDATE 
	| 
	BTHANKS 
		{AddPHint(0);p("</par><thanks><par>");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par></thanks><par>\n");AddPHint(1);} 
	ETHANKS  
	| 
	BURL 
		{mathmode=0;canbreak=0;AddPHint(0);pHints=0;p("<vaddress>");} 
		document 
		{canbreak=1;p("</vaddress>\n");pHints=1;AddPHint(1);} 
	EURL
	| 
	BEMAIL 
		{mathmode=0;canbreak=0;AddPHint(0);pHints=0;p("<email>");} 
		document 
		{canbreak=1;p("</email>\n");pHints=1;AddPHint(1);} 
	EEMAIL
	| 
	BAFFIL 
		{mathmode=0;AddPHint(0);p("<affiliation>\n<par>\n");AddPHint(1);} 
		document 
		{AddPHint(0);p("\n</par>\n</affiliation>\n");AddPHint(1);} 
	EAFFIL
	| 
	IMATHB BAUTHOR 
		{
		mathmode=0;canbreak=0;AddPHint(0);
		p("</par>\n<author>\n<par>\n");	AddPHint(1);
		} 
		document 
		{
		AddPHint(0);p("</par>\n</author>\n<par>\n");
		canbreak=1;AddPHint(1);
		} 
	EAUTHOR IMATHE 
	|
	BName
		{
		mathmode=0;canbreak=0;AddPHint(0);
		p("</par>\n<name>");	AddPHint(1);
		} 
		document 
		{
		AddPHint(0);p("</name>\n<par>\n");
		canbreak=1;AddPHint(1);
		} 
	EName
	| 
	FontChange {if (!noDVIY) {AddPHint(0);AddPHint(1);}}
	|
	BKeywords 
		{pHints=0;p("\n<keywords>");}
	document 
		{p("</keywords>\n");pHints=1;} 
	EKeywords
;

headline:
	BHEADLINE 
		{AddPHint(0);p("<headline><par>");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par></headline>");AddPHint(1);} 
	EHEADLINE
	|
	BFOOTLINE 
		{AddPHint(0);p("<footline><par>");AddPHint(1);} 
		document 
		{AddPHint(0);p("</par></footline>");AddPHint(1);} 
	EFOOTLINE
;

fhp:
	BFoot {
		mathmode=0;infhp=1;p("<foot>");
	} headerfooter 
	EFoot {
		p("</foot>");infhp=0;
	} 
	| 
	BHead {
		mathmode=0;infhp=1;p("<head>");
	} headerfooter 
	EHead {
		p("</head>");infhp=0;
	}
	| 
	BPage {
		mathmode=0;pHints=0;	infhp=1;	p("<page nr=\"");
	} document 
	EPage {
		p("\"/>");infhp=0;pHints=1;
	}
	|figure
;


headerfooter:
	| text headerfooter
	| 
	BPage 
		{mathmode=0;pHints=0; canbreak=0;infhp=1;p("<page nr=\"");} 
		document 
		{p("\"/>");canbreak=1;infhp=0;pHints=1;}  
	EPage 
	headerfooter 
;

citation:
	 | ANY {if (*yytext==',') p("]</pref><pref>["); else mapp_char();} citation
	 | DVIY  citation
	 | fhp citation
	 | 
	 BMBOX 
		{mathBox=1;p("<mtext>");} 
		document 
		{p("</mtext>");mathBox=0;} 
	 EMBOX citation
	 |	FontChange citation

;

dvi:	| dvi DVIY {fakesp=0;p("<dviy/>");}
;


accent: TACCENT happenings ANY {saveAccent(*yytext);} text {contractTextAccent();inhibitspace=0;noDVIY=0;}
			| TACCENT happenings SET ANY {mapp_char();inhibitspace=0;noDVIY=0;}
			| TACCENTU text ANY {saveAccentUnder(*yytext);contractTextAccent();inhibitspace=0;noDVIY=0;} 
			| MACCENT happenings ANY {saveAccent(*yytext);} text {contractTextAccent();inhibitspace=0;}
;

happenings:
	| 
	BBibLabel 
		{pHints=0;p("\n<label>");} 
		document 
		{p("</label>\n");pHints=1;AddPHint(1);} 
	EBibLabel 
	|	FontChange {AddPHint(0);AddPHint(1);} 
;

mathmode_on:{
	if (mathBox) p("</mtext>"); 
	else mathmode=1;
	}
;
mathmode_off:{ 
	if (mathBox) p("<mtext>"); 
	else mathmode=0;
	}
;

math:	IMATHB mathmode_on  {mathblock=0;} phints
			formula 
		IMATHE mathmode_off 
		| 
		DMATHB mathmode_on  {mathblock=1;} phints
			formula 
		DMATHE mathmode_off 
//		| 
//		BEqnarray mathmode_on {mathblock=1;} {p("<mtr><mtd>");} phints
//			eqnarray  {p("</mtd></mtr>");} 
//		EEqnarray mathmode_off 
		| ams_align
		| mtable
		| eqnarray
		| array
;


phints: |FontChange {AddPHint(0);AddPHint(1);};
ams_align: 
		DMATHB mathmode_on {mathblock=1;} CR  {p("<mtr><mtd>");} optheadline
		cams_align 
		CR optheadline DMATHE {p("</mtd></mtr>");} mathmode_off  
;


optheadline:| mathmode_off headline mathmode_on optheadline ;
cams_align: amscells  
	| cams_align CR optheadline {p("</mtd></mtr><mtr><mtd>");}  cams_align 
;
amscells:optEqno IMATHB expression optalign IMATHE optEqno|amscells IMATHB expression optalign IMATHE optEqno ;

optalign:| ALIGN {p("</mtd><mtd>");}|CR;


//eqnarray: 
//|eqnarray  ALIGN {p("</mtd><mtd>");} expression 
//eqnarray  CR {p("</mtd></mtr><mtr><mtd>");} eqnarray 
//|formula 
//;

optEqno:|phints eqno ;

eqno:
		 BEqNum  {p("<label>");mathText=1;} document {mathText=0;p("</label>");} EEqNum 
;

expression:  | formula ;
formula:
		 mtext expression 
		| ops expression
		| function expression
		| 
		IMATHB 	{if (mathBox) p("<mtext>"); }
			expression 
		IMATHE 	{if (mathBox) p("</mtext>"); }
		expression
		| DMATHB expression DMATHE expression
		| eqno expression
		| eqtags expression
		| mathML_content expression
		| BFoot {mathmode=0;p("<foot>");} headerfooter EFoot {p("</foot>");mathmode=1;} expression
		| BHead {mathmode=0;p("<head>");} headerfooter EHead {p("</head>");mathmode=1;}  expression
		| BPage {mathmode=0;pHints=0;p("<page nr=\"");} document EPage {p("\"/>");mathmode=1;}  expression
		| mtable expression
		| eqalign expression
		| extensions expression
		| mathmode_off headline mathmode_on expression
		| mathmode_off footnote mathmode_on expression
		| Left {p("<mrow>");} expression Right {p("</mrow>");} expression
		| eqnarray expression
		| array expression
		| matrix expression
		| amsla_split expression
		| BSP ESP  expression //ignoring vphantoms
		| BSB ESB  expression //ignoring vphantoms
		| Id {printId();} expression
		| OVER {p("<OVER/>");} expression
		| CHOOSE {p("<CHOOSE/>");} expression
		| ATOP {p("<ATOP/>");} expression

;

amsla_split: 
		BSplit	
		{p("<mtable><mtr><mtd>");}
		almtcore  
  	ESplit
;


extensions:		BBINOM BBINOMUP {p("<mfrac linethickness=\"0\"><mrow>");} formula EBINOMUP	{p("</mrow><mrow>");} BBINOMDOWN formula EBINOMDOWN {p("</mrow></mfrac>");} EBINOM 
		| BBra ANY {pmath=ld;pmt(0x2329);} formula EBra ANY {pmath=rd;pmt('|');}
		| BKet ANY {pmath=ld;pmt('|');} formula EKet ANY {pmath=rd;pmt(0x232A);}
		| BPMOD {pmath=ld;pmt('(');p("<mo>mod</mo>");} formula EPMOD {pmath=rd;pmt(')');}
;

eqalign: beqalign  cmtable eeqalign;

beqalign: BEQALIGN {mathblock=1;} IMATHB{p("<mtr><mtd>");} expression mtablecolumns  IMATHE ;

eeqalign: IMATHB expression IMATHE EEQALIGN {p("</mtd></mtr>");}  
	| IMATHB expression CR IMATHE EEQALIGN {p("</mtd></mtr>");} 
;


eqnarray: 
	BEqnArray {mathmode=1;mathblock=1;} 
	{p("<mtable><mtr><mtd>");}
	almtcore
	EEqnArray {mathmode=0;mathblock=0;}
 
;

array: 
	BARRAY 
	{p("<mtable><mtr><mtd>");}
	almtcore
	EARRAY 
;

almtcore:
	trows {p("</mtable>");}
	|
	DMATHB trows {p("</mtable>");} DMATHE  
;

trows: 
	trow 
	| 
	trows {p("<mtr><mtd>");} trow 
;

trow: 
	tcell 
	| 
	tcells tcell 
;

tcells:
	tmcell
	|
	tcells tmcell
;
	
tcell:	
	IMATHB formula IMATHE {p("</mtd>");} optEqno {p("</mtr>");}
	|
	IMATHB IMATHE {p("</mtd>");} optEqno {p("</mtr>");}
;

tmcell:IMATHB expression ALIGN IMATHE {p("</mtd><mtd>");}
;


mtable: BMTABLE mathmode_on mtable_core EMTABLE {p("</mtd></mtr>");} ;

mtable_core:IMATHB IMATHE bmtable  cmtable emtable IMATHB IMATHE 
|DMATHB bmtable  cmtable emtable DMATHE
;

optfhp:|fhp;

bmtable:  IMATHB{p("<mtr><mtd>");} expression mtablecolumns  IMATHE ;
mtablecolumns: {p("</mtd></mtr><mtr><mtd>");} | ALIGN {p("</mtd><mtd>");} |CR {p("</mtd></mtr><mtr><mtd>");} optEqno;
emtable: IMATHB expression IMATHE  optEqno optfhp ;

cmtable: 	| cmtable mtcell; 

mtcell:IMATHB expression ALIGN IMATHE {p("</mtd><mtd>");}
		|IMATHB expression CR IMATHE {p("</mtd></mtr><mtr><mtd>");} optEqno
;

eqtags:EQNO|LEQNO|REQNO
;


mtext: ANY {mapp_char();}
	| SET ANY {mapp_char();}
	| math_accent
	| 
	BMBOX 
		{mathBox=1;p("<mtext>");} 
	document 
		{p("</mtext>");mathBox=0;} 
	EMBOX 
	| BFBOX {mathBox=1;p("<mtext>");} document {p("</mtext>");mathBox=0;} EFBOX 
	| NOTIN IMATHB ANY IMATHE IMATHB ANY IMATHE {pmath=mo;pmt(0x2209);}
	| LeftNull {p("<mrow><mrow>");}
	| RightNull {p("</mrow></mrow>");}
//	| BTabular IMATHB  mathmode_off document IMATHE mathmode_on ETabular 
	| table
	| 
	BCite mathmode_off 
	{AddPHint(0);pHints=0;p("<cite>");} 
	CiteSRef{printCiteSRef();}
	BCiteLabel 
	{p("<pref>");}
	citation 
	ECiteLabel
	ECite
	{p("</pref></cite>");pHints=1;AddPHint(1);} mathmode_on

;


math_accent: MACCENT {p("<mover><mrow>");} mtext {p("</mrow><mrow>");} omtext {p("</mrow>");endMAccent();p("</mover>");}
 	|	BOVERLARROW  {p("<mover accent=\"true\"><mrow>");hbrace=1;} formula EOVERLARROW 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x02190));p("</mo></mover>");} 
 	|	BUNDERLARROW  {p("<munder accentunder=\"true\"><mrow>");hbrace=1;} formula EUNDERLARROW 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x02190));p("</mo></munder>");} 
 	|	BOVERRARROW  {p("<mover accent=\"true\"><mrow>");hbrace=1;} formula EOVERRARROW 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x02192));p("</mo></mover>");} 
 	|	BUNDERRARROW  {p("<munder accentunder=\"true\"><mrow>");hbrace=1;} formula EUNDERRARROW 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x02192));p("</mo></munder>");} 
 	|	BOVERBRACE  {p("<mover accent=\"true\"><mrow>");hbrace=1;} formula EOVERBRACE 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x0FE37));p("</mo></mover>");} 
 	|	BDOT MACCENT ANY {p("<mover accent=\"true\"><mrow>");hbrace=1;} expression EDOT 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x02d9));p("</mo></mover>");} 
	|	BUNDERBRACE {p("<munder accentunder=\"true\"><mrow>");hbrace=1;} formula EUNDERBRACE 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x0FE38));p("</mo></munder>");} 
	|	BWIDEHAT  MACCENT ANY {p("<mover accent=\"true\"><mrow>");hbrace=1;} formula EWIDEHAT 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8('^'));p("</mo></mover>");} 
	|	BWIDETILDE  MACCENT ANY {p("<mover accent=\"true\"><mrow>");hbrace=1;} formula EWIDETILDE 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8('~'));p("</mo></mover>");} 
	|	BOVERLINE  {p("<mover accent=\"true\"><mrow>");hbrace=1;} formula EOVERLINE 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x000AF));p("</mo></mover>");} 
	|	BUNDERLINE  {p("<munder accent=\"true\"><mrow>");hbrace=1;} formula EUNDERLINE 
		{hbrace=0;p("</mrow><mo>");p(ul2utf8(0x00332));p("</mo></munder>");} 
	| 	TACCENT dvi ANY {saveAccent(*yytext);} text {contractTextAccent();}
;

omtext: mtext| IMATHB mtext IMATHE;

mml_bdegree:{p("<degree>");};
mml_edegree:{p("</degree>");};

function:
		{p("<mo>");} tex_func {p("</mo>");}
		| {p("<mo>");} extras {p("</mo>");}
		|	BIGSQCAP {pmath=mo;pmt(0x2A05);}
		|	BIGSQCUP {pmath=mo;pmt(0x2A06);}
		|	MAPSTO {pmath=mo;pmt(0x21A6);}
		|	LMAPSTO {pmath=mo;pmt(0x27FC);}
		|	MODELS {pmath=mo;pmt(0x22A7);}
		|	HLARROW {pmath=mo;pmt(0x21A9);}
		|	HRARROW {pmath=mo;pmt(0x21AA);}
		|	lLARROW {pmath=mo;pmt(0x27F5);}
		|	LLARROW {pmath=mo;pmt(0x27F8);}
		|	lRARROW {pmath=mo;pmt(0x27F6);}
		|	LRARROW {pmath=mo;pmt(0x27F9);}
		|	lLRARROW {pmath=mo;pmt(0x27F7);}
		|	LLRARROW {pmath=mo;pmt(0x27FA);}
		|	BOWTIE {pmath=mo;pmt(0x22C8);}
;

ld:{p(" LD ");};
rd:{p(" RD ");};

junk:	ANY ;

ops:	{p("<mo>");} symbol {p("</mo>");}
		| tex_sup_op
		| BFRAC {p("<mfrac><mrow>");} expression FRACN {p("</mrow><mrow>");} endfrac 
		| BROOT IMATHB {p("<mroot><mrow>");}  formula 
			ROOT IMATHE {p("</mrow><mrow>");} 
		IMATHB junk formula  stupid_ROOT 
		| BSQRT optjunks SQRT {p("<msqrt>");} formula {p("</msqrt>");} ESQRT
		| BBUILDREL {p("<mover><mrow>");} formula 
			BUILDREL {p("</mrow><mrow>");} formula 
		EBUILDREL {p("</mrow></mover>");}
		|BMO {p("<mo>");mathOp=1;} document EMO {mathOp=0;p("</mo>");}
;

stupid_ROOT:
EROOT IMATHE swap_ROOT 
|
IMATHE EROOT swap_ROOT
;

swap_ROOT:
{ //swap the arguments of root
	char*temp,*tail;
	temp=strrchr(doc_math,0);
	strcpy(temp,"</mrow>");
	temp=MatchTagLeft(temp,"<mrow");
	tail=(char*)malloc(strlen(temp)+1);
	strcpy(tail,temp);
	strcpy(temp,"</mroot>");
	temp--;
	while(*temp!='<')temp--;
	temp=MatchTagLeft(temp,"<mrow");
	Insert(temp,tail);
	free(tail);
}


endfrac:OVER FRACD expression EFRAC {p("</mrow></mfrac>");} 
|FRACD expression EFRAC {p("</mrow></mfrac>");}
;

tex_sup_op:
		BSP {if (!mathText) beginSuperScript();}  formula {if (!mathText) endSuperScript();} ESP
		|BSB {if (!mathText) beginSubScript();} formula {if (!mathText) endSubScript();} ESB
;


mathML_content:
		mathML_basic
		|	mathML_relations
		|	mathML_arithmetic_logic
		|	mathML_calculus_vector
		|	mathML_sequences_series
		|	mathML_set_theory
		|	mathML_elementary
		|	mathML_statistics
		|	mathML_linear_algebra
		|	mathML_constants_symbols
;

mathML_basic:
	BInterval mml_binterval {p("<ci>");} formula Interval junk {p("</ci><ci>");} formula EInterval mml_einterval
	|BInverse {p("<apply><inverse/><ci>");} formula Inverse BSP junk junk junk junk ESP EInverse {p("</ci></apply>");}
	|BCompose {p("<apply><compose/><ci>");} formula Compose junk {p("</ci><ci>");} formula ECompose {p("</ci></apply>");}
	|BDomain  {p("<apply><domain/><ci type=\"function\">");} junk formula EDomain junk {p("</ci></apply>");}
	|BCodomain {p("<apply><codomain/><ci type=\"function\">");} junk formula ECodomain junk {p("</ci></apply>");}
	|BImage {p("<apply><image/><ci type=\"function\">");} junk formula EImage junk {p("</ci></apply>");}
	|BAmsCases Left junks amscases RightNull Right EAmsCases 
	|BLaCases Left junks {p("<piecewise><piece><ci>");} lacases IMATHB formula IMATHE {p("</ci></piece></piecewise>");}  RightNull Right ELaCases 
;

lacases: IMATHB formula ALIGN {p("</ci><ci>");} IMATHE optjunks
| 
lacases 
	IMATHB formula IMATHE optjunks CR {p("</ci></piece><piece><ci>");} 
	IMATHB formula ALIGN IMATHE optjunks {p("</ci><ci>");}
;

optjunks:| junks;

amscases: BMTABLE bcases  ccases ecases EMTABLE
|
BARRAY {p("<piecewise>");} amslacases EARRAY {p("</piecewise>");}
;

bcases: IMATHB IMATHE  {p("<piecewise><piece><ci>");} IMATHB expression casescolumns IMATHE;
casescolumns: ALIGN {p("</ci><ci>");} |CR {p("</ci></piece><piece><ci>");};

ecases: IMATHB expression  IMATHE {p("</ci></piece></piecewise>");} IMATHB IMATHE ;

ccases: 	| ccases amsccell; 
			
amsccell:IMATHB expression ALIGN IMATHE {p("</ci><ci>");}
		|IMATHB expression CR IMATHE {p("</ci></piece><piece><ci>");}
		;

amslacase: IMATHB IMATHE  {p("<piece><ci>");} 
	IMATHB expression ALIGN {p("</ci><ci>");}  IMATHE
	IMATHB IMATHE
	IMATHB expression {p("</ci></piece>");}  IMATHE
	IMATHB IMATHE
;

amslacases: amslacase
|
amslacases IMATHB IMATHE amslacase
;

junks: junk| junks junk 
;




mml_binterval:{p("<interval closure=\"-\">");};
mml_einterval:{
	char*temp=strrchr(doc_math,0),*open="open",*closed="closed";
	temp=MatchTagLeft(temp,"<interval");
	if (strchr(temp,'(')) {
		Insert(strchr(temp,'\"')+1,open) ;
		Clean(temp,"<mrow><mo>(</mo><mrow>",1);
	}
	if (strchr(temp,'[')) {
	Insert(strchr(temp,'\"')+1,closed) ;
	Clean(temp,"<mrow><mo>[</mo><mrow>",1);
	}
	if (strchr(temp,')')) {
	Insert(strchr(temp,'-')+1,open) ;
	Clean(temp,"</mrow><mo>)</mo></mrow>",1);
	}
	if (strchr(temp,']')) {
	Insert(strchr(temp,'-')+1,closed) ;
	Clean(temp,"</mrow><mo>]</mo></mrow>",1);
	}
	p("</ci></interval>");
};



mathML_arithmetic_logic:
		BQuotient {p("<apply><quotient/><ci>");} junk formula	Quotient junk {p("</ci><ci>");}	Quotient formula {p("</ci></apply>");} EQuotient junk
		|BFactorial {p("<apply><factorial/><ci>");} ld formula rd Factorial junk EFactorial {p("</ci></apply>");}
		|BFrac {p("<apply><divide><ci>");} formula Fracn {p("</ci><ci>");} EndFrac 
		|BMaxl MAX {p("<apply><max/>");} junk clist EMaxl junk {p("</apply>");}
		|BMaxc MAX {p("<apply><max/>");} BSB bvar ESB junk opt_expression optjunk condition junk EMaxc {p("</apply>");}
		|BMinl MIN {p("<apply><min/>");} junk clist EMinl junk {p("</apply>");}
		|BMinc MIN {p("<apply><min/>");} BSB bvar ESB junk opt_expression optjunk condition junk EMinc {p("</apply>");}
		|BPower	{p("<apply><power/><ci>");}  formula Power {p("</ci><ci>");} BSP formula ESP EPower {p("</ci></apply>");}
		|BRem	{p("<apply><rem/><ci>");} formula {p("</ci><ci>");} Rem REM formula ERem {p("</ci></apply>");}
		|BPlus	{p("<apply><plus/><ci>");} formula Plus {p("</ci><ci>");} formula EPlus {p("</ci></apply>");}
		|BMinus	{p("<apply><minus/><ci>");} formula Minus {p("</ci><ci>");} formula EMinus {p("</ci></apply>");}
		|BTimes	{p("<apply><times/><ci>");} formula Times {p("</ci><ci>");} formula ETimes {p("</ci></apply>");}
		|BRoot IMATHB {p("<apply><root/>");} mml_bdegree formula mml_edegree Root {p("<ci>");} IMATHE IMATHB junk formula  stupid_root {p("</ci></apply>");}
		|BSqrt {p("<apply><root/><degree><cn>2</cn></degree><ci>");} ld formula rd {p("</ci></apply>");} ESqrt
		|BGcd	GCD {p("<apply><gcd/><ci>");} formula {p("</ci></apply>");} EGcd
		|BLand	{p("<apply><and/><ci>");}  formula Land junk {p("</ci><ci>");} formula ELand {p("</ci></apply>");}
		|BLor	{p("<apply><or/><ci>");}  formula Lor junk {p("</ci><ci>");} formula ELor {p("</ci></apply>");}
		|BXor	{p("<apply><xor/><ci>");}  formula Xor XOR {p("</ci><ci>");} formula EXor {p("</ci></apply>");}
		|BNot	{p("<apply><not/><ci>");}  formula {p("</ci>");} ENot
		|BImplies	{p("<apply><implies/><ci>");} formula {p("</ci><ci>");} Implies junk formula{p("</ci></apply>");} EImplies
		|BForall {p("<apply><forall/>");} bvar optjunk opt_condition BAssert junk formula EAssert EForall {p("</apply>");}
		|BExists {p("<apply><exists/>");} bvar optjunk opt_condition BAssert junk formula EAssert EExists {p("</apply>");}
		|Babs {p("<apply><abs/><ci>");} junk formula Eabs junk {p("</ci></apply>");}
		|Bconjugate {p("<apply><conjugate/><ci>");} BOVERLINE formula EOVERLINE Econjugate {p("</ci></apply>");}
		|BArg ARG {p("<apply><arg/><ci>");} formula  EArg {p("</ci></apply>");}
		|BRe	junk {p("<apply><real/><ci>");} formula ERe {p("</ci></apply>");}
		|BIm	junk {p("<apply><imaginary/><ci>");} formula EIm {p("</ci></apply>");}
		|BLcm	LCM {p("<apply><lcm/><ci>");} formula {p("</ci></apply>");} ELcm
		|Bfloor junk {p("<apply><floor/><ci>");} formula {p("</ci></apply>");} Efloor junk
		|Bceil junk {p("<apply><ceiling/><ci>");} formula {p("</ci></apply>");} Eceil junk
;


EndFrac:OVER Fracd formula EFrac {p("</ci></apply>");} 
|Fracd formula EFrac {p("</ci></apply>");}
;

stupid_root:
ERoot IMATHE
|
IMATHE ERoot
;

bvar: BVar {p("<bvar>");} clist {p("</bvar>");} EVar fix_bvar
;
opt_expression: | BExpr {p("<ci>");} formula  {p("</ci>");} EExpr;
condition: BCond {p("<condition>");} formula ECond {p("</condition>");}
;
opt_condition: | condition;



clist: {p(" LIST <ci>");} formula fix_list;
fix_list:
{
	char*temp=strrchr(doc_math,0),*tail,*lock;
	while (temp!=strstr(temp," LIST ")) temp--;
	lock=temp;
	while ((temp=strstr(temp,"<mo>,</mo>"))){
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,temp+strlen("<mo>,</mo>"));
		strcpy(temp,"</ci><ci>");
		strcat(temp,tail);
		free(tail);
	}
	tail=(char*)malloc(strlen(lock)+1);
	strcpy(tail,lock+strlen(" LIST "));
	*lock=0;
	strcpy(lock,tail);
	free(tail);
	p("</ci>");
}
;

fix_bvar:
{
	char*temp=strrchr(doc_math,0),*tail,*lock;
	while (temp!=strstr(temp,"<bvar>")) temp--;
	lock=temp;
	while ((temp=strstr(temp,"</ci><ci>"))){
		if (strstr(temp,"</bvar")){
			tail=(char*)malloc(strlen(temp)+1);
			strcpy(tail,temp+strlen("</ci><ci>"));
			strcpy(temp,"</ci></bvar><bvar><ci>");
			lock=strrchr(temp,0);
			strcat(temp,tail);
			temp=lock;
			free(tail);
		}else break;
	}
}
;

mathML_relations:
	BEqual	{p("<apply><eq/><ci>");}  formula Equal junk {p("</ci><ci>");} formula EEqual {p("</ci></apply>");}
	|BNequal	{p("<apply><neq/><ci>");}  formula Nequal junk junk {p("</ci><ci>");} formula ENequal {p("</ci></apply>");}
	|BLequal	{p("<apply><leq/><ci>");}  formula Lequal junk {p("</ci><ci>");} formula ELequal {p("</ci></apply>");}
	|BGequal	{p("<apply><geq/><ci>");}  formula Gequal junk {p("</ci><ci>");} formula EGequal {p("</ci></apply>");}
	|BEquiv	{p("<apply><equivalent/><ci>");}  formula Equiv junk {p("</ci><ci>");} formula EEquiv {p("</ci></apply>");}
	|BApprox	{p("<apply><approx/><ci>");}  formula Approx junk {p("</ci><ci>");} formula EApprox {p("</ci></apply>");}
	|BGthan	{p("<apply><gt/><ci>");}  formula Gthan junk {p("</ci><ci>");} formula EGthan {p("</ci></apply>");}
	|BLthan	{p("<apply><lt/><ci>");}  formula Lthan junk {p("</ci><ci>");} formula ELthan {p("</ci></apply>");}
	|BFactor {p("<apply><factorof/><ci>");} formula Factor junk {p("</ci><ci>");} formula EFactor {p("</ci></apply>");}
;

mathML_set_theory:
		BSetl junk {p("<set>");} clist ESetl junk {p("</set>");}
		|BSetc junk {p("<set>");} bvar junk condition junk ESetc  {p("</set>");}
		|BListl junk {p("<list>");} clist EListl junk {p("</list>");}
		|BListc junk {p("<list>");} bvar junk condition junk EListc {p("</list>");}
		|BSubset	{p("<apply><prsubset/><ci>");}  formula Subset junk {p("</ci><ci>");} formula ESubset {p("</ci></apply>");}
		|BSubseteq	{p("<apply><subset/><ci>");}  formula Subseteq junk {p("</ci><ci>");} formula ESubseteq {p("</ci></apply>");}
		|BNotsubset	{p("<apply><notprsubset/><ci>");}  formula Notsubset junk {p("</ci><ci>");}  formula ENotsubset {p("</ci></apply>");}
		|BNotsubseteq	{p("<apply><notsubset/><ci>");}  formula Notsubseteq junk {p("</ci><ci>");}  formula ENotsubseteq {p("</ci></apply>");}
		|BUnion	{p("<apply><union/><ci>");}  formula Union junk {p("</ci><ci>");} formula EUnion {p("</ci></apply>");}
		|BIntersect	{p("<apply><intersect/><ci>");}  formula Intersect junk {p("</ci><ci>");} formula EIntersect {p("</ci></apply>");}
		|BIn	{p("<apply><in/><ci>");}  formula In junk{p("</ci><ci>");}formula EIn {p("</ci></apply>");}
		|BNotin	{p("<apply><notin/><ci>");}  formula Notin {p("</ci><ci>");} formula ENotin {p("</ci></apply>");}
		|BSetdiff {p("<apply><setdiff/><ci>");} formula Setdiff junk {p("</ci><ci>");}  formula ESetdiff {p("</ci></apply>");}
		|BCard {p("<apply><card/><ci>");} junk formula ECard junk {p("</ci></apply>");}
		|BCartesian {p("<apply><cartesianproduct/><ci>");} formula Cartesian junk {p("</ci><ci>");}  formula ECartesian {p("</ci></apply>");}
;

mathML_elementary:
		BArccos ARCCOS {p("<apply><arccos/><ci>");} formula {p("</ci></apply>");} EArccos
		|BArccosh Arccosh {p("<apply><arccosh/><ci>");} formula {p("</ci></apply>");} EArccosh
		|BArcsin ARCSIN  {p("<apply><arcsin/><ci>");} formula {p("</ci></apply>");} EArcsin
		|BArcsinh Arcsinh {p("<apply><arcsinh/><ci>");} formula {p("</ci></apply>");} EArcsinh
		|BArctan ARCTAN {p("<apply><arctan/><ci>");} formula {p("</ci></apply>");} EArctan
		|BArctanh Arctanh {p("<apply><arctanh/><ci>");} formula {p("</ci></apply>");} EArctanh
		|BCos COS {p("<apply><cos/><ci>");} formula {p("</ci></apply>");} ECos
		|BCosh COSH {p("<apply><cosh/><ci>");} formula {p("</ci></apply>");} ECosh
		|BCot COT {p("<apply><cot/><ci>");} formula {p("</ci></apply>");} ECot
		|BArccot Arccot {p("<apply><arccot/><ci>");} formula {p("</ci></apply>");} EArccot
		|BCoth COTH {p("<apply><coth/><ci>");} formula {p("</ci></apply>");} ECoth
		|BArccoth Arccoth {p("<apply><arccoth/><ci>");} formula {p("</ci></apply>");} EArccoth
		|BCsc CSC {p("<apply><csc/><ci>");} formula {p("</ci></apply>");} ECsc
		|BArccsc Arccsc {p("<apply><arccsc/><ci>");} formula {p("</ci></apply>");} EArccsc
		|BCsch Csch {p("<apply><csch/><ci>");} formula {p("</ci></apply>");} ECsch
		|BArccsch Arccsch {p("<apply><arccsch/><ci>");} formula {p("</ci></apply>");} EArccsch
		|BExp EXP {p("<apply><exp/><ci>");} formula {p("</ci></apply>");} EExp
		|BLg LG {p("<apply><lg/><logbase><cn>10</cn></logbase><ci>");} formula {p("</ci></apply>");} ELog
		|BLn LN {p("<apply><ln/><ci>");} formula {p("</ci></apply>");} ELn
		|BLog LOG {p("<apply><log/><ci>");} formula {p("</ci></apply>");} ELog
		|BSec SEC {p("<apply><sec/><ci>");} formula {p("</ci></apply>");} ESec
		|BArcsec Arcsec {p("<apply><arcsec/><ci>");} formula {p("</ci></apply>");} EArcsec
		|BSech Sech {p("<apply><sech/><ci>");} formula {p("</ci></apply>");} ESech
		|BArcsech Arcsech {p("<apply><arcsech/><ci>");} formula {p("</ci></apply>");} EArcsech
		|BSin SIN {p("<apply><sin/><ci>");} formula {p("</ci></apply>");} ESin
		|BSinh SINH  {p("<apply><sinh/><ci>");} formula {p("</ci></apply>");} ESinh
		|BTan TAN {p("<apply><tan/><ci>");} formula {p("</ci></apply>");} ETan
		|BTanh TANH {p("<apply><tanh/><ci>");} formula {p("</ci></apply>");} ETanh
;

mathML_statistics:
		BMean {p("<apply><mean/><ci>");} formula EMean {p("</ci></apply>");}
		|BSDev junk junk {p("<apply><sdev/><ci>");} formula  ESDev junk {p("</ci></apply>");}
		|BVariance junk junk {p("<apply><variance/><ci>");} formula Variance junk BSP junk ESP EVariance {p("</ci></apply>");}
		|BMedian {p("<apply><median/><ci>");} Median junk formula EMedian junk {p("</ci></apply>");}
		|BMode {p("<apply><mode/><ci>");} Mode junk formula EMode junk {p("</ci></apply>");}
		|BMoment {p("<apply><moment/><ci>");} formula {p("</ci>");} mml_moment_degree EMoment mml_emoment
		|BMomenta {p("<apply><moment/><ci>");} mml_moment_arg {p("</ci>");} optjunk mml_moment_about mml_moment_degree EMomenta mml_emoment
;

mml_moment_arg:optjunk BMomentArg formula EMomentArg;
mml_moment_about:|BMabout {p("<momentabout><ci>");} formula EMabout optjunk {p("</ci></momentabout>");};
mml_moment_degree:| BMomentDeg {p("<degree>");} BSP  {p("<cn>");} mtext {p("</cn>");} EMomentDeg ESP {p("</degree>");};
mml_emoment:{
	//make the first child the last
	char*temp=strrchr(doc_math,0), *tail,*lock;
	lock=MatchTagLeft(temp,"<apply");temp=NULL;
	if ((temp=strstr(lock,"<momentabout")));
	else temp=strstr(lock,"<degree");
	if (temp){
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,temp);*temp=0;
		lock=strstr(lock,"<ci");
		Insert(lock,tail);
		free(tail);
	}
	p("</apply>");
};

mathML_linear_algebra:
		vector
		|Matrix
		|BDet DET {p("<apply><determinant/><ci>");} formula EDet {p("</ci></apply>");}
		|BTranspose {p("<apply><transpose/><ci type=\"matrix\">");} text BSP junk ESP ETranspose {p("</ci></apply>");}
		|BSelector {p("<apply><selector/>");} selector_content {p("<cn>");} BSB selector ESB ESelector mml_eselector
		|BVectorProduct mml_bapply {p("<vectorproduct/><ci>");} formula VectorProduct junk {p("</ci><ci>");} formula EVectorProduct {p("</ci></apply>");}
		|BScalarProduct mml_bapplyi {p("<scalarproduct/><ci>");} formula ScalarProduct junk  {p("</ci><ci>");} formula EScalarProduct {p("</ci></apply>");}
		|BOuterProduct mml_bapply {p("<outerproduct/><ci>");} formula OuterProduct junk  {p("</ci><ci>");} formula EOuterProduct {p("</ci></apply>");}
;

vector:	BVector {p("<vector><ci>");} optjunk BMATRIX formula EMATRIX optjunk  mml_evector EVector;

Matrix: BMatrix optjunk matrix optjunk EMatrix ;

matrix: bmatrix  cmatrix ematrix;

bmatrix: BMATRIX {p("<matrix><matrixrow><ci>");} IMATHB IMATHE IMATHB expression matrixcolumns  IMATHE ;
matrixcolumns: ALIGN {p("</ci><ci>");} |CR {p("</ci></matrixrow><matrixrow><ci>");};

ematrix: IMATHB expression IMATHE IMATHB IMATHE EMATRIX {p("</ci></matrixrow></matrix>");}  ;

cmatrix: 	| cmatrix matrixcell; 

matrixcell:IMATHB expression ALIGN IMATHE {p("</ci><ci>");}
		|IMATHB expression CR IMATHE {p("</ci></matrixrow><matrixrow><ci>");}
;

selector_content: {p("<ci type=\"vector\">");} text {p("</ci>");}
	| SelectorMatrix {p("<ci type=\"matrix\">");} text {p("</ci>");}
	| vector
	| SelectorMatrix matrix
;
selector: formula ;

optjunk:  | junk optjunk;

mml_evector:{
	char*temp=strrchr(doc_math,0),*lock,*tail;
	temp=MatchTagLeft(temp,"<vector");
	temp=strstr(temp,">");temp++;
	lock=temp;
	//replace <mo>,</mo> with </ci><ci>
	while ((temp=strstr(temp,"<mo>,</mo>"))){
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,temp+strlen("<mo>,</mo>"));
		strcpy(temp,"</ci><ci>");
		strcat(temp,tail);
		free(tail);
	}
	temp=lock;
	while ((temp=strstr(temp,"<mo> CR </mo>"))){
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,temp+strlen("<mo> CR </mo>"));
		strcpy(temp,"</ci><ci>");
		strcat(temp,tail);
		free(tail);
	}
	p("</ci></vector>");
};

mml_eselector:{
//	printf("\ntest:\n%s\n",doc_math);
	char*temp=strrchr(doc_math,0),*lock,*tail;
	temp=MatchTagLeft(temp,"<apply");
	temp=strstr(temp,">");temp++;
	lock=temp;
	//replace <mo>,</mo> with </cn><cn>
	while ((temp=strstr(temp,"<mo>,</mo>"))){
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,temp+strlen("<mo>,</mo>"));
		strcpy(temp,"</cn><cn>");
		strcat(temp,tail);
		free(tail);
	}
	p("</cn></apply>");
};

mathML_constants_symbols:
	Integers {p("<integers/>");}
	|Naturals {p("<naturalnumbers/>");}
	|Rationals {p("<rationals/>");}
	|Reals {p("<reals/>");}
	|Complexes {p("<complexes/>");}
	|Primes	{p("<primes/>");}
	|ExponentialE {p("<exponentiale/>");}
	|ImaginaryI	{p("<imaginaryi/>");}
	|NotANumber	{p("<notanumber/>");}
	|Emptyset {p("<emptyset/>");}
	|True	{p("<true/>");}
	|False	{p("<false/>");}
	|PiCst	{p("<pi/>");}
	|EulerGamma	{p("<eulergamma/>");}
	|Infty {p("<infinity/>");}
	|Ident {p("<ident/>");}
;


extras:
	Trace	{p("tr");}
;

tex_func:
		 ARCCOS {p("arccos");}
		 |Arccosh {p("arccosh");}
		|ARCSIN   {p("arcsin");}
		|Arcsinh {p("arcsinh");}
		|ARCTAN  {p("arctan");}
		|Arctanh  {p("arctanh");}
		|ARG  {p("arg");}
		|COS  {p("cos");}
		|COSH  {p("cosh");}
		|COT  {p("cot");}
		|Arccot  {p("arccot");}
		|COTH  {p("coth");}
		|Arccoth  {p("arccoth");}
		|CSC  {p("csc");}
		|Arccsc  {p("arccsc");}
		|Csch  {p("csch");}
		|Arccsch  {p("arccsch");}
		|DEG  {p("deg");}
		|DET  {p("det");}
		|DIM  {p("dim");}
		|EXP  {p("exp");}
		|GCD  {p("gcd");}
		|LCM  {p("lcm");}
		|HOM  {p("hom");}
		|INF  {p("inf");}
		|KER  {p("ker");}
		|LG  {p("log");}
		|LIM  {p("lim");}
		|LIMINF {p("liminf");}
		|LIMSUP {p("limsup");}
		|LN  {p("ln");}
		|LOG  {p("log");}
		|MAX  {p("max");}
		|MIN  {p("min");}
		|PR  {p("pr");}
		|SEC  {p("sec");}
		|Arcsec  {p("arcsec");}
		|Sech  {p("sech");}
		|Arcsech  {p("arcsech");}
		|SIN  {p("sin");}
		|SINH  {p("sinh");}
		|SUP  {p("sup");}
		|TAN  {p("tan");}
		|TANH  {p("tanh");}

		|REM  {p("mod");}
		|XOR  {p("xor");}
		
;

opt_over:|OVER
;

mathML_calculus_vector:
		BInt {p("<apply><int/>");} mml_Ilimits BIntarg {p("<ci>");} formula EIntarg {p("</ci><bvar><ci>");} BIntbe junk formula EIntbe {p("</ci></bvar>");} flipIntegrand EInt
	 	|BDiff {p("<apply><diff/>");} BFRAC junk mml_diff_degree0 BDiffarg {p("<ci>");} formula EDiffarg FRACN 
		opt_over
		FRACD junk {p("</ci><bvar><ci>");} BDiffbe formula EDiffbe {p("</ci>");} mml_diff_degree {p("</bvar></apply>");} EFRAC EDiff
		|BDivt {p("<apply><divergence/><ci>");} formula EDiv {p("</ci></apply>");}
		|BDivs {p("<apply><divergence/><ci>");} formula EDiv {p("</ci></apply>");}
		|BGradt {p("<apply><grad/><ci>");} formula EGrad {p("</ci></apply>");}
		|BGrads {p("<apply><grad/><ci>");} formula EGrad {p("</ci></apply>");}
		|BCurlt {p("<apply><curl/><ci>");} formula ECurl {p("</ci></apply>");}
		|BCurls {p("<apply><curl/><ci>");} formula ECurl {p("</ci></apply>");}
		|BLaplacian {p("<apply><laplacian/><ci>");} BSP junk ESP formula ELaplacian {p("</ci></apply>");}

;

flipIntegrand:{
	char*temp=strrchr(doc_math,0),*tail;
	while (strstr(temp,"</bvar")!=temp) temp--;
	temp=MatchTagLeft(temp,"<bvar");
	tail=(char*)malloc(strlen(temp)+1);
	strcpy(tail,temp);*temp=0;
	while (strstr(temp,"</ci")!=temp) temp--;
	temp=MatchTagLeft(temp,"<ci");
	Insert(temp,tail);
	free(tail);
	p("</apply>");
}
;

mml_diff_degree0: |
		BDiffdeg BSP junk ESP EDiffdeg
;
mml_diff_degree: |
		BDiffdeg BSP {p("<degree><ci>");} mtext {p("</ci></degree>");} ESP EDiffdeg
;
mathML_sequences_series:
		BSum {p("<apply><sum/>");} mml_Slimits {p("<ci>");} BSumarg formula ESumarg ESum {p("</ci></apply>");}
		|BProd {p("<apply><product/>");} mml_Plimits {p("<ci>");} BProdarg formula EProdarg EProd {p("</ci></apply>");}
		|BLimit {p("<apply><limit/>");} LIM mml_bcondition BSB  formula ESB mml_elimit mml_econdition {p("<ci>");} BLimitarg formula ELimitarg ELimit {p("</ci></apply>");}
		|BTendsto {p("<apply><tendsto/><ci>");} formula {p("</ci><ci>");} Tendsto expression ETendsto {p("</ci></apply>");}
;

mml_Ilimits:	
		|	BSP mml_buplimit BIntul formula EIntul ESP junk mml_euplimit BSB  mml_bllimit BIntll  formula EIntll ESB mml_ellimit
		|junk BSP mml_buplimit BIntul formula EIntul ESP mml_euplimit BSB  mml_bllimit BIntll  formula EIntll ESB mml_ellimit
		|BSB  mml_bllimit BIntll formula EIntll ESB junk mml_ellimit
		|junk BSB  mml_bllimit BIntll formula EIntll ESB mml_ellimit
		|BSP  mml_buplimit BIntul formula EIntul ESP junk mml_euplimit
		|junk BSP  mml_buplimit BIntul formula EIntul ESP mml_euplimit
;

mml_Slimits:	|
		BSP mml_buplimit BSumul formula ESumul ESP junk mml_euplimit BSB  mml_bllimit BSumll  formula ESumll ESB mml_ellimit
		|junk BSP mml_buplimit BSumul formula ESumul ESP mml_euplimit BSB  mml_bllimit BSumll  formula ESumll ESB mml_ellimit
		|junk BSB  mml_bllimit BSumll formula ESumll ESB mml_ellimit
		|BSP  mml_buplimit BSumul formula ESumul ESP junk mml_euplimit
		|junk BSP  mml_buplimit BSumul formula ESumul ESP mml_euplimit
;

mml_Plimits:	|
		BSP mml_buplimit BProdul formula EProdul ESP junk mml_euplimit BSB  mml_bllimit BProdll  formula EProdll ESB mml_ellimit
		|junk BSP mml_buplimit BProdul formula EProdul ESP mml_euplimit BSB  mml_bllimit BProdll  formula EProdll ESB mml_ellimit
		|junk BSB  mml_bllimit BProdll formula EProdll ESB mml_ellimit
		|BSP  mml_buplimit BProdul formula EProdul ESP junk mml_euplimit
		|junk BSP  mml_buplimit BProdul formula EProdul ESP mml_euplimit
;




mml_bcondition:{p("<condition>");};
mml_econdition:{p("</condition>");};
mml_elimit:{
	char*temp=doc_math,*limit,*lock,*tail,*bvar;
	while ((temp=strstr(temp,"<limit/>"))) lock=temp++;
	limit=temp=lock;
	limit=strstr(limit,">")+1;
	while ((temp=strstr(temp,"<condition>"))) lock=temp++;
	temp=lock;
	while ((temp=strstr(temp,"<ci"))) lock=temp++;
	temp=lock;
	lock=strstr(temp,"</ci>")+strlen("</ci>");
	tail=(char*)malloc(strlen(lock)+1);
	strcpy(tail,lock);*lock=0;
	bvar=(char*)malloc(strlen(temp)+1);
	strcpy(bvar,temp);
	strcat(temp,tail);free(tail);
	limit=Insert(limit,"<bvar>");
	limit=Insert(limit,bvar);
	Insert(limit,"</bvar>");free(bvar);
};


mml_bllimit:{p("<lowlimit><ci>");};
mml_buplimit:{p("<uplimit><ci>");};
mml_ellimit:{p("</ci></lowlimit>");};
mml_euplimit:{p("</ci></uplimit>");};


symbol:
		CDOTS {p(ul2utf8(0x022EF));}
		|DDOTS {p(ul2utf8(0x022F1));}
		|LDOTS {p(ul2utf8(0x02026));}
		|VDOTS {p(ul2utf8(0x022EE));}
;

mml_bapply: {p("<apply>");};

mml_bapplyi: {
	p("<apply>");
};


%%

int main(int argc, char*argv[])
{
	unsigned long p2post, al;
	unsigned char i, endian[5],*temp;
	char test[512],*supportedFonts="cmr,cmu,cmb,cmsl,\
cmti,cmtex,cmtt,cmtcsc,cmssdc,cmss,\
cmmi,cmmib,cmsy,cmbsy,cmbx,cmbxti,cmex,\
msam,msbm,\
eufm,eurm,eusm,euex,cmcsc,wncyr,wncyi,rsfs,lassdc,\
pplr8t,pplri8t,pplb8t,zppler7y,zppler7t,zppler7m,\
zppler7v,zppleb7y,zppleb7m,zppleb7t,\
lasy,wasy,\
ecrm,ecb,ecbi,ecbx,ecti,ecsc,ecsl,\
pxr,pxi,pxb,pxbi,pxbsc,pxbsl,pxsl,pxsc,pxss,pxsssl,pxsssc,\
pxtt,pxbtt,pxttsl,pxbttsl,pxttsc,pxbttsc,\
p1xr,p1xi,p1xb,p1xbi,p1xbsl,p1xbsc,p1xsl,p1xsc,p1xss,p1xsssl,p1xsssc,\
p1xtt,p1xttsl,p1xttsc,\
pxmi,pxbmi,pxmi1,pxbmi1,pxmia,pxsy,pxsya,pxbsya,pxsyb,pxbsyb,pxsyc,pxbsyc,pxex,pxexa,\
txr,txi,txb,txbi,txbsc,txbsl,txsl,txsc,txss,txsssl,txsssc,\
txtt,txbtt,txttsl,txbttsl,txttsc,txbttsc,\
t1xr,t1xi,t1xb,t1xbi,t1xbsl,t1xbsc,t1xsl,t1xsc,t1xss,t1xsssl,t1xsssc,\
t1xtt,t1xttsl,t1xttsc,\
txmi,txbmi,txmi1,txbmi1,txmia,txsy,txsya,txbsya,txsyb,txbsyb,txsyc,txbsyc,txex,txexa";
	short int j=1;
	endian[4]=0;//just in case :)
	BigEndian=((char*)&j)[1];
	if (argc==1) {
		printf("Hermes version %s, covered by GNU GPL\nusage: hermes name.s.dvi\n", VERSION);
		exit(EXIT_SUCCESS);
	}
	if(argc>=2){
		yyin=fopen(argv[1],"rb");
		if (yyin==NULL){
			printf("%s not found",argv[1]);
			exit(EXIT_FAILURE);
		}
//		if (argc==3) {INFER_CONTENT=1;}
		//if (argc==3) {DEBUG=1;}
		DEBUG=1;
		fseek(yyin,0,SEEK_SET);
		fread(&i,1,1,yyin);
		if (i!=247){
			fprintf(stderr,"expected the dvi 'pre' command, got %d,\nthis might not be a dvi file, quitting\n",i);
			fclose(yyin);
			exit(EXIT_FAILURE);
		}
		if (!BigEndian){
			for(j=3;j>=0;j--){
				fread(endian+j,1,1,yyin);
			}
			scale.num=*((unsigned long*) endian);
		}else
			fread(&scale.num,4,1,yyin);
		if (!BigEndian){
			for(j=3;j>=0;j--){
				fread(endian+j,1,1,yyin);
			}
			scale.den=*((unsigned long*) endian);
		}else
			fread(&scale.den,4,1,yyin);
		if (!BigEndian){
			for(j=3;j>=0;j--){
				fread(endian+j,1,1,yyin);
			}
			scale.mag=*((unsigned long*) endian);
		}else
			fread(&scale.mag,4,1,yyin);

		fseek(yyin,0,SEEK_END);
		fseek(yyin,-1,SEEK_CUR);
		do{
			fread(&i,1,1,yyin);
			fseek(yyin,-2,SEEK_CUR);
		}while(i==223);
		if (i!=2){
			printf("not prepared for right to left typesetting\n");
			fclose(yyin);
			exit(EXIT_FAILURE);
		}
		fseek(yyin,-3,SEEK_CUR);
		if (!BigEndian){
			for(j=3;j>=0;j--){
				fread(endian+j,1,1,yyin);
			}
			p2post=*((unsigned long*) endian);
		}else
			fread(&p2post,4,1,yyin);

		fseek(yyin,p2post,SEEK_SET);
		fread(&i,1,1,yyin);
		if (i!=248){//DVI POST
			fclose(yyin);
			die("didn't find 'post' where it should be,\nthis input maybe corrupted, dying...\n");
		}
		fseek(yyin,28,SEEK_CUR);//jump to font definitions
		fread(&i,1,1,yyin);
		maxFontNr=0;
		
		while(i<=246 && i>=243){//count fonts used
			fseek(yyin,(i-242)+12,SEEK_CUR);
			fread(&i,1,1,yyin);al=i;
			fread(&i,1,1,yyin);al+=i;
			fread(test,al,1,yyin);
			test[al]=0;//make the fontname a C string
			temp=strrchr(test,0);
			while ((char*)temp!=(char*)test){
				temp--;
				if (*temp>='0' && *temp<='9') *temp=0;
				else break;
			}
			if (strstr(supportedFonts,test)==NULL){
				fprintf(stderr,"\nerror:\nfont %s not yet mapped, quitting\n",test);
				fclose(yyin);
				exit(EXIT_FAILURE);
			}
			maxFontNr++;
			fread(&i,1,1,yyin);
		}
		fseek(yyin,0,SEEK_SET);
	}
	doc_math=(char*)malloc(LIMIT);
	doc_text=(char*)malloc(LIMIT);
	*doc_math=0;*doc_text=0;
	strcpy(fname,argv[1]);
	fprintf(stdout,"<?xml version=\"1.0\" encoding=\"utf-8\"?>\n");
	fprintf(stdout,"<document>\n<generator>\n");
	fprintf(stdout,"<name>Hermes</name>\n");
	fprintf(stdout,"<version>%s</version>\n",VERSION);
	fprintf(stdout,"<date>%s</date>\n",DATE);
	fprintf(stdout,"<license>GNU GPL</license>\n");
	fprintf(stdout,"<description>%s</description>\n",DESCRIPTION);
	fprintf(stdout,"</generator>\n");
	fprintf(stdout,"<section><type>envelope</type>\n<par>\n");
//	if (*currentFont){
		fprintf(stdout,"<ph f=\"");
		fprintf(stdout,currentFont);
		fprintf(stdout,"\">\n");
//	}
	yyparse ();
	printf("\n</ph></par>\n</section>\n</document>");
 	if(yyin) fclose(yyin);
 	if(yyout) fclose(yyout);
 	if (doc_math) free(doc_math);
 	if (doc_text) free(doc_text);
 	return 0;
}


int yywrap() {
return 1;
}

int yyerror(char* msg) {
	flushText();
	fflush(stdout);
	fprintf(stderr,"\n\nparsing error:\nlast token received was '%s'\n",lastToken);
 	if (*doc_math) {
 		fprintf(stderr,"\nmath leftovers:\n'%s'\n",doc_math);
 		free(doc_math);
 	}
//	if (msg[0]=='2') fprintf(stderr,"\nwellformedness error: an opening/closing parenthesis is missing, dying.\n");
//		showcontext();
 	empty();
	exit(EXIT_FAILURE);
}

void p(char*s){
	char *temp=doc_text,*lock=doc_text;
	if (strstr(s,"<mtext>")==s) mathText=1;
	
	if (!fakesp){
		//doc_text is flushed at each space or 'dviy' encountered
		fakesp=1;
		//rid of hyphenchar
		if (*doc_text){
			lock=temp=strrchr(doc_text,0);
			temp--;lock--;
			if (*temp=='-')*temp=0;
			else{
				if (*temp!=' ' && *temp!='>' && !inCitation) 
					strcat(doc_text," ");
			}
		}
		if(*doc_math && (!mathmode ||mathText) && !mathOp)
			strcat(doc_math," ");
		fprintf(stdout,"%s",doc_text);
		if (strcmp(s,"<dviy/>")==0){
			if (*lock==' ') {while(*lock==' ')lock--;}
			if (strpbrk(lock,":.!?") && canbreak){
					while(*lock!=' ' && *lock!='>' && lock!=doc_text) {
						lock--;
					}
					if (*lock=='>' || *lock==' ') lock++;
					if ((*lock <'A' || *lock >'Z') && !inTable && !inBibliography) {
						fprintf(stdout,"</ph></par>\n");
						fprintf(stdout,"<par><ph f=\"");
						fprintf(stdout,currentFont);
						fprintf(stdout,"\">");
					}
			}
			*doc_text=0;
			return;
		}
		*doc_text=0;
	}
	if ((mathmode || mathText)&& !infhp) strcat(doc_math,s);
	else strcat(doc_text,s);
	if (strstr(s,"</mtext>")==s) mathText=0;
}



char* MoveLeft(char*where,char*temp)
{
	char*seek,*tail;
	while(temp!=strstr(temp,"</c") && temp!=strstr(temp," RD ") && temp!=strstr(temp," RD </apply>")) temp--;
	if (temp==strstr(temp," RD </apply>")){
		temp=SkipBracketsLeft(temp);
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,temp);*temp=0;
		if (strrchr(where,'<')!=strstr(seek=strrchr(where,'<'),"<c")){
			while(temp!=strstr(temp,"<apply>")) {if (temp==where) break;temp--;}
			if(temp!=where)
				temp=MoveLeft(where,temp=seek);
		}
		strcat(temp,tail);
		free(tail);
	}else{
		if (temp==strstr(temp,"</ci>"))
			temp=MatchTagLeft(temp,"<ci");
		else{
			if (temp==strstr(temp,"</cn>"))
				temp=MatchTagLeft(temp,"<cn");
			else{
				if (temp==strstr(temp," RD ")){
					temp=SkipBracketsLeft(temp);
				}
			}
		}

	}
	return temp;
}


int IsComplete(char*temp){

	if (strstr(temp,"<csymbol")==temp) return 1;

	if (strstr(temp,"<plus/>")==temp) return 1;
	if (strstr(temp,"<minus/>")==temp) return 1;
	if (strstr(temp,"<power/>")==temp) return 1;
	if (strstr(temp,"<eq/>")==temp) return 1;

	if (strstr(temp,"<root/>")==temp) return 1;
	if (strstr(temp,"<gcd/>")==temp) return 1;
	if (strstr(temp,"<lcm/>")==temp) return 1;
	if (strstr(temp,"<not/>")==temp) return 1;
	if (strstr(temp,"<partialdiff/>")==temp) return 1;
	if (strstr(temp,"<real/>")==temp) return 1;
	if (strstr(temp,"<imaginary/>")==temp) return 1;
	if (strstr(temp,"<int/>")==temp) return 1;
	if (strstr(temp,"<diff/>")==temp) return 1;
	if (strstr(temp,"<divergence/>")==temp) return 1;
	if (strstr(temp,"<grad/>")==temp) return 1;
	if (strstr(temp,"<curl/>")==temp) return 1;
	if (strstr(temp,"<laplacian/>")==temp) return 1;
	if (strstr(temp,"<mean/>")==temp) return 1;
	if (strstr(temp,"<sdev/>")==temp) return 1;
	if (strstr(temp,"<variance/>")==temp) return 1;
	if (strstr(temp,"<median/>")==temp) return 1;
	if (strstr(temp,"<mode/>")==temp) return 1;
	if (strstr(temp,"<limit/>")==temp) return 1;
	if (strstr(temp,"<moment/>")==temp) return 1;
	if (strstr(temp,"<sum/>")==temp) return 1;
	if (strstr(temp,"<product/>")==temp) return 1;
	if (strstr(temp,"<limit/>")==temp) return 1;
	if (strstr(temp,"<transpose/>")==temp) return 1;
	if (strstr(temp,"<selector/>")==temp) return 1;
	if (strstr(temp,"<vectorproduct/>")==temp) return 1;
	if (strstr(temp,"<scalarproduct/>")==temp) return 1;
	if (strstr(temp,"<outerproduct/>")==temp) return 1;
	if (strstr(temp,"<card/>")==temp) return 1;
	if (strstr(temp,"<max/>")==temp) return 1;
	if (strstr(temp,"<min/>")==temp) return 1;
	if (strstr(temp,"<forall/>")==temp) return 1;
	if (strstr(temp,"<exists/>")==temp) return 1;
	if (strstr(temp,"<abs/>")==temp) return 1;
	if (strstr(temp,"<conjugate/>")==temp) return 1;
	if (strstr(temp,"<arg/>")==temp) return 1;
	if (strstr(temp,"<floor/>")==temp) return 1;
	if (strstr(temp,"<ceiling/>")==temp) return 1;

	if (strstr(temp,"<inverse/>")==temp) return 1;
	if (strstr(temp,"<domain/>")==temp) return 1;
	if (strstr(temp,"<codomain/>")==temp) return 1;
	if (strstr(temp,"<image/>")==temp) return 1;

	if (strstr(temp,"<factorial/>")==temp) return 1;
	//if (strstr(temp,"<tendsto/>")==temp) return wrapped[complete=tendsto];
	//if (strstr(temp,"<in/>")==temp) return wrapped[complete=in];
	//if (strstr(temp,"<notin/>")==temp) return wrapped[complete=notin];
	//if (strstr(temp,"<intersect/>")==temp) return wrapped[complete=intersect];
	//if (strstr(temp,"<union/>")==temp) return wrapped[complete=union_];
	//if (strstr(temp,"<compose/>")==temp) return wrapped[complete=compose];
	//if (strstr(temp,"<power/>")==temp) return wrapped[complete=power];
	//if (strstr(temp,"<divide/>")==temp) return wrapped[complete=divide];
	//if (strstr(temp,"<times/>")==temp) return wrapped[complete=times];
	//if (strstr(temp,"<minus/>")==temp) return wrapped[complete=minus];
	//if (strstr(temp,"<plus/>")==temp) return wrapped[complete=plus];
	//if (strstr(temp,"<rem/>")==temp) return wrapped[complete=rem];
	//if (strstr(temp,"<gt/>")==temp) return wrapped[complete=gt];
	//if (strstr(temp,"<lt/>")==temp) return wrapped[complete=lt];
	//if (strstr(temp,"<eq/>")==temp) return wrapped[complete=eq];
	//if (strstr(temp,"<neq/>")==temp) return wrapped[complete=neq];
	//if (strstr(temp,"<geq/>")==temp) return wrapped[complete=geq];
	//if (strstr(temp,"<leq/>")==temp) return wrapped[complete=leq];
	//if (strstr(temp,"<equivalent/>")==temp) return wrapped[complete=equivalent];
	//if (strstr(temp,"<approx/>")==temp) return wrapped[complete=approx];
	//if (strstr(temp,"<cartesianproduct/>")==temp) return wrapped[complete=cartesianproduct];
	//if (strstr(temp,"<setdiff/>")==temp) return wrapped[complete=setdiff];
	//if (strstr(temp,"<subset/>")==temp) return wrapped[complete=subset];
	//if (strstr(temp,"<prsubset/>")==temp) return wrapped[complete=prsubset];
//	if (strstr(temp,"<notsubset/>")==temp) return wrapped[complete=notsubset];
//	if (strstr(temp,"<notprsubset/>")==temp) return wrapped[complete=notprsubset];
//	if (strstr(temp,"<and/>")==temp) return wrapped[complete=and];
//	if (strstr(temp,"<or/>")==temp) return wrapped[complete=or];
//	if (strstr(temp,"<xor/>")==temp) return wrapped[complete=xor];
//	if (strstr(temp,"<implies/>")==temp) return wrapped[complete=implies];

	if (strstr(temp,"<arccos/>")==temp) return 1;
	if (strstr(temp,"<arccosh/>")==temp) return 1;
	if (strstr(temp,"<arcsin/>")==temp) return 1;
	if (strstr(temp,"<arcsinh/>")==temp) return 1;
	if (strstr(temp,"<arctan/>")==temp) return 1;
	if (strstr(temp,"<arctanh/>")==temp) return 1;
	if (strstr(temp,"<arg/>")==temp) return 1;
	if (strstr(temp,"<cos/>")==temp) return 1;
	if (strstr(temp,"<cosh/>")==temp) return 1;
	if (strstr(temp,"<cot/>")==temp) return 1;
	if (strstr(temp,"<arccot/>")==temp) return 1;
	if (strstr(temp,"<coth/>")==temp) return 1;
	if (strstr(temp,"<arccoth/>")==temp) return 1;
	if (strstr(temp,"<csc/>")==temp) return 1;
	if (strstr(temp,"<arccsc/>")==temp) return 1;
	if (strstr(temp,"<csch/>")==temp) return 1;
	if (strstr(temp,"<arccsch/>")==temp) return 1;
	if (strstr(temp,"<determinant/>")==temp) return 1;
	if (strstr(temp,"<exp/>")==temp) return 1;
	if (strstr(temp,"<ln/>")==temp) return 1;
	if (strstr(temp,"<log/>")==temp) return 1;
	if (strstr(temp,"<max/>")==temp) return 1;
	if (strstr(temp,"<min/>")==temp) return 1;
	if (strstr(temp,"<sec/>")==temp) return 1;
	if (strstr(temp,"<arcsec/>")==temp) return 1;
	if (strstr(temp,"<sech/>")==temp) return 1;
	if (strstr(temp,"<arcsech/>")==temp) return 1;
	if (strstr(temp,"<sin/>")==temp) return 1;
	if (strstr(temp,"<sinh/>")==temp) return 1;
	if (strstr(temp,"<tan/>")==temp) return 1;
	if (strstr(temp,"<tanh/>")==temp) return 1;

	return 0;
}

int IsMMLContainerEnd(char*temp){
	if (strstr(temp,"</mtable>")==temp) return 1;
	if (strstr(temp,"</mtr>")==temp) return 1;
	if (strstr(temp,"</mtd>")==temp) return 1;
	if (strstr(temp,"</mrow>")==temp) return 1;
	if (strstr(temp,"</mtext>")==temp) return 1;
	if (strstr(temp,"</mi>")==temp) return 1;
	if (strstr(temp,"</mn>")==temp) return 1;
	if (strstr(temp,"</mo>")==temp) return 1;
	if (strstr(temp,"</mover>")==temp) return 1;
	if (strstr(temp,"</munder>")==temp) return 1;
	if (strstr(temp,"</msub>")==temp) return 1;
	if (strstr(temp,"</msup>")==temp) return 1;
	if (strstr(temp,"</msubsup>")==temp) return 1;
	if (strstr(temp,"</mfrac>")==temp) return 1;
	if (strstr(temp,"</msqrt>")==temp) return 1;
	if (strstr(temp,"</mroot>")==temp) return 1;
	if (strstr(temp,"</ms>")==temp) return 1;

	if (strstr(temp,"</ci>")==temp) return 1;
	if (strstr(temp,"</cn>")==temp) return 1;
	if (strstr(temp,"</csymbol>")==temp) return 1;
	if (strstr(temp,"</apply>")==temp) return 1;
	if (strstr(temp,"</logbase>")==temp) return 1;
	if (strstr(temp,"</bvar>")==temp) return 1;
	if (strstr(temp,"</degree>")==temp) return 1;
	if (strstr(temp,"</condition>")==temp) return 1;
	if (strstr(temp,"</vector>")==temp) return 1;
	if (strstr(temp,"</matrix>")==temp) return 1;
	if (strstr(temp,"</matrixrow>")==temp) return 1;
	if (strstr(temp,"</lowlimit>")==temp) return 1;
	if (strstr(temp,"</uplimit>")==temp) return 1;
	if (strstr(temp,"</moment>")==temp) return 1;
	if (strstr(temp,"</momentabout>")==temp) return 1;
	if (strstr(temp,"</set>")==temp) return 1;
	if (strstr(temp,"</list>")==temp) return 1;
	if (strstr(temp,"</interval>")==temp) return 1;
	if (strstr(temp,"</piece>")==temp) return 1;
	if (strstr(temp,"</piecewise>")==temp) return 1;

	return 0;
}
int IsMMLContainerStart(char*temp){
	if (strstr(temp,"<mtable")==temp) return 1;
	if (strstr(temp,"<mtr")==temp) return 1;
	if (strstr(temp,"<mtd")==temp) return 1;
	if (strstr(temp,"<mrow")==temp) return 1;
	if (strstr(temp,"<mtext")==temp) return 1;
	if (strstr(temp,"<mi")==temp) return 1;
	if (strstr(temp,"<mn")==temp) return 1;
	if (strstr(temp,"<mover")==temp) return 1;
	if (strstr(temp,"<munder")==temp) return 1;
	if (strstr(temp,"<mo")==temp) return 1;
	if (strstr(temp,"<msub")==temp) return 1;
	if (strstr(temp,"<msup")==temp) return 1;
	if (strstr(temp,"<msubsup")==temp) return 1;
	if (strstr(temp,"<mfrac")==temp) return 1;
	if (strstr(temp,"<msqrt")==temp) return 1;
	if (strstr(temp,"<mroot")==temp) return 1;
	if (strstr(temp,"<ms")==temp) return 1;

	if (strstr(temp,"<ci")==temp) return 1;
	if (strstr(temp,"<cn")==temp) return 1;
	if (strstr(temp,"<csymbol")==temp) return 1;
	if (strstr(temp,"<apply")==temp) return 1;
	if (strstr(temp,"<logbase")==temp) return 1;
	if (strstr(temp,"<bvar")==temp) return 1;
	if (strstr(temp,"<degree")==temp) return 1;
	if (strstr(temp,"<condition")==temp) return 1;
	if (strstr(temp,"<vector")==temp) return 1;
	if (strstr(temp,"<matrix")==temp) return 1;
	if (strstr(temp,"<matrixrow")==temp) return 1;
	if (strstr(temp,"<lowlimit")==temp) return 1;
	if (strstr(temp,"<uplimit")==temp) return 1;
	if (strstr(temp,"<moment")==temp) return 1;
	if (strstr(temp,"<momentabout")==temp) return 1;
	if (strstr(temp,"<set")==temp) return 1;
	if (strstr(temp,"<list")==temp) return 1;
	if (strstr(temp,"<interval")==temp) return 1;
	if (strstr(temp,"<piece")==temp) return 1;
	if (strstr(temp,"<piecewise")==temp) return 1;

	return 0;
}

int IsMMLConstant(char*temp){
	if (strstr(temp,"<integers/>")==temp) return 1;
	if (strstr(temp,"<reals/>")==temp) return 1;
	if (strstr(temp,"<rationals/>")==temp) return 1;
	if (strstr(temp,"<naturalnumbers/>")==temp) return 1;
	if (strstr(temp,"<complexes/>")==temp) return 1;
	if (strstr(temp,"<primes/>")==temp) return 1;
	if (strstr(temp,"<exponentiale/>")==temp) return 1;
	if (strstr(temp,"<imaginaryi/>")==temp) return 1;
	if (strstr(temp,"<notanumber/>")==temp) return 1;
	if (strstr(temp,"<true/>")==temp) return 1;
	if (strstr(temp,"<false/>")==temp) return 1;
	if (strstr(temp,"<emptyset/>")==temp) return 1;
	if (strstr(temp,"<pi/>")==temp) return 1;
	if (strstr(temp,"<eulergamma/>")==temp) return 1;
	if (strstr(temp,"<infinity/>")==temp) return 1;
	if (strstr(temp,"<ident/>")==temp) return 1;
	return 0;
}

char* Insert(char*at,char*what){
	//return a pointer to the next byte after the inserted string
	char*s,*final;
	if(*at){
		s=(char*)malloc(strlen(at)+1);
		strcpy(s,at);
		strcpy(at,what);final=strrchr(at,0);
		strcat(at,s);
		free(s);
	}else{
		strcpy(at,what);final=strrchr(at,0);
	}
	assert(final);
	return final;
}

char* MatchCloseLeft(char*where, char*from, char*what){
	char *temp=where,*lock;
//	s=(char*)malloc(strlen(from)+1);
//	strcpy(s,from);
	while((temp=strstr(temp,what))) {lock=temp;temp++;}
//	strcpy(from,s);
//	free(s);
	assert(lock);
	return lock;
}

char* MatchTagLeft(char*from, char*what){ //start from closing tag, match to left
	char*temp=from,*ctag;
	int wraps=1;
	ctag=(char*)malloc(strlen(what)+2);
	strcpy(ctag,"</");strcat(ctag,what+1);//assuming 'what' is an opening tag
	while(wraps){
		if (temp==doc_math) {
			free(ctag);
			die("can't match tag left...");
		}
		temp--;
		while(temp!=strstr(temp,what)) {
			if (temp==strstr(temp," RD ")) temp=SkipBracketsLeft(temp);
			else if (temp==strstr(temp,ctag)) wraps++;
			temp--;
			if (temp==doc_math && temp!=strstr(temp,what)){
				free(ctag);
				die("error:\ncan't match tag left...\n");
			}
		}
		wraps--;
		assert(wraps>=0);
	}
	free(ctag);
	assert(temp);
	return temp;
}

char* MatchTagRight(char*from){
	//in: pointer to a starting tag
	//returns: a pointer to the first byte after 
	//the corresponding enclosing tag
	char *temp,*btag,*etag,*check;
	int wraps=1, len=strcspn(from,"> ");

	//create the begin and end tags
	temp=from;
	if (temp==strstr(temp,"<apply")){
		len=strcspn(from,"/");
		btag=(char*)malloc(len+3);
		check=btag;
		while(*temp!='/')
			*check++=*temp++;
		*check=0;
		strcat(btag,"/>");
		len=strcspn(btag,"> ");
		etag=(char*)malloc(len+3);
		strcpy(etag,"</");
		check=strrchr(etag,0);temp=btag+1;
		while(*temp!='>' && *temp!=' ')
			*check++=*temp++;
		*check=0;
		strcat(etag,">");
	}else{
		btag=(char*)malloc(len+2);
		check=btag;
		while(*temp!='>' && *temp!=' ')
			*check++=*temp++;
		*check=0;
		etag=(char*)malloc(strlen(btag)+3);
		strcpy(etag,"</");strcat(etag,btag+1);strcat(etag,">");
	}

	if (!strstr(from,etag)){
		printf("\n error:\ninput was:\n %s\n", doc_math);
		printf("for %s, couldn't find '%s' tag, dying...\n", btag,etag);
		free(btag);
		free(etag);
		yyerror("");
	}

	temp=from;
	while(wraps){
		temp++;
		while(temp!=strstr(temp,etag)) {
			if (temp==strstr(temp," LD ")) temp=SkipBracketsRight(temp);
			else {
				if (temp==strstr(temp,btag)) wraps++;
				else {
					if (temp==strstr(temp,"<apply>")){
						check=strstr(temp,">");check++;
						check=strstr(check,"<");
						if (IsComplete(check) && btag==strstr(btag,"<apply>")) wraps ++;
					}
				}
				if (*temp) temp++;
				else {
					printf("\ncan't find end tag %s for starting tag %s, dying...\n", etag,btag);
					free(btag);
					free(etag);
					yyerror("");
				}
			}
		}
		wraps--;
		assert(wraps>=0);
	}
	assert(temp);
	temp+=strlen(etag);
	free(btag);
	free(etag);
	return temp;
}

char* SkipBracketsLeft(char*from){//assume start from right bracket
	int wraps=1;
	char*temp=from;
	while(wraps) {
		temp--;
		if(temp!=strstr(temp," LD ")){
			if(temp==strstr(temp," RD ")) wraps++;
		}else wraps--;
	}
	assert(temp);
	return temp;
}

char* SkipBracketsRight(char*from){//assume start from left bracket
	int wraps=1;
	char*temp=from+strlen(" LD ");
	temp--;
	while(wraps) {
		temp++;
		if(temp!=strstr(temp," RD ")){
			if(temp==strstr(temp," LD ")) wraps++;
		}else wraps--;
	}
	assert(temp);
	temp+=strlen(" RD ");
	return temp;
}

void pretty(char*s, int eraseBrackets){

	char* temp,*pick,*shadow=0;
	int spaces;
	temp=s;pick=s;
	spaces=0;
	if (eraseBrackets && strstr(s," LD ")){ //strip LDs
		shadow=temp=(char*)malloc(strlen(s)+1);
		while(*pick){
			if (pick!=strstr(pick," LD ") && pick!=strstr(pick," RD ")) {
					*shadow++=*pick++;
			}else
				pick+=strlen(" LD ");
		}
		*shadow=0;
		shadow=temp;
	}
	if (mathblock)	
		printf("<math xmlns=\"http://www.w3.org/1998/Math/MathML\" display=\"block\"");
	else	
		printf("<math xmlns=\"http://www.w3.org/1998/Math/MathML\"");
	//print indented
	if (*id) printf(" id=\"%s\">",id);
	else printf(">");
	while (*temp){
		if (IsMMLContainerStart(temp)){
			temp=IndentContainer(temp,&spaces,1);
		}else{
			if (IsMMLContainerEnd(temp)){
				temp=IndentContainer(temp,&spaces,0);
			}else
				printf("%c",*temp++);
		}
	}
	// we check a kind of wellformedness here 
	if (spaces) 
		die("\nwellformedness error: an opening/closing	parenthesis is missing, dying.\n");
	printf("\n</math>\n");
	if (eraseBrackets && shadow) free (shadow);

}

char* IndentContainer(char*pos,int* spaces,int start){
	int i;
	if (start){
		printf("\n");
		i=*spaces;
		while (i-- >0) printf(" ");
		if (strstr(pos,"<apply>")==pos){
			do{	printf("%c",*pos);
			}while(strstr(pos,"/>")!=pos++);
		}
		do{	printf("%c",*pos);
		}while(*pos++!='>');

		while(*pos && *pos!='<' && strstr(pos,"/>")!=pos)
			printf("%c",*pos++);
		if(strstr(pos,"/>")==pos ||strstr(pos,"</")==pos){
			while(*pos && *pos!='>') printf("%c",*pos++);
			(*spaces)--;
		}
		(*spaces)++;
	}else{
		printf("\n");
		(*spaces)-=1;i=*spaces;
		while (i-- >0) printf(" ");
		do{	printf("%c",*pos);
		}while(*pos && *pos++!='>');
	}
	return pos;
}

void Clean(char*from, char*what,int how){
//how=0 clean just "<apply><times/> what"
//how=1 clean just "what"
//how=2 clean both "<apply><times/> what" and "what" after
	char *temp=from,*tail,*trash;
	if (how==0 || how==2){
		trash=(char*)malloc(strlen("<apply><times/>")+strlen(what)+1);
		strcpy(trash,"<apply><times/>");strcat(trash,what);
		while ((temp=strstr(temp,trash))){		// clean the 'trash' starting at 'from'
			tail=(char*)malloc(strlen(temp)+1);
			strcpy(tail,temp+strlen(trash));
			*temp=0;
			strcpy(temp,tail);
			free(tail);
		}
		free(trash);
	}
	temp=from;
	if (how==1 || how==2){
		while ((temp=strstr(temp,what))){		// clean the 'what' starting at 'from'
			tail=(char*)malloc(strlen(temp)+1);
			strcpy(tail,temp+strlen(what));
			*temp=0;
			strcpy(temp,tail);
			free(tail);
		}
	}
}

void flushText()
{
	int length=strlen(doc_text);
	if (*doc_text==0) return;
	assert(length<LIMIT);

	/*
	char *temp=doc_text, *lock,*tail,*rest;
	int mixedup=0;
	if ((temp=strstr(temp,"<foot>"))){
		lock=temp;
		
		temp--;
		while(*temp==' ' || *temp=='>'){
			while(*temp==' ') temp--;
			while(*temp!='<') temp--;
			if (temp==strstr(temp,"</")) break;
			else mixedup=1;
			temp--;
		}
		if (mixedup){
			rest=strstr(lock,"</foot>");
			rest=strstr(lock,">");rest++;
			tail=(char*)malloc(strlen(rest)+1);
			strcpy(tail,rest);*rest=0;
			rest=(char*)malloc(strlen(lock)+1);
			strcpy(rest,lock);
			strcpy(lock,tail);
			free(tail);
			
			Insert(temp,rest);
			free(rest);
		}
	}
	*/
	fprintf(stdout,"%s\n",doc_text);*doc_text=0;
}

void flushMath()
{
char*temp,*lock;
int length=strlen(doc_math);
assert(length<LIMIT);

//there should be no random spaces between tags in 'doc_math'
	fixBackParsedPrimitive("<OVER/>");
	fixBackParsedPrimitive("<ATOP/>");
	fixBackParsedPrimitive("<CHOOSE/>");
	fixLabels();
	fixIds();
	
//	if (INFER_CONTENT) InferContent();
	fprintf(stdout,"</ph>\n");
	if ((lock=temp=strstr(doc_math,"<source"))){
		temp=strstr(temp,"</source>");
		temp=strstr(temp,">");
		temp++;*temp=0;
		fprintf(stdout,"\n%s\n",lock);
	}else
		pretty(doc_math,1);
	*doc_math=0;
	fprintf(stdout,"\n<ph f=\"%s\">",currentFont);
	if (*doc_text)
		printf("%s\n",doc_text);


	 return;
};

void die(char* text){
	fprintf(stderr,"\n%s\n",text);
	yyerror("");
}

void fixLabels(){
//getting the full math string
//locating and positioning Labels:
//creating mtable with mlabeledtr wrappers where found
char *temp=doc_math,*tail,*lock,*plabel=label;

	while((temp=strstr(doc_math,"<label>"))){
		if (temp==doc_math){
			//simple left labeled expression
			//copy label contents
			lock=strstr(temp,">");lock++;
			while(*lock!='<'){
				*plabel++=*lock++;
			};
			*plabel=0;
			lock=strstr(lock,">");lock++;
			//backup the rest of doc_math
			tail=(char*)malloc(strlen(lock)+1);
			strcpy(tail,lock);
			strcpy(doc_math,"<mtable><mlabeletdr><mtd><mtext>");
			strcat(doc_math,plabel);
			strcat(doc_math,"</mtext></mtd><mtd>");
			strcat(doc_math,tail);
			strcat(doc_math,"</mtd></mlabeletdr></mtable>");
			free(tail);
			return;
		}
		temp=strstr(temp,"<label>");
		//copy label contents
		lock=strstr(temp,">");lock++;
		plabel=label;
		while(*lock!='<'){
			*plabel++=*lock++;
		};
		*plabel=0;
		lock=strstr(lock,">");lock++;
		//rid of the label element
		tail=(char*)malloc(strlen(lock)+1);
		strcpy(tail,lock);
		strcpy(temp,tail);
		free(tail);
		if (temp==strstr(temp,"</mtr>")){
			temp+=3;
			Insert(temp,"labeled");
			temp=MatchTagLeft(temp,"<mtr");
			temp+=2;
			Insert(temp,"labeled");
			temp=strstr(temp,">");temp++;
			temp=Insert(temp,"<mtd><mtext>");
			temp=Insert(temp,label);
			Insert(temp,"</mtext></mtd>");
		}else{
			//label is the last
			//if (*temp) die("error:label should be the last, and it isn't\n");
			strcat(doc_math,"</mtd></mlabeledtr></mtable>");
			temp=doc_math;
			temp=Insert(temp,"<mtable><mlabeledtr><mtd><mtext>");
			temp=Insert(temp,label);
			Insert(temp,"</mtext></mtd><mtd>");
		}
	}
}

void fixBackParsedPrimitive(const char * what)
{
	char *temp=doc_math,*tail,*lock;
	
	while((temp=strstr(doc_math,what))){
		lock=strstr(temp,">");lock++;
		tail=(char*)malloc(strlen(lock)+1);
		strcpy(tail,lock);
		*temp=0;
	
		temp=MatchTagLeft(temp,"<mrow");
		temp=Insert(temp,"<mfrac");
		if (strcmp(what,"<OVER/>")==0)
			Insert(temp,">");
		else
			Insert(temp," linethickness=\"0\">");
		strcat(temp,"</mrow>");
		lock=strrchr(temp,0);
		strcat(temp,"<mrow>");
		strcat(temp,tail);
		free (tail);
		temp=MatchTagRight(lock);
		Insert(temp,"</mfrac>");
	}
}

void fixIds(){
//getting the full math string
//locating and positioning Ids:
//moving id labels content from cells to their parent rows
char *temp=doc_math,*tail,*lock,*pid=id;

	while((temp=strstr(doc_math,"<id>"))){
		temp=strstr(temp,"<id>");
		//copy id contents
		lock=strstr(temp,">");lock++;
		pid=id;
		while(*lock!='<'){
			*pid++=*lock++;
		};
		*pid=0;
		lock=strstr(lock,">");lock++;
		//rid of the id element
		tail=(char*)malloc(strlen(lock)+1);
		strcpy(tail,lock);
		strcpy(temp,tail);
		free(tail);
		//locate the parent mtr or mlabeledtr
		//or point to the math wrapper
		lock=strstr(temp,"</mlabeledtr");
		tail=strstr(temp,"</mtr");
		if (lock&& tail){
			if (tail==strstr(lock,"</mtr>")){
				temp=lock;
				temp=MatchTagLeft(temp,"<mlabeledtr");
			}else{
				temp=tail;
				temp=MatchTagLeft(temp,"<mtr");
			}
		}else{
			if (tail){
				temp=tail;
				temp=MatchTagLeft(temp,"<mtr");
			}else{
				if (lock){
					temp=lock;
					temp=MatchTagLeft(temp,"<mlabeledtr");
				}else
					return;
			}
		}
		//and load the id
		temp=strstr(temp,">");
		temp=Insert(temp," id=\"");
		temp=Insert(temp,id);
		temp=Insert(temp,"\"");
		*id=0;
	}
}

void mapp_char()
{
	unsigned char* temp=(unsigned char*)yytext;
	if ((strstr(currentFont,"cmr"))||(strstr(currentFont,"cmu"))||(strstr(currentFont,"zppler7t"))){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mo;pmt(0x0394);break;//Delta
			case 0x02:pmath=mo;pmt(0x0398);break;//Theta
			case 0x03:pmath=mo;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mo;pmt(0x039E);break;//Xi
			case 0x05:pmath=mo;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mo;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mo;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mo;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mo;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mo;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mo;pmt(0x0131);break;//imath
			case 0x11:pmath=mo;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mo;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mo;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mo;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mo;pmt(0x02D8);break;//breve
			case 0x16:pmath=mo;pmt(0x00AF);break;//macron
			case 0x17:pmath=mo;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mo;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mo;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mo;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mo;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mo;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mo;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mo;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mo;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mo;pmt(*temp);break;//!
			case 0x22:pmath=mo;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:pmath=mo;pmt(*temp);break;//US dollar symbol
			case 0x25:pmath=mo;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo>&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(*temp);break;//quoteright
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mo;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mo;pmt(*temp);break;//:
			case 0x3B:pmath=mo;pmt(*temp);break;//;
			case 0x3C:pmath=mo;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D: //equal
				pmath=mo;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mo;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mo;pmt(*temp);break;//?

			case 0x40:pmath=mo;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=mo;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			case 0x5E:pmath=mo;pmt(*temp);break;//^
			case 0x5F:pmath=mo;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mo;pmt(*temp);break;//`

			case 0x7B:pmath=mo;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mo;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mo;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mo;pmt(*temp);break;//tilde
			case 0x7F:pmath=mo;pmt(0x00A8);break;//diaeresis
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"cmb"))||(strstr(currentFont,"zppleb7t"))){
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mob;pmt(0x0394);break;//Delta
			case 0x02:pmath=mob;pmt(0x0398);break;//Theta
			case 0x03:pmath=mob;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mob;pmt(0x039E);break;//Xi
			case 0x05:pmath=mob;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mob;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mob;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mob;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mob;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mob;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mob;pmt(0x0131);break;//imath
			case 0x11:pmath=mob;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mob;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mob;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mob;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mob;pmt(0x02D8);break;//breve
			case 0x16:pmath=mob;pmt(0x00AF);break;//macron
			case 0x17:pmath=mob;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mob;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mob;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mob;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mob;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mob;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mob;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mob;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mob;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mob;pmt(*temp);break;//!
			case 0x22:pmath=mob;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:pmath=mob;pmt(*temp);break;//US dollar symbol
			case 0x25:pmath=mob;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mob;pmt(*temp);break;//quoteright
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mob;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mob;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnb;pmt(*temp);break;
			case 0x3A:pmath=mob;pmt(*temp);break;//:
			case 0x3B:pmath=mob;pmt(*temp);break;//;
			case 0x3C:pmath=mob;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D: //equal
				pmath=mob;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mob;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mob;pmt(*temp);break;//?

			case 0x40:pmath=mob;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mob;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			case 0x5E:pmath=mob;pmt(*temp);break;//^
			case 0x5F:pmath=mob;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mob;pmt(*temp);break;//`

			case 0x7B:pmath=mob;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mob;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mob;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mob;pmt(*temp);break;//tilde
			case 0x7F:pmath=mob;pmt(0x00A8);break;//diaeresis
			default:pmath=mob;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
		
	if ((strstr(currentFont,"pxr"))||(strstr(currentFont,"txr"))){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mo;pmt(0x0394);break;//Delta
			case 0x02:pmath=mo;pmt(0x0398);break;//Theta
			case 0x03:pmath=mo;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mo;pmt(0x039E);break;//Xi
			case 0x05:pmath=mo;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mo;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mo;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mo;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mo;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mo;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mo;pmt(0x0131);break;//imath
			case 0x11:pmath=mo;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mo;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mo;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mo;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mo;pmt(0x02D8);break;//breve
			case 0x16:pmath=mo;pmt(0x00AF);break;//macron
			case 0x17:pmath=mo;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mo;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mo;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mo;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mo;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mo;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mo;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mo;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mo;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mo;pmt(*temp);break;//!
			case 0x22:pmath=mo;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:pmath=mo;pmt(*temp);break;//US dollar symbol
			case 0x25:pmath=mo;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo>&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(*temp);break;//'
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mo;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mo;pmt(*temp);break;//:
			case 0x3B:pmath=mo;pmt(*temp);break;//;
			case 0x3C:pmath=mo;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D: //equal
				pmath=mo;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mo;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mo;pmt(*temp);break;//?

			case 0x40:pmath=mo;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=mo;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			case 0x5E:pmath=mo;pmt(*temp);break;//^
			case 0x5F:pmath=mo;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mo;pmt(*temp);break;//`

			case 0x7B:pmath=mo;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mo;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mo;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mo;pmt(*temp);break;//tilde
			case 0x7F:pmath=mo;pmt(0x00A8);break;//diaeresis
			
			case 0x8A:pmath=mo;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=mo;pmt(*temp);break;//cent sign
			case 0xA3:pmath=mo;pmt(*temp);break;//pound sign
			case 0xAA:pmath=mo;pmt(0x00AA);break;//l with stroke
			case 0xC5:pmath=mo;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=mo;pmt(*temp);break;//a with ring above
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

		if ((strstr(currentFont,"pxi"))||(strstr(currentFont,"txi"))||(strstr(currentFont,"pxsl"))||(strstr(currentFont,"txsl"))){
		do{
			switch(*temp){
			case 0x00:pmath=mi;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mi;pmt(0x0394);break;//Delta
			case 0x02:pmath=mi;pmt(0x0398);break;//Theta
			case 0x03:pmath=mi;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mi;pmt(0x039E);break;//Xi
			case 0x05:pmath=mi;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mi;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mi;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mi;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mi;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mi;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=moi;pmt(0x0131);break;//imath
			case 0x11:pmath=moi;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=moi;pmt(0x0060);break;//grave accent
			case 0x13:pmath=moi;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=moi;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=moi;pmt(0x02D8);break;//breve
			case 0x16:pmath=moi;pmt(0x00AF);break;//macron
			case 0x17:pmath=moi;pmt(0x02DA);break;//ring above
			case 0x18:pmath=moi;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mi;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mi;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mi;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mi;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mi;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mi;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mi;pmt(0x00D8);break;//O slash

			case 0x20:pmath=moi;pmt(0x0374);break;//greek numerical sign
			case 0x21:pmath=moi;pmt(*temp);break;//!
			case 0x22:pmath=moi;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moi;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"italic\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(*temp);break;//'
			case 0x28:pmath=ldi;pmt(*temp);break;//(
			case 0x29:pmath=rdi;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moi;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=moi;pmt(*temp);break;//:
			case 0x3B:pmath=moi;pmt(*temp);break;//;
			case 0x3C:pmath=moi;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D:	//equal
				pmath=moi;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=moi;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=moi;pmt(*temp);break;//?

			case 0x40:pmath=moi;pmt(*temp);break;//@

			case 0x5B:pmath=ldi;pmt(*temp);break;//[
			case 0x5C:pmath=moi;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdi;pmt(*temp);break;//]
			case 0x5E:pmath=moi;pmt(*temp);break;//^
			case 0x5F:pmath=moi;pmt(0x02D9);break;//dot above

			case 0x60:pmath=moi;pmt(*temp);break;//`

			case 0x7B:pmath=moi;pmt(0x2013);break;//en dash
			case 0x7C:pmath=moi;pmt(0x2014);break;//em dash
			case 0x7D:pmath=moi;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=moi;pmt(*temp);break;//tilde
			case 0x7F:pmath=moi;pmt(0x00A8);break;//diaeresis

			case 0x8A:pmath=mi;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=mi;pmt(*temp);break;//cent sign
			case 0xA3:pmath=mi;pmt(*temp);break;//pound sign
			case 0xAA:pmath=mi;pmt(0x00AA);break;//l with stroke
			case 0xC5:pmath=mi;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=mi;pmt(*temp);break;//a with ring above
			default:pmath=mi;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"pxbi"))||(strstr(currentFont,"txbi"))||(strstr(currentFont,"pxbsl"))||(strstr(currentFont,"txbsl"))){
		do{
			switch(*temp){
			case 0x00:pmath=mib;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mib;pmt(0x0394);break;//Delta
			case 0x02:pmath=mib;pmt(0x0398);break;//Theta
			case 0x03:pmath=mib;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mib;pmt(0x039E);break;//Xi
			case 0x05:pmath=mib;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mib;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mib;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mib;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mib;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mib;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mobi;pmt(0x0131);break;//imath
			case 0x11:pmath=mobi;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mobi;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mobi;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mobi;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mobi;pmt(0x02D8);break;//breve
			case 0x16:pmath=mobi;pmt(0x00AF);break;//macron
			case 0x17:pmath=mobi;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mobi;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mib;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mib;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mib;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mib;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mib;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mib;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mib;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mobi;pmt(*temp);break;//!
			case 0x22:pmath=mobi;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:pmath=mobi;pmt(*temp);break;//US dollar symbol
			case 0x25:pmath=mobi;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold-italic\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mobi;pmt(*temp);break;//'
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mobi;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mobi;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnb;pmt(*temp);break;
			case 0x3A:pmath=mobi;pmt(*temp);break;//:
			case 0x3B:pmath=mobi;pmt(*temp);break;//;
			case 0x3C:pmath=mobi;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D: //equal
				pmath=mobi;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mobi;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mobi;pmt(*temp);break;//?

			case 0x40:pmath=mobi;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mobi;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			case 0x5E:pmath=mobi;pmt(*temp);break;//^
			case 0x5F:pmath=mobi;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mobi;pmt(*temp);break;//`

			case 0x7B:pmath=mobi;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mobi;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mobi;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mobi;pmt(*temp);break;//tilde
			case 0x7F:pmath=mobi;pmt(0x00A8);break;//diaeresis
			
			case 0x8A:pmath=mib;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=mib;pmt(*temp);break;//cent sign
			case 0xA3:pmath=mib;pmt(*temp);break;//pound sign
			case 0xAA:pmath=mib;pmt(0x00AA);break;//l with stroke
			case 0xC5:pmath=mib;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=mib;pmt(*temp);break;//a with ring above
			default:pmath=mib;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	
	if ((strstr(currentFont,"pxb"))||(strstr(currentFont,"txb"))){
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mob;pmt(0x0394);break;//Delta
			case 0x02:pmath=mob;pmt(0x0398);break;//Theta
			case 0x03:pmath=mob;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mob;pmt(0x039E);break;//Xi
			case 0x05:pmath=mob;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mob;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mob;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mob;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mob;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mob;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mob;pmt(0x0131);break;//imath
			case 0x11:pmath=mob;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mob;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mob;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mob;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mob;pmt(0x02D8);break;//breve
			case 0x16:pmath=mob;pmt(0x00AF);break;//macron
			case 0x17:pmath=mob;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mob;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mob;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mob;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mob;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mob;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mob;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mob;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mob;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mob;pmt(*temp);break;//!
			case 0x22:pmath=mob;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:pmath=mob;pmt(*temp);break;//US dollar symbol
			case 0x25:pmath=mob;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mob;pmt(*temp);break;//'
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mob;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mob;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnb;pmt(*temp);break;
			case 0x3A:pmath=mob;pmt(*temp);break;//:
			case 0x3B:pmath=mob;pmt(*temp);break;//;
			case 0x3C:pmath=mob;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D: //equal
				pmath=mob;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mob;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mob;pmt(*temp);break;//?

			case 0x40:pmath=mob;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mob;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			case 0x5E:pmath=mob;pmt(*temp);break;//^
			case 0x5F:pmath=mob;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mob;pmt(*temp);break;//`

			case 0x7B:pmath=mob;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mob;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mob;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mob;pmt(*temp);break;//tilde
			case 0x7F:pmath=mob;pmt(0x00A8);break;//diaeresis
			
			case 0x8A:pmath=mob;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=mob;pmt(*temp);break;//cent sign
			case 0xA3:pmath=mob;pmt(*temp);break;//pound sign
			case 0xAA:pmath=mob;pmt(0x00AA);break;//l with stroke
			case 0xC5:pmath=mob;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=mob;pmt(*temp);break;//a with ring above
			default:pmath=mob;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	

	if ((strstr(currentFont,"pxbsc"))||(strstr(currentFont,"txbsc"))){//leave to the sylesheet the small-caps'ing
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mob;pmt(0x0394);break;//Delta
			case 0x02:pmath=mob;pmt(0x0398);break;//Theta
			case 0x03:pmath=mob;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mob;pmt(0x039E);break;//Xi
			case 0x05:pmath=mob;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mob;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mob;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mob;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mob;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mob;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=mob;pmt(0x2191);break;//up arrow
			case 0x0C:pmath=mob;pmt(0x2193);break;//down arrow
			case 0x0D:pmath=mob;pmt(0x2032);break;//prime
			case 0x0E:pmath=mob;pmt(0x00A1);break;//inverted exclamation mark
			case 0x0F:pmath=mob;pmt(0x00BF);break;//inverted question mark

			case 0x10:pmath=mob;pmt(0x026A);break;//latin i small capital
			case 0x11:pmath=mob;pmt(0x006A);break;//j (ascii)
			case 0x12:pmath=mob;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mob;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mob;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mob;pmt(0x02D8);break;//breve
			case 0x16:pmath=mob;pmt(0x00AF);break;//macron
			case 0x17:pmath=mob;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mob;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mob;pmt(0x00DF);break;//german SS (XXX)
			case 0x1A:pmath=mob;pmt(0x00E6);break;//ae
			case 0x1B:pmath=mob;pmt(0x0153);break;//oe
			case 0x1C:pmath=mob;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mob;pmt(0x00C6);break;//AE
			case 0x1E:pmath=mob;pmt(0x0152);break;//OE
			case 0x1F:pmath=mob;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mob;pmt(*temp);break;//!
			case 0x22:pmath=mob;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mob;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mob;pmt(*temp);break;//'
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mob;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mob;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnb;pmt(*temp);break;
			case 0x3A:pmath=mob;pmt(*temp);break;//:
			case 0x3B:pmath=mob;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold\">&lt;</mo>");
				break;
			case 0x3D: //equal
				pmath=mob;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold\">&gt;</mo>");
				break;
			case 0x3F:pmath=mob;pmt(*temp);break;//?

			case 0x40:pmath=mob;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=ldb;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			case 0x5E:pmath=mob;pmt(*temp);break;//^
			case 0x5F:pmath=mob;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mob;pmt(*temp);break;//`
			
			
			case 0x7B:pmath=mob;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mob;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mob;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mob;pmt(*temp);break;//tilde
			case 0x7F:pmath=mob;pmt(0x00A8);break;//diaeresis

			case 0x8A:pmath=mob;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=mob;pmt(*temp);break;//cent sign
			case 0xA3:pmath=mob;pmt(*temp);break;//pound sign
			case 0xAA:pmath=mob;pmt(0x1D0C);break;//L with stroke, small
			case 0xC5:pmath=mob;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=mob;pmt(*temp);break;//a with ring above, XXX no (small capital) Unicode 4.1 equivalent 
			default:pmath=mob;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"pxsc"))||(strstr(currentFont,"txsc"))){//leave to the sylesheet the small-caps'ing
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mo;pmt(0x0394);break;//Delta
			case 0x02:pmath=mo;pmt(0x0398);break;//Theta
			case 0x03:pmath=mo;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mo;pmt(0x039E);break;//Xi
			case 0x05:pmath=mo;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mo;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mo;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mo;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mo;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mo;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=mo;pmt(0x2191);break;//up arrow
			case 0x0C:pmath=mo;pmt(0x2193);break;//down arrow
			case 0x0D:pmath=mo;pmt(0x2032);break;//prime
			case 0x0E:pmath=mo;pmt(0x00A1);break;//inverted exclamation mark
			case 0x0F:pmath=mo;pmt(0x00BF);break;//inverted question mark

			case 0x10:pmath=mo;pmt(0x026A);break;//latin i small capital
			case 0x11:pmath=mo;pmt(0x006A);break;//j (ascii)
			case 0x12:pmath=mo;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mo;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mo;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mo;pmt(0x02D8);break;//breve
			case 0x16:pmath=mo;pmt(0x00AF);break;//macron
			case 0x17:pmath=mo;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mo;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mo;pmt(0x00DF);break;//german SS (XXX)
			case 0x1A:pmath=mo;pmt(0x00E6);break;//ae
			case 0x1B:pmath=mo;pmt(0x0153);break;//oe
			case 0x1C:pmath=mo;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mo;pmt(0x00C6);break;//AE
			case 0x1E:pmath=mo;pmt(0x0152);break;//OE
			case 0x1F:pmath=mo;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mo;pmt(*temp);break;//!
			case 0x22:pmath=mo;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mo;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo>&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(*temp);break;//'
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mo;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mo;pmt(*temp);break;//:
			case 0x3B:pmath=mo;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo>&lt;</mo>");
				break;
			case 0x3D: //equal
				pmath=mo;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo>&gt;</mo>");
				break;
			case 0x3F:pmath=mo;pmt(*temp);break;//?

			case 0x40:pmath=mo;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=ld;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			case 0x5E:pmath=mo;pmt(*temp);break;//^
			case 0x5F:pmath=mo;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mo;pmt(*temp);break;//`
			
			
			case 0x7B:pmath=mo;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mo;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mo;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mo;pmt(*temp);break;//tilde
			case 0x7F:pmath=mo;pmt(0x00A8);break;//diaeresis

			case 0x8A:pmath=mo;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=mo;pmt(*temp);break;//cent sign
			case 0xA3:pmath=mo;pmt(*temp);break;//pound sign
			case 0xAA:pmath=mo;pmt(0x1D0C);break;//L with stroke, small
			case 0xC5:pmath=mo;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=mo;pmt(*temp);break;//a with ring above, XXX no (small capital) Unicode 4.1 equivalent 
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

		

	
	if ((strstr(currentFont,"pxsssc"))||(strstr(currentFont,"txsssc"))){//leave the small-caps'ing to the stylesheet
		do{
			switch(*temp){
			case 0x00:pmath=moss;pmt(0x0393);break;//Gamma
			case 0x01:pmath=moss;pmt(0x0394);break;//Delta
			case 0x02:pmath=moss;pmt(0x0398);break;//Theta
			case 0x03:pmath=moss;pmt(0x039B);break;//Lambda
			case 0x04:pmath=moss;pmt(0x039E);break;//Xi
			case 0x05:pmath=moss;pmt(0x03A0);break;//Pi
			case 0x06:pmath=moss;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=moss;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=moss;pmt(0x03A6);break;//Phi
			case 0x09:pmath=moss;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=moss;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=moss;pmt(0x2191);break;//up arrow
			case 0x0C:pmath=moss;pmt(0x2193);break;//down arrow
			case 0x0D:pmath=moss;pmt(0x2032);break;//prime
			case 0x0E:pmath=moss;pmt(0x00A1);break;//inverted exclamation mark
			case 0x0F:pmath=moss;pmt(0x00BF);break;//inverted question mark

			case 0x10:pmath=moss;pmt(0x026A);break;//latin i small capital
			case 0x11:pmath=moss;pmt(0x006A);break;//j (ascii)
			case 0x12:pmath=moss;pmt(0x0060);break;//grave accent
			case 0x13:pmath=moss;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=moss;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=moss;pmt(0x02D8);break;//breve
			case 0x16:pmath=moss;pmt(0x00AF);break;//macron
			case 0x17:pmath=moss;pmt(0x02DA);break;//ring above
			case 0x18:pmath=moss;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=moss;pmt(0x00DF);break;//german SS (XXX)
			case 0x1A:pmath=moss;pmt(0x00E6);break;//ae
			case 0x1B:pmath=moss;pmt(0x0153);break;//oe
			case 0x1C:pmath=moss;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=moss;pmt(0x00C6);break;//AE
			case 0x1E:pmath=moss;pmt(0x0152);break;//OE
			case 0x1F:pmath=moss;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=moss;pmt(*temp);break;//!
			case 0x22:pmath=moss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moss;pmt(*temp);break;//'
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moss;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnss;pmt(*temp);break;
			case 0x3A:pmath=moss;pmt(*temp);break;//:
			case 0x3B:pmath=moss;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&lt;</mo>");
				break;
			case 0x3D: //equal
				pmath=mo;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&gt;</mo>");
				break;
			case 0x3F:pmath=moss;pmt(*temp);break;//?

			case 0x40:pmath=moss;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=ld;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			case 0x5E:pmath=moss;pmt(*temp);break;//^
			case 0x5F:pmath=moss;pmt(0x02D9);break;//dot above

			case 0x60:pmath=moss;pmt(*temp);break;//`
			
			case 0x7B:pmath=moss;pmt(0x2013);break;//en dash
			case 0x7C:pmath=moss;pmt(0x2014);break;//em dash
			case 0x7D:pmath=moss;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=moss;pmt(*temp);break;//tilde
			case 0x7F:pmath=moss;pmt(0x00A8);break;//diaeresis

			case 0x8A:pmath=moss;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=moss;pmt(*temp);break;//cent sign
			case 0xA3:pmath=moss;pmt(*temp);break;//pound sign
			case 0xAA:pmath=moss;pmt(0x1D0C);break;//L with stroke, small
			case 0xC5:pmath=moss;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=moss;pmt(*temp);break;//a with ring above, XXX no (small capital) Unicode 4.1 equivalent 
			default:pmath=moss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

		if ((strstr(currentFont,"pxsssl"))||(strstr(currentFont,"txsssl"))){
		do{
			switch(*temp){
			case 0x00:pmath=missi;pmt(0x0393);break;//Gamma
			case 0x01:pmath=missi;pmt(0x0394);break;//Delta
			case 0x02:pmath=missi;pmt(0x0398);break;//Theta
			case 0x03:pmath=missi;pmt(0x039B);break;//Lambda
			case 0x04:pmath=missi;pmt(0x039E);break;//Xi
			case 0x05:pmath=missi;pmt(0x03A0);break;//Pi
			case 0x06:pmath=missi;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=missi;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=missi;pmt(0x03A6);break;//Phi
			case 0x09:pmath=missi;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=missi;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mossi;pmt(0x0131);break;//imath
			case 0x11:pmath=mossi;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mossi;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mossi;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mossi;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mossi;pmt(0x02D8);break;//breve
			case 0x16:pmath=mossi;pmt(0x00AF);break;//macron
			case 0x17:pmath=mossi;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mossi;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=missi;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=missi;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=missi;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=missi;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=missi;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=missi;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=missi;pmt(0x00D8);break;//O slash

			case 0x20:pmath=mossi;pmt(0x0374);break;//greek numerical sign
			case 0x21:pmath=mossi;pmt(*temp);break;//!
			case 0x22:pmath=mossi;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mossi;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"sans-serif-italic\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mossi;pmt(*temp);break;//'
			case 0x28:pmath=ldssi;pmt(*temp);break;//(
			case 0x29:pmath=rdssi;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mossi;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mossi;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnss;pmt(*temp);break;
			case 0x3A:pmath=mossi;pmt(*temp);break;//:
			case 0x3B:pmath=mossi;pmt(*temp);break;//;
			case 0x3C:pmath=mossi;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D:	//equal
				pmath=mossi;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mossi;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mossi;pmt(*temp);break;//?

			case 0x40:pmath=mossi;pmt(*temp);break;//@

			case 0x5B:pmath=ldssi;pmt(*temp);break;//[
			case 0x5C:pmath=mossi;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdssi;pmt(*temp);break;//]
			case 0x5E:pmath=mossi;pmt(*temp);break;//^
			case 0x5F:pmath=mossi;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mossi;pmt(*temp);break;//`

			case 0x7B:pmath=mossi;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mossi;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mossi;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mossi;pmt(*temp);break;//tilde
			case 0x7F:pmath=mossi;pmt(0x00A8);break;//diaeresis

			case 0x8A:pmath=missi;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=missi;pmt(*temp);break;//cent sign
			case 0xA3:pmath=missi;pmt(*temp);break;//pound sign
			case 0xAA:pmath=missi;pmt(0x00AA);break;//l with stroke
			case 0xC5:pmath=missi;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=missi;pmt(*temp);break;//a with ring above
			default:pmath=missi;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
		if ((strstr(currentFont,"pxss"))||(strstr(currentFont,"txss"))){
		do{
			switch(*temp){
			case 0x00:pmath=miss;pmt(0x0393);break;//Gamma
			case 0x01:pmath=miss;pmt(0x0394);break;//Delta
			case 0x02:pmath=miss;pmt(0x0398);break;//Theta
			case 0x03:pmath=miss;pmt(0x039B);break;//Lambda
			case 0x04:pmath=miss;pmt(0x039E);break;//Xi
			case 0x05:pmath=miss;pmt(0x03A0);break;//Pi
			case 0x06:pmath=miss;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=miss;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=miss;pmt(0x03A6);break;//Phi
			case 0x09:pmath=miss;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=miss;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=moss;pmt(0x0131);break;//imath
			case 0x11:pmath=moss;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=moss;pmt(0x0060);break;//grave accent
			case 0x13:pmath=moss;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=moss;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=moss;pmt(0x02D8);break;//breve
			case 0x16:pmath=moss;pmt(0x00AF);break;//macron
			case 0x17:pmath=moss;pmt(0x02DA);break;//ring above
			case 0x18:pmath=moss;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=miss;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=miss;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=miss;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=miss;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=miss;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=miss;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=miss;pmt(0x00D8);break;//O slash

			case 0x20:pmath=moss;pmt(0x0374);break;//greek numerical sign
			case 0x21:pmath=moss;pmt(*temp);break;//!
			case 0x22:pmath=moss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moss;pmt(*temp);break;//'
			case 0x28:pmath=ldi;pmt(*temp);break;//(
			case 0x29:pmath=rdi;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moss;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnss;pmt(*temp);break;
			case 0x3A:pmath=moss;pmt(*temp);break;//:
			case 0x3B:pmath=moss;pmt(*temp);break;//;
			case 0x3C:pmath=moss;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D:	//equal
				pmath=moss;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=moss;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=moss;pmt(*temp);break;//?

			case 0x40:pmath=moss;pmt(*temp);break;//@

			case 0x5B:pmath=ldi;pmt(*temp);break;//[
			case 0x5C:pmath=moss;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdi;pmt(*temp);break;//]
			case 0x5E:pmath=moss;pmt(*temp);break;//^
			case 0x5F:pmath=moss;pmt(0x02D9);break;//dot above

			case 0x60:pmath=moss;pmt(*temp);break;//`

			case 0x7B:pmath=moss;pmt(0x2013);break;//en dash
			case 0x7C:pmath=moss;pmt(0x2014);break;//em dash
			case 0x7D:pmath=moss;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=moss;pmt(*temp);break;//tilde
			case 0x7F:pmath=moss;pmt(0x00A8);break;//diaeresis

			case 0x8A:pmath=miss;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=miss;pmt(*temp);break;//cent sign
			case 0xA3:pmath=miss;pmt(*temp);break;//pound sign
			case 0xAA:pmath=miss;pmt(0x00AA);break;//l with stroke
			case 0xC5:pmath=miss;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=miss;pmt(*temp);break;//a with ring above
			default:pmath=miss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
		
	if ((strstr(currentFont,"pxtt"))||(strstr(currentFont,"txtt"))||(strstr(currentFont,"pxbtt"))||(strstr(currentFont,"txbtt"))){//leave the slanting and small-caps'ing to the stylesheet
		do{
			switch(*temp){
			case 0x00:pmath=mitt;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mitt;pmt(0x0394);break;//Delta
			case 0x02:pmath=mitt;pmt(0x0398);break;//Theta
			case 0x03:pmath=mitt;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mitt;pmt(0x039E);break;//Xi
			case 0x05:pmath=mitt;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mitt;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mitt;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mitt;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mitt;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mitt;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=mott;pmt(0x2191);break;//up arrow
			case 0x0C:pmath=mott;pmt(0x2193);break;//down arrow
			case 0x0D:pmath=mott;pmt(0x2032);break;//prime
			case 0x0E:pmath=mott;pmt(0x00A1);break;//inverted exclamation mark
			case 0x0F:pmath=mott;pmt(0x00BF);break;//inverted question mark

			case 0x10:pmath=mott;pmt(0x026A);break;//latin i small capital
			case 0x11:pmath=mott;pmt(0x006A);break;//j (ascii)
			case 0x12:pmath=mott;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mott;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mott;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mott;pmt(0x02D8);break;//breve
			case 0x16:pmath=mott;pmt(0x00AF);break;//macron
			case 0x17:pmath=mott;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mott;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mitt;pmt(0x00DF);break;//german SS (XXX)
			case 0x1A:pmath=mitt;pmt(0x1D01);break;//AE small
			case 0x1B:pmath=mitt;pmt(0x0276);break;//OE small
			case 0x1C:pmath=mitt;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mitt;pmt(0x00C6);break;//AE
			case 0x1E:pmath=mitt;pmt(0x0152);break;//OE
			case 0x1F:pmath=mitt;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mott;pmt(*temp);break;//!
			case 0x22:pmath=mott;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mott;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"monospace\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mott;pmt(*temp);break;//'
			case 0x28:pmath=ldtt;pmt(*temp);break;//(
			case 0x29:pmath=rdtt;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mott;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mott;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mntt;pmt(*temp);break;
			case 0x3A:pmath=mott;pmt(*temp);break;//:
			case 0x3B:pmath=mott;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"monospace\">&lt;</mo>");
				break;
			case 0x3D: //equal
				pmath=mott;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"monospace\">&gt;</mo>");
				break;
			case 0x3F:pmath=mott;pmt(*temp);break;//?

			case 0x40:pmath=mott;pmt(*temp);break;//@

			case 0x5B:pmath=ldtt;pmt(*temp);break;//[
			case 0x5C:pmath=ldtt;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdtt;pmt(*temp);break;//]
			case 0x5E:pmath=mott;pmt(*temp);break;//^
			case 0x5F:pmath=mott;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mott;pmt(*temp);break;//`
			
			case 0x61:pmath=mitt;pmt(0x0041);break;//(XXX, should be) small capital a 
			case 0x62:pmath=mitt;pmt(0x0299);break;//small capital b
			case 0x63:pmath=mitt;pmt(0x0043);break;//(XXX, should be) small capital c 
			case 0x64:pmath=mitt;pmt(0x0044);break;//(XXX, should be) small capital d
			case 0x65:pmath=mitt;pmt(0x0045);break;//(XXX, should be) small capital e
			case 0x66:pmath=mitt;pmt(0x0046);break;//(XXX, should be) small capital f
			case 0x67:pmath=mitt;pmt(0x0262);break;//small capital g
			case 0x68:pmath=mitt;pmt(0x029C);break;//small capital h
			case 0x69:pmath=mitt;pmt(0x026A);break;//small capital i
			case 0x6A:pmath=mitt;pmt(0x004A);break;//(XXX, should be) small capital j
			case 0x6B:pmath=mitt;pmt(0x004B);break;//(XXX, should be) small capital k
			case 0x6C:pmath=mitt;pmt(0x029F);break;//small capital l
			case 0x6D:pmath=mitt;pmt(0x004D);break;//(XXX, should be) small capital m
			case 0x6E:pmath=mitt;pmt(0x0274);break;//small capital n
			case 0x6F:pmath=mitt;pmt(0x004F);break;//(XXX, should be) small capital o
			case 0x70:pmath=mitt;pmt(0x0050);break;//(XXX, should be) small capital p
			case 0x71:pmath=mitt;pmt(0x0051);break;//(XXX, should be) small capital q
			case 0x72:pmath=mitt;pmt(0x0280);break;//small capital r
			case 0x73:pmath=mitt;pmt(0x0053);break;//(XXX, should be) small capital s
			case 0x74:pmath=mitt;pmt(0x0054);break;//(XXX, should be) small capital t
			case 0x75:pmath=mitt;pmt(0x0055);break;//(XXX, should be) small capital u
			case 0x76:pmath=mitt;pmt(0x0056);break;//(XXX, should be) small capital v
			case 0x77:pmath=mitt;pmt(0x0057);break;//(XXX, should be) small capital w
			case 0x78:pmath=mitt;pmt(0x0058);break;//(XXX, should be) small capital x
			case 0x79:pmath=mitt;pmt(0x028F);break;//small capital y
			case 0x7A:pmath=mitt;pmt(0x0059);break;//(XXX, should be) small capital z
			
			case 0x7B:pmath=mott;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mott;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mott;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mott;pmt(*temp);break;//tilde
			case 0x7F:pmath=mott;pmt(0x00A8);break;//diaeresis

			case 0x8A:pmath=mitt;pmt(0x0141);break;//L with stroke
			case 0xA2:pmath=mitt;pmt(*temp);break;//cent sign
			case 0xA3:pmath=mitt;pmt(*temp);break;//pound sign
			case 0xAA:pmath=mitt;pmt(0x1D0C);break;//L with stroke, small
			case 0xC5:pmath=mitt;pmt(*temp);break;//A with ring above, Angstrom
			case 0xE5:pmath=mitt;pmt(*temp);break;//a with ring above, XXX no (small capital) Unicode 4.1 equivalent 
			default:pmath=mitt;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

		
	if ((strstr(currentFont,"ecrm"))||(strstr(currentFont,"p1xr"))||(strstr(currentFont,"t1xr"))){//same as pplr8
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x0060);break;//grave accent
			case 0x01:pmath=mo;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=mo;pmt(0x005E);break;//hat
			case 0x03:pmath=mo;pmt(0x007E);break;//tilde
			case 0x04:pmath=mo;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=mo;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=mo;pmt(0x02DA);break;//ring above
			case 0x07:pmath=mo;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=mo;pmt(0x02D8);break;//breve
			case 0x09:pmath=mo;pmt(0x00AF);break;//macron
			case 0x0A:pmath=mo;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=mo;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=mo;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=mo;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=mo;pmt(0x2329);break;//left angle
			case 0x0F:pmath=mo;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ld;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=ld;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=mo;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=mo;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=mo;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=mo;pmt(0x2013);break;//en dash
			case 0x16:pmath=mo;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=mo;pmt(0x00B0);break; //degree sign
			case 0x19:pmath=mo;pmt(0x0131);break;//imath
			case 0x1A:pmath=mo;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=mo;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=mo;pmt(*temp);break;//!
			case 0x22:pmath=mo;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mo;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo>&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(*temp);break;//'
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mo;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mo;pmt(*temp);break;//:
			case 0x3B:pmath=mo;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo>&lt;</mo>");
				break;
			case 0x3D:pmath=mo;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo>&gt;</mo>");
				break;
			case 0x3F:pmath=mo;pmt(*temp);break;//?

			case 0x40:pmath=mo;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=mo;pmt(*temp);break;//backslash
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			
			case 0x5E:pmath=mo;pmt(*temp);break;//^
			case 0x5F:pmath=mo;pmt(*temp);break;//_
			case 0x60:pmath=mo;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ld;pmt(*temp);break;//left brace
			case 0x7C:pmath=mo;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rd;pmt(*temp);break;//right brace
			case 0x7E:pmath=mo;pmt(*temp);break;//tilde
			case 0x7F:pmath=mo;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=mo;pmt(0x0102);break;//A breve
			case 0x81:pmath=mo;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=mo;pmt(0x0106);break;//C acute
			case 0x83:pmath=mo;pmt(0x010C);break;//C caron
			case 0x84:pmath=mo;pmt(0x010E);break;//D caron
			case 0x85:pmath=mo;pmt(0x011A);break;//E caron
			case 0x86:pmath=mo;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=mo;pmt(0x011E);break;//G breve
			case 0x88:pmath=mo;pmt(0x0139);break;//L acute
			case 0x89:pmath=mo;pmt(0x013D);break;//L caron
			case 0x8A:pmath=mo;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=mo;pmt(0x0143);break;//N acute
			case 0x8C:pmath=mo;pmt(0x0147);break;//N caron
			case 0x8D:pmath=mo;pmt(0x014A);break;//ENG
			case 0x8E:pmath=mo;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=mo;pmt(0x0154);break;//R acute

			case 0x90:pmath=mo;pmt(0x0158);break;//R caron
			case 0x91:pmath=mo;pmt(0x015A);break;//S acute
			case 0x92:pmath=mo;pmt(0x0160);break;//S caron
			case 0x93:pmath=mo;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=mo;pmt(0x0164);break;//T caron
			case 0x95:pmath=mo;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=mo;pmt(0x0170);break;//U double acute
			case 0x97:pmath=mo;pmt(0x016E);break;//U ring above
			case 0x98:pmath=mo;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=mo;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=mo;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=mo;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=mo;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=mo;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=mo;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=mo;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=mo;pmt(0x0103);break;//a breve
			case 0xA1:pmath=mo;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=mo;pmt(0x0107);break;//c acute
			case 0xA3:pmath=mo;pmt(0x010D);break;//c caron
			case 0xA4:pmath=mo;pmt(0x010F);break;//d caron
			case 0xA5:pmath=mo;pmt(0x011B);break;//e caron
			case 0xA6:pmath=mo;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=mo;pmt(0x011F);break;//g breve
			case 0xA8:pmath=mo;pmt(0x013A);break;//l acute
			case 0xA9:pmath=mo;pmt(0x013E);break;//l caron
			case 0xAA:pmath=mo;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=mo;pmt(0x0144);break;//n acute
			case 0xAC:pmath=mo;pmt(0x0148);break;//n caron
			case 0xAD:pmath=mo;pmt(0x014B);break;//eng
			case 0xAE:pmath=mo;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=mo;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=mo;pmt(0x0159);break;//r caron
			case 0xB1:pmath=mo;pmt(0x015B);break;//s acute
			case 0xB2:pmath=mo;pmt(0x0161);break;//s caron
			case 0xB3:pmath=mo;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=mo;pmt(0x0165);break;//t caron
			case 0xB5:pmath=mo;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=mo;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=mo;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=mo;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=mo;pmt(0x017A);break;//z acute
			case 0xBA:pmath=mo;pmt(0x017E);break;//z caron
			case 0xBB:pmath=mo;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=mo;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=mo;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=mo;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=mo;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=mo;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=mo;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=mo;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=mo;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=mo;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=mo;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=mo;pmt(*temp);break;//thorn
			case 0xFF:pmath=mo;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

		
		if ((strstr(currentFont,"t1xsssc"))||(strstr(currentFont,"p1xsssc"))){//small-caps'ing left to stylesheet
		do{
			switch(*temp){
			case 0x00:pmath=moss;pmt(0x0060);break;//grave accent
			case 0x01:pmath=moss;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=moss;pmt(0x005E);break;//hat
			case 0x03:pmath=moss;pmt(0x007E);break;//tilde
			case 0x04:pmath=moss;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=moss;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=moss;pmt(0x02DA);break;//ring above
			case 0x07:pmath=moss;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=moss;pmt(0x02D8);break;//breve
			case 0x09:pmath=moss;pmt(0x00AF);break;//macron
			case 0x0A:pmath=moss;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=moss;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=moss;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=moss;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=moss;pmt(0x2329);break;//left angle
			case 0x0F:pmath=moss;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ld;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=ld;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=moss;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=moss;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=moss;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=moss;pmt(0x2013);break;//en dash
			case 0x16:pmath=moss;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=moss;pmt(0x00B0);break; //degree sign
			case 0x19:pmath=moss;pmt(0x0131);break;//imath
			case 0x1A:pmath=moss;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=moss;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=moss;pmt(*temp);break;//!
			case 0x22:pmath=moss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moss;pmt(*temp);break;//'
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moss;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=moss;pmt(*temp);break;//:
			case 0x3B:pmath=moss;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&lt;</mo>");
				break;
			case 0x3D:pmath=moss;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&gt;</mo>");
				break;
			case 0x3F:pmath=moss;pmt(*temp);break;//?

			case 0x40:pmath=moss;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=moss;pmt(*temp);break;//backslash
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			
			case 0x5E:pmath=moss;pmt(*temp);break;//^
			case 0x5F:pmath=moss;pmt(*temp);break;//_
			case 0x60:pmath=moss;pmt(*temp);break;//`
			
			case 0x7B:pmath=ld;pmt(*temp);break;//left brace
			case 0x7C:pmath=moss;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rd;pmt(*temp);break;//right brace
			case 0x7E:pmath=moss;pmt(*temp);break;//tilde
			case 0x7F:pmath=moss;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=miss;pmt(0x0102);break;//A breve
			case 0x81:pmath=miss;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=miss;pmt(0x0106);break;//C acute
			case 0x83:pmath=miss;pmt(0x010C);break;//C caron
			case 0x84:pmath=miss;pmt(0x010E);break;//D caron
			case 0x85:pmath=miss;pmt(0x011A);break;//E caron
			case 0x86:pmath=miss;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=miss;pmt(0x011E);break;//G breve
			case 0x88:pmath=miss;pmt(0x0139);break;//L acute
			case 0x89:pmath=miss;pmt(0x013D);break;//L caron
			case 0x8A:pmath=miss;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=miss;pmt(0x0143);break;//N acute
			case 0x8C:pmath=miss;pmt(0x0147);break;//N caron
			case 0x8D:pmath=miss;pmt(0x014A);break;//ENG
			case 0x8E:pmath=miss;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=miss;pmt(0x0154);break;//R acute

			case 0x90:pmath=miss;pmt(0x0158);break;//R caron
			case 0x91:pmath=miss;pmt(0x015A);break;//S acute
			case 0x92:pmath=miss;pmt(0x0160);break;//S caron
			case 0x93:pmath=miss;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=miss;pmt(0x0164);break;//T caron
			case 0x95:pmath=miss;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=miss;pmt(0x0170);break;//U double acute
			case 0x97:pmath=miss;pmt(0x016E);break;//U ring above
			case 0x98:pmath=miss;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=miss;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=miss;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=miss;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=miss;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=miss;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=miss;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=miss;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=miss;pmt(0x0103);break;//a breve
			case 0xA1:pmath=miss;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=miss;pmt(0x0107);break;//c acute
			case 0xA3:pmath=miss;pmt(0x010D);break;//c caron
			case 0xA4:pmath=miss;pmt(0x010F);break;//d caron
			case 0xA5:pmath=miss;pmt(0x011B);break;//e caron
			case 0xA6:pmath=miss;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=miss;pmt(0x011F);break;//g breve
			case 0xA8:pmath=miss;pmt(0x013A);break;//l acute
			case 0xA9:pmath=miss;pmt(0x013E);break;//l caron
			case 0xAA:pmath=miss;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=miss;pmt(0x0144);break;//n acute
			case 0xAC:pmath=miss;pmt(0x0148);break;//n caron
			case 0xAD:pmath=miss;pmt(0x014B);break;//eng
			case 0xAE:pmath=miss;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=miss;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=miss;pmt(0x0159);break;//r caron
			case 0xB1:pmath=miss;pmt(0x015B);break;//s acute
			case 0xB2:pmath=miss;pmt(0x0161);break;//s caron
			case 0xB3:pmath=miss;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=miss;pmt(0x0165);break;//t caron
			case 0xB5:pmath=miss;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=miss;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=miss;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=miss;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=miss;pmt(0x017A);break;//z acute
			case 0xBA:pmath=miss;pmt(0x017E);break;//z caron
			case 0xBB:pmath=miss;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=miss;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=moss;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=moss;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=miss;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=miss;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=miss;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=miss;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=miss;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=miss;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=miss;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=miss;pmt(*temp);break;//thorn
			case 0xFF:pmath=miss;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=miss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"p1xss"))||(strstr(currentFont,"t1xss"))){
		do{
			switch(*temp){
			case 0x00:pmath=moss;pmt(0x0060);break;//grave accent
			case 0x01:pmath=moss;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=moss;pmt(0x005E);break;//hat
			case 0x03:pmath=moss;pmt(0x007E);break;//tilde
			case 0x04:pmath=moss;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=moss;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=moss;pmt(0x02DA);break;//ring above
			case 0x07:pmath=moss;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=moss;pmt(0x02D8);break;//breve
			case 0x09:pmath=moss;pmt(0x00AF);break;//macron
			case 0x0A:pmath=moss;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=moss;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=moss;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=moss;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=moss;pmt(0x2329);break;//left angle
			case 0x0F:pmath=moss;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ld;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=ld;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=moss;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=moss;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=moss;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=moss;pmt(0x2013);break;//en dash
			case 0x16:pmath=moss;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=moss;pmt(0x00B0);break; //degree sign
			case 0x19:pmath=moss;pmt(0x0131);break;//imath
			case 0x1A:pmath=moss;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=moss;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=moss;pmt(*temp);break;//!
			case 0x22:pmath=moss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moss;pmt(*temp);break;//'
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moss;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=moss;pmt(*temp);break;//:
			case 0x3B:pmath=moss;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&lt;</mo>");
				break;
			case 0x3D:pmath=moss;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&gt;</mo>");
				break;
			case 0x3F:pmath=moss;pmt(*temp);break;//?

			case 0x40:pmath=moss;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=moss;pmt(*temp);break;//backslash
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			
			case 0x5E:pmath=moss;pmt(*temp);break;//^
			case 0x5F:pmath=moss;pmt(*temp);break;//_
			case 0x60:pmath=moss;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ld;pmt(*temp);break;//left brace
			case 0x7C:pmath=moss;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rd;pmt(*temp);break;//right brace
			case 0x7E:pmath=moss;pmt(*temp);break;//tilde
			case 0x7F:pmath=moss;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=miss;pmt(0x0102);break;//A breve
			case 0x81:pmath=miss;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=miss;pmt(0x0106);break;//C acute
			case 0x83:pmath=miss;pmt(0x010C);break;//C caron
			case 0x84:pmath=miss;pmt(0x010E);break;//D caron
			case 0x85:pmath=miss;pmt(0x011A);break;//E caron
			case 0x86:pmath=miss;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=miss;pmt(0x011E);break;//G breve
			case 0x88:pmath=miss;pmt(0x0139);break;//L acute
			case 0x89:pmath=miss;pmt(0x013D);break;//L caron
			case 0x8A:pmath=miss;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=miss;pmt(0x0143);break;//N acute
			case 0x8C:pmath=miss;pmt(0x0147);break;//N caron
			case 0x8D:pmath=miss;pmt(0x014A);break;//ENG
			case 0x8E:pmath=miss;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=miss;pmt(0x0154);break;//R acute

			case 0x90:pmath=miss;pmt(0x0158);break;//R caron
			case 0x91:pmath=miss;pmt(0x015A);break;//S acute
			case 0x92:pmath=miss;pmt(0x0160);break;//S caron
			case 0x93:pmath=miss;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=miss;pmt(0x0164);break;//T caron
			case 0x95:pmath=miss;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=miss;pmt(0x0170);break;//U double acute
			case 0x97:pmath=miss;pmt(0x016E);break;//U ring above
			case 0x98:pmath=miss;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=miss;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=miss;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=miss;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=miss;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=miss;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=miss;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=miss;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=miss;pmt(0x0103);break;//a breve
			case 0xA1:pmath=miss;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=miss;pmt(0x0107);break;//c acute
			case 0xA3:pmath=miss;pmt(0x010D);break;//c caron
			case 0xA4:pmath=miss;pmt(0x010F);break;//d caron
			case 0xA5:pmath=miss;pmt(0x011B);break;//e caron
			case 0xA6:pmath=miss;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=miss;pmt(0x011F);break;//g breve
			case 0xA8:pmath=miss;pmt(0x013A);break;//l acute
			case 0xA9:pmath=miss;pmt(0x013E);break;//l caron
			case 0xAA:pmath=miss;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=miss;pmt(0x0144);break;//n acute
			case 0xAC:pmath=miss;pmt(0x0148);break;//n caron
			case 0xAD:pmath=miss;pmt(0x014B);break;//eng
			case 0xAE:pmath=miss;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=miss;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=miss;pmt(0x0159);break;//r caron
			case 0xB1:pmath=miss;pmt(0x015B);break;//s acute
			case 0xB2:pmath=miss;pmt(0x0161);break;//s caron
			case 0xB3:pmath=miss;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=miss;pmt(0x0165);break;//t caron
			case 0xB5:pmath=miss;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=miss;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=miss;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=miss;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=miss;pmt(0x017A);break;//z acute
			case 0xBA:pmath=miss;pmt(0x017E);break;//z caron
			case 0xBB:pmath=miss;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=miss;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=moss;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=moss;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=miss;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=miss;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=miss;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=miss;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=miss;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=miss;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=miss;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=miss;pmt(*temp);break;//thorn
			case 0xFF:pmath=miss;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=miss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
		if ((strstr(currentFont,"t1xtt"))||(strstr(currentFont,"p1xtt"))){//leave t1xttsl/p1xttsl and t1xttsc/p1xttsc to the stylesheet
		do{
			switch(*temp){
			case 0x00:pmath=mott;pmt(0x0060);break;//grave accent
			case 0x01:pmath=mott;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=mott;pmt(0x005E);break;//hat
			case 0x03:pmath=mott;pmt(0x007E);break;//tilde
			case 0x04:pmath=mott;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=mott;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=mott;pmt(0x02DA);break;//ring above
			case 0x07:pmath=mott;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=mott;pmt(0x02D8);break;//breve
			case 0x09:pmath=mott;pmt(0x00AF);break;//macron
			case 0x0A:pmath=mott;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=mott;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=mott;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=mott;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=mott;pmt(0x2329);break;//left angle
			case 0x0F:pmath=mott;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ldtt;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=ldtt;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=mott;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=mott;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=mott;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=mott;pmt(0x2013);break;//en dash
			case 0x16:pmath=mott;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=mott;pmt(0x00B0);break; //degree sign
			case 0x19:pmath=mott;pmt(0x0131);break;//imath
			case 0x1A:pmath=mott;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=mott;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=mott;pmt(*temp);break;//!
			case 0x22:pmath=mott;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mott;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mott;pmt(*temp);break;//'
			case 0x28:pmath=ldtt;pmt(*temp);break;//(
			case 0x29:pmath=rdtt;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mott;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mott;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mott;pmt(*temp);break;//:
			case 0x3B:pmath=mott;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&lt;</mo>");
				break;
			case 0x3D:pmath=mott;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&gt;</mo>");
				break;
			case 0x3F:pmath=mott;pmt(*temp);break;//?

			case 0x40:pmath=mott;pmt(*temp);break;//@

			case 0x5B:pmath=ldtt;pmt(*temp);break;//[
			case 0x5C:pmath=mott;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdtt;pmt(*temp);break;//]
			
			case 0x5E:pmath=mott;pmt(*temp);break;//^
			case 0x5F:pmath=mott;pmt(*temp);break;//_
			case 0x60:pmath=mott;pmt(*temp);break;//`
			
			case 0x7B:pmath=ldtt;pmt(*temp);break;//left brace
			case 0x7C:pmath=mott;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdtt;pmt(*temp);break;//right brace
			case 0x7E:pmath=mott;pmt(*temp);break;//tilde
			case 0x7F:pmath=mott;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=mitt;pmt(0x0102);break;//A breve
			case 0x81:pmath=mitt;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=mitt;pmt(0x0106);break;//C acute
			case 0x83:pmath=mitt;pmt(0x010C);break;//C caron
			case 0x84:pmath=mitt;pmt(0x010E);break;//D caron
			case 0x85:pmath=mitt;pmt(0x011A);break;//E caron
			case 0x86:pmath=mitt;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=mitt;pmt(0x011E);break;//G breve
			case 0x88:pmath=mitt;pmt(0x0139);break;//L acute
			case 0x89:pmath=mitt;pmt(0x013D);break;//L caron
			case 0x8A:pmath=mitt;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=mitt;pmt(0x0143);break;//N acute
			case 0x8C:pmath=mitt;pmt(0x0147);break;//N caron
			case 0x8D:pmath=mitt;pmt(0x014A);break;//ENG
			case 0x8E:pmath=mitt;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=mitt;pmt(0x0154);break;//R acute

			case 0x90:pmath=mitt;pmt(0x0158);break;//R caron
			case 0x91:pmath=mitt;pmt(0x015A);break;//S acute
			case 0x92:pmath=mitt;pmt(0x0160);break;//S caron
			case 0x93:pmath=mitt;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=mitt;pmt(0x0164);break;//T caron
			case 0x95:pmath=mitt;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=mitt;pmt(0x0170);break;//U double acute
			case 0x97:pmath=mitt;pmt(0x016E);break;//U ring above
			case 0x98:pmath=mitt;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=mitt;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=mitt;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=mitt;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=mitt;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=mitt;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=mitt;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=mitt;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=mitt;pmt(0x0103);break;//a breve
			case 0xA1:pmath=mitt;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=mitt;pmt(0x0107);break;//c acute
			case 0xA3:pmath=mitt;pmt(0x010D);break;//c caron
			case 0xA4:pmath=mitt;pmt(0x010F);break;//d caron
			case 0xA5:pmath=mitt;pmt(0x011B);break;//e caron
			case 0xA6:pmath=mitt;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=mitt;pmt(0x011F);break;//g breve
			case 0xA8:pmath=mitt;pmt(0x013A);break;//l acute
			case 0xA9:pmath=mitt;pmt(0x013E);break;//l caron
			case 0xAA:pmath=mitt;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=mitt;pmt(0x0144);break;//n acute
			case 0xAC:pmath=mitt;pmt(0x0148);break;//n caron
			case 0xAD:pmath=mitt;pmt(0x014B);break;//eng
			case 0xAE:pmath=mitt;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=mitt;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=mitt;pmt(0x0159);break;//r caron
			case 0xB1:pmath=mitt;pmt(0x015B);break;//s acute
			case 0xB2:pmath=mitt;pmt(0x0161);break;//s caron
			case 0xB3:pmath=mitt;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=mitt;pmt(0x0165);break;//t caron
			case 0xB5:pmath=mitt;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=mitt;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=mitt;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=mitt;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=mitt;pmt(0x017A);break;//z acute
			case 0xBA:pmath=mitt;pmt(0x017E);break;//z caron
			case 0xBB:pmath=mitt;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=mitt;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=mott;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=mott;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=mitt;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=mitt;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=mitt;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=mitt;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=mitt;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=mitt;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=mitt;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=mitt;pmt(*temp);break;//thorn
			case 0xFF:pmath=mitt;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=mitt;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if (strstr(currentFont,"ecbx")){// ~ as pplr8
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x0060);break;//grave accent
			case 0x01:pmath=mob;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=mob;pmt(0x005E);break;//hat
			case 0x03:pmath=mob;pmt(0x007E);break;//tilde
			case 0x04:pmath=mob;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=mob;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=mob;pmt(0x02DA);break;//ring above
			case 0x07:pmath=mob;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=mob;pmt(0x02D8);break;//breve
			case 0x09:pmath=mob;pmt(0x00AF);break;//macron
			case 0x0A:pmath=mob;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=mob;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=mob;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=mob;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=mob;pmt(0x2329);break;//left angle
			case 0x0F:pmath=mob;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ldb;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=ldb;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=mob;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=mob;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=mob;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=mob;pmt(0x2013);break;//en dash
			case 0x16:pmath=mob;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=mob;pmt(0x00B0);break; //degree sign
			case 0x19:pmath=mob;pmt(0x0131);break;//imath
			case 0x1A:pmath=mob;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=mob;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=mob;pmt(*temp);break;//!
			case 0x22:pmath=mob;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mob;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mob;pmt(*temp);break;//'
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mob;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mob;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnb;pmt(*temp);break;
			case 0x3A:pmath=mob;pmt(*temp);break;//:
			case 0x3B:pmath=mob;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold\">&lt;</mo>");
				break;
			case 0x3D:pmath=mob;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold\">&gt;</mo>");
				break;
			case 0x3F:pmath=mob;pmt(*temp);break;//?

			case 0x40:pmath=mob;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mob;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			
			case 0x5E:pmath=mob;pmt(*temp);break;//^
			case 0x5F:pmath=mob;pmt(*temp);break;//_
			case 0x60:pmath=mob;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ldb;pmt(*temp);break;//left brace
			case 0x7C:pmath=mob;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdb;pmt(*temp);break;//right brace
			case 0x7E:pmath=mob;pmt(*temp);break;//tilde
			case 0x7F:pmath=mob;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=mob;pmt(0x0102);break;//A breve
			case 0x81:pmath=mob;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=mob;pmt(0x0106);break;//C acute
			case 0x83:pmath=mob;pmt(0x010C);break;//C caron
			case 0x84:pmath=mob;pmt(0x010E);break;//D caron
			case 0x85:pmath=mob;pmt(0x011A);break;//E caron
			case 0x86:pmath=mob;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=mob;pmt(0x011E);break;//G breve
			case 0x88:pmath=mob;pmt(0x0139);break;//L acute
			case 0x89:pmath=mob;pmt(0x013D);break;//L caron
			case 0x8A:pmath=mob;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=mob;pmt(0x0143);break;//N acute
			case 0x8C:pmath=mob;pmt(0x0147);break;//N caron
			case 0x8D:pmath=mob;pmt(0x014A);break;//ENG
			case 0x8E:pmath=mob;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=mob;pmt(0x0154);break;//R acute

			case 0x90:pmath=mob;pmt(0x0158);break;//R caron
			case 0x91:pmath=mob;pmt(0x015A);break;//S acute
			case 0x92:pmath=mob;pmt(0x0160);break;//S caron
			case 0x93:pmath=mob;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=mob;pmt(0x0164);break;//T caron
			case 0x95:pmath=mob;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=mob;pmt(0x0170);break;//U double acute
			case 0x97:pmath=mob;pmt(0x016E);break;//U ring above
			case 0x98:pmath=mob;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=mob;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=mob;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=mob;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=mob;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=mob;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=mob;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=mob;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=mob;pmt(0x0103);break;//a breve
			case 0xA1:pmath=mob;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=mob;pmt(0x0107);break;//c acute
			case 0xA3:pmath=mob;pmt(0x010D);break;//c caron
			case 0xA4:pmath=mob;pmt(0x010F);break;//d caron
			case 0xA5:pmath=mob;pmt(0x011B);break;//e caron
			case 0xA6:pmath=mob;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=mob;pmt(0x011F);break;//g breve
			case 0xA8:pmath=mob;pmt(0x013A);break;//l acute
			case 0xA9:pmath=mob;pmt(0x013E);break;//l caron
			case 0xAA:pmath=mob;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=mob;pmt(0x0144);break;//n acute
			case 0xAC:pmath=mob;pmt(0x0148);break;//n caron
			case 0xAD:pmath=mob;pmt(0x014B);break;//eng
			case 0xAE:pmath=mob;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=mob;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=mob;pmt(0x0159);break;//r caron
			case 0xB1:pmath=mob;pmt(0x015B);break;//s acute
			case 0xB2:pmath=mob;pmt(0x0161);break;//s caron
			case 0xB3:pmath=mob;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=mob;pmt(0x0165);break;//t caron
			case 0xB5:pmath=mob;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=mob;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=mob;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=mob;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=mob;pmt(0x017A);break;//z acute
			case 0xBA:pmath=mob;pmt(0x017E);break;//z caron
			case 0xBB:pmath=mob;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=mob;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=mob;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=mob;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=mob;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=mob;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=mob;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=mob;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=mob;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=mob;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=mob;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=mob;pmt(*temp);break;//thorn
			case 0xFF:pmath=mob;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=mob;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if ((strstr(currentFont,"ecti"))||(strstr(currentFont,"ecsl"))||(strstr(currentFont,"ecsc"))||(strstr(currentFont,"p1xi"))||(strstr(currentFont,"t1xi"))||(strstr(currentFont,"p1xsl"))||(strstr(currentFont,"t1xsl"))||(strstr(currentFont,"p1xsc"))||(strstr(currentFont,"t1xsc"))){
		do{
			switch(*temp){
			case 0x00:pmath=moi;pmt(0x0060);break;//grave accent
			case 0x01:pmath=moi;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=moi;pmt(0x005E);break;//hat
			case 0x03:pmath=moi;pmt(0x007E);break;//tilde
			case 0x04:pmath=moi;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=moi;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=moi;pmt(0x02DA);break;//ring above
			case 0x07:pmath=moi;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=moi;pmt(0x02D8);break;//breve
			case 0x09:pmath=moi;pmt(0x00AF);break;//macron
			case 0x0A:pmath=moi;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=moi;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=moi;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=moi;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=moi;pmt(0x2329);break;//left angle
			case 0x0F:pmath=moi;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ldi;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=rdi;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=moi;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=moi;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=moi;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=moi;pmt(0x2013);break;//en dash
			case 0x16:pmath=moi;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=moi;pmt(0x00B0);break; //degree sign
			case 0x19:pmath=moi;pmt(0x0131);break;//imath
			case 0x1A:pmath=moi;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=moi;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=moi;pmt(*temp);break;//!
			case 0x22:pmath=moi;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moi;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"italic\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moi;pmt(*temp);break;//'
			case 0x28:pmath=ldi;pmt(*temp);break;//(
			case 0x29:pmath=rdi;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moi;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moi;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mni;pmt(*temp);break;
			case 0x3A:pmath=moi;pmt(*temp);break;//:
			case 0x3B:pmath=moi;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"italic\">&lt;</mo>");
				break;
			case 0x3D:pmath=moi;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"italic\">&gt;</mo>");
				break;
			case 0x3F:pmath=moi;pmt(*temp);break;//?

			case 0x40:pmath=moi;pmt(*temp);break;//@

			case 0x5B:pmath=ldi;pmt(*temp);break;//[
			case 0x5C:pmath=moi;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdi;pmt(*temp);break;//]
			
			case 0x5E:pmath=moi;pmt(*temp);break;//^
			case 0x5F:pmath=moi;pmt(*temp);break;//_
			case 0x60:pmath=moi;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ldi;pmt(*temp);break;//left brace
			case 0x7C:pmath=moi;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdi;pmt(*temp);break;//right brace
			case 0x7E:pmath=moi;pmt(*temp);break;//tilde
			case 0x7F:pmath=moi;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=mi;pmt(0x0102);break;//A breve
			case 0x81:pmath=mi;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=mi;pmt(0x0106);break;//C acute
			case 0x83:pmath=mi;pmt(0x010C);break;//C caron
			case 0x84:pmath=mi;pmt(0x010E);break;//D caron
			case 0x85:pmath=mi;pmt(0x011A);break;//E caron
			case 0x86:pmath=mi;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=mi;pmt(0x011E);break;//G breve
			case 0x88:pmath=mi;pmt(0x0139);break;//L acute
			case 0x89:pmath=mi;pmt(0x013D);break;//L caron
			case 0x8A:pmath=mi;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=mi;pmt(0x0143);break;//N acute
			case 0x8C:pmath=mi;pmt(0x0147);break;//N caron
			case 0x8D:pmath=mi;pmt(0x014A);break;//ENG
			case 0x8E:pmath=mi;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=mi;pmt(0x0154);break;//R acute

			case 0x90:pmath=mi;pmt(0x0158);break;//R caron
			case 0x91:pmath=mi;pmt(0x015A);break;//S acute
			case 0x92:pmath=mi;pmt(0x0160);break;//S caron
			case 0x93:pmath=mi;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=mi;pmt(0x0164);break;//T caron
			case 0x95:pmath=mi;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=mi;pmt(0x0170);break;//U double acute
			case 0x97:pmath=mi;pmt(0x016E);break;//U ring above
			case 0x98:pmath=mi;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=mi;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=mi;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=mi;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=mi;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=mi;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=mi;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=mi;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=mi;pmt(0x0103);break;//a breve
			case 0xA1:pmath=mi;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=mi;pmt(0x0107);break;//c acute
			case 0xA3:pmath=mi;pmt(0x010D);break;//c caron
			case 0xA4:pmath=mi;pmt(0x010F);break;//d caron
			case 0xA5:pmath=mi;pmt(0x011B);break;//e caron
			case 0xA6:pmath=mi;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=mi;pmt(0x011F);break;//g breve
			case 0xA8:pmath=mi;pmt(0x013A);break;//l acute
			case 0xA9:pmath=mi;pmt(0x013E);break;//l caron
			case 0xAA:pmath=mi;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=mi;pmt(0x0144);break;//n acute
			case 0xAC:pmath=mi;pmt(0x0148);break;//n caron
			case 0xAD:pmath=mi;pmt(0x014B);break;//eng
			case 0xAE:pmath=mi;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=mi;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=mi;pmt(0x0159);break;//r caron
			case 0xB1:pmath=mi;pmt(0x015B);break;//s acute
			case 0xB2:pmath=mi;pmt(0x0161);break;//s caron
			case 0xB3:pmath=mi;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=mi;pmt(0x0165);break;//t caron
			case 0xB5:pmath=mi;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=mi;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=mi;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=mi;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=mi;pmt(0x017A);break;//z acute
			case 0xBA:pmath=mi;pmt(0x017E);break;//z caron
			case 0xBB:pmath=mi;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=mi;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=moi;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=moi;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=mi;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=mi;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=mi;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=mi;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=mi;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=mi;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=mi;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=mi;pmt(*temp);break;//thorn
			case 0xFF:pmath=mi;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=mi;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"ecbi"))||(strstr(currentFont,"p1xbi"))||(strstr(currentFont,"t1xbi"))||(strstr(currentFont,"p1xbsl"))||(strstr(currentFont,"t1xbsl"))||(strstr(currentFont,"p1xbsc"))||(strstr(currentFont,"t1xbsc"))){
		do{
			switch(*temp){
			case 0x00:pmath=mobi;pmt(0x0060);break;//grave accent
			case 0x01:pmath=mobi;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=mobi;pmt(0x005E);break;//hat
			case 0x03:pmath=mobi;pmt(0x007E);break;//tilde
			case 0x04:pmath=mobi;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=mobi;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=mobi;pmt(0x02DA);break;//ring above
			case 0x07:pmath=mobi;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=mobi;pmt(0x02D8);break;//breve
			case 0x09:pmath=mobi;pmt(0x00AF);break;//macron
			case 0x0A:pmath=mobi;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=mobi;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=mobi;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=mobi;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=mobi;pmt(0x2329);break;//left angle
			case 0x0F:pmath=mobi;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ldbi;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=rdbi;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=mobi;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=mobi;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=mobi;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=mobi;pmt(0x2013);break;//en dash
			case 0x16:pmath=mobi;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=mobi;pmt(0x00B0);break; //degree sign
			case 0x19:pmath=mobi;pmt(0x0131);break;//imath
			case 0x1A:pmath=mobi;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=mobi;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=mobi;pmt(*temp);break;//!
			case 0x22:pmath=mobi;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mobi;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold-italic\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mobi;pmt(*temp);break;//'
			case 0x28:pmath=ldbi;pmt(*temp);break;//(
			case 0x29:pmath=rdbi;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mobi;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mobi;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnbi;pmt(*temp);break;
			case 0x3A:pmath=mobi;pmt(*temp);break;//:
			case 0x3B:pmath=mobi;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold-italic\">&lt;</mo>");
				break;
			case 0x3D:pmath=mobi;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold-italic\">&gt;</mo>");
				break;
			case 0x3F:pmath=mobi;pmt(*temp);break;//?

			case 0x40:pmath=mobi;pmt(*temp);break;//@

			case 0x5B:pmath=ldbi;pmt(*temp);break;//[
			case 0x5C:pmath=mobi;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdbi;pmt(*temp);break;//]
			
			case 0x5E:pmath=mobi;pmt(*temp);break;//^
			case 0x5F:pmath=mobi;pmt(*temp);break;//_
			case 0x60:pmath=mobi;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ldbi;pmt(*temp);break;//left brace
			case 0x7C:pmath=mobi;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdbi;pmt(*temp);break;//right brace
			case 0x7E:pmath=mobi;pmt(*temp);break;//tilde
			case 0x7F:pmath=mobi;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=mib;pmt(0x0102);break;//A breve
			case 0x81:pmath=mib;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=mib;pmt(0x0106);break;//C acute
			case 0x83:pmath=mib;pmt(0x010C);break;//C caron
			case 0x84:pmath=mib;pmt(0x010E);break;//D caron
			case 0x85:pmath=mib;pmt(0x011A);break;//E caron
			case 0x86:pmath=mib;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=mib;pmt(0x011E);break;//G breve
			case 0x88:pmath=mib;pmt(0x0139);break;//L acute
			case 0x89:pmath=mib;pmt(0x013D);break;//L caron
			case 0x8A:pmath=mib;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=mib;pmt(0x0143);break;//N acute
			case 0x8C:pmath=mib;pmt(0x0147);break;//N caron
			case 0x8D:pmath=mib;pmt(0x014A);break;//ENG
			case 0x8E:pmath=mib;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=mib;pmt(0x0154);break;//R acute

			case 0x90:pmath=mib;pmt(0x0158);break;//R caron
			case 0x91:pmath=mib;pmt(0x015A);break;//S acute
			case 0x92:pmath=mib;pmt(0x0160);break;//S caron
			case 0x93:pmath=mib;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=mib;pmt(0x0164);break;//T caron
			case 0x95:pmath=mib;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=mib;pmt(0x0170);break;//U double acute
			case 0x97:pmath=mib;pmt(0x016E);break;//U ring above
			case 0x98:pmath=mib;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=mib;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=mib;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=mib;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=mib;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=mib;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=mib;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=mib;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=mib;pmt(0x0103);break;//a breve
			case 0xA1:pmath=mib;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=mib;pmt(0x0107);break;//c acute
			case 0xA3:pmath=mib;pmt(0x010D);break;//c caron
			case 0xA4:pmath=mib;pmt(0x010F);break;//d caron
			case 0xA5:pmath=mib;pmt(0x011B);break;//e caron
			case 0xA6:pmath=mib;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=mib;pmt(0x011F);break;//g breve
			case 0xA8:pmath=mib;pmt(0x013A);break;//l acute
			case 0xA9:pmath=mib;pmt(0x013E);break;//l caron
			case 0xAA:pmath=mib;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=mib;pmt(0x0144);break;//n acute
			case 0xAC:pmath=mib;pmt(0x0148);break;//n caron
			case 0xAD:pmath=mib;pmt(0x014B);break;//eng
			case 0xAE:pmath=mib;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=mib;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=mib;pmt(0x0159);break;//r caron
			case 0xB1:pmath=mib;pmt(0x015B);break;//s acute
			case 0xB2:pmath=mib;pmt(0x0161);break;//s caron
			case 0xB3:pmath=mib;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=mib;pmt(0x0165);break;//t caron
			case 0xB5:pmath=mib;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=mib;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=mib;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=mib;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=mib;pmt(0x017A);break;//z acute
			case 0xBA:pmath=mib;pmt(0x017E);break;//z caron
			case 0xBB:pmath=mib;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=mib;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=mobi;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=mobi;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=mib;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=mib;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=mib;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=mib;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=mib;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=mib;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=mib;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=mib;pmt(*temp);break;//thorn
			case 0xFF:pmath=mib;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=mib;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if ((strstr(currentFont,"ecb"))||(strstr(currentFont,"p1xb"))||(strstr(currentFont,"t1xb"))||(strstr(currentFont,"p1xbsl"))||(strstr(currentFont,"t1xbsl"))){
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x0060);break;//grave accent
			case 0x01:pmath=mob;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=mob;pmt(0x005E);break;//hat
			case 0x03:pmath=mob;pmt(0x007E);break;//tilde
			case 0x04:pmath=mob;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=mob;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=mob;pmt(0x02DA);break;//ring above
			case 0x07:pmath=mob;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=mob;pmt(0x02D8);break;//breve
			case 0x09:pmath=mob;pmt(0x00AF);break;//macron
			case 0x0A:pmath=mob;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=mob;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=mob;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=mob;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=mob;pmt(0x2329);break;//left angle
			case 0x0F:pmath=mob;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ldb;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=rdb;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=mob;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=mob;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=mob;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=mob;pmt(0x2013);break;//en dash
			case 0x16:pmath=mob;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=mob;pmt(0x00B0);break; //degree sign
			case 0x19:pmath=mob;pmt(0x0131);break;//imath
			case 0x1A:pmath=mob;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=mob;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=mob;pmt(*temp);break;//!
			case 0x22:pmath=mob;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mob;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mob;pmt(*temp);break;//'
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mob;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mob;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnb;pmt(*temp);break;
			case 0x3A:pmath=mob;pmt(*temp);break;//:
			case 0x3B:pmath=mob;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold\">&lt;</mo>");
				break;
			case 0x3D:pmath=mob;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold\">&gt;</mo>");
				break;
			case 0x3F:pmath=mob;pmt(*temp);break;//?

			case 0x40:pmath=mob;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mob;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			
			case 0x5E:pmath=mob;pmt(*temp);break;//^
			case 0x5F:pmath=mob;pmt(*temp);break;//_
			case 0x60:pmath=mob;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ldb;pmt(*temp);break;//left brace
			case 0x7C:pmath=mob;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdb;pmt(*temp);break;//right brace
			case 0x7E:pmath=mob;pmt(*temp);break;//tilde
			case 0x7F:pmath=mob;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=mob;pmt(0x0102);break;//A breve
			case 0x81:pmath=mob;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=mob;pmt(0x0106);break;//C acute
			case 0x83:pmath=mob;pmt(0x010C);break;//C caron
			case 0x84:pmath=mob;pmt(0x010E);break;//D caron
			case 0x85:pmath=mob;pmt(0x011A);break;//E caron
			case 0x86:pmath=mob;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=mob;pmt(0x011E);break;//G breve
			case 0x88:pmath=mob;pmt(0x0139);break;//L acute
			case 0x89:pmath=mob;pmt(0x013D);break;//L caron
			case 0x8A:pmath=mob;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=mob;pmt(0x0143);break;//N acute
			case 0x8C:pmath=mob;pmt(0x0147);break;//N caron
			case 0x8D:pmath=mob;pmt(0x014A);break;//ENG
			case 0x8E:pmath=mob;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=mob;pmt(0x0154);break;//R acute

			case 0x90:pmath=mob;pmt(0x0158);break;//R caron
			case 0x91:pmath=mob;pmt(0x015A);break;//S acute
			case 0x92:pmath=mob;pmt(0x0160);break;//S caron
			case 0x93:pmath=mob;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=mob;pmt(0x0164);break;//T caron
			case 0x95:pmath=mob;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=mob;pmt(0x0170);break;//U double acute
			case 0x97:pmath=mob;pmt(0x016E);break;//U ring above
			case 0x98:pmath=mob;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=mob;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=mob;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=mob;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=mob;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=mob;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=mob;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=mob;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=mob;pmt(0x0103);break;//a breve
			case 0xA1:pmath=mob;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=mob;pmt(0x0107);break;//c acute
			case 0xA3:pmath=mob;pmt(0x010D);break;//c caron
			case 0xA4:pmath=mob;pmt(0x010F);break;//d caron
			case 0xA5:pmath=mob;pmt(0x011B);break;//e caron
			case 0xA6:pmath=mob;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=mob;pmt(0x011F);break;//g breve
			case 0xA8:pmath=mob;pmt(0x013A);break;//l acute
			case 0xA9:pmath=mob;pmt(0x013E);break;//l caron
			case 0xAA:pmath=mob;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=mob;pmt(0x0144);break;//n acute
			case 0xAC:pmath=mob;pmt(0x0148);break;//n caron
			case 0xAD:pmath=mob;pmt(0x014B);break;//eng
			case 0xAE:pmath=mob;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=mob;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=mob;pmt(0x0159);break;//r caron
			case 0xB1:pmath=mob;pmt(0x015B);break;//s acute
			case 0xB2:pmath=mob;pmt(0x0161);break;//s caron
			case 0xB3:pmath=mob;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=mob;pmt(0x0165);break;//t caron
			case 0xB5:pmath=mob;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=mob;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=mob;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=mob;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=mob;pmt(0x017A);break;//z acute
			case 0xBA:pmath=mob;pmt(0x017E);break;//z caron
			case 0xBB:pmath=mob;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=mob;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=mob;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=mob;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=mob;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=mob;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=mob;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=mob;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=mob;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=mob;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=mob;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=mob;pmt(*temp);break;//thorn
			case 0xFF:pmath=mob;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=mob;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	
	if ((strstr(currentFont,"cmtt"))||(strstr(currentFont,"cmtcsc"))){
		do{
			switch(*temp){
			case 0x00:pmath=mitt;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mitt;pmt(0x0394);break;//Delta
			case 0x02:pmath=mitt;pmt(0x0398);break;//Theta
			case 0x03:pmath=mitt;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mitt;pmt(0x039E);break;//Xi
			case 0x05:pmath=mitt;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mitt;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mitt;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mitt;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mitt;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mitt;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;
			case 0x0C:p("fi");break;
			case 0x0D:p("fl");break;
			case 0x0E:p("ffi");break;
			case 0x0F:p("ffl");break;

			case 0x10:pmath=mott;pmt(0x0131);break;//imath
			case 0x11:pmath=mott;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mott;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mott;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mott;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mott;pmt(0x02D8);break;//breve
			case 0x16:pmath=mott;pmt(0x02C9);break;//macron
			case 0x17:pmath=mott;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mott;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mitt;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mitt;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mitt;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mitt;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mitt;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mitt;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mitt;pmt(0x00D8);break;//O slash

			case 0x20:pmath=mott;pmt(*temp);break;//greek numerical sign
					
			case 0x21:pmath=mott;pmt(*temp);break;//right double quotation mark
			case 0x22:pmath=mott;pmt(0x201D);break;//right double quotation mark
			case 0x23:pmath=mott;pmt(*temp);break;//sharp
			case 0x24:pmath=mott;pmt(*temp);break;//$
			case 0x25:pmath=mott;pmt(*temp);break;//%
			case 0x26:
					if (mathmode && !mathText){
						p("<mo mathvariant=\"monospace\">&amp;</mo>");
					}else 
						p("&amp;");
				break;//ampersand
			case 0x27:pmath=mott;pmt(*temp);break;//'
			case 0x28:pmath=ldtt;pmt(*temp);break;//(
			case 0x29:pmath=rdtt;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mott;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mott;pmt(*temp);break;
			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mntt;pmt(*temp);break;
			case 0x3A:
			case 0x3B:pmath=mott;pmt(*temp);break;
			case 0x3C:pmath=mott;pmt(0x2039);break;//angle quotation
			case 0x3D:pmath=mott;//equal
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mott;pmt(0x203A);break;//angle quotation
			case 0x3F:pmath=mott;pmt(*temp);break;//question sign
			case 0x40:pmath=mott;pmt(*temp);break;//at sign

			case 0x5B:pmath=ldtt;pmt(*temp);break;//left bracket
			case 0x5C:pmath=mott;pmt(*temp);break;//left double quotation mark
			case 0x5D:pmath=rdtt;pmt(*temp);break;//right bracket
			case 0x5E:pmath=mott;pmt(*temp);break;//^
			case 0x5F:pmath=mott;pmt(*temp);break;//dot above

			case 0x60:pmath=mott;pmt(*temp);break;//`

			case 0x7B:pmath=mott;pmt(*temp);break;//left brace
			case 0x7C:pmath=mott;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=mott;pmt(*temp);break;//right brace
			case 0x7E:pmath=mott;pmt(*temp);break;//tilde
			case 0x7F:pmath=mott;pmt(0x00A8);break;//diaeresis
			default:pmath=mitt;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"cmtex"))){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x00B7);break;//center dot
			case 0x01:pmath=mo;pmt(0x2193);break;//downwards arrow
			case 0x02:pmath=mi;pmt(0x0381);break;//alpha
			case 0x03:pmath=mi;pmt(0x0382);break;//beta
			case 0x04:pmath=mo;pmt(0x2227);break;//logical and
			case 0x05:pmath=mo;pmt(0x00AC);break;//not sign
			case 0x06:pmath=mo;pmt(0x2208);break;//element of
			case 0x07:pmath=mi;pmt(0x03C0);break;//pi
			case 0x08:pmath=mi;pmt(0x03BB);break;//lambda
			case 0x09:pmath=mi;pmt(0x03B3);break;//gamma
			case 0x0A:pmath=mi;pmt(0x03B4);break;//delta
			case 0x0B:pmath=mo;pmt(0x2191);break;//upwards arrow
			case 0x0C:pmath=mo;pmt(0x00B1);break;//plus-minus
			case 0x0D:pmath=mo;pmt(0x2295);break;//circled plus,\oplus
			case 0x0E:pmath=mn;pmt(0x221E);break;//infinity
			case 0x0F:pmath=mo;pmt(0x2202);break;//partial differential

			case 0x10:pmath=mo;pmt(0x2282);break;//subset of
			case 0x11:pmath=mo;pmt(0x2283);break;//superset of
			case 0x12:pmath=mo;pmt(0x2229);break;//intersection
			case 0x13:pmath=mo;pmt(0x222A);break;//union
			case 0x14:pmath=mo;pmt(0x2200);break;//for all
			case 0x15:pmath=mo;pmt(0x2203);break;//there exists
			case 0x16:pmath=mo;pmt(0x2297);break;//circled times,\otimes
			case 0x17:pmath=mo;pmt(0x21C6);break;//left arrow over right arrow
			case 0x18:pmath=mo;pmt(0x2190);break;//left arrow
			case 0x19:pmath=mo;pmt(0x2192);break;//right arrow
			case 0x1A:pmath=mo;pmt(0x2260);break;//not equal
			case 0x1B:pmath=mo;pmt(0x25CA);break;//lozenge
			case 0x1C:pmath=mo;pmt(0x2264);break;//less than or equal
			case 0x1D:pmath=mo;pmt(0x2265);break;//greater than or equal
			case 0x1E:pmath=mo;pmt(0x2261);break;//identical to
			case 0x1F:pmath=mo;pmt(0x2228);break;//logical or

			case 0x20:break;//XXX:space?,nothing
			case 0x21:pmath=mo;pmt(*temp);break;//right double quotation mark
			case 0x22:pmath=mo;pmt(0x201D);break;//right double quotation mark
			case 0x23:pmath=mo;pmt(*temp);break;//sharp
			case 0x24:pmath=mo;pmt(*temp);break;//$
			case 0x25:pmath=mo;pmt(*temp);break;//%
			case 0x26:
					if (mathmode && !mathText){
						p("<mo>&amp;</mo>");
					}else 
						p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(*temp);break;//'
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mo;pmt(*temp);break;
			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:
			case 0x3B:pmath=mo;pmt(*temp);break;
			case 0x3C:pmath=mo;pmt(0x2039);break;//angle quotation
			case 0x3D:pmath=mo;//equal
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mo;pmt(0x203A);break;//angle quotation
			case 0x3F:pmath=mo;pmt(*temp);break;//question sign
			case 0x40:pmath=mo;pmt(*temp);break;//at sign

			case 0x5B:pmath=ld;pmt(*temp);break;//left bracket
			case 0x5C:pmath=mo;pmt(*temp);break;//left double quotation mark
			case 0x5D:pmath=rd;pmt(*temp);break;//right bracket
			case 0x5E:pmath=mo;pmt(*temp);break;//^
			case 0x5F:pmath=mo;pmt(*temp);break;//dot above

			case 0x60:pmath=mo;pmt(*temp);break;//`

			case 0x7B:pmath=mo;pmt(*temp);break;//left brace
			case 0x7C:pmath=mo;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=mo;pmt(*temp);break;//right brace
			case 0x7E:pmath=mo;pmt(*temp);break;//tilde
			case 0x7F:pmath=mo;pmt(0x222B);break;//integral sign
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"cmmib"))||(strstr(currentFont,"pxbmi"))||(strstr(currentFont,"txbmi"))||(strstr(currentFont,"zppleb7m"))){//includes px/txbmi1
		do{
			switch(*temp){
			case 0x00:pmath=mib;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mib;pmt(0x0394);break;//Delta
			case 0x02:pmath=mib;pmt(0x0398);break;//Theta
			case 0x03:pmath=mib;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mib;pmt(0x039E);break;//Xi
			case 0x05:pmath=mib;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mib;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mib;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mib;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mib;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mib;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=mib;pmt(0x03B1);break;//alpha
			case 0x0C:pmath=mib;pmt(0x03B2);break;//beta
			case 0x0D:pmath=mib;pmt(0x03B3);break;//gamma
			case 0x0E:pmath=mib;pmt(0x03B4);break;//delta
			case 0x0F:pmath=mib;pmt(0x03B5);break;//epsilon

			case 0x10:pmath=mib;pmt(0x03B6);break;//zeta
			case 0x11:pmath=mib;pmt(0x03B7);break;//eta
			case 0x12:pmath=mib;pmt(0x03B8);break;//theta
			case 0x13:pmath=mib;pmt(0x03B9);break;//iota
			case 0x14:pmath=mib;pmt(0x03BA);break;//kappa
			case 0x15:pmath=mib;pmt(0x03BB);break;//lambda
			case 0x16:pmath=mib;pmt(0x03BC);break;//mu
			case 0x17:pmath=mib;pmt(0x03BD);break;//nu
			case 0x18:pmath=mib;pmt(0x03BE);break;//xi
			case 0x19:pmath=mib;pmt(0x03C0);break;//pi
			case 0x1A:pmath=mib;pmt(0x03C1);break;//ro
			case 0x1B:pmath=mib;pmt(0x03C3);break;//sigma
			case 0x1C:pmath=mib;pmt(0x03C4);break;//tau
			case 0x1D:pmath=mib;pmt(0x03C5);break;//upsilon
			case 0x1E:pmath=mib;pmt(0x03C6);break;//phi
			case 0x1F:pmath=mib;pmt(0x03C7);break;//chi

			case 0x20:pmath=mib;pmt(0x03C8);break;//psi
			case 0x21:pmath=mib;pmt(0x03C9);break;//omega
			case 0x22:pmath=mib;pmt(0x025B);break;//latin epsilon
			case 0x23:pmath=mib;pmt(0x03D1);break;//script theta
			case 0x24:pmath=mib;pmt(0x03D6);break;//varpi
			case 0x25:pmath=mib;pmt(0x03F1);break;//varrho
			case 0x26:pmath=mib;pmt(0x03C2);break;//final sigma
			case 0x27:pmath=mib;pmt(0x03C6);break;//italic phi
			case 0x28:pmath=mob;pmt(0x21BC);break;//left harpoon up
			case 0x29:pmath=mob;pmt(0x21BD);break;//left harpoon down
			case 0x2A:pmath=mob;pmt(0x21C0);break;//right harpoon up
			case 0x2B:pmath=mob;pmt(0x21C1);break;//right harpoon down
			case 0x2C:pmath=mob;pmt(0x02BF);break;//left half ring
			case 0x2D:pmath=mob;pmt(0x02BE);break;//right half ring
			case 0x2E:pmath=mob;pmt(0x25B9);break;//right triangle small
			case 0x2F:pmath=mob;pmt(0x25C3);break;//left triangle small

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnb;pmt(*temp);break;//digits
			case 0x3A:pmath=mob;pmt(0x002E);break;//dot
			case 0x3B:pmath=mob;pmt(0x002C);break;//comma
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold\">&lt;</mo>");
				break;
			case 0x3D:pmath=mob;pmt(0x002F);break;//division
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold\">&gt;</mo>");
				break;
			case 0x3F:pmath=mob;pmt(0x25C6);break;//star operator

			case 0x40:pmath=mibi;pmt(0x2202);break;//partial diff

			case 0x5B:pmath=mob;pmt(0x266D);break;//music flat
			case 0x5C:pmath=mob;pmt(0x266E);break;//music natural
			case 0x5D:pmath=mob;pmt(0x266F);break;//music sharp
			case 0x5E:pmath=mob;pmt(0x203F);break;//character tie
			case 0x5F:pmath=mob;pmt(0x2040);break;//under tie

			case 0x60:pmath=mob;pmt(0x2113);break;//ell script

			case 0x7B:pmath=mib;pmt(0x0131);break;//imath
			case 0x7C:pmath=mib;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x7D:pmath=mobs;pmt('P');break;//pmath=mib;pmt(0x2188);break;//script capital P
			case 0x7E:pmath=mib;pmt(0x20d7);break;//combining right arrow above, cmmi is spacing though
			case 0x7F:pmath=mib;pmt(0x2040);break;//tie
			default:pmath=mib;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if ((strstr(currentFont,"pxmia"))||(strstr(currentFont,"txmia"))){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mo;pmt(0x0394);break;//Delta
			case 0x02:pmath=mo;pmt(0x0398);break;//Theta
			case 0x03:pmath=mo;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mo;pmt(0x039E);break;//Xi
			case 0x05:pmath=mo;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mo;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mo;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mo;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mo;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mo;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=mo;pmt(0x03B1);break;//alpha
			case 0x0C:pmath=mo;pmt(0x03B2);break;//beta
			case 0x0D:pmath=mo;pmt(0x03B3);break;//gamma
			case 0x0E:pmath=mo;pmt(0x03B4);break;//delta
			case 0x0F:pmath=mo;pmt(0x03B5);break;//epsilon

			case 0x10:pmath=mo;pmt(0x03B6);break;//zeta
			case 0x11:pmath=mo;pmt(0x03B7);break;//eta
			case 0x12:pmath=mo;pmt(0x03B8);break;//theta
			case 0x13:pmath=mo;pmt(0x03B9);break;//iota
			case 0x14:pmath=mo;pmt(0x03BA);break;//kappa
			case 0x15:pmath=mo;pmt(0x03BB);break;//lambda
			case 0x16:pmath=mo;pmt(0x03BC);break;//mu
			case 0x17:pmath=mo;pmt(0x03BD);break;//nu
			case 0x18:pmath=mo;pmt(0x03BE);break;//xi
			case 0x19:pmath=mo;pmt(0x03C0);break;//pi
			case 0x1A:pmath=mo;pmt(0x03C1);break;//ro
			case 0x1B:pmath=mo;pmt(0x03C3);break;//sigma
			case 0x1C:pmath=mo;pmt(0x03C4);break;//tau
			case 0x1D:pmath=mo;pmt(0x03C5);break;//upsilon
			case 0x1E:pmath=mo;pmt(0x03C6);break;//phi
			case 0x1F:pmath=mo;pmt(0x03C7);break;//chi

			case 0x20:pmath=mo;pmt(0x03C8);break;//psi
			case 0x21:pmath=mo;pmt(0x03C9);break;//omega
			case 0x22:pmath=mo;pmt(0x025B);break;//latin epsilon
			case 0x23:pmath=mo;pmt(0x03D1);break;//script theta
			case 0x24:pmath=mo;pmt(0x03D6);break;//varpi
			case 0x25:pmath=mo;pmt(0x03F1);break;//varrho
			case 0x26:pmath=mo;pmt(0x03C2);break;//final sigma
			case 0x27:pmath=mo;pmt(0x03C6);break;//italic phi
			
			//nothing here
			
			case 0x31:pmath=mi;pmt(0x0261);break;//varg, latin g
			case 0x32:pmath=mi;pmt(0x0079);break;//\yl, only in tx
			case 0x33:pmath=mi;pmt(0x0076);break;//\vl, only in tx
			case 0x34:pmath=mi;pmt(0x0077);break;//\wl, only in tx
			
			//nothing here
			
			case 0x41://pmt(0x1D504);break;//fraktur A
			case 0x42://pmt(0x1D505);break;//fraktur B
			case 0x43://pmath=mif;pmt(0x212D);break;//fraktur C
			case 0x44://pmt(0x1D507);break;//fraktur D
			case 0x45://pmt(0x1D508);break;//fraktur E
			case 0x46://pmt(0x1D509);break;//fraktur F
			case 0x47://pmt(0x1D50A);break;//fraktur G
			case 0x48://pmt(0x210C);break;//fraktur H
			case 0x49://pmt(0x2111);break;//fraktur I
			case 0x4A://pmt(0x1D50D);break;//fraktur J
			case 0x4B://pmt(0x1D50E);break;//fraktur K
			case 0x4C://pmt(0x1D50F);break;//fraktur L
			case 0x4D://pmt(0x1D510);break;//fraktur M
			case 0x4E://pmt(0x1D511);break;//fraktur N
			case 0x4F://pmt(0x1D512);break;//fraktur O

			case 0x50://pmt(0x2119);break;//pmt(0x1D513);break;//fraktur P
			case 0x51://pmt(0x211A);break;//pmt(0x1D514);break;//fraktur Q
			case 0x52://pmt(0x211C);break;//fraktur R
			case 0x53://pmt(0x1D516);break;//fraktur S
			case 0x54://pmt(0x1D517);break;//fraktur T
			case 0x55://pmt(0x1D518);break;//fraktur U
			case 0x56://pmt(0x1D519);break;//fraktur V
			case 0x57://pmt(0x1D51A);break;//fraktur W
			case 0x58://pmt(0x1D51B);break;//fraktur X
			case 0x59://pmt(0x1D51C);break;//fraktur Y
			case 0x5A:pmath=mif;pmt(*temp);break;//pmt(0x2128);break;//fraktur Z

			//nothing
						
			case 0x61://pmt(0x1D586);break;//fraktur a
			case 0x62://pmt(0x1D587);break;//fraktur b
			case 0x63://pmt(0x1D588);break;//fraktur c
			case 0x64://pmt(0x1D589);break;//fraktur d
			case 0x65://pmt(0x1D58A);break;//fraktur e
			case 0x66://pmt(0x1D58B);break;//fraktur f
			case 0x67://pmt(0x1D58C);break;//fraktur g
			case 0x68://pmt(0x1D58D);break;//fraktur h
			case 0x69://pmt(0x1D58E);break;//fraktur i
			case 0x6A://pmt(0x1D58F);break;//fraktur j
			case 0x6B://pmt(0x1D590);break;//fraktur k
			case 0x6C://pmt(0x1D591);break;//fraktur k
			case 0x6D://pmt(0x1D592);break;//fraktur m
			case 0x6E://pmt(0x1D593);break;//fraktur n
			case 0x6F://pmt(0x1D594);break;//fraktur o

			case 0x70://pmt(0x1D595);break;//fraktur p
			case 0x71://pmt(0x1D596);break;//fraktur q
			case 0x72://pmt(0x1D597);break;//fraktur r
			case 0x73://pmt(0x1D598);break;//fraktur s
			case 0x74://pmt(0x1D599);break;//fraktur t
			case 0x75://pmt(0x1D59A);break;//fraktur u
			case 0x76://pmt(0x1D59B);break;//fraktur v
			case 0x77://pmt(0x1D59C);break;//fraktur w
			case 0x78://pmt(0x1D59D);break;//fraktur x
			case 0x79://pmt(0x1D59E);break;//fraktur y
			case 0x7A:pmath=mif;pmt(*temp);break;//pmt(0x1D59F);break;//fraktur z
			//nothing
			case 0x7F:pmath=mo;pmt(0x2040);break;//tie

			//only txmia from here
			//nothing
			case 0x81:
			case 0x82:
			case 0x83:
			case 0x84:
			case 0x85:
			case 0x86:
			case 0x87:
			case 0x88:
			case 0x89:
			case 0x8A:
			case 0x8B:
			case 0x8C:
			case 0x8D:
			case 0x8E:
			case 0x8F:

			case 0x90:
			case 0x91:
			case 0x92:
			case 0x93:
			case 0x94:
			case 0x95:
			case 0x96:
			case 0x97:
			case 0x98:
			case 0x99:
			case 0x9A:pmath=mids;pmt(*temp-0x20);break;//ds A-Z
			
			//nothing
		
			case 0xAB:pmath=mids;pmt('k');break;//ds k
			//nothing
			}
			temp++;
		}while(*temp);
		return;
	}
	

		
	if ((strstr(currentFont,"cmmi"))||(strstr(currentFont,"pxmi"))||(strstr(currentFont,"txmi"))||(strstr(currentFont,"zppler7m"))){//includes pxmi1,txmi1
		do{
			switch(*temp){
			case 0x00:pmath=mi;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mi;pmt(0x0394);break;//Delta
			case 0x02:pmath=mi;pmt(0x0398);break;//Theta
			case 0x03:pmath=mi;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mi;pmt(0x039E);break;//Xi
			case 0x05:pmath=mi;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mi;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mi;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mi;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mi;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mi;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=mi;pmt(0x03B1);break;//alpha
			case 0x0C:pmath=mi;pmt(0x03B2);break;//beta
			case 0x0D:pmath=mi;pmt(0x03B3);break;//gamma
			case 0x0E:pmath=mi;pmt(0x03B4);break;//delta
			case 0x0F:pmath=mi;pmt(0x03B5);break;//epsilon

			case 0x10:pmath=mi;pmt(0x03B6);break;//zeta
			case 0x11:pmath=mi;pmt(0x03B7);break;//eta
			case 0x12:pmath=mi;pmt(0x03B8);break;//theta
			case 0x13:pmath=mi;pmt(0x03B9);break;//iota
			case 0x14:pmath=mi;pmt(0x03BA);break;//kappa
			case 0x15:pmath=mi;pmt(0x03BB);break;//lambda
			case 0x16:pmath=mi;pmt(0x03BC);break;//mu
			case 0x17:pmath=mi;pmt(0x03BD);break;//nu
			case 0x18:pmath=mi;pmt(0x03BE);break;//xi
			case 0x19:pmath=mi;pmt(0x03C0);break;//pi
			case 0x1A:pmath=mi;pmt(0x03C1);break;//ro
			case 0x1B:pmath=mi;pmt(0x03C3);break;//sigma
			case 0x1C:pmath=mi;pmt(0x03C4);break;//tau
			case 0x1D:pmath=mi;pmt(0x03C5);break;//upsilon
			case 0x1E:pmath=mi;pmt(0x03C6);break;//phi
			case 0x1F:pmath=mi;pmt(0x03C7);break;//chi

			case 0x20:pmath=mi;pmt(0x03C8);break;//psi
			case 0x21:pmath=mi;pmt(0x03C9);break;//omega
			case 0x22:pmath=mi;pmt(0x025B);break;//latin epsilon
			case 0x23:pmath=mi;pmt(0x03D1);break;//script theta
			case 0x24:pmath=mi;pmt(0x03D6);break;//varpi
			case 0x25:pmath=mi;pmt(0x03F1);break;//varrho
			case 0x26:pmath=mi;pmt(0x03C2);break;//final sigma
			case 0x27:pmath=mi;pmt(0x03C6);break;//italic phi
			case 0x28:pmath=mo;pmt(0x21BC);break;//left harpoon up
			case 0x29:pmath=mo;pmt(0x21BD);break;//left harpoon down
			case 0x2A:pmath=mo;pmt(0x21C0);break;//right harpoon up
			case 0x2B:pmath=mo;pmt(0x21C1);break;//right harpoon down
			case 0x2C:pmath=mo;pmt(0x02BF);break;//left half ring
			case 0x2D:pmath=mo;pmt(0x02BE);break;//right half ring
			case 0x2E:pmath=mo;pmt(0x25B9);break;//right triangle small
			case 0x2F:pmath=mo;pmt(0x25C3);break;//left triangle small

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;//digits
			case 0x3A:pmath=mo;pmt(0x002E);break;//dot
			case 0x3B:pmath=mo;pmt(0x002C);break;//comma
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo>&lt;</mo>");
				break;
			case 0x3D:pmath=mo;pmt(0x002F);break;//division
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo>&gt;</mo>");
				break;
			case 0x3F:pmath=mo;pmt(0x25C6);break;//star operator

			case 0x40:pmath=mo;pmt(0x2202);break;//partial diff

			case 0x5B:pmath=mo;pmt(0x266D);break;//music flat
			case 0x5C:pmath=mo;pmt(0x266E);break;//music natural
			case 0x5D:pmath=mo;pmt(0x266F);break;//music sharp
			case 0x5E:pmath=mo;pmt(0x203F);break;//character tie
			case 0x5F:pmath=mo;pmt(0x2040);break;//under tie

			case 0x60:pmath=mo;pmt(0x2113);break;//ell script

			case 0x7B:pmath=mo;pmt(0x0131);break;//imath
			case 0x7C:pmath=mo;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x7D:pmath=mos;pmt('P');break;//pmath=mi;pmt(0x2188);break;//script capital P
			case 0x7E:pmath=mo;pmt(0x20d7);break;//combining right arrow above, cmmi is spacing though
			case 0x7F:pmath=mo;pmt(0x2040);break;//tie
			default:pmath=mi;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	

	if ((strstr(currentFont,"msam"))||(strstr(currentFont,"pxsya"))||(strstr(currentFont,"txsya"))){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x22A1);break;//squared dot
			case 0x01:pmath=mo;pmt(0x229E);break;//squared plus
			case 0x02:pmath=mo;pmt(0x22A0);break;//squared times
			case 0x03:pmath=mo;pmt(0x25A1);break;//white square (d'Alembertian :()
			case 0x04:pmath=mo;pmt(0x25A0);break;//black square
			case 0x05:pmath=mo;pmt(0x00B7);break;//center dot
			case 0x06:pmath=mo;pmt(0x25CA);break;//lozenge
			case 0x07:pmath=mo;pmt(0x29EB);break;//black lozenge
			case 0x08:pmath=mo;pmt(0x21BB);break;//circlearrowright
			case 0x09:pmath=mo;pmt(0x21BA);break;//circlearrowleft
			case 0x0A:pmath=mo;pmt(0x21CC);break;//rightleftharpoons
			case 0x0B:pmath=mo;pmt(0x21CB);break;//leftrightharpoons
			case 0x0C:pmath=mo;pmt(0x229F);break;//squared minus
			case 0x0D:pmath=mo;	//Vdash
				precomposedNegative(0x22A9,0x22AE);
				break;
			case 0x0E:pmath=mo;pmt(0x22AA);break;//Vvdash
			case 0x0F:pmath=mo;	//vDash
				precomposedNegative(0x22A8,0x22AD);
				break;

			case 0x10:pmath=mo;pmt(0x21A0);break;//twoheadrightarrow
			case 0x11:pmath=mo;pmt(0x219E);break;//twoheadleftarrow
			case 0x12:pmath=mo;pmt(0x21C7);break;//left paired arrows
			case 0x13:pmath=mo;pmt(0x21C9);break;//right paired arrows
			case 0x14:pmath=mo;pmt(0x21C8);break;//up paired arrows
			case 0x15:pmath=mo;pmt(0x21CA);break;//down paired arrows
			case 0x16:pmath=mo;pmt(0x21BE);break;//up harpoon right barb
			case 0x17:pmath=mo;pmt(0x21C2);break;//down harpoon right barb
			case 0x18:pmath=mo;pmt(0x21BF);break;//up harpoon left barb
			case 0x19:pmath=mo;pmt(0x21C3);break;//down harpoon left barb
			case 0x1A:pmath=mo;pmt(0x21A3);break;//rightarrowtail
			case 0x1B:pmath=mo;pmt(0x21A2);break;//leftarrowtail
			case 0x1C:pmath=mo;pmt(0x21C6);break;//left over right arrows
			case 0x1D:pmath=mo;pmt(0x21C4);break;//right over left arrows
			case 0x1E:pmath=mo;pmt(0x21B0);break;//uparrow left tip
			case 0x1F:pmath=mo;pmt(0x21B1);break;//uparrow right tip

			case 0x20:pmath=mo;pmt(0x21DD);break;//right squiggle arrow
			case 0x21:pmath=mo;pmt(0x21AD);break;//leftright wave arrow
			case 0x22:pmath=mo;pmt(0x21AB);break;//left arrow loop
			case 0x23:pmath=mo;pmt(0x21AC);break;//right arrow loop
			case 0x24:pmath=mo;pmt(0x2257);break;//ring equal
			case 0x25:pmath=mo;pmt(0x227F);break;//succeedes equivalent
			case 0x26:pmath=mo;									//greater equivalent
								precomposedNegative(0x2273,0x2275);
								break;
			case 0x27:pmath=mo;pmt(0x2267);break;//greater over equal
			case 0x28:pmath=mo;pmt(0x22B8);break;//multimap
			case 0x29:pmath=mo;pmt(0x2234);break;//therefore
			case 0x2A:pmath=mo;pmt(0x2235);break;//because
			case 0x2B:pmath=mo;pmt(0x2251);break;//geometric equal
			case 0x2C:pmath=mo;pmt(0x225C);break;//delta equal
			case 0x2D:pmath=mo;pmt(0x227E);break;//precedes equiv
			case 0x2E:pmath=mo;									//less equiv
								precomposedNegative(0x2272,0x2274);
								break;
			case 0x2F:pmath=mo;pmt(0x2AB7);break;//precapprox

			case 0x30:pmath=mo;pmt(0x22DC);break;//equal less
			case 0x31:pmath=mo;pmt(0x22DD);break;//equal greater
			case 0x32:pmath=mo;pmt(0x22DE);break;//equal preceds
			case 0x33:pmath=mo;pmt(0x22DF);break;//equal succeedes
			case 0x34:pmath=mo;	//precedes equal
				precomposedNegative(0x227C,0x22E0);
				break;
			case 0x35:pmath=mo;pmt(0x2266);break;//less over equal
			case 0x36:pmath=mo;pmt(0x2A7D);break;//leqslant
			case 0x37:pmath=mo;									//less greater
								precomposedNegative(0x2276,0x2278);
								break;
			case 0x38:pmath=mo;pmt(0x2035);break;//back prime
			case 0x39:pmath=mo;pmt(0x2012);break;//figure dash
			case 0x3A:pmath=mo;pmt(0x2253);break;//image approx
			case 0x3B:pmath=mo;pmt(0x2252);break;//approx image
			case 0x3C:pmath=mo;	//succeeds equal
				precomposedNegative(0x227D,0x22E1);
				break;
			case 0x3D:pmath=mo;pmt(0x2267);break;//greater over equal
			case 0x3E:pmath=mo;pmt(0x2A7E);break;//greater equal slant
			case 0x3F:pmath=mo;									//greater less
								precomposedNegative(0x2277,0x2279);
								break;
			case 0x40:pmath=mo;pmt(0x228F);break;//square subset
			case 0x41:pmath=mo;pmt(0x2290);break;//square superset
			case 0x42:pmath=mo;	//normal subgroup
				precomposedNegative(0x22B2,0x22EA);
				break;
			case 0x43:pmath=mo;	//contains as normal subgroup
				precomposedNegative(0x22B3,0x22EB);
				break;
			case 0x44:pmath=mo;	//contains as normal subgroup equal
				precomposedNegative(0x22B5,0x22ED);
				break;
			case 0x45:pmath=mo;	//normal subgroup equal
				precomposedNegative(0x22B4,0x22EC);
				break;
			case 0x46:pmath=mo;pmt(0x2605);break;//bigstar
			case 0x47:pmath=mo;pmt(0x226C);break;//between
			case 0x48:pmath=mo;pmt(0x25BE);break;//black triangle down
			case 0x49:pmath=mo;pmt(0x25B8);break;//black triangle right
			case 0x4A:pmath=mo;pmt(0x25C2);break;//black triangle left
			case 0x4B:pmath=mo;pmt(0x20D7);break;//combining arrow right
			case 0x4C:pmath=mo;pmt(0x20D6);break;//combining arrow left
			case 0x4D:pmath=mo;pmt(0x25B5);break;//white triangle up
			case 0x4E:pmath=mo;pmt(0x25B4);break;//black triangle up
			case 0x4F:pmath=mo;pmt(0x25BF);break;//white triangle down

			case 0x50:pmath=mo;pmt(0x2256);break;//ring in equal to
			case 0x51:pmath=mo;pmt(0x22DA);break;//less equal greater
			case 0x52:pmath=mo;pmt(0x22DB);break;//greater equal less
			case 0x53:pmath=mo;pmt(0x2A8B);break;//less eqqual greater
			case 0x54:pmath=mo;pmt(0x2A8C);break;//greater eqqual less
			case 0x55:pmath=mo;pmt(0x00A5);break;//yuan
			case 0x56:pmath=mo;pmt(0x21DB);break;//right triple arrow
			case 0x57:pmath=mo;pmt(0x21DA);break;//left triple arrow
			case 0x58:pmath=mo;pmt(0x2713);break;//check mark
			case 0x59:pmath=mo;pmt(0x22BB);break;//xor
			case 0x5A:pmath=mo;pmt(0x22BC);break;//nand
			case 0x5B:pmath=mo;pmt(0x2306);break;//perspective
			case 0x5C:pmath=mo;pmt(0x2220);break;//angle
			case 0x5D:pmath=mo;pmt(0x2221);break;//measured angle
			case 0x5E:pmath=mo;pmt(0x2222);break;//arc angle
			case 0x5F:pmath=mo;pmt(0x221D);break;//propto

			case 0x60:pmath=mo;pmt(0x2323);break;//ssmile
			case 0x61:pmath=mo;pmt(0x2322);break;//sfrown
			case 0x62:pmath=mo;pmt(0x22D0);break;//double subset
			case 0x63:pmath=mo;pmt(0x22D1);break;//double superset
			case 0x64:pmath=mo;pmt(0x22D2);break;//double union
			case 0x65:pmath=mo;pmt(0x22D3);break;//double intersection
			case 0x66:pmath=mo;pmt(0x22CF);break;//curly logical and
			case 0x67:pmath=mo;pmt(0x22CE);break;//curly logical or
			case 0x68:pmath=mo;pmt(0x22CB);break;//left semidirect product
			case 0x69:pmath=mo;pmt(0x22CC);break;//right semidirect product
			case 0x6A:pmath=mo;pmt(0x2AC5);break;//subseteqq
			case 0x6B:pmath=mo;pmt(0x2AC6);break;//supseteqq
			case 0x6C:pmath=mo;pmt(0x224F);break;//difference
			case 0x6D:pmath=mo;pmt(0x224E);break;//geometrical equivalent
			case 0x6E:pmath=mo;pmt(0x22D8);break;//very much less
			case 0x6F:pmath=mo;pmt(0x22D9);break;//very much greater

			case 0x70:pmath=mo;pmt(0x231C);break;//top left corner
			case 0x71:pmath=mo;pmt(0x231D);break;//top right corner
			case 0x72:pmath=mo;pmt(0x24C7);break;//circle R
			case 0x73:pmath=mo;pmt(0x24C8);break;//circle S
			case 0x74:pmath=mo;pmt(0x22D4);break;//pitchfork
			case 0x75:pmath=mo;pmt(0x2214);break;//dot plus
			case 0x76:pmath=mo;pmt(0x223D);break;//reversed tilde
			case 0x77:pmath=mo;pmt(0x22CD);break;//reversed tilde equal
			case 0x78:pmath=mo;pmt(0x231E);break;//bottom left corner
			case 0x79:pmath=mo;pmt(0x231F);break;//bottom right corner
			case 0x7A:pmath=mo;pmt(0x2720);break;//maltese cross
			case 0x7B:pmath=mo;pmt(0x2201);break;//complement
			case 0x7C:pmath=mo;pmt(0x22BA);break;//intercal
			case 0x7D:pmath=mo;pmt(0x229A);break;//circled ring
			case 0x7E:pmath=mo;pmt(0x229B);break;//circled asterisk
			case 0x7F:pmath=mo;pmt(0x229D);break;//circled dash

			}
			temp++;
		}while(*temp) ;
		return;
	}
	
	if ((strstr(currentFont,"pxbsya"))||(strstr(currentFont,"txbsya"))){
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x22A1);break;//squared dot
			case 0x01:pmath=mob;pmt(0x229E);break;//squared plus
			case 0x02:pmath=mob;pmt(0x22A0);break;//squared times
			case 0x03:pmath=mob;pmt(0x25A1);break;//white square (d'Alembertian :()
			case 0x04:pmath=mob;pmt(0x25A0);break;//black square
			case 0x05:pmath=mob;pmt(0x00B7);break;//center dot
			case 0x06:pmath=mob;pmt(0x25CA);break;//lozenge
			case 0x07:pmath=mob;pmt(0x29EB);break;//black lozenge
			case 0x08:pmath=mob;pmt(0x21BB);break;//circlearrowright
			case 0x09:pmath=mob;pmt(0x21BA);break;//circlearrowleft
			case 0x0A:pmath=mob;pmt(0x21CC);break;//rightleftharpoons
			case 0x0B:pmath=mob;pmt(0x21CB);break;//leftrightharpoons
			case 0x0C:pmath=mob;pmt(0x229F);break;//squared minus
			case 0x0D:pmath=mob;	//Vdash
				precomposedNegative(0x22A9,0x22AE);
				break;
			case 0x0E:pmath=mob;pmt(0x22AA);break;//Vvdash
			case 0x0F:pmath=mob;	//vDash
				precomposedNegative(0x22A8,0x22AD);
				break;

			case 0x10:pmath=mob;pmt(0x21A0);break;//twoheadrightarrow
			case 0x11:pmath=mob;pmt(0x219E);break;//twoheadleftarrow
			case 0x12:pmath=mob;pmt(0x21C7);break;//left paired arrows
			case 0x13:pmath=mob;pmt(0x21C9);break;//right paired arrows
			case 0x14:pmath=mob;pmt(0x21C8);break;//up paired arrows
			case 0x15:pmath=mob;pmt(0x21CA);break;//down paired arrows
			case 0x16:pmath=mob;pmt(0x21BE);break;//up harpoon right barb
			case 0x17:pmath=mob;pmt(0x21C2);break;//down harpoon right barb
			case 0x18:pmath=mob;pmt(0x21BF);break;//up harpoon left barb
			case 0x19:pmath=mob;pmt(0x21C3);break;//down harpoon left barb
			case 0x1A:pmath=mob;pmt(0x21A3);break;//rightarrowtail
			case 0x1B:pmath=mob;pmt(0x21A2);break;//leftarrowtail
			case 0x1C:pmath=mob;pmt(0x21C6);break;//left over right arrows
			case 0x1D:pmath=mob;pmt(0x21C4);break;//right over left arrows
			case 0x1E:pmath=mob;pmt(0x21B0);break;//uparrow left tip
			case 0x1F:pmath=mob;pmt(0x21B1);break;//uparrow right tip

			case 0x20:pmath=mob;pmt(0x21DD);break;//right squiggle arrow
			case 0x21:pmath=mob;pmt(0x21AD);break;//leftright wave arrow
			case 0x22:pmath=mob;pmt(0x21AB);break;//left arrow loop
			case 0x23:pmath=mob;pmt(0x21AC);break;//right arrow loop
			case 0x24:pmath=mob;pmt(0x2257);break;//ring equal
			case 0x25:pmath=mob;pmt(0x227F);break;//succeedes equivalent
			case 0x26:pmath=mob;									//greater equivalent
								precomposedNegative(0x2273,0x2275);
								break;
			case 0x27:pmath=mob;pmt(0x2267);break;//greater over equal
			case 0x28:pmath=mob;pmt(0x22B8);break;//multimap
			case 0x29:pmath=mob;pmt(0x2234);break;//therefore
			case 0x2A:pmath=mob;pmt(0x2235);break;//because
			case 0x2B:pmath=mob;pmt(0x2251);break;//geometric equal
			case 0x2C:pmath=mob;pmt(0x225C);break;//delta equal
			case 0x2D:pmath=mob;pmt(0x227E);break;//precedes equiv
			case 0x2E:pmath=mob;									//less equiv
								precomposedNegative(0x2272,0x2274);
								break;
			case 0x2F:pmath=mob;pmt(0x2AB7);break;//precapprox

			case 0x30:pmath=mob;pmt(0x22DC);break;//equal less
			case 0x31:pmath=mob;pmt(0x22DD);break;//equal greater
			case 0x32:pmath=mob;pmt(0x22DE);break;//equal preceds
			case 0x33:pmath=mob;pmt(0x22DF);break;//equal succeedes
			case 0x34:pmath=mob;	//precedes equal
				precomposedNegative(0x227C,0x22E0);
				break;
			case 0x35:pmath=mob;pmt(0x2266);break;//less over equal
			case 0x36:pmath=mob;pmt(0x2A7D);break;//leqslant
			case 0x37:pmath=mob;									//less greater
								precomposedNegative(0x2276,0x2278);
								break;
			case 0x38:pmath=mob;pmt(0x2035);break;//back prime
			case 0x39:pmath=mob;pmt(0x2012);break;//figure dash
			case 0x3A:pmath=mob;pmt(0x2253);break;//image approx
			case 0x3B:pmath=mob;pmt(0x2252);break;//approx image
			case 0x3C:pmath=mob;	//succeeds equal
				precomposedNegative(0x227D,0x22E1);
				break;
			case 0x3D:pmath=mob;pmt(0x2267);break;//greater over equal
			case 0x3E:pmath=mob;pmt(0x2A7E);break;//greater equal slant
			case 0x3F:pmath=mob;									//greater less
								precomposedNegative(0x2277,0x2279);
								break;
								
			case 0x40:pmath=mob;pmt(0x228F);break;//square subset
			case 0x41:pmath=mob;pmt(0x2290);break;//square superset
			case 0x42:pmath=mob;	//normal subgroup
				precomposedNegative(0x22B2,0x22EA);
				break;
			case 0x43:pmath=mob;	//contains as normal subgroup
				precomposedNegative(0x22B3,0x22EB);
				break;
			case 0x44:pmath=mob;	//contains as normal subgroup equal
				precomposedNegative(0x22B5,0x22ED);
				break;
			case 0x45:pmath=mob;	//normal subgroup equal
				precomposedNegative(0x22B4,0x22EC);
				break;
			case 0x46:pmath=mob;pmt(0x2605);break;//bigstar
			case 0x47:pmath=mob;pmt(0x226C);break;//between
			case 0x48:pmath=mob;pmt(0x25BE);break;//black triangle down
			case 0x49:pmath=mob;pmt(0x25B8);break;//black triangle right
			case 0x4A:pmath=mob;pmt(0x25C2);break;//black triangle left
			case 0x4B:pmath=mob;pmt(0x20D7);break;//combining arrow right
			case 0x4C:pmath=mob;pmt(0x20D6);break;//combining arrow left
			case 0x4D:pmath=mob;pmt(0x25B5);break;//white triangle up
			case 0x4E:pmath=mob;pmt(0x25B4);break;//black triangle up
			case 0x4F:pmath=mob;pmt(0x25BF);break;//white triangle down

			case 0x50:pmath=mob;pmt(0x2256);break;//ring in equal to
			case 0x51:pmath=mob;pmt(0x22DA);break;//less equal greater
			case 0x52:pmath=mob;pmt(0x22DB);break;//greater equal less
			case 0x53:pmath=mob;pmt(0x2A8B);break;//less eqqual greater
			case 0x54:pmath=mob;pmt(0x2A8C);break;//greater eqqual less
			case 0x55:pmath=mob;pmt(0x00A5);break;//yuan
			case 0x56:pmath=mob;pmt(0x21DB);break;//right triple arrow
			case 0x57:pmath=mob;pmt(0x21DA);break;//left triple arrow
			case 0x58:pmath=mob;pmt(0x2713);break;//check mark
			case 0x59:pmath=mob;pmt(0x22BB);break;//xor
			case 0x5A:pmath=mob;pmt(0x22BC);break;//nand
			case 0x5B:pmath=mob;pmt(0x2306);break;//perspective
			case 0x5C:pmath=mob;pmt(0x2220);break;//angle
			case 0x5D:pmath=mob;pmt(0x2221);break;//measured angle
			case 0x5E:pmath=mob;pmt(0x2222);break;//arc angle
			case 0x5F:pmath=mob;pmt(0x221D);break;//propto

			case 0x60:pmath=mob;pmt(0x2323);break;//ssmile
			case 0x61:pmath=mob;pmt(0x2322);break;//sfrown
			case 0x62:pmath=mob;pmt(0x22D0);break;//double subset
			case 0x63:pmath=mob;pmt(0x22D1);break;//double superset
			case 0x64:pmath=mob;pmt(0x22D2);break;//double union
			case 0x65:pmath=mob;pmt(0x22D3);break;//double intersection
			case 0x66:pmath=mob;pmt(0x22CF);break;//curly logical and
			case 0x67:pmath=mob;pmt(0x22CE);break;//curly logical or
			case 0x68:pmath=mob;pmt(0x22CB);break;//left semidirect product
			case 0x69:pmath=mob;pmt(0x22CC);break;//right semidirect product
			case 0x6A:pmath=mob;pmt(0x2AC5);break;//subseteqq
			case 0x6B:pmath=mob;pmt(0x2AC6);break;//supseteqq
			case 0x6C:pmath=mob;pmt(0x224F);break;//difference
			case 0x6D:pmath=mob;pmt(0x224E);break;//geometrical equivalent
			case 0x6E:pmath=mob;pmt(0x22D8);break;//very much less
			case 0x6F:pmath=mob;pmt(0x22D9);break;//very much greater

			case 0x70:pmath=mob;pmt(0x231C);break;//top left corner
			case 0x71:pmath=mob;pmt(0x231D);break;//top right corner
			case 0x72:pmath=mob;pmt(0x24C7);break;//circle R
			case 0x73:pmath=mob;pmt(0x24C8);break;//circle S
			case 0x74:pmath=mob;pmt(0x22D4);break;//pitchfork
			case 0x75:pmath=mob;pmt(0x2214);break;//dot plus
			case 0x76:pmath=mob;pmt(0x223D);break;//reversed tilde
			case 0x77:pmath=mob;pmt(0x22CD);break;//reversed tilde equal
			case 0x78:pmath=mob;pmt(0x231E);break;//bottom left corner
			case 0x79:pmath=mob;pmt(0x231F);break;//bottom right corner
			case 0x7A:pmath=mob;pmt(0x2720);break;//maltese cross
			case 0x7B:pmath=mob;pmt(0x2201);break;//complement
			case 0x7C:pmath=mob;pmt(0x22BA);break;//intercal
			case 0x7D:pmath=mob;pmt(0x229A);break;//circled ring
			case 0x7E:pmath=mob;pmt(0x229B);break;//circled asterisk
			case 0x7F:pmath=mob;pmt(0x229D);break;//circled dash

			}
			temp++;
		}while(*temp) ;
		return;
	}
	
	
	
	if ((strstr(currentFont,"msbm"))||(strstr(currentFont,"pxsyb"))||(strstr(currentFont,"txsyb"))){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x2268);break;//less not equal
			case 0x01:pmath=mo;pmt(0x2269);break;//greater not equal
			case 0x02:pmath=mo;pmt(0x2270);break;//not less not equal
			case 0x03:pmath=mo;pmt(0x2271);break;//not greater not equal
			case 0x04:pmath=mo;pmt(0x226E);break;//not less
			case 0x05:pmath=mo;pmt(0x226F);break;//not greater
			case 0x06:pmath=mo;pmt(0x2280);break;//not precede
			case 0x07:pmath=mo;pmt(0x2281);break;//not succceed
			case 0x08:pmath=mo;pmt(0x2268);break;//less than not equal
			case 0x09:pmath=mo;pmt(0x2269);break;//greater than not equal
			case 0x0A:pmath=mo;pmt(0x2270);break;//not less not equal
			case 0x0B:pmath=mo;pmt(0x2271);break;//not greater not equal
			case 0x0C:pmath=mo;pmt(0x2A87);break;//less not equal
			case 0x0D:pmath=mo;pmt(0x2A88);break;//greater not equal
			case 0x0E:p("<mo>");p(ul2utf8(0x2AAF));p(ul2utf8(0x0338));p("</mo>");break;//not precedes not equal
			case 0x0F:p("<mo>");p(ul2utf8(0x2AB0));p(ul2utf8(0x0338));p("</mo>");break;//not succeeds not equal

			case 0x10:pmath=mo;pmt(0x22E7);break;//precedes not equivalent
			case 0x11:pmath=mo;pmt(0x22E8);break;//succeeds not equivalent
			case 0x12:pmath=mo;pmt(0x22E6);break;//less not equivalent
			case 0x13:pmath=mo;pmt(0x22E7);break;//greater not equivalent
			case 0x14:p("<mo>");p(ul2utf8(0x2266));p(ul2utf8(0x0338));p("</mo>");break;//not less not equal
			case 0x15:p("<mo>");p(ul2utf8(0x2267));p(ul2utf8(0x0338));p("</mo>");break;//not greater not equal
			case 0x16:pmath=mo;pmt(0x2AB5);break;//precedes not equal
			case 0x17:pmath=mo;pmt(0x2AB6);break;//succeedes not equal
			case 0x18:pmath=mo;pmt(0x2AB9);break;//precedes not approx
			case 0x19:pmath=mo;pmt(0x2ABA);break;//succeeds not approx
			case 0x1A:pmath=mo;pmt(0x2A89);break;//less not approx
			case 0x1B:pmath=mo;pmt(0x2A8A);break;//greater not approx
			case 0x1C:pmath=mo;pmt(0x2241);break;//not tilde
			case 0x1D:pmath=mo;pmt(0x2247);break;//not approximate not equal
			case 0x1E:pmath=mo;pmt(0x2571);break;//diagup
			case 0x1F:pmath=mo;pmt(0x2572);break;//diagdown

			case 0x20:p("<mo>");p(ul2utf8(0x228A));p(ul2utf8(0xFE00));p("</mo>");break;//var subset not equal
			case 0x21:p("<mo>");p(ul2utf8(0x228B));p(ul2utf8(0xFE00));p("</mo>");break;//var supset not equal
			case 0x22:p("<mo>");p(ul2utf8(0x2AC5));p(ul2utf8(0x0338));p("</mo>");break;//not subset not eqqual
			case 0x23:p("<mo>");p(ul2utf8(0x2AC6));p(ul2utf8(0x0338));p("</mo>");break;//not superset not eqqual
			case 0x24:pmath=mo;pmt(0x2ACB);break;//subset not eqqual
			case 0x25:pmath=mo;pmt(0x2ACC);break;//superset not eqqual
			case 0x26:p("<mo>");p(ul2utf8(0x2ACB));p(ul2utf8(0xFE00));p("/<mo>");break;//var subset not eqqual
			case 0x27:p("<mo>");p(ul2utf8(0x2ACC));p(ul2utf8(0xFE00));p("/<mo>");break;//var superset not eqqual
			case 0x28:pmath=mo;pmt(0x228A);break;//subset not equal
			case 0x29:pmath=mo;pmt(0x228B);break;//superset not equal
			case 0x2A:pmath=mo;pmt(0x2288);break;//not subset not equal
			case 0x2B:pmath=mo;pmt(0x2289);break;//not superset not equal
			case 0x2C:pmath=mo;pmt(0x2226);break;//not parallel
			case 0x2D:pmath=mo;pmt(0x2224);break;//not divide
			case 0x2E:pmath=mo;pmt(0x2224);break;//short not divide
			case 0x2F:pmath=mo;pmt(0x2226);break;//short not parallel

			case 0x30:pmath=mo;pmt(0x22AC);break;//does not prove
			case 0x31:pmath=mo;pmt(0x22AE);break;//does not force
			case 0x32:pmath=mo;pmt(0x22AD);break;//not true
			case 0x33:pmath=mo;pmt(0x22AF);break;//nVDash
			case 0x34:pmath=mo;pmt(0x22ED);break;//not triangle right not equal
			case 0x35:pmath=mo;pmt(0x22EC);break;//not triangle left not equal
			case 0x36:pmath=mo;pmt(0x22EA);break;//not triangle left
			case 0x37:pmath=mo;pmt(0x22EC);break;//not triangle right
			case 0x38:pmath=mo;pmt(0x219A);break;//not left arrow
			case 0x39:pmath=mo;pmt(0x219B);break;//not right arrow
			case 0x3A:pmath=mo;pmt(0x21CD);break;//not left double arrow
			case 0x3B:pmath=mo;pmt(0x21CF);break;//not right double arrow
			case 0x3C:pmath=mo;pmt(0x21CE);break;//not left right double arrow
			case 0x3D:pmath=mo;pmt(0x21AE);break;//not left right arrow
			case 0x3E:pmath=mo;pmt(0x22C7);break;//division times
			case 0x3F:pmath=mo;pmt(0x2205);break;//var empty set

			case 0x40:pmath=mo;pmt(0x2204);break;//not exist
			case 0x41:
			case 0x42:
			case 0x43:
			case 0x44:
			case 0x45:
			case 0x46:
			case 0x47:
			case 0x48:
			case 0x49:
			case 0x4A:
			case 0x4B:
			case 0x4C:
			case 0x4D:
			case 0x4E:
			case 0x4F:

			case 0x50:
			case 0x51:
			case 0x52:
			case 0x53:
			case 0x54:
			case 0x55:
			case 0x56:
			case 0x57:
			case 0x58:
			case 0x59:
			case 0x5A:pmath=mods;break;//double A-Z
			case 0x5B:pmath=mo;pmt('^');break;//
			case 0x5C:pmath=mo;pmt('^');break;//
			case 0x5D:pmath=mo;pmt('~');break;//
			case 0x5E:pmath=mo;pmt('~');break;//
			
			//nothing
			
			case 0x60:pmath=mo;pmt(0x2132);break;//turned capital F
			case 0x61:pmath=mo;pmt(0x2141);break;//turned sans-serif capital G

			case 0x66:pmath=mo;pmt(0x2127);break;//mho
			case 0x67:pmath=mo;pmt(0x00D0);break;//eth
			case 0x68:pmath=mo;pmt(0x2242);break;//minus tilde
			case 0x69:pmath=mo;pmt(0x2136);break;//beth
			case 0x6A:pmath=mo;pmt(0x2137);break;//gimel
			case 0x6B:pmath=mo;pmt(0x2138);break;//daleth
			case 0x6C:pmath=mo;pmt(0x22D6);break;//less dot
			case 0x6D:pmath=mo;pmt(0x22D7);break;//greater dot
			case 0x6E:pmath=mo;pmt(0x22C9);break;//left normal factor semidirect product
			case 0x6F:pmath=mo;pmt(0x2216);break;//right normal factor semidirect product

			case 0x70:pmath=mo;pmt(0x2223);break;//divides
			case 0x71:pmath=mo;pmt(0x2225);break;//parallel to
			case 0x72:pmath=mo;pmt(0x005C);break;//integer divide
			case 0x73:pmath=mo;								//similar
				precomposedNegative(0x223C, 0x2241);
				break;
			case 0x74:pmath=mo;									//thickapprox
				precomposedNegative(0x2248, 0x2249);
				break;
			case 0x75:pmath=mo;pmt(0x224A);break;//approxeq
			case 0x76:pmath=mo;pmt(0x2AB8);break;//succapprox
			case 0x77:pmath=mo;pmt(0x2AB7);break;//precapprox
			case 0x78:pmath=mo;pmt(0x21B6);break;//curve arrow left
			case 0x79:pmath=mo;pmt(0x21B7);break;//curve arrow right
			case 0x7A:pmath=mo;pmt(0x03DD);break;//digamma
			case 0x7B:pmath=mo;pmt(0x03F0);break;//varkappa
			case 0x7C:pmath=mids;pmt(0x006b);break;//bbbk
			case 0x7D:pmath=mo;pmt(0x210F);break;//hslash
			case 0x7E:pmath=mo;pmt(0x210F);break;//hbar
			case 0x7F:pmath=mo;pmt(0x03F6);break;//backepsilon

			}
			temp++;
		}while(*temp) ;
		return;
	}

	if ((strstr(currentFont,"pxbsyb"))||(strstr(currentFont,"txbsyb"))){
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x2268);break;//less not equal
			case 0x01:pmath=mob;pmt(0x2269);break;//greater not equal
			case 0x02:pmath=mob;pmt(0x2270);break;//not less not equal
			case 0x03:pmath=mob;pmt(0x2271);break;//not greater not equal
			case 0x04:pmath=mob;pmt(0x226E);break;//not less
			case 0x05:pmath=mob;pmt(0x226F);break;//not greater
			case 0x06:pmath=mob;pmt(0x2280);break;//not precede
			case 0x07:pmath=mob;pmt(0x2281);break;//not succceed
			case 0x08:pmath=mob;pmt(0x2268);break;//less than not equal
			case 0x09:pmath=mob;pmt(0x2269);break;//greater than not equal
			case 0x0A:pmath=mob;pmt(0x2270);break;//not less not equal
			case 0x0B:pmath=mob;pmt(0x2271);break;//not greater not equal
			case 0x0C:pmath=mob;pmt(0x2A87);break;//less not equal
			case 0x0D:pmath=mob;pmt(0x2A88);break;//greater not equal
			case 0x0E:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AAF));p(ul2utf8(0x0338));p("</mo>");break;//not precedes not equal
			case 0x0F:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AB0));p(ul2utf8(0x0338));p("</mo>");break;//not succeeds not equal

			case 0x10:pmath=mob;pmt(0x22E7);break;//precedes not equivalent
			case 0x11:pmath=mob;pmt(0x22E8);break;//succeeds not equivalent
			case 0x12:pmath=mob;pmt(0x22E6);break;//less not equivalent
			case 0x13:pmath=mob;pmt(0x22E7);break;//greater not equivalent
			case 0x14:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2266));p(ul2utf8(0x0338));p("</mo>");break;//not less not equal
			case 0x15:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2267));p(ul2utf8(0x0338));p("</mo>");break;//not greater not equal
			case 0x16:pmath=mob;pmt(0x2AB5);break;//precedes not equal
			case 0x17:pmath=mob;pmt(0x2AB6);break;//succeedes not equal
			case 0x18:pmath=mob;pmt(0x2AB9);break;//precedes not approx
			case 0x19:pmath=mob;pmt(0x2ABA);break;//succeeds not approx
			case 0x1A:pmath=mob;pmt(0x2A89);break;//less not approx
			case 0x1B:pmath=mob;pmt(0x2A8A);break;//greater not approx
			case 0x1C:pmath=mob;pmt(0x2241);break;//not tilde
			case 0x1D:pmath=mob;pmt(0x2247);break;//not approximate not equal
			case 0x1E:pmath=mob;pmt(0x2571);break;//diagup
			case 0x1F:pmath=mob;pmt(0x2572);break;//diagdown

			case 0x20:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x228A));p(ul2utf8(0xFE00));p("</mo>");break;//var subset not equal
			case 0x21:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x228B));p(ul2utf8(0xFE00));p("</mo>");break;//var supset not equal
			case 0x22:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AC5));p(ul2utf8(0x0338));p("</mo>");break;//not subset not eqqual
			case 0x23:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AC6));p(ul2utf8(0x0338));p("</mo>");break;//not superset not eqqual
			case 0x24:pmath=mob;pmt(0x2ACB);break;//subset not eqqual
			case 0x25:pmath=mob;pmt(0x2ACC);break;//superset not eqqual
			case 0x26:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2ACB));p(ul2utf8(0xFE00));p("/<mo>");break;//var subset not eqqual
			case 0x27:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2ACC));p(ul2utf8(0xFE00));p("/<mo>");break;//var superset not eqqual
			case 0x28:pmath=mob;pmt(0x228A);break;//subset not equal
			case 0x29:pmath=mob;pmt(0x228B);break;//superset not equal
			case 0x2A:pmath=mob;pmt(0x2288);break;//not subset not equal
			case 0x2B:pmath=mob;pmt(0x2289);break;//not superset not equal
			case 0x2C:pmath=mob;pmt(0x2226);break;//not parallel
			case 0x2D:pmath=mob;pmt(0x2224);break;//not divide
			case 0x2E:pmath=mob;pmt(0x2224);break;//short not divide
			case 0x2F:pmath=mob;pmt(0x2226);break;//short not parallel

			case 0x30:pmath=mob;pmt(0x22AC);break;//does not prove
			case 0x31:pmath=mob;pmt(0x22AE);break;//does not force
			case 0x32:pmath=mob;pmt(0x22AD);break;//not true
			case 0x33:pmath=mob;pmt(0x22AF);break;//nVDash
			case 0x34:pmath=mob;pmt(0x22ED);break;//not triangle right not equal
			case 0x35:pmath=mob;pmt(0x22EC);break;//not triangle left not equal
			case 0x36:pmath=mob;pmt(0x22EA);break;//not triangle left
			case 0x37:pmath=mob;pmt(0x22EC);break;//not triangle right
			case 0x38:pmath=mob;pmt(0x219A);break;//not left arrow
			case 0x39:pmath=mob;pmt(0x219B);break;//not right arrow
			case 0x3A:pmath=mob;pmt(0x21CD);break;//not left double arrow
			case 0x3B:pmath=mob;pmt(0x21CF);break;//not right double arrow
			case 0x3C:pmath=mob;pmt(0x21CE);break;//not left right double arrow
			case 0x3D:pmath=mob;pmt(0x21AE);break;//not left right arrow
			case 0x3E:pmath=mob;pmt(0x22C7);break;//division times
			case 0x3F:pmath=mob;pmt(0x2205);break;//var empty set

			case 0x40:pmath=mob;pmt(0x2204);break;//not exist
			case 0x41:pmath=mids;pmt(*temp);break;//pmt(0x1D538);break;//double A
			case 0x42:pmath=mids;pmt(*temp);break;//pmt(0x1D538);break;//double B
			case 0x43:pmath=mi;pmt(0x2102);break;//double C
			case 0x44:pmath=mids;pmt(*temp);break;//pmt(0x1D53B);break;//double D
			case 0x45:pmath=mids;pmt(*temp);break;//pmt(0x1D53C);break;//double E
			case 0x46:pmath=mids;pmt(*temp);break;//pmt(0x1D53D);break;//double F
			case 0x47:pmath=mids;pmt(*temp);break;//pmt(0x1D53E);break;//double G
			case 0x48:pmath=mi;pmt(0x210D);break;//double H
			case 0x49:pmath=mids;pmt(*temp);break;//pmt(0x1D540);break;//double I
			case 0x4A:pmath=mids;pmt(*temp);break;//pmt(0x1D541);break;//double J
			case 0x4B:pmath=mids;pmt(*temp);break;//pmt(0x1D542);break;//double K
			case 0x4C:pmath=mids;pmt(*temp);break;//pmt(0x1D543);break;//double L
			case 0x4D:pmath=mids;pmt(*temp);break;//pmt(0x1D544);break;//double M
			case 0x4E:pmath=mi;pmt(0x2115);break;//double N
			case 0x4F:pmath=mids;pmt(*temp);break;//pmt(0x1D546);break;//double O

			case 0x50:pmath=mi;pmt(0x2119);break;//double P
			case 0x51:pmath=mi;pmt(0x211A);break;//double Q
			case 0x52:pmath=mi;pmt(0x211D);break;//double R
			case 0x53:pmath=mids;pmt(*temp);break;//pmt(0x1D54A);break;//double S
			case 0x54:pmath=mids;pmt(*temp);break;//pmt(0x1D54B);break;//double T
			case 0x55:pmath=mids;pmt(*temp);break;//pmt(0x1D54C);break;//double U
			case 0x56:pmath=mids;pmt(*temp);break;//pmt(0x1D54D);break;//double V
			case 0x57:pmath=mids;pmt(*temp);break;//pmt(0x1D54E);break;//double W
			case 0x58:pmath=mids;pmt(*temp);break;//pmt(0x1D54F);break;//double X
			case 0x59:pmath=mids;pmt(*temp);break;//pmt(0x1D550);break;//double Y
			case 0x5A:pmath=mi;pmt(0x2124);break;//double Z
			case 0x5B:pmath=mob;pmt('^');break;//double Z
			case 0x5C:pmath=mob;pmt('^');break;//double Z
			case 0x5D:pmath=mob;pmt('~');break;//double Z
			case 0x5E:pmath=mob;pmt('~');break;//double Z
			//missing stuff 0x5F

			//missing stuff 0x60 - 0x65
			case 0x66:pmath=mob;pmt(0x2127);break;//mho
			case 0x67:pmath=mob;pmt(0x00D0);break;//eth
			case 0x68:pmath=mob;pmt(0x2242);break;//minus tilde
			case 0x69:pmath=mob;pmt(0x2136);break;//beth
			case 0x6A:pmath=mob;pmt(0x2137);break;//gimel
			case 0x6B:pmath=mob;pmt(0x2138);break;//daleth
			case 0x6C:pmath=mob;pmt(0x22D6);break;//less dot
			case 0x6D:pmath=mob;pmt(0x22D7);break;//greater dot
			case 0x6E:pmath=mob;pmt(0x22C9);break;//up down double arrow
			case 0x6F:pmath=mob;pmt(0x2216);break;//set minus

			case 0x70:pmath=mob;pmt(0x2223);break;//shortmid
			case 0x71:pmath=mob;pmt(0x2225);break;//shortparallel
			case 0x72:pmath=mob;pmt(0x2216);break;//smallsetminus
			case 0x73:pmath=mob;								//thicksim
				precomposedNegative(0x223C, 0x2241);
				break;
			case 0x74:pmath=mob;									//thickapprox
				precomposedNegative(0x2248, 0x2249);
				break;
			case 0x75:pmath=mob;pmt(0x224A);break;//approxeq
			case 0x76:pmath=mob;pmt(0x2AB8);break;//succapprox
			case 0x77:pmath=mob;pmt(0x2AB7);break;//precapprox
			case 0x78:pmath=mob;pmt(0x21B6);break;//curve arrow left
			case 0x79:pmath=mob;pmt(0x21B7);break;//curve arrow right
			case 0x7A:pmath=mob;pmt(0x03DD);break;//digamma
			case 0x7B:pmath=mob;pmt(0x03F0);break;//varkappa
			case 0x7C:pmath=mids;pmt(0x006b);break;//bbbk
			case 0x7D:pmath=mob;pmt(0x210F);break;//hslash
			case 0x7E:pmath=mob;pmt(0x210F);break;//hbar
			case 0x7F:pmath=mob;pmt(0x03F6);break;//backepsilon

			default:pmath=mi;pmt(*temp);
			}
			temp++;
		}while(*temp) ;
		return;
	}
		
	
	if ((strstr(currentFont,"pxsyc"))||(strstr(currentFont,"txsyc"))){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x22A3);break;//left tack
			case 0x01:pmath=mo;pmt(0x22A7);break;//models
			case 0x02:pmath=mo;pmt(0x2AE4);break;//vertical bar left double turnstile
			case 0x03:pmath=mo;pmt(0x22A9);break;//forces
			case 0x04:pmath=mo;pmt(0x2AE3);break;//double vertical bar left turnstile
			case 0x05:pmath=mo;pmt(0x22AB);break;//double vertical bar right double turnstile
			case 0x06:pmath=mo;pmt(0x2AE5);break;//double vertical bar left double turnstile
			case 0x07:pmath=mo;pmt(0x25CB);break;//white circle
			case 0x08:pmath=mo;pmt(0x25CF);break;//black circle
			case 0x09:pmath=mo;pmt(0x2AFD);break;//double solidus, varparallel
			case 0x0A:pmath=mo;pmt(0x244A);break;//OCR double backslash, nvarparallelinv
			case 0x0B:p("<mo>");p(ul2utf8(0x2AFD));p(ul2utf8(0x0338));p("</mo>");break;//negated double solidus, nvarparallel
			case 0x0C:p("<mo>");p(ul2utf8(0x244A));p(ul2utf8(0x0338));p("</mo>");break;//negated OCR double backslash, nvarparallelinv
			case 0x0D:p("<mo>");p(":");p(ul2utf8(0x2248));p("</mo>");break;//XXX,colon almost equal,\colonapprox
			case 0x0E:p("<mo>");p(":");p(ul2utf8(0x223C));p("</mo>");break;//XXX,colon similar, \colonsim
			case 0x0F:p("<mo>");p("::");p(ul2utf8(0x2248));p("</mo>");break;//XXX,double colon almost equal,\Colonapprox

			case 0x10:p("<mo>");p("::");p(ul2utf8(0x223C));p("</mo>");break;//double colon similar,\Colonsim
			case 0x11:pmath=mo;pmt(0x2250);break;//approaches the limit,\doteq
			case 0x12:pmath=mo;pmt(0x27DC);break;//left multimap
			case 0x13:pmath=mo;pmt(0x29DF);break;//double-ended multimap
			case 0x14:p("<mo>");p(ul2utf8(0x2212));p(ul2utf8(0x2022));p("</mo>");break;//XXX=minus+bullet,\multimapdot
			case 0x15:p("<mo>");p(ul2utf8(0x2022));p(ul2utf8(0x2212));p("</mo>");break;//XXX,\multimapdotinv
			case 0x16:p("<mo>");p(ul2utf8(0x2022));p(ul2utf8(0x2212));p(ul2utf8(0x2022));p("</mo>");break;//XXX,\multimapdotboth
			case 0x17:pmath=mo;pmt(0x22B6);break;//original of
			case 0x18:pmath=mo;pmt(0x22B7);break; //image of
			case 0x19:pmath=mo;pmt(0x22AB);break;//double vertical bar double turnstile right
			case 0x1A:p("<mo>");p("|");p(ul2utf8(0x22AB));p("</mo>");break; //XXX, triple vbar double turnstile right
			case 0x1B:pmath=mo;pmt(0x2245);break; //\cong
			case 0x1C:pmath=mo;pmt(0x2AAF);break; //\preceqq
			case 0x1D:pmath=mo;pmt(0x2AB0);break; //\succeqq
			case 0x1E:p("<mo>");p(ul2utf8(0x227E));p(ul2utf8(0x0338));p("</mo>");break; //\nprecsim
			case 0x1F:p("<mo>");p(ul2utf8(0x227F));p(ul2utf8(0x0338));p("</mo>");break; //\nsuccsim

			case 0x20:pmath=mo;pmt(0x2274);break;//\nlesssim
			case 0x21:pmath=mo;pmt(0x2275);break;//\ngtrsim
			case 0x22:p("<mo>");p(ul2utf8(0x2A85));p(ul2utf8(0x0338));p("</mo>");break;//XXX,\nlessapprox
			case 0x23:p("<mo>");p(ul2utf8(0x2A86));p(ul2utf8(0x0338));p("</mo>");break;//XXX,\ngtrapprox
			case 0x24:pmath=mo;pmt(0x22E0);break;//\npreccurlyeq
			case 0x25:pmath=mo;pmt(0x22E1);break;//\nsucccurlyeq
			case 0x26:pmath=mo;pmt(0x2278);break;//\ngtrless
			case 0x27:pmath=mo;pmt(0x2279);break;//\nlessgtr
			case 0x28:p("<mo>");p(ul2utf8(0x224F));p(ul2utf8(0x0338));p("</mo>");break;//\nbumpeq
			case 0x29:p("<mo>");p(ul2utf8(0x224E));p(ul2utf8(0x0338));p("</mo>");break;//\nBumpeq
			case 0x2A:p("<mo>");p(ul2utf8(0x223D));p(ul2utf8(0x0338));p("</mo>");break;//\nbacksim
			case 0x2B:p("<mo>");p(ul2utf8(0x224C));p(ul2utf8(0x0338));p("</mo>");break;//\nbacksimeq
			case 0x2C:pmath=mo;pmt(0x2260);break;//\neq
			case 0x2D:pmath=mo;pmt(0x226D);break;//\nasymp
			case 0x2E:pmath=mo;pmt(0x2262);break;//\nequiv
			case 0x2F:pmath=mo;pmt(0x2241);break;//\nsim

			case 0x30:pmath=mo;pmt(0x2249);break;//\napprox
			case 0x31:pmath=mo;pmt(0x2284);break;//\nsubset
			case 0x32:pmath=mo;pmt(0x2285);break;//\nsupset
			case 0x33:p("<mo>");p(ul2utf8(0x226A));p(ul2utf8(0x0338));p("</mo>");break;//\nll
			case 0x34:p("<mo>");p(ul2utf8(0x226B));p(ul2utf8(0x0338));p("</mo>");break;//\ngg
			case 0x35:pmath=mo;pmt(0x2249);break;//\nthickapprox
			case 0x36:pmath=mo;pmt(0x224A);break;//\napproxeq
			case 0x37:p("<mo>");p(ul2utf8(0x2AB7));p(ul2utf8(0x0338));p("</mo>");break;//\nprecapprox
			case 0x38:p("<mo>");p(ul2utf8(0x2AB8));p(ul2utf8(0x0338));p("</mo>");break;//\nsuccapprox
			case 0x39:p("<mo>");p(ul2utf8(0x2AB3));p(ul2utf8(0x0338));p("</mo>");break;//\npreceqq
			case 0x3A:p("<mo>");p(ul2utf8(0x2AB4));p(ul2utf8(0x0338));p("</mo>");break;//\nsucceqq
			case 0x3B:pmath=mo;pmt(0x2244);break;//\nsimeq 
			case 0x3C:pmath=mo;pmath=mo;pmt(0x2209);break;//\notin
			case 0x3D:pmt(0x220C);break;//\notni
			case 0x3E:p("<mo>");p(ul2utf8(0x22D0));p(ul2utf8(0x0338));p("</mo>");break;//\nSubset
			case 0x3F:p("<mo>");p(ul2utf8(0x22D1));p(ul2utf8(0x0338));p("</mo>");break;//\nSupset

			case 0x40:pmath=mo;pmt(0x22E2);break;//\nsqsubseteq
			case 0x41:pmath=mo;pmt(0x22E3);break;//\nsqsupseteq
			case 0x42:pmath=mo;pmt(0x2254);break;//\coloneqq
			case 0x43:pmath=mo;pmt(0x2255);break;//\eqqcolon
			case 0x44:p("<mo>");p(":-");p("</mo>");break;//XXX,\coloneq
			case 0x45:pmath=mo;pmt(0x2239);break;//\eqcolon
			case 0x46:pmath=mo;pmt(0x2A74);break;//\Coloneqq
			case 0x47:p("<mo>");p("=::");p("</mo>");break;//XXX,\Eqqcolon

			case 0x48:p("<mo>");p("::-");p("</mo>");break;//\Coloneq
			case 0x49:p("<mo>");p("-::");p("</mo>");break;//\Eqcolon
			case 0x4A:pmath=mo;pmt(0x297D);break;//XXX, \strictif
			case 0x4B:pmath=mo;pmt(0x297C);break;//XXX, \strictfi
			case 0x4C:p("<mo>");p(ul2utf8(0x297C));p(ul2utf8(0x297D));p("</mo>");break;//\strictiff
			case 0x4D:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1=frown,\invamp
			case 0x4E:pmath=ld;pmt(0x27C5);break;//\lbag
			case 0x4F:pmath=rd;pmt(0x27C6);break;//\rbag
			
			case 0x50:pmath=ld;pmt(0x27C5);break;//\Lbag
			case 0x51:pmath=rd;pmt(0x27C6);break;//\Rbag
			case 0x52:pmath=mo;pmt(0x29C0);break;//\circledless
			case 0x53:pmath=mo;pmt(0x29C1);break;//\circledgtr
			case 0x54:p("<mo>");p(ul2utf8(0x2227));p(ul2utf8(0x20DD));p("</mo>");break;//\circledwedge
			case 0x55:p("<mo>");p(ul2utf8(0x2228));p(ul2utf8(0x20DD));p("</mo>");break;//\circledvee
			case 0x56:pmath=mo;pmt(0x29B6);break;//\circledbar
			case 0x57:pmath=mo;pmt(0x29B8);break;//\circledbslash
			case 0x58:pmath=mo;pmt(0x22C9);break;//XXX?,\lJoin
			case 0x59:pmath=mo;pmt(0x22CA);break;//XXX?,\rJoin
			case 0x5A:pmath=mo;pmt(0x2A1D);break;//\Join
			case 0x5B:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,\openJoin
			case 0x5C:pmath=mo;pmt(0x22C8);break;//\lrtimes
			case 0x5D:pmath=mo;pmt(0x2A09);break;//\opentimes
			case 0x5E:pmath=mo;pmt(0x25C7);break;//\Diamond
			case 0x5F:pmath=mo;pmt(0x25C6);break;//\Diamondblack

			case 0x60:pmath=mo;pmt(0x22C2);break;//XXX n-ary intersection,\nplus
			case 0x61:p("<mo>");p(ul2utf8(0x228F));p(ul2utf8(0x0338));p("</mo>");break;//\nsqsubset
			case 0x62:p("<mo>");p(ul2utf8(0x2290));p(ul2utf8(0x0338));p("</mo>");break;//\nsqsupset
			case 0x63:pmath=mo;pmt(0x21E0);break;//\dashleftarrow
			case 0x64:pmath=mo;pmt(0x21E2);break;//\dashrightarrow
			case 0x65:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,\dashleftrightarrow
			case 0x66:pmath=mo;pmt(0x21DC);break;//\leftsquigarrow
			case 0x67:p("<mo>");p(ul2utf8(0x21A0));p(ul2utf8(0x0338));p("</mo>");break;//\ntwoheadrightarrow
			case 0x68:p("<mo>");p(ul2utf8(0x219E));p(ul2utf8(0x0338));p("</mo>");break;//\ntwoheadleftarrow
			case 0x69:pmath=mo;pmt(0x29C6);break;//\boxast
			case 0x6A:pmath=mo;pmt(0x2342);break;//\boxbslash
			case 0x6B:p("<mo>");p("|");p(ul2utf8(0x20DE));p("</mo>");break;//\boxbar
			case 0x6C:pmath=mo;pmt(0x2341);break;//\boxslash
			case 0x6D:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1=frown,\Wr
			case 0x6E:pmath=mo;pmt(0x019B);break;//\lambdaslash
			case 0x6F:pmath=mo;pmt(0x019B);break;//\lambdabar
			
			case 0x70:pmath=mo;pmt(0x2667);break;//\varclubsuit
			case 0x71:pmath=mo;pmt(0x2666);break;//\vardiamondsuit
			case 0x72:pmath=mo;pmt(0x2665);break;//\varheartsuit
			case 0x73:pmath=mo;pmt(0x2664);break;//\varspadesuit
			case 0x74:pmath=mo;pmt(0x2B01);break;//\Nearrow
			case 0x75:pmath=mo;pmt(0x2B02);break;//\Searrow
			case 0x76:pmath=mo;pmt(0x2B00);break;//\Nwarrow
			case 0x77:pmath=mo;pmt(0x2B03);break;//\Swarrow
			case 0x78:pmath=mo;pmt(0x2AEA);break;//\Top
			case 0x79:pmath=mo;pmt(0x2AEB);break;//\Bot,\Perp
			case 0x7A:pmath=mo;pmt(0x223C);break;//\leadstoext
			case 0x7B:pmath=mo;pmt(0x219D);break;//\leadsto
			case 0x7C:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,\sqcupplus
			case 0x7D:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,\sqcapplus
			case 0x7E:pmath=ld;pmt(0x301A);break;//\llbracket
			case 0x7F:pmath=rd;pmt(0x301B);break;//\rrbracket
			
			case 0x80:p("<mo>");p(ul2utf8(0x25A1));p(ul2utf8(0x2192));p("</mo>");break;//\boxright
			case 0x81:p("<mo>");p(ul2utf8(0x2190));p(ul2utf8(0x25A1));p("</mo>");break;//\boxleft
			case 0x82:p("<mo>");p(ul2utf8(0x22A1));p(ul2utf8(0x2192));p("</mo>");break;//\boxdotright
			case 0x83:p("<mo>");p(ul2utf8(0x2190));p(ul2utf8(0x22A1));p("</mo>");break;//\boxdotleft
			case 0x84:p("<mo>");p(ul2utf8(0x22C4));p(ul2utf8(0x2192));p("</mo>");break;//\Diamondright
			case 0x85:p("<mo>");p(ul2utf8(0x2190));p(ul2utf8(0x22C4));p("</mo>");break;//\Diamondleft
			case 0x86:p("<mo>");p(ul2utf8(0x27D0));p(ul2utf8(0x2192));p("</mo>");break;//\Diamonddotright
			case 0x87:p("<mo>");p(ul2utf8(0x2190));p(ul2utf8(0x27D0));p("</mo>");break;//\Diamonddotleft
			case 0x88:p("<mo>");p(ul2utf8(0x25A1));p(ul2utf8(0x21D2));p("</mo>");break;//\boxRight
			case 0x89:p("<mo>");p(ul2utf8(0x21D0));p(ul2utf8(0x25A1));p("</mo>");break;//\boxLeft
			case 0x8A:p("<mo>");p(ul2utf8(0x22A1));p(ul2utf8(0x21D2));p("</mo>");break;//\boxdotRight
			case 0x8B:p("<mo>");p(ul2utf8(0x21D0));p(ul2utf8(0x22A1));p("</mo>");break;//\boxdotLeft
			case 0x8C:p("<mo>");p(ul2utf8(0x22C4));p(ul2utf8(0x21D2));p("</mo>");break;//\DiamondRight
			case 0x8D:p("<mo>");p(ul2utf8(0x21D0));p(ul2utf8(0x22C4));p("</mo>");break;//\DiamondLeft
			case 0x8E:p("<mo>");p(ul2utf8(0x27D0));p(ul2utf8(0x21D2));p("</mo>");break;//\DiamonddotRight
			case 0x8F:p("<mo>");p(ul2utf8(0x21D0));p(ul2utf8(0x27D0));p("</mo>");break;//\DiamonddotLeft

			case 0x90:pmath=mo;pmt(0x27D0);break;//\Diamonddot
			case 0x91:p("<mo>");p(ul2utf8(0x25CB));p(ul2utf8(0x2192));p("</mo>");break;//\circleright
			case 0x92:p("<mo>");p(ul2utf8(0x2190));p(ul2utf8(0x25CB));p("</mo>");break;//\circleleft
			case 0x93:p("<mo>");p(ul2utf8(0x2299));p(ul2utf8(0x2192));p("</mo>");break;//\circledotright
			case 0x94:p("<mo>");p(ul2utf8(0x2190));p(ul2utf8(0x2299));p("</mo>");break;//\circledotleft
			case 0x95:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,\multimapbothvert
			case 0x96:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,\multimapdotbothvert
			case 0x97:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,\multimapdotbothBvert
			case 0x98:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,\multimapdotbothAvert
			default:pmath=mif;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"pxbsyc"))||(strstr(currentFont,"txbsyc"))){
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x22A3);break;//left tack
			case 0x01:pmath=mob;pmt(0x22A7);break;//models
			case 0x02:pmath=mob;pmt(0x2AE4);break;//vertical bar left double turnstile
			case 0x03:pmath=mob;pmt(0x22A9);break;//forces
			case 0x04:pmath=mob;pmt(0x2AE3);break;//double vertical bar left turnstile
			case 0x05:pmath=mob;pmt(0x22AB);break;//double vertical bar right double turnstile
			case 0x06:pmath=mob;pmt(0x2AE5);break;//double vertical bar left double turnstile
			case 0x07:pmath=mob;pmt(0x25CB);break;//white circle
			case 0x08:pmath=mob;pmt(0x25CF);break;//black circle
			case 0x09:pmath=mob;pmt(0x2AFD);break;//double solidus, varparallel
			case 0x0A:pmath=mob;pmt(0x244A);break;//OCR double backslash, nvarparallelinv
			case 0x0B:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AFD));p(ul2utf8(0x0338));p("</mo>");break;//negated double solidus, nvarparallel
			case 0x0C:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x244A));p(ul2utf8(0x0338));p("</mo>");break;//negated OCR double backslash, nvarparallelinv
			case 0x0D:p("<mo mathvariant=\"bold\">");p(":");p(ul2utf8(0x2248));p("</mo>");break;//XXX,colon almost equal,\colonapprox
			case 0x0E:p("<mo mathvariant=\"bold\">");p(":");p(ul2utf8(0x223C));p("</mo>");break;//XXX,colon similar, \colonsim
			case 0x0F:p("<mo mathvariant=\"bold\">");p("::");p(ul2utf8(0x2248));p("</mo>");break;//XXX,double colon almost equal,\Colonapprox

			case 0x10:p("<mo mathvariant=\"bold\">");p("::");p(ul2utf8(0x223C));p("</mo>");break;//double colon similar,\Colonsim
			case 0x11:pmath=mob;pmt(0x2250);break;//approaches the limit,\doteq
			case 0x12:pmath=mob;pmt(0x27DC);break;//left multimap
			case 0x13:pmath=mob;pmt(0x29DF);break;//double-ended multimap
			case 0x14:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2212));p(ul2utf8(0x2022));p("</mo>");break;//XXX=minus+bullet,\multimapdot
			case 0x15:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2022));p(ul2utf8(0x2212));p("</mo>");break;//XXX,\multimapdotinv
			case 0x16:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2022));p(ul2utf8(0x2212));p(ul2utf8(0x2022));p("</mo>");break;//XXX,\multimapdotboth
			case 0x17:pmath=mob;pmt(0x22B6);break;//original of
			case 0x18:pmath=mob;pmt(0x22B7);break; //image of
			case 0x19:pmath=mob;pmt(0x22AB);break;//double vertical bar double turnstile right
			case 0x1A:p("<mo mathvariant=\"bold\">");p("|");p(ul2utf8(0x22AB));p("</mo>");break; //XXX, triple vbar double turnstile right
			case 0x1B:pmath=mob;pmt(0x2245);break; //\cong
			case 0x1C:pmath=mob;pmt(0x2AAF);break; //\preceqq
			case 0x1D:pmath=mob;pmt(0x2AB0);break; //\succeqq
			case 0x1E:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x227E));p(ul2utf8(0x0338));p("</mo>");break; //\nprecsim
			case 0x1F:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x227F));p(ul2utf8(0x0338));p("</mo>");break; //\nsuccsim

			case 0x20:pmath=mob;pmt(0x2274);break;//\nlesssim
			case 0x21:pmath=mob;pmt(0x2275);break;//\ngtrsim
			case 0x22:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2A85));p(ul2utf8(0x0338));p("</mo>");break;//XXX,\nlessapprox
			case 0x23:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2A86));p(ul2utf8(0x0338));p("</mo>");break;//XXX,\ngtrapprox
			case 0x24:pmath=mob;pmt(0x22E0);break;//\npreccurlyeq
			case 0x25:pmath=mob;pmt(0x22E1);break;//\nsucccurlyeq
			case 0x26:pmath=mob;pmt(0x2278);break;//\ngtrless
			case 0x27:pmath=mob;pmt(0x2279);break;//\nlessgtr
			case 0x28:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x224F));p(ul2utf8(0x0338));p("</mo>");break;//\nbumpeq
			case 0x29:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x224E));p(ul2utf8(0x0338));p("</mo>");break;//\nBumpeq
			case 0x2A:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x223D));p(ul2utf8(0x0338));p("</mo>");break;//\nbacksim
			case 0x2B:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x224C));p(ul2utf8(0x0338));p("</mo>");break;//\nbacksimeq
			case 0x2C:pmath=mob;pmt(0x2260);break;//\neq
			case 0x2D:pmath=mob;pmt(0x226D);break;//\nasymp
			case 0x2E:pmath=mob;pmt(0x2262);break;//\nequiv
			case 0x2F:pmath=mob;pmt(0x2241);break;//\nsim

			case 0x30:pmath=mob;pmt(0x2249);break;//\napprox
			case 0x31:pmath=mob;pmt(0x2284);break;//\nsubset
			case 0x32:pmath=mob;pmt(0x2285);break;//\nsupset
			case 0x33:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x226A));p(ul2utf8(0x0338));p("</mo>");break;//\nll
			case 0x34:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x226B));p(ul2utf8(0x0338));p("</mo>");break;//\ngg
			case 0x35:pmath=mob;pmt(0x2249);break;//\nthickapprox
			case 0x36:pmath=mob;pmt(0x224A);break;//\napproxeq
			case 0x37:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AB7));p(ul2utf8(0x0338));p("</mo>");break;//\nprecapprox
			case 0x38:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AB8));p(ul2utf8(0x0338));p("</mo>");break;//\nsuccapprox
			case 0x39:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AB3));p(ul2utf8(0x0338));p("</mo>");break;//\npreceqq
			case 0x3A:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2AB4));p(ul2utf8(0x0338));p("</mo>");break;//\nsucceqq
			case 0x3B:pmath=mob;pmt(0x2244);break;//\nsimeq 
			case 0x3C:pmath=mob;pmt(0x2209);break;//\notin
			case 0x3D:pmt(0x220C);break;//\notni
			case 0x3E:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x22D0));p(ul2utf8(0x0338));p("</mo>");break;//\nSubset
			case 0x3F:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x22D1));p(ul2utf8(0x0338));p("</mo>");break;//\nSupset

			case 0x40:pmath=mob;pmt(0x22E2);break;//\nsqsubseteq
			case 0x41:pmath=mob;pmt(0x22E3);break;//\nsqsupseteq
			case 0x42:pmath=mob;pmt(0x2254);break;//\coloneqq
			case 0x43:pmath=mob;pmt(0x2255);break;//\eqqcolon
			case 0x44:p("<mo mathvariant=\"bold\">");p(":-");p("</mo>");break;//XXX,\coloneq
			case 0x45:pmath=mob;pmt(0x2239);break;//\eqcolon
			case 0x46:pmath=mob;pmt(0x2A74);break;//\Coloneqq
			case 0x47:p("<mo mathvariant=\"bold\">");p("=::");p("</mo>");break;//XXX,\Eqqcolon

			case 0x48:p("<mo mathvariant=\"bold\">");p("::-");p("</mo>");break;//\Coloneq
			case 0x49:p("<mo mathvariant=\"bold\">");p("-::");p("</mo>");break;//\Eqcolon
			case 0x4A:pmath=mob;pmt(0x297D);break;//XXX, \strictif
			case 0x4B:pmath=mob;pmt(0x297C);break;//XXX, \strictfi
			case 0x4C:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x297C));p(ul2utf8(0x297D));p("</mo>");break;//\strictiff
			case 0x4D:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1=frown,\invamp
			case 0x4E:pmath=ldb;pmt(0x27C5);break;//\lbag
			case 0x4F:pmath=rdb;pmt(0x27C6);break;//\rbag
			
			case 0x50:pmath=ldb;pmt(0x27C5);break;//\Lbag
			case 0x51:pmath=rdb;pmt(0x27C6);break;//\Rbag
			case 0x52:pmath=mob;pmt(0x29C0);break;//\circledless
			case 0x53:pmath=mob;pmt(0x29C1);break;//\circledgtr
			case 0x54:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2227));p(ul2utf8(0x20DD));p("</mo>");break;//\circledwedge
			case 0x55:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2228));p(ul2utf8(0x20DD));p("</mo>");break;//\circledvee
			case 0x56:pmath=mob;pmt(0x29B6);break;//\circledbar
			case 0x57:pmath=mob;pmt(0x29B8);break;//\circledbslash
			case 0x58:pmath=mob;pmt(0x22C9);break;//XXX?,\lJoin
			case 0x59:pmath=mob;pmt(0x22CA);break;//XXX?,\rJoin
			case 0x5A:pmath=mob;pmt(0x2A1D);break;//\Join
			case 0x5B:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1,\openJoin
			case 0x5C:pmath=mob;pmt(0x22C8);break;//\lrtimes
			case 0x5D:pmath=mob;pmt(0x2A09);break;//\opentimes
			case 0x5E:pmath=mob;pmt(0x25C7);break;//\Diamond
			case 0x5F:pmath=mob;pmt(0x25C6);break;//\Diamondblack

			case 0x60:pmath=mob;pmt(0x22C2);break;//XXX n-ary intersection,\nplus
			case 0x61:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x228F));p(ul2utf8(0x0338));p("</mo>");break;//\nsqsubset
			case 0x62:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2290));p(ul2utf8(0x0338));p("</mo>");break;//\nsqsupset
			case 0x63:pmath=mob;pmt(0x21E0);break;//\dashleftarrow
			case 0x64:pmath=mob;pmt(0x21E2);break;//\dashrightarrow
			case 0x65:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1,\dashleftrightarrow
			case 0x66:pmath=mob;pmt(0x21DC);break;//\leftsquigarrow
			case 0x67:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x21A0));p(ul2utf8(0x0338));p("</mo>");break;//\ntwoheadrightarrow
			case 0x68:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x219E));p(ul2utf8(0x0338));p("</mo>");break;//\ntwoheadleftarrow
			case 0x69:pmath=mob;pmt(0x29C6);break;//\boxast
			case 0x6A:pmath=mob;pmt(0x2342);break;//\boxbslash
			case 0x6B:p("<mo mathvariant=\"bold\">");p("|");p(ul2utf8(0x20DE));p("</mo>");break;//\boxbar
			case 0x6C:pmath=mob;pmt(0x2341);break;//\boxslash
			case 0x6D:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1=frown,\Wr
			case 0x6E:pmath=mob;pmt(0x019B);break;//\lambdaslash
			case 0x6F:pmath=mob;pmt(0x019B);break;//\lambdabar
			
			case 0x70:pmath=mob;pmt(0x2667);break;//\varclubsuit
			case 0x71:pmath=mob;pmt(0x2666);break;//\vardiamondsuit
			case 0x72:pmath=mob;pmt(0x2665);break;//\varheartsuit
			case 0x73:pmath=mob;pmt(0x2664);break;//\varspadesuit
			case 0x74:pmath=mob;pmt(0x2B01);break;//\Nearrow
			case 0x75:pmath=mob;pmt(0x2B02);break;//\Searrow
			case 0x76:pmath=mob;pmt(0x2B00);break;//\Nwarrow
			case 0x77:pmath=mob;pmt(0x2B03);break;//\Swarrow
			case 0x78:pmath=mob;pmt(0x2AEA);break;//\Top
			case 0x79:pmath=mob;pmt(0x2AEB);break;//\Bot,\Perp
			case 0x7A:pmath=mob;pmt(0x223C);break;//\leadstoext
			case 0x7B:pmath=mob;pmt(0x219D);break;//\leadsto
			case 0x7C:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1,\sqcupplus
			case 0x7D:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1,\sqcapplus
			case 0x7E:pmath=ldb;pmt(0x301A);break;//\llbracket
			case 0x7F:pmath=rdb;pmt(0x301B);break;//\rrbracket
			
			case 0x80:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x25A1));p(ul2utf8(0x2192));p("</mo>");break;//\boxright
			case 0x81:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2190));p(ul2utf8(0x25A1));p("</mo>");break;//\boxleft
			case 0x82:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x22A1));p(ul2utf8(0x2192));p("</mo>");break;//\boxdotright
			case 0x83:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2190));p(ul2utf8(0x22A1));p("</mo>");break;//\boxdotleft
			case 0x84:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x22C4));p(ul2utf8(0x2192));p("</mo>");break;//\Diamondright
			case 0x85:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2190));p(ul2utf8(0x22C4));p("</mo>");break;//\Diamondleft
			case 0x86:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x27D0));p(ul2utf8(0x2192));p("</mo>");break;//\Diamonddotright
			case 0x87:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2190));p(ul2utf8(0x27D0));p("</mo>");break;//\Diamonddotleft
			case 0x88:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x25A1));p(ul2utf8(0x21D2));p("</mo>");break;//\boxRight
			case 0x89:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x21D0));p(ul2utf8(0x25A1));p("</mo>");break;//\boxLeft
			case 0x8A:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x22A1));p(ul2utf8(0x21D2));p("</mo>");break;//\boxdotRight
			case 0x8B:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x21D0));p(ul2utf8(0x22A1));p("</mo>");break;//\boxdotLeft
			case 0x8C:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x22C4));p(ul2utf8(0x21D2));p("</mo>");break;//\DiamondRight
			case 0x8D:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x21D0));p(ul2utf8(0x22C4));p("</mo>");break;//\DiamondLeft
			case 0x8E:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x27D0));p(ul2utf8(0x21D2));p("</mo>");break;//\DiamonddotRight
			case 0x8F:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x21D0));p(ul2utf8(0x27D0));p("</mo>");break;//\DiamonddotLeft

			case 0x90:pmath=mob;pmt(0x27D0);break;//\Diamonddot
			case 0x91:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x25CB));p(ul2utf8(0x2192));p("</mo>");break;//\circleright
			case 0x92:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2190));p(ul2utf8(0x25CB));p("</mo>");break;//\circleleft
			case 0x93:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2299));p(ul2utf8(0x2192));p("</mo>");break;//\circledotright
			case 0x94:p("<mo mathvariant=\"bold\">");p(ul2utf8(0x2190));p(ul2utf8(0x2299));p("</mo>");break;//\circledotleft
			case 0x95:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1,\multimapbothvert
			case 0x96:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1,\multimapdotbothvert
			case 0x97:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1,\multimapdotbothBvert
			case 0x98:pmath=mob;pmt(0x2639);break;//XXX not found in Unicode 4.1,\multimapdotbothAvert
			default:pmath=mif;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if ((strstr(currentFont,"cmsy"))||(strstr(currentFont,"pxsy"))||(strstr(currentFont,"txsy"))||(strstr(currentFont,"zppler7y"))){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x2212);break;//minus
			case 0x01:pmath=mo;pmt(0x22C5);break;//dot operator
			case 0x02:pmath=mo;pmt(0x00D7);break;//times
			case 0x03:pmath=mo;pmt(0x002a);break;//asterisk
			case 0x04:pmath=mo;pmt(0x00F7);break;//div
			case 0x05:pmath=mo;pmt(0x22C4);break;//diamond
			case 0x06:pmath=mo;pmt(0x00B1);break;//plus-minus
			case 0x07:pmath=mo;pmt(0x2213);break;//minus-plus
			case 0x08:pmath=mo;pmt(0x2295);break;//oplus
			case 0x09:pmath=mo;pmt(0x2296);break;//ominus
			case 0x0A:pmath=mo;pmt(0x2297);break;//otimes
			case 0x0B:pmath=mo;pmt(0x2298);break;//odivision
			case 0x0C:pmath=mo;pmt(0x2299);break;//odot
			case 0x0D:pmath=mo;
			if (combiningUnicode=='c')	pmt(0x01); //dirty trick to recover the copyright symbol
			else	pmt(0x25EF);
				break;//bigcirc
			case 0x0E:pmath=mo;pmt(0x2218);break;//empty ring
			case 0x0F:pmath=mo;pmt(0x2219);break;//filled ring

			case 0x10:pmath=mo;pmt(0x224D);break;//equivalent to
			case 0x11:pmath=mo;//\equiv, identical to
				precomposedNegative(0x2261,0x2262);
				break;
			break;
			case 0x12:pmath=mo; //subset equal
				precomposedNegative(0x2286,0x2288);
				break;
			case 0x13:pmath=mo; //superset equal
				precomposedNegative(0x2287,0x2289);
				break;
			case 0x14:pmath=mo;		//less equal
				precomposedNegative(0x2264,0x2270);
				break;
			case 0x15:pmath=mo;		//greater equal
				precomposedNegative(0x2265,0x2271);
				break;
			case 0x16:pmath=mo;	//precedes equal
				precomposedNegative(0x227C,0x22E0);
				break;
			case 0x17:pmath=mo;	//succeedes equal
				precomposedNegative(0x227D,0x22E1);
				break;
			case 0x18:pmath=mo;//similar
				precomposedNegative(0x223C,0x2241);
				break;
			case 0x19:pmath=mo;	//almost equal
				precomposedNegative(0x2248,0x2249);
				break;
			case 0x1A:pmath=mo; //subset
				precomposedNegative(0x2282,0x2284);
				break;
			case 0x1B:pmath=mo; //superset
				precomposedNegative(0x2283,0x2285);
				break;
			case 0x1C:pmath=mo;pmt(0x226A);break;//much less
			case 0x1D:pmath=mo;pmt(0x226B);break;//much greater
			case 0x1E:pmath=mo;							//precedes
				precomposedNegative(0x227A,0x2280);
				break;
			case 0x1F:pmath=mo;							//succeedes
				precomposedNegative(0x227B,0x2281);
				break;
			case 0x20:pmath=mo;pmt(0x2190);break;//leftarrow
			case 0x21:pmath=mo;pmt(0x2192);break;//rightarrow
			case 0x22:pmath=mo;pmt(0x2191);break;//uparrow
			case 0x23:pmath=mo;pmt(0x2193);break;//downarrow
			case 0x24:pmath=mo;pmt(0x2194);break;//leftrightarrow
			case 0x25:pmath=mo;pmt(0x2197);break;//nearrow
			case 0x26:pmath=mo;pmt(0x2198);break;//searrow
			case 0x27:pmath=mo;//asympequal
				precomposedNegative(0x2243, 0x2244);
				break;			
			case 0x28:pmath=mo;pmt(0x21D0);break;//left double arrow
			case 0x29:pmath=mo;pmt(0x21D2);break;//right double arrow
			case 0x2A:pmath=mo;pmt(0x21D1);break;//up double arrow
			case 0x2B:pmath=mo;pmt(0x21D3);break;//down double arrow
			case 0x2C:pmath=mo;pmt(0x21D4);break;//leftright double arrow
			case 0x2D:pmath=mo;pmt(0x2196);break;//nwarrow
			case 0x2E:pmath=mo;pmt(0x2199);break;//swarrow
			case 0x2F:pmath=mo;pmt(0x221D);break;//propto

			case 0x30:pmath=mo;pmt(0x2032);break;//prime
			case 0x31:pmath=mo;pmt(0x221E);break;//infinity
			case 0x32:pmath=mo;//belongs
				precomposedNegative(0x2208,0x2209);
			break;
			case 0x33:pmath=mo;pmt(0x220B);break;//contains
			case 0x34:pmath=mo;pmt(0x25B3);break;//up triangle
			case 0x35:pmath=mo;pmt(0x25BD);break;//down triangle
			case 0x36:combiningUnicode=0x0338;break;//combining slash
			case 0x37:pmath=mo;pmt(0x22A6);break;//assertion
			case 0x38:pmath=mo;pmt(0x2200);break;//forall
			case 0x39:pmath=mo;pmt(0x2203);break;//exists
			case 0x3A:pmath=mo;pmt(0x00AC);break;//not
			case 0x3B:pmath=mo;pmt(0x2205);break;//emptyset
			case 0x3C:pmath=mo;pmt(0x211C);break;//real part
			case 0x3D:pmath=mo;pmt(0x2111);break;//image part
			case 0x3E:pmath=mo;pmt(0x22A4);break;//down tack
			case 0x3F:pmath=mo;pmt(0x22A5);break;//up tack

			case 0x40:pmath=mi;pmt(0x2135);break;//aleph
			case 0x41:pmath=mis;pmt('A');break;//pmath=mib;pmt(0x1D49C);break;//A script
			case 0x42:pmath=mis;pmt('B');break;//pmt(0x212C);break;//B script
			case 0x43:pmath=mis;pmt('C');break;//pmath=mib;pmt(0x1D49E);break;//C script
			case 0x44:pmath=mis;pmt('D');break;//pmath=mib;pmt(0x1D49F);break;//D script
			case 0x45:pmath=mis;pmt('E');break;//pmt(0x2130);break;//E script
			case 0x46:pmath=mis;pmt('F');break;//pmt(0x2131);break;//F script
			case 0x47:pmath=mis;pmt('G');break;//pmath=mib;pmt(0x1D4A2);break;//G script
			case 0x48:pmath=mis;pmt('H');break;//pmt(0x210B);break;//H script
			case 0x49:pmath=mis;pmt('F');break;//pmt(0x2110);break;//I script
			case 0x4A:pmath=mis;pmt('J');break;//pmath=mib;pmt(0x1D4A5);break;//J script
			case 0x4B:pmath=mis;pmt('K');break;//pmath=mib;pmt(0x1D4A6);break;//K script
			case 0x4C:pmath=mis;pmt('L');break;//pmt(0x2112);break;//L script
			case 0x4D:pmath=mis;pmt('M');break;//pmt(0x2133);break;//M script
			case 0x4E:pmath=mis;pmt('N');break;//pmath=mib;pmt(0x1D4A9);break;//N script
			case 0x4F:pmath=mis;pmt('O');break;//pmath=mib;pmt(0x1D4AA);break;//O script

			case 0x50:pmath=mis;pmt('P');break;//pmath=mi;//pmt(0x1D4AB);break;//P script
			case 0x51:pmath=mis;pmt('Q');break;//pmath=mi;pmt(0x1D4AC);break;//Q script
			case 0x52:pmath=mis;pmt('R');break;//pmt(0x211B);break;//R script
			case 0x53:pmath=mis;pmt('S');break;//pmath=mi;pmt(0x1D4AE);break;//S script
			case 0x54:pmath=mis;pmt('T');break;//pmath=mi;pmt(0x1D4AF);break;//T script
			case 0x55:pmath=mis;pmt('U');break;//pmath=mi;pmt(0x1D4B0);break;//U script
			case 0x56:pmath=mis;pmt('V');break;//pmath=mi;pmt(0x1D4B1);break;//V script
			case 0x57:pmath=mis;pmt('W');break;//pmath=mi;pmt(0x1D4B2);break;//W script
			case 0x58:pmath=mis;pmt('X');break;//pmath=mi;pmt(0x1D4B3);break;//X script
			case 0x59:pmath=mis;pmt('Y');break;//pmath=mi;pmt(0x1D4B4);break;//Y script
			case 0x5A:pmath=mis;pmt('Z');break;//pmath=mi;pmt(0x1D4B5);break;//Z script
			case 0x5B:pmath=mo;pmt(0x222A);break;//cup
			case 0x5C:pmath=mo;pmt(0x2229);break;//cap
			case 0x5D:pmath=mo;pmt(0x228E);break;//multiset union
			case 0x5E:pmath=mo;pmt(0x2227);break;//logical and, wedge
			case 0x5F:pmath=mo;pmt(0x2228);break;//logical or, vee

			case 0x60:pmath=mo; //right tack
				precomposedNegative(0x22A2,0x22AC);
				break;
			case 0x61:pmath=mo;pmt(0x22A3);break;//left tack
			case 0x62:pmath=ld;pmt(0x230A);break;//left floor
			case 0x63:pmath=rd;pmt(0x230B);break;//right floor
			case 0x64:pmath=ld;pmt(0x2308);break;//left ceiling
			case 0x65:pmath=rd;pmt(0x2309);break;//right ceiling
			case 0x66:pmath=ld;pmt(0x007B);break;//left brace
			case 0x67:pmath=rd;pmt(0x007D);break;//right brace
			case 0x68:pmath=mo;pmt(0x2329);break;//left angle bracket
			case 0x69:pmath=mo;pmt(0x232A);break;//right angle bracket
			case 0x6A:pmath=mo;pmt(0x007C);break;//divides, vert
			case 0x6B:pmath=mo;pmt(0x2225);break;//parallel
			case 0x6C:pmath=mo;pmt(0x2195);break;//up down arrow
			case 0x6D:pmath=mo;pmt(0x21D5);break;//up down double arrow
			case 0x6E:pmath=mo;pmt(0x005C);break;//backslash
			case 0x6F:pmath=mo;pmt(0x2240);break;//wreath product

			case 0x70:pmath=mo;pmt(0x2713);break;//square root
			case 0x71:pmath=mo;pmt(0x2210);break;//binary product
			case 0x72:pmath=mo;pmt(0x2207);break;//nabla
			case 0x73:pmath=mo;pmt(0x2228);break;//integral
			case 0x74:pmath=mo;pmt(0x2294);break;//square cup
			case 0x75:pmath=mo;pmt(0x2293);break;//square cap
			case 0x76:pmath=mo;	//square image equal
				precomposedNegative(0x2291,0x22E2);
				break;
			case 0x77:pmath=mo;	//square original equal
				precomposedNegative(0x2292,0x22E3);
				break;
			case 0x78:pmath=mo;pmt(0x00A7);break;//section
			case 0x79:pmath=mo;pmt(0x2020);break;//dagger
			case 0x7A:pmath=mo;pmt(0x2021);break;//ddagger
			case 0x7B:pmath=mo;pmt(0x0086);break;//paragraph
			case 0x7C:pmath=mo;pmt(0x2663);break;//black club suit
			case 0x7D:pmath=mo;pmt(0x2662);break;//white diamond suit
			case 0x7E:pmath=mo;pmt(0x2661);break;//white heart suit
			case 0x7F:pmath=mo;pmt(0x2660);break;//black spade suit
			}
			temp++;
		}while(*temp) ;
		return;
	}


	if ((strstr(currentFont,"cmbsy"))||(strstr(currentFont,"zppleb7y"))){
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x2212);break;//minus
			case 0x01:pmath=mob;pmt(0x22C5);break;//dot operator
			case 0x02:pmath=mob;pmt(0x00D7);break;//times
			case 0x03:pmath=mob;pmt(0x2217);break;//asterisk
			case 0x04:pmath=mob;pmt(0x00F7);break;//div
			case 0x05:pmath=mob;pmt(0x22C4);break;//diamond
			case 0x06:pmath=mob;pmt(0x0081);break;//plus-minus
			case 0x07:pmath=mob;pmt(0x2213);break;//minus-plus
			case 0x08:pmath=mob;pmt(0x2295);break;//oplus
			case 0x09:pmath=mob;pmt(0x2296);break;//ominus
			case 0x0A:pmath=mob;pmt(0x2297);break;//otimes
			case 0x0B:pmath=mob;pmt(0x2298);break;//odivision
			case 0x0C:pmath=mob;pmt(0x2299);break;//odot
			case 0x0D:pmath=mob;pmt(0x25EF);break;//bigcirc
			case 0x0E:pmath=mob;pmt(0x2218);break;//empty ring
			case 0x0F:pmath=mob;pmt(0x2219);break;//filled ring

			case 0x10:pmath=mob;pmt(0x224D);break;//equivalent to
			case 0x11:pmath=mob;pmt(0x2261);break;//\equiv, identical to
			case 0x12:pmath=mob; //subset equal
				precomposedNegative(0x2286,0x2288);
				break;
			case 0x13:pmath=mob; //superset equal
				precomposedNegative(0x2287,0x2289);
				break;
			case 0x14:pmath=mob;		//less equal
				precomposedNegative(0x2264,0x2270);
				break;
			case 0x15:pmath=mob;		//greater equal
				precomposedNegative(0x2265,0x2271);
				break;
			case 0x16:pmath=mob;	//precedes equal
				precomposedNegative(0x227C,0x22E0);
				break;
			case 0x17:pmath=mob;	//succeedes equal
				precomposedNegative(0x227D,0x22E1);
				break;
			case 0x18:pmath=mob;//similar
				precomposedNegative(0x223C,0x2241);
				break;
			case 0x19:pmath=mob;	//almost equal
				precomposedNegative(0x2248,0x2249);
				break;
			case 0x1A:pmath=mob; //subset
				precomposedNegative(0x2282,0x2284);
				break;
			case 0x1B:pmath=mob; //superset
				precomposedNegative(0x2283,0x2285);
				break;
			case 0x1C:pmath=mob;pmt(0x226A);break;//much less
			case 0x1D:pmath=mob;pmt(0x226B);break;//much greater
			case 0x1E:pmath=mob;							//precedes
				precomposedNegative(0x227A,0x2280);
				break;
			case 0x1F:pmath=mob;							//succeedes
				precomposedNegative(0x227B,0x2281);
				break;
			case 0x20:pmath=mob;pmt(0x2190);break;//leftarrow
			case 0x21:pmath=mob;pmt(0x2192);break;//rightarrow
			case 0x22:pmath=mob;pmt(0x2191);break;//uparrow
			case 0x23:pmath=mob;pmt(0x2193);break;//downarrow
			case 0x24:pmath=mob;pmt(0x2194);break;//leftrightarrow
			case 0x25:pmath=mob;pmt(0x2197);break;//nearrow
			case 0x26:pmath=mob;pmt(0x2198);break;//searrow
			case 0x27:pmath=mob;//asympequal
				precomposedNegative(0x2243, 0x2244);
				break;			
			case 0x28:pmath=mob;pmt(0x21D0);break;//left double arrow
			case 0x29:pmath=mob;pmt(0x21D2);break;//right double arrow
			case 0x2A:pmath=mob;pmt(0x21D1);break;//up double arrow
			case 0x2B:pmath=mob;pmt(0x21D3);break;//down double arrow
			case 0x2C:pmath=mob;pmt(0x21D4);break;//leftright double arrow
			case 0x2D:pmath=mob;pmt(0x2196);break;//nwarrow
			case 0x2E:pmath=mob;pmt(0x2199);break;//swarrow
			case 0x2F:pmath=mob;pmt(0x221D);break;//propto

			case 0x30:pmath=mob;pmt(0x2032);break;//prime
			case 0x31:pmath=mob;pmt(0x221E);break;//infinity
			case 0x32:pmath=mob;pmt(0x2208);break;//belongs
			case 0x33:pmath=mob;pmt(0x220B);break;//contains
			case 0x34:pmath=mob;pmt(0x25B3);break;//up triangle
			case 0x35:pmath=mob;pmt(0x25BD);break;//down triangle
			case 0x36:combiningUnicode=0x0338;break;//combining slash
			case 0x37:pmath=mob;pmt(0x22A6);break;//assertion
			case 0x38:pmath=mob;pmt(0x2200);break;//forall
			case 0x39:pmath=mob;pmt(0x2203);break;//exists
			case 0x3A:pmath=mob;pmt(0x00AC);break;//not
			case 0x3B:pmath=mob;pmt(0x2205);break;//emptyset
			case 0x3C:pmath=mob;pmt(0x211C);break;//real part
			case 0x3D:pmath=mob;pmt(0x2111);break;//image part
			case 0x3E:pmath=mob;pmt(0x22A4);break;//down tack
			case 0x3F:pmath=mob;pmt(0x22A5);break;//up tack

			case 0x40:pmath=mib;pmt(0x2135);break;//aleph
			case 0x41:pmath=mibs;pmt('A');break;//pmath=mib;pmt(0x1D49C);break;//A script
			case 0x42:pmath=mib;pmt(0x212C);break;//B script
			case 0x43:pmath=mibs;pmt('C');break;//pmath=mib;pmt(0x1D49E);break;//C script
			case 0x44:pmath=mibs;pmt('D');break;//pmath=mib;pmt(0x1D49F);break;//D script
			case 0x45:pmath=mib;pmt(0x2130);break;//E script
			case 0x46:pmath=mib;pmt(0x2131);break;//F script
			case 0x47:pmath=mibs;pmt('G');break;//pmath=mib;pmt(0x1D4A2);break;//G script
			case 0x48:pmath=mib;pmt(0x2108);break;//H script
			case 0x49:pmath=mib;pmt(0x2110);break;//I script
			case 0x4A:pmath=mibs;pmt('J');break;//pmath=mib;pmt(0x1D4A5);break;//J script
			case 0x4B:pmath=mibs;pmt('K');break;//pmath=mib;pmt(0x1D4A6);break;//K script
			case 0x4C:pmath=mib;pmt(0x2112);break;//L script
			case 0x4D:pmath=mib;pmt(0x2133);break;//M script
			case 0x4E:pmath=mibs;pmt('N');break;//pmath=mib;pmt(0x1D4A9);break;//N script
			case 0x4F:pmath=mibs;pmt('O');break;//pmath=mib;pmt(0x1D4AA);break;//O script

			case 0x50:pmath=mibs;pmt('P');break;//pmath=mib;pmt(0x1D4AB);break;//P script
			case 0x51:pmath=mibs;pmt('Q');break;//pmath=mib;pmt(0x1D4AC);break;//Q script
			case 0x52:pmath=mib;pmt(0x211B);break;//R script
			case 0x53:pmath=mibs;pmt('S');break;//pmath=mib;pmt(0x1D4AE);break;//S script
			case 0x54:pmath=mibs;pmt('T');break;//pmath=mib;pmt(0x1D4AF);break;//T script
			case 0x55:pmath=mibs;pmt('U');break;//pmath=mib;pmt(0x1D4B0);break;//U script
			case 0x56:pmath=mibs;pmt('V');break;//pmath=mib;pmt(0x1D4B1);break;//V script
			case 0x57:pmath=mibs;pmt('W');break;//pmath=mib;pmt(0x1D4B2);break;//W script
			case 0x58:pmath=mibs;pmt('X');break;//pmath=mib;pmt(0x1D4B3);break;//X script
			case 0x59:pmath=mibs;pmt('Y');break;//pmath=mib;pmt(0x1D4B4);break;//Y script
			case 0x5A:pmath=mibs;pmt('Z');break;//pmath=mib;pmt(0x1D4B5);break;//Z script
			case 0x5B:pmath=mob;pmt(0x222A);break;//cup
			case 0x5C:pmath=mob;pmt(0x2229);break;//cap
			case 0x5D:pmath=mob;pmt(0x228E);break;//multiset union
			case 0x5E:pmath=mob;pmt(0x2227);break;//logical and
			case 0x5F:pmath=mob;pmt(0x22C1);break;//logical or

			case 0x60:pmath=mob; //right tack
				precomposedNegative(0x22A2,0x22AC);
				break;
			case 0x61:pmath=mob;pmt(0x22A3);break;//left tack
			case 0x62:pmath=ldb;pmt(0x230A);break;//left floor
			case 0x63:pmath=rdb;pmt(0x230B);break;//right floor
			case 0x64:pmath=ldb;pmt(0x2308);break;//left ceiling
			case 0x65:pmath=rdb;pmt(0x2309);break;//right ceiling
			case 0x66:pmath=ldb;pmt(0x007B);break;//left brace
			case 0x67:pmath=rdb;pmt(0x007D);break;//right brace
			case 0x68:pmath=mob;pmt(0x2329);break;//left angle bracket
			case 0x69:pmath=mob;pmt(0x232A);break;//right angle bracket
			case 0x6A:pmath=mob;pmt(0x007C);break;//divides
			case 0x6B:pmath=mob;pmt(0x2225);break;//parallel
			case 0x6C:pmath=mob;pmt(0x2195);break;//up down arrow
			case 0x6D:pmath=mob;pmt(0x21D5);break;//up down double arrow
			case 0x6E:pmath=mob;pmt(0x005C);break;//backslash
			case 0x6F:pmath=mob;pmt(0x2240);break;//wreath product

			case 0x70:pmath=mob;pmt(0x221A);break;//square root
			case 0x71:pmath=mob;pmt(0x2210);break;//binary product
			case 0x72:pmath=mob;pmt(0x2207);break;//nabla
			case 0x73:pmath=mob;pmt(0x2228);break;//integral
			case 0x74:pmath=mob;pmt(0x2294);break;//square cup
			case 0x75:pmath=mob;pmt(0x2293);break;//square cap
			case 0x76:pmath=mob;	//square image equal
				precomposedNegative(0x2291,0x22E2);
				break;
			case 0x77:pmath=mob;	//square original equal
				precomposedNegative(0x2292,0x22E3);
				break;
			case 0x78:pmath=mob;pmt(0x00A7);break;//section
			case 0x79:pmath=mob;pmt(0x2020);break;//dagger
			case 0x7A:pmath=mob;pmt(0x2021);break;//ddagger
			case 0x7B:pmath=mob;pmt(0x0086);break;//paragraph
			case 0x7C:pmath=mob;pmt(0x2663);break;//black club suit
			case 0x7D:pmath=mob;pmt(0x2662);break;//white diamond suit
			case 0x7E:pmath=mob;pmt(0x2661);break;//white heart suit
			case 0x7F:pmath=mob;pmt(0x2660);break;//black spade suit
			}
			temp++;
		}while(*temp) ;
		return;
	}

	
		if (strstr(currentFont,"cmbxti")){
		do{
			switch(*temp){
			case 0x00:pmath=mib;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mib;pmt(0x0394);break;//Delta
			case 0x02:pmath=mib;pmt(0x0398);break;//Theta
			case 0x03:pmath=mib;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mib;pmt(0x039E);break;//Xi
			case 0x05:pmath=mib;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mib;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mib;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mib;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mib;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mib;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mobi;pmt(0x0131);break;//imath
			case 0x11:pmath=mobi;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mobi;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mobi;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mobi;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mobi;pmt(0x02D8);break;//breve
			case 0x16:pmath=mobi;pmt(0x00AF);break;//macron
			case 0x17:pmath=mobi;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mobi;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mib;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mib;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mib;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mib;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mib;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mib;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mib;pmt(0x00D8);break;//O slash

			case 0x20:pmath=mobi;pmt(0x0374);break;//greek numerical sign
			case 0x21:pmath=mobi;pmt(*temp);break;//!
			case 0x22:pmath=mobi;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:pmath=mobi;pmt(0x00A3);break;//UK sterling symbol
			case 0x25:pmath=mobi;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold-italic\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mobi;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mobi;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mobi;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mni;pmt(*temp);break;
			case 0x3A:pmath=mobi;pmt(*temp);break;//:
			case 0x3B:pmath=mobi;pmt(*temp);break;//;
			case 0x3C:pmath=mobi;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D:pmath=mobi;//equal
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mobi;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mobi;pmt(*temp);break;//?

			case 0x40:pmath=mobi;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mobi;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			case 0x5E:pmath=mobi;pmt(*temp);break;//^
			case 0x5F:pmath=mobi;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mobi;pmt(*temp);break;//`

			case 0x7B:pmath=mobi;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mobi;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mobi;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mobi;pmt(*temp);break;//tilde
			case 0x7F:pmath=mobi;pmt(0x00A8);break;//diaeresis
			default:pmath=mib;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if (strstr(currentFont,"cmbx")){
		do{
			switch(*temp){
			case 0x00:pmath=mob;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mob;pmt(0x0394);break;//Delta
			case 0x02:pmath=mob;pmt(0x0398);break;//Theta
			case 0x03:pmath=mob;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mob;pmt(0x039E);break;//Xi
			case 0x05:pmath=mob;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mob;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mob;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mob;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mob;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mob;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mob;pmt(0x0131);break;//imath
			case 0x11:pmath=mob;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mob;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mob;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mob;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mob;pmt(0x02D8);break;//breve
			case 0x16:pmath=mob;pmt(0x00AF);break;//macron
			case 0x17:pmath=mob;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mob;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mob;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mob;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mob;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mob;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mob;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mob;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mob;pmt(0x00D8);break;//O slash

			case 0x20:pmath=mob;pmt(0x0374);break;//greek numerical sign
			case 0x21:pmath=mob;pmt(*temp);break;//!
			case 0x22:pmath=mob;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mob;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mob;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mob;pmt(*temp);break;//:
			case 0x3B:pmath=mob;pmt(*temp);break;//;
			case 0x3C:pmath=mob;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D:pmath=mob;//equal
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mob;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mob;pmt(*temp);break;//?

			case 0x40:pmath=mob;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mob;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			case 0x5E:pmath=mob;pmt(*temp);break;//^
			case 0x5F:pmath=mob;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mob;pmt(*temp);break;//`

			case 0x7B:pmath=mob;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mob;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mob;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mob;pmt(*temp);break;//tilde
			case 0x7F:pmath=mob;pmt(0x00A8);break;//diaeresis
			default:pmath=mob;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if (strstr(currentFont,"cmssdc")){
		do{
			switch(*temp){
			case 0x00:pmath=mobss;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mobss;pmt(0x0394);break;//Delta
			case 0x02:pmath=mobss;pmt(0x0398);break;//Theta
			case 0x03:pmath=mobss;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mobss;pmt(0x039E);break;//Xi
			case 0x05:pmath=mobss;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mobss;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mobss;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mobss;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mobss;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mobss;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mobss;pmt(0x0131);break;//imath
			case 0x11:pmath=mobss;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mobss;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mobss;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mobss;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mobss;pmt(0x02D8);break;//breve
			case 0x16:pmath=mobss;pmt(0x00AF);break;//macron
			case 0x17:pmath=mobss;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mobss;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mobss;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mobss;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mobss;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mobss;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mobss;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mobss;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mobss;pmt(0x00D8);break;//O slash

			case 0x20:pmath=mobss;pmt(0x0374);break;//greek numerical sign
			case 0x21:pmath=mobss;pmt(*temp);break;//!
			case 0x22:pmath=mobss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mobss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold-sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mobss;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mobss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mobss;pmt(*temp);break;//:
			case 0x3B:pmath=mobss;pmt(*temp);break;//;
			case 0x3C:pmath=mobss;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D:pmath=mobss;	//equal
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mobss;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mobss;pmt(*temp);break;//?

			case 0x40:pmath=mobss;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mobss;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			case 0x5E:pmath=mobss;pmt(*temp);break;//^
			case 0x5F:pmath=mobss;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mobss;pmt(*temp);break;//`

			case 0x7B:pmath=mobss;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mobss;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mobss;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mobss;pmt(*temp);break;//tilde
			case 0x7F:pmath=mobss;pmt(0x00A8);break;//diaeresis
			default:pmath=mobss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if ((strstr(currentFont,"cmti"))||(strstr(currentFont,"cmsl"))){//slanting delegated to the stylesheet
		do{
			switch(*temp){
			case 0x00:pmath=mi;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mi;pmt(0x0394);break;//Delta
			case 0x02:pmath=mi;pmt(0x0398);break;//Theta
			case 0x03:pmath=mi;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mi;pmt(0x039E);break;//Xi
			case 0x05:pmath=mi;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mi;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mi;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mi;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mi;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mi;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=moi;pmt(0x0131);break;//imath
			case 0x11:pmath=moi;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=moi;pmt(0x0060);break;//grave accent
			case 0x13:pmath=moi;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=moi;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=moi;pmt(0x02D8);break;//breve
			case 0x16:pmath=moi;pmt(0x00AF);break;//macron
			case 0x17:pmath=moi;pmt(0x02DA);break;//ring above
			case 0x18:pmath=moi;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mi;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mi;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mi;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mi;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mi;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mi;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mi;pmt(0x00D8);break;//O slash

			case 0x20:pmath=moi;pmt(0x0374);break;//greek numerical sign
			case 0x21:pmath=moi;pmt(*temp);break;//!
			case 0x22:pmath=moi;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moi;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"italic\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moi;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldi;pmt(*temp);break;//(
			case 0x29:pmath=rdi;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moi;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moi;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mni;pmt(*temp);break;
			case 0x3A:pmath=moi;pmt(*temp);break;//:
			case 0x3B:pmath=moi;pmt(*temp);break;//;
			case 0x3C:pmath=moi;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D:pmath=moi;	//equal
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=moi;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=moi;pmt(*temp);break;//?

			case 0x40:pmath=moi;pmt(*temp);break;//@

			case 0x5B:pmath=ldi;pmt(*temp);break;//[
			case 0x5C:pmath=moi;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdi;pmt(*temp);break;//]
			case 0x5E:pmath=moi;pmt(*temp);break;//^
			case 0x5F:pmath=moi;pmt(0x02D9);break;//dot above

			case 0x60:pmath=moi;pmt(*temp);break;//`

			case 0x7B:pmath=moi;pmt(0x2013);break;//en dash
			case 0x7C:pmath=moi;pmt(0x2014);break;//em dash
			case 0x7D:pmath=moi;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=moi;pmt(*temp);break;//tilde
			case 0x7F:pmath=moi;pmt(0x00A8);break;//diaeresis
			default:pmath=mi;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
		
	if ((strstr(currentFont,"cmss"))){
		do{
			switch(*temp){
			case 0x00:pmath=moss;pmt(0x0393);break;//Gamma
			case 0x01:pmath=moss;pmt(0x0394);break;//Delta
			case 0x02:pmath=moss;pmt(0x0398);break;//Theta
			case 0x03:pmath=moss;pmt(0x039B);break;//Lambda
			case 0x04:pmath=moss;pmt(0x039E);break;//Xi
			case 0x05:pmath=moss;pmt(0x03A0);break;//Pi
			case 0x06:pmath=moss;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=moss;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=moss;pmt(0x03A6);break;//Phi
			case 0x09:pmath=moss;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=moss;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=moss;pmt(0x0131);break;//imath
			case 0x11:pmath=moss;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=moss;pmt(0x0060);break;//grave accent
			case 0x13:pmath=moss;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=moss;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=moss;pmt(0x02D8);break;//breve
			case 0x16:pmath=moss;pmt(0x00AF);break;//macron
			case 0x17:pmath=moss;pmt(0x02DA);break;//ring above
			case 0x18:pmath=moss;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=moss;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=moss;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=moss;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=moss;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=moss;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=moss;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=moss;pmt(0x00D8);break;//O slash

			case 0x20:pmath=moss;pmt(0x0374);break;//greek numerical sign
			case 0x21:pmath=moss;pmt(*temp);break;//!
			case 0x22:pmath=moss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moss;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldss;pmt(*temp);break;//(
			case 0x29:pmath=rdss;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moss;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnss;pmt(*temp);break;
			case 0x3A:pmath=moss;pmt(*temp);break;//:
			case 0x3B:pmath=moss;pmt(*temp);break;//;
			case 0x3C:pmath=moss;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D:pmath=moss;	//equal
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=moss;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=moss;pmt(*temp);break;//?

			case 0x40:pmath=moss;pmt(*temp);break;//@

			case 0x5B:pmath=ldss;pmt(*temp);break;//[
			case 0x5C:pmath=moss;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdss;pmt(*temp);break;//]
			case 0x5E:pmath=moss;pmt(*temp);break;//^
			case 0x5F:pmath=moss;pmt(0x02D9);break;//dot above

			case 0x60:pmath=moss;pmt(*temp);break;//`

			case 0x7B:pmath=moss;pmt(0x2013);break;//en dash
			case 0x7C:pmath=moss;pmt(0x2014);break;//em dash
			case 0x7D:pmath=moss;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=moss;pmt(*temp);break;//tilde
			case 0x7F:pmath=moss;pmt(0x00A8);break;//diaeresis
			default:pmath=moss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	
	if ((strstr(currentFont,"pxexa"))||(strstr(currentFont,"txexa"))){
		do{
			switch(*temp){
			case 0x00:
			case 0x01:
			case 0x02:
			case 0x03:
			case 0x04:
			case 0x05:pmath=mo;pmt(0x2639);break;//XXX not found in Unicode 4.1,
			case 0x06:
			case 0x07:pmath=mo;pmt(0x2293);break;//square cap
			case 0x08:
			case 0x09:pmath=mo;pmt(0x222F);break;//surface integral
			case 0x0A:
			case 0x0B:pmath=mo;pmt(0x2233);break;//anti-clockwise contour integral
			case 0x0C:
			case 0x0D:pmath=mo;pmt(0x2232);break;//clockwise contour integral
			case 0x0E:
			case 0x0F:pmath=mo;pmt(0x2A16);break;//quaternion integral operator

			case 0x10:
			case 0x11:pmath=mo;pmt(0x00D7);break;//multiplication sign
			case 0x12:pmath=ld;pmt(0x27E6);break;//math left white square bracket
			case 0x13:pmath=rd;pmt(0x27E7);break;//math right white square bracket
			case 0x14:pmath=ld;pmt(0x27E6);break;//math left white square bracket
			case 0x15:pmath=rd;pmt(0x27E7);break;//math right white square bracket
			case 0x16:pmath=ld;pmt(0x27E6);break;//math left white square bracket
			case 0x17:pmath=rd;pmt(0x27E7);break;//math right white square bracket
			case 0x18:pmath=ld;pmt(0x27E6);break;//math left white square bracket
			case 0x19:pmath=rd;pmt(0x27E7);break;//math right white square bracket
			case 0x1A:pmath=ld;pmt(0x27E6);break;//math left white square bracket
			case 0x1B:pmath=rd;pmt(0x27E7);break;//math right white square bracket
			case 0x1C:break;//ignore, left bracket bottom
			case 0x1D:break;//ignore, right bracket bottom
			case 0x1E:break;//ignore, left bracket extension
			case 0x1F:break;//ignore, right bracket extension

			case 0x20:break;//should be horizontal brace extension
			case 0x21:
			case 0x22:pmath=mo;pmt(0x222C);break;//double integral
			case 0x23:
			case 0x24:pmath=mo;pmt(0x222D);break;//triple integral
			case 0x25:
			case 0x26:pmath=mo;pmt(0x2A0C);break;//quad integral
			case 0x27:
			case 0x28:p("<mo>");p(ul2utf8(0x222B));p(ul2utf8(0x2026));p(ul2utf8(0x222B));p("</mo>");break;//integral dots integral
			case 0x29:
			case 0x2A:pmath=mo;pmt(0x2230);break;//volume integral
			case 0x2B:
			case 0x2C:pmath=mo;pmt(0x2233);break;//anti-clockwise contour integral
			case 0x2D:
			case 0x2E:pmath=mo;pmt(0x2232);break;//clockwise contour integral
			case 0x2F:break;//nothing here

			case 0x30:pmath=ld;pmt(0x27C5);break;//left s-bag
			case 0x31:pmath=rd;pmt(0x27C6);break;//right s-bag
			case 0x32:pmath=ld;pmt(0x27C5);break;//left s-bag
			case 0x33:pmath=rd;pmt(0x27C6);break;//right s-bag
			case 0x34:pmath=ld;pmt(0x27C5);break;//left s-bag
			case 0x35:pmath=rd;pmt(0x27C6);break;//right s-bag
			case 0x36:pmath=ld;pmt(0x27C5);break;//left s-bag
			case 0x37:pmath=rd;pmt(0x27C6);break;//right s-bag
			case 0x38:pmath=ld;pmt(0x27C5);break;//left s-bag
			case 0x39:pmath=rd;pmt(0x27C6);break;//right s-bag
			case 0x3A:pmath=ld;pmt(0x27C5);break;//left s-bag
			case 0x3B:pmath=rd;pmt(0x27C6);break;//right s-bag
			case 0x3C:pmath=ld;pmt(0x27C5);break;//left s-bag
			case 0x3D:pmath=rd;pmt(0x27C6);break;//right s-bag
			case 0x3E:
			case 0x3F:pmath=mo;pmt(0x2A0F);break;//integral avergae with slash

			case 0x40://XXX should be anti-clockwise
			case 0x41://XXX should be anti-clockwise
			case 0x42://XXX should be clockwise
			case 0x43:pmath=mo;pmt(0x222F);break;//surface integral, XXX should be clockwise
			case 0x44:
			case 0x45:
			case 0x46:
			case 0x47:pmath=mo;pmt(0x2230);break;//volume integral, XXX should be oriented
			case 0x48:
			case 0x49:
			case 0x4A:
			case 0x4B:pmath=mo;pmt(0x222F);break;//surface integral, XXX should be variations of 0x40-0x43
			case 0x4C:
			case 0x4D:
			case 0x4E:
			case 0x4F:pmath=mo;pmt(0x2230);break;//volume integral, XXX should be variations of 0x44-0x47

			case 0x50:
			case 0x51:
			case 0x52:
			case 0x53:pmath=mo;pmt(0x222F);break;//surface integral, XXX should be quaternion and oriented
			case 0x54:
			case 0x55:
			case 0x56:
			case 0x57:
			case 0x58:
			case 0x59:
			case 0x5A:
			case 0x5B:
			case 0x5C:
			case 0x5D:
			case 0x5E:
			case 0x5F:break;
			
			//nothing else in the TeX pxexa font;
			}
			temp++;
		}while(*temp) ;
		return;
	}

	
	
	if ((strstr(currentFont,"cmex"))||(strstr(currentFont,"pxex"))||(strstr(currentFont,"txex"))||(strstr(currentFont,"zppler7v"))){
		do{
			switch(*temp){
			case 0x00:pmath=ld;pmt(0x0028);break;//left parenthesis
			case 0x01:pmath=rd;pmt(0x0029);break;//right parenthesis
			case 0x02:pmath=ld;pmt(0x005B);break;//left bracket
			case 0x03:pmath=rd;pmt(0x005D);break;//right bracket
			case 0x04:pmath=ld;pmt(0x230A);break;//left floor
			case 0x05:pmath=rd;pmt(0x230B);break;//right floor
			case 0x06:pmath=ld;pmt(0x2308);break;//left ceil
			case 0x07:pmath=rd;pmt(0x2309);break;//right ceil
			case 0x08:pmath=ld;pmt(0x007b);break;//left brace
			case 0x09:pmath=rd;pmt(0x007d);break;//right brace
			case 0x0A:pmath=mo;pmt(0x2329);break;//left angle
			case 0x0B:pmath=mo;pmt(0x232A);break;//right angle
			case 0x0C:pmath=mo;pmt(0x007C);blockthis=0x007c;break;//vertical line
			case 0x0D:pmath=mo;pmt(0x2016);blockthis=0x2016;break;//double vertical line
			case 0x0E:pmath=mo;pmt(0x007C);break;//division
			case 0x0F:pmath=mo;pmt(0x2216);break;//set minus

			case 0x10:pmath=ld;pmt(0x0028);break;//left parenthesis
			case 0x11:pmath=rd;pmt(0x0029);break;//right parenthesis
			case 0x12:pmath=ld;pmt(0x0028);break;//left parenthesis
			case 0x13:pmath=rd;pmt(0x0029);break;//right parenthesis
			case 0x14:pmath=ld;pmt(0x005B);break;//left bracket
			case 0x15:pmath=rd;pmt(0x005D);break;//right bracket
			case 0x16:pmath=ld;pmt(0x230A);break;//left floor
			case 0x17:pmath=rd;pmt(0x230B);break;//right floor
			case 0x18:pmath=ld;pmt(0x2308);break;//left ceil
			case 0x19:pmath=rd;pmt(0x2309);break;//right ceil
			case 0x1A:pmath=ld;pmt(0x007B);break;//left brace
			case 0x1B:pmath=rd;pmt(0x007D);break;//right brace
			case 0x1C:pmath=mo;pmt(0x2329);break;//left angle
			case 0x1D:pmath=mo;pmt(0x232A);break;//right angle
			case 0x1E:pmath=mo;pmt(0x007C);break;//division
			case 0x1F:pmath=mo;pmt(0x2216);break;//set minus

			case 0x20:pmath=ld;pmt(0x0028);break;//left parenthesis
			case 0x21:pmath=rd;pmt(0x0029);break;//right parenthesis
			case 0x22:pmath=ld;pmt(0x005B);break;//left bracket
			case 0x23:pmath=rd;pmt(0x005D);break;//right bracket
			case 0x24:pmath=ld;pmt(0x230A);break;//left floor
			case 0x25:pmath=rd;pmt(0x230B);break;//right floor
			case 0x26:pmath=ld;pmt(0x2308);break;//left ceil
			case 0x27:pmath=rd;pmt(0x2309);break;//right ceil
			case 0x28:pmath=ld;pmt(0x007B);break;//left curly bracket
			case 0x29:pmath=rd;pmt(0x007D);break;//right curly bracket
			case 0x2A:pmath=mo;pmt(0x2329);break;//left angle bracket
			case 0x2B:pmath=mo;pmt(0x232A);break;//right angle bracket
			case 0x2C:pmath=mo;pmt(0x007C);break;//division
			case 0x2D:pmath=mo;pmt(0x2216);break;//set minus
			case 0x2E:pmath=mo;pmt(0x2215);break;//division
			case 0x2F:pmath=mo;pmt(0x2216);break;//set minus

			case 0x30:pmath=ld;pmt(0x0028);break;//pmath=ld_b;pmt(0x239B);break;//left parenthesis top
			case 0x31:pmath=rd;pmt(0x0029);break;//pmath=rd_b;pmt(0x239E);break;//right parenthesis top
			case 0x32:pmath=ld;pmt(0x005B);break;//pmath=ld_b;pmt(0x23A1);break;//left bracket upper corner
			case 0x33:pmath=rd;pmt(0x005D);break;//pmath=rd_b;pmt(0x23A4);break;//right bracket upper corner
			case 0x34:break;//pmath=ld_e;pmt(0x23A3);break;//left bracket lower corner
			case 0x35:break;//pmath=rd_e;pmt(0x23A6);break;//right bracket lower corner
			case 0x36:break;//pmath=ld_x;pmt(0x23A2);break;//left bracket extension
			case 0x37:break;//pmath=rd_x;pmt(0x23A5);break;//right bracket extension
			case 0x38:pmath=ld;pmt(0x007B);break;//pmath=ld_b;pmt(0x23A7);break;//left curly bracket top
			case 0x39:pmath=rd;pmt(0x007D);break;//pmath=rd_b;pmt(0x23AB);break;//right curly bracket top
			case 0x3A:break;//pmath=ld_e;pmt(0x23A9);break;//left curly bracket bottom
			case 0x3B:break;//pmath=rd_e;pmt(0x23AD);break;//right curly bracket bottom
			case 0x3C:break;//pmath=ld_x;pmt(0x23A8);break;//left curly bracket middle piece
			case 0x3D:break;//pmath=rd_x;pmt(0x23AC);break;//right curly bracket middle piece
			case 0x3E:break;//pmath=ld_x;pmt(0x23AA);break;//curly bracket extension
			case 0x3F:break;//pmath=mo;pmt(0x23D0);break;//vertical arrow extension

			case 0x40:break;//pmath=ld_e;pmt(0x239D);break;//left parenthesis bottom
			case 0x41:break;//pmath=rd_e;pmt(0x23A0);break;//right parenthesis bottom
			case 0x42:break;//pmath=ld_x;pmt(0x239C);break;//left parenthesis extension
			case 0x43:break;//pmath=rd_x;pmt(0x239F);break;//right parenthesis extension
			case 0x44:pmath=mo;pmt(0x2329);break;//left angle bracket
			case 0x45:pmath=mo;pmt(0x232A);break;//right angle bracket
			case 0x46:pmath=mo;pmt(0x2294);break;//square cup
			case 0x47:pmath=mo;pmt(0x2294);break;//square cup
			case 0x48:pmath=mo;pmt(0x222E);break;//textstyle contour integral
			case 0x49:pmath=mo;pmt(0x222E);break;//displaystyle contour integral
			case 0x4A:pmath=mo;pmt(0x2299);break;//circled dot operator
			case 0x4B:pmath=mo;pmt(0x2A00);break;//n-ary circled dot operator
			case 0x4C:pmath=mo;pmt(0x2295);break;//circled plus
			case 0x4D:pmath=mo;pmt(0x2295);break;//circled plus//pmt(0x2A01);break;//n-ary circled plus, XXX not yet available in fonts
			case 0x4E:pmath=mo;pmt(0x2297);break;//circled times
			case 0x4F:pmath=mo;pmt(0x2297);break;//circled times//pmt(0x2A02);break;//n-ary circled times, XXX not yet available in fonts

			case 0x50:pmath=mo;pmt(0x2211);break;//n-ary summation
			case 0x51:pmath=mo;pmt(0x220F);break;//n-ary product
			case 0x52:pmath=mo;pmt(0x222B);break;//integral sign
			case 0x53:pmath=mo;pmt(0x222A);break;//cup
			case 0x54:pmath=mo;pmt(0x2229);break;//cap
			case 0x55:pmath=mo;pmt(0x228E);break;//multiset union
			case 0x56:pmath=mo;pmt(0x2227);break;//logical and
			case 0x57:pmath=mo;pmt(0x2228);break;//logical or
			case 0x58:pmath=mo;pmt(0x2211);break;//n-ary sigma
			case 0x59:pmath=mo;pmt(0x220F);break;//n-ary product
			case 0x5A:pmath=mo;pmt(0x222B);break;//integral sign
			case 0x5B:pmath=mo;pmt(0x22C3);break;//n-ary cap
			case 0x5C:pmath=mo;pmt(0x22C2);break;//n-ary cup
			case 0x5D:pmath=mo;pmt(0x2A04);break;//n-ary multiset union
			case 0x5E:pmath=mo;pmt(0x22C0);break;//n-ary logical and
			case 0x5F:pmath=mo;pmt(0x22C1);break;//n-ary logical or

			case 0x60:pmath=mo;pmt(0x220F);break;//n-ary coproduct
			case 0x61:pmath=mo;pmt(0x220F);break;//n-ary coproduct
			case 0x62:pmath=mo;pmt(0x005E);break;//hat
			case 0x63:pmath=mo;pmt(0x005E);break;//hat
			case 0x64:pmath=mo;pmt(0x005E);break;//hat
			case 0x65:pmath=mo;pmt(0x007E);break;//tilde
			case 0x66:pmath=mo;pmt(0x22CF);break;//tilde
			case 0x67:pmath=mo;pmt(0x22CE);break;//tilde
			case 0x68:pmath=ld;pmt(0x005B);break;//left bracket
			case 0x69:pmath=rd;pmt(0x005D);break;//right bracket
			case 0x6A:pmath=ld;pmt(0x230A);break;//left floor
			case 0x6B:pmath=rd;pmt(0x230B);break;//right floor
			case 0x6C:pmath=ld;pmt(0x2308);break;//left ceil
			case 0x6D:pmath=rd;pmt(0x2309);break;//right ceil
			case 0x6E:pmath=ld;pmt(0x007B);break;//left curly bracket
			case 0x6F:pmath=rd;pmt(0x007D);break;//right curly bracket

			case 0x70:pmath=mo;pmt(0x221A);break;//radical sign
			case 0x71:pmath=mo;pmt(0x221A);break;//radical sign
			case 0x72:pmath=mo;pmt(0x221A);break;//radical sign
			case 0x73:pmath=mo;pmt(0x221A);break;//radical sign
			case 0x74:pmath=mo;pmt(0x221A);break;//radical sign extensible XXX
			case 0x75:break;//radical sign extension	XXX
			case 0x76:break;//radical sign top	XXX
			case 0x77:break;//double vertical line extension  XXX
			case 0x78:break;//tip vertical arrow upwards	XXXXX
			case 0x79:break;//tip vertical arrow downwards	XXXXXX
			case 0x7A:break;//horizontal curly bracket tip down-left,	handled in grammar at overbrace
			case 0x7B:break;//horizontal curly bracket tip down-right,	same here
			case 0x7C:break;//horizontal curly bracket tip up-left, handled in grammar at underbrace
			case 0x7D:break;//horizontal curly bracket tip up-right,	same here
			case 0x7E:break;//tip vertical double arrow upwards		XXX
			case 0x7F:break;//tip vertical double arrow downwards XXX

			default:pmath=mi;pmt(*temp);
			}
			temp++;
		}while(*temp) ;
		return;
	}


		if (strstr(currentFont,"eurm")){//identical to cmmi, but upright
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mo;pmt(0x0394);break;//Delta
			case 0x02:pmath=mo;pmt(0x0398);break;//Theta
			case 0x03:pmath=mo;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mo;pmt(0x039E);break;//Xi
			case 0x05:pmath=mo;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mo;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mo;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mo;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mo;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mo;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=mo;pmt(0x03B1);break;//alpha
			case 0x0C:pmath=mo;pmt(0x03B2);break;//beta
			case 0x0D:pmath=mo;pmt(0x03B3);break;//gamma
			case 0x0E:pmath=mo;pmt(0x03B4);break;//delta
			case 0x0F:pmath=mo;pmt(0x03B5);break;//epsilon

			case 0x10:pmath=mo;pmt(0x03B6);break;//zeta
			case 0x11:pmath=mo;pmt(0x03B7);break;//eta
			case 0x12:pmath=mo;pmt(0x03B8);break;//theta
			case 0x13:pmath=mo;pmt(0x03B9);break;//iota
			case 0x14:pmath=mo;pmt(0x03BA);break;//kappa
			case 0x15:pmath=mo;pmt(0x03BB);break;//lambda
			case 0x16:pmath=mo;pmt(0x03BC);break;//mu
			case 0x17:pmath=mo;pmt(0x03BD);break;//nu
			case 0x18:pmath=mo;pmt(0x03BE);break;//xi
			case 0x19:pmath=mo;pmt(0x03C0);break;//pi
			case 0x1A:pmath=mo;pmt(0x03C1);break;//ro
			case 0x1B:pmath=mo;pmt(0x03C3);break;//sigma
			case 0x1C:pmath=mo;pmt(0x03C4);break;//tau
			case 0x1D:pmath=mo;pmt(0x03C5);break;//upsilon
			case 0x1E:pmath=mo;pmt(0x03C6);break;//phi
			case 0x1F:pmath=mo;pmt(0x03C7);break;//chi

			case 0x20:pmath=mo;pmt(0x03C8);break;//psi
			case 0x21:pmath=mo;pmt(0x03C9);break;//omega
			case 0x22:pmath=mo;pmt(0x025B);break;//latin epsilon
			case 0x23:pmath=mo;pmt(0x03D1);break;//script theta
			case 0x24:pmath=mo;pmt(0x03D6);break;//varpi

			//nothing here

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;//digits
			case 0x3A:pmath=mo;pmt(0x002E);break;//dot
			case 0x3B:pmath=mo;pmt(0x002C);break;//comma
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"normal\">&lt;</mo>");
				break;
			case 0x3D:pmath=mo;pmt(0x002F);break;//division
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"normal\">&gt;</mo>");
				break;
			//nothing here
			
			case 0x40:pmath=mo;pmt(0x2202);break;//partial diff

			//nothing here

			case 0x60:pmath=mo;pmt(0x2113);break;//ell script

			case 0x7B:pmath=mo;pmt(0x0131);break;//imath
			case 0x7C:pmath=mo;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x7D:pmath=mos;pmt('P');break;//pmath=mo;pmt(0x2188);break;//script capital P
			//nothing here
			
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if (strstr(currentFont,"eufm")){//fraktur
		do{
			switch(*temp){
			case 0x00:pmath=mof;pmt(0x0076);break;//v, should be pmt(0x1D533),FIXME not sure
			case 0x01:pmath=mof;pmt(0x0064);break;//d, should be pmt(0x1D521),FIXME not sure
			case 0x02:pmath=mof;pmt(0x0066);break;//f, should be pmt(0x1D523),FIXME not sure
			case 0x03:pmath=mof;pmt(0x0066);break;//f, should be pmt(0x1D523),FIXME not sure
			case 0x04:pmath=mof;pmt(0x0067);break;//g, should be pmt(0x1D524),FIXME not sure
			case 0x05:pmath=mof;pmt(0x006B);break;//k, should be pmt(0x1D528),FIXME not sure
			case 0x06:pmath=mof;pmt(0x0074);break;//t, should be pmt(0x1D531),FIXME not sure
			case 0x07:pmath=mof;pmt(0x0075);break;//u, should be pmt(0x1D532),FIXME not sure
			
			//nothing
			
			case 0x12:pmath=ld;pmt(0x2018);break;//leftquote
			case 0x13:pmath=rd;pmt(0x2019);break;//rightquote
			
			//nothing
			
			case 0x21:pmath=mof;pmt(*temp);break;//!
			
			//nothing
			
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"fraktur\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"fraktur\">&apos;</mo>");
				}else 
					p("&apos;");
				break;//single quote, apostrophe
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mof;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mof;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:
			case 0x3B:pmath=mof;pmt(*temp);break;//;
			//nothing
			case 0x3D:pmath=mof; //equal
				precomposedNegative(*temp, 0x2260);
				break;
			//nothing
			case 0x3F:

			case 0x41:
			case 0x42:
			case 0x43:
			case 0x44:
			case 0x45:
			case 0x46:
			case 0x47:
			case 0x48:
			case 0x49:
			case 0x4A:
			case 0x4B:
			case 0x4C:
			case 0x4D:
			case 0x4E:
			case 0x4F:

			case 0x50:
			case 0x51:
			case 0x52:
			case 0x53:
			case 0x54:
			case 0x55:
			case 0x56:
			case 0x57:
			case 0x58:
			case 0x59:
			case 0x5A:pmath=mof;pmt(*temp);break;//pmt(0x2128);break;//fraktur A-Z
			case 0x5B:pmath=ld;pmt(*temp);break;//[
			//nothing
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			case 0x5E:pmath=rd;pmt(*temp);break;//^
			
			//nothing

			case 0x61:
			case 0x62:
			case 0x63:
			case 0x64:
			case 0x65:
			case 0x66:
			case 0x67:
			case 0x68:
			case 0x69:
			case 0x6A:
			case 0x6B:
			case 0x6C:
			case 0x6D:
			case 0x6E:
			case 0x6F:

			case 0x70:
			case 0x71:
			case 0x72:
			case 0x73:
			case 0x74:
			case 0x75:
			case 0x76:
			case 0x77:
			case 0x78:
			case 0x79:
			case 0x7A:pmath=mof;pmt(*temp);break;//pmt(0x1D59F);break;//fraktur a-z
			//nothing
			case 0x7D:pmath=mof;pmt(0x0022);break;//quotation mark, (XXX)
			//nothing

			}
			temp++;
		}while(*temp) ;
		return;
	}
	
	if (strstr(currentFont,"cmcsc")){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mo;pmt(0x0394);break;//Delta
			case 0x02:pmath=mo;pmt(0x0398);break;//Theta
			case 0x03:pmath=mo;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mo;pmt(0x039E);break;//Xi
			case 0x05:pmath=mo;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mo;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mo;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mo;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mo;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mo;pmt(0x03A9);break;//Omega
			case 0x0B:pmath=mo;pmt(0x2191);break;//up arrow
			case 0x0C:pmath=mo;pmt(0x2193);break;//down arrow
			case 0x0D:pmath=mo;pmt(0x2032);break;//prime
			case 0x0E:pmath=mo;pmt(0x00A1);break;//inverted exclamation mark
			case 0x0F:pmath=mo;pmt(0x00BF);break;//inverted question mark

			case 0x10:pmath=mo;pmt(0x026A);break;//latin i small capital
			case 0x11:pmath=mo;pmt(0x006A);break;//j (ascii)
			case 0x12:pmath=mo;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mo;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mo;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mo;pmt(0x02D8);break;//breve
			case 0x16:pmath=mo;pmt(0x00AF);break;//macron
			case 0x17:pmath=mo;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mo;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mo;pmt(0x00DF);break;//german SS (XXX)
			case 0x1A:pmath=mo;pmt(0x00E6);break;//latin ae (XXX)
			case 0x1B:pmath=mo;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mo;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mo;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mo;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mo;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mo;pmt(*temp);break;//!
			case 0x22:pmath=mo;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mo;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo>&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mo;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mo;pmt(*temp);break;//:
			case 0x3B:pmath=mo;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo>&lt;</mo>");
				break;
			case 0x3D: //equal
				pmath=mo;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo>&gt;</mo>");
				break;
			case 0x3F:pmath=mo;pmt(*temp);break;//?

			case 0x40:pmath=mo;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=ld;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			case 0x5E:pmath=mo;pmt(*temp);break;//^
			case 0x5F:pmath=mo;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mo;pmt(*temp);break;//`
			
			case 0x7B:pmath=mo;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mo;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mo;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mo;pmt(*temp);break;//tilde
			case 0x7F:pmath=mo;pmt(0x00A8);break;//diaeresis
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if (strstr(currentFont,"cmu")){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x0393);break;//Gamma
			case 0x01:pmath=mo;pmt(0x0394);break;//Delta
			case 0x02:pmath=mo;pmt(0x0398);break;//Theta
			case 0x03:pmath=mo;pmt(0x039B);break;//Lambda
			case 0x04:pmath=mo;pmt(0x039E);break;//Xi
			case 0x05:pmath=mo;pmt(0x03A0);break;//Pi
			case 0x06:pmath=mo;pmt(0x03A3);break;//Sigma
			case 0x07:pmath=mo;pmt(0x03D2);break;//Upsilon with hook
			case 0x08:pmath=mo;pmt(0x03A6);break;//Phi
			case 0x09:pmath=mo;pmt(0x03A8);break;//Psi
			case 0x0A:pmath=mo;pmt(0x03A9);break;//Omega
			case 0x0B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x0C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x0D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x0E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x0F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x10:pmath=mo;pmt(0x0131);break;//imath
			case 0x11:pmath=mo;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x12:pmath=mo;pmt(0x0060);break;//grave accent
			case 0x13:pmath=mo;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=mo;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=mo;pmt(0x02D8);break;//breve
			case 0x16:pmath=mo;pmt(0x00AF);break;//macron
			case 0x17:pmath=mo;pmt(0x02DA);break;//ring above
			case 0x18:pmath=mo;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mo;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mo;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mo;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mo;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mo;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mo;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mo;pmt(0x00D8);break;//O slash

			case 0x20:combiningUnicode=0x0374;break;//overlay short solidus
			case 0x21:pmath=mo;pmt(*temp);break;//!
			case 0x22:pmath=mo;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:pmath=mo;pmt(0x00A3);break;//UK sterling symbol
			case 0x25:pmath=mo;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo>&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mo;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mo;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mo;pmt(*temp);break;//:
			case 0x3B:pmath=mo;pmt(*temp);break;//;
			case 0x3C:pmath=mo;pmt(0x00A1);break;//inverted exclamation mark
			case 0x3D: //equal
				pmath=mo;
				precomposedNegative(*temp, 0x2260);
				break;
			case 0x3E:pmath=mo;pmt(0x00BF);break;//inverted question mark
			case 0x3F:pmath=mo;pmt(*temp);break;//?

			case 0x40:pmath=mo;pmt(*temp);break;//@

			case 0x5B:pmath=ld;pmt(*temp);break;//[
			case 0x5C:pmath=mo;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rd;pmt(*temp);break;//]
			case 0x5E:pmath=mo;pmt(*temp);break;//^
			case 0x5F:pmath=mo;pmt(0x02D9);break;//dot above

			case 0x60:pmath=mo;pmt(0x2018);break;//leftquote

			case 0x7B:pmath=mo;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mo;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mo;pmt(0x02DD);break;//double acute accent
			case 0x7E:pmath=mo;pmt(*temp);break;//tilde
			case 0x7F:pmath=mo;pmt(0x00A8);break;//diaeresis
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if (strstr(currentFont,"wncyr")){//cyrillic
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x040A);break;//NJE
			case 0x01:pmath=mo;pmt(0x0409);break;//LJE
			case 0x02:pmath=mo;pmt(0x040F);break;//DZHE
			case 0x03:pmath=mo;pmt(0x042D);break;//E
			case 0x04:pmath=mo;pmt(0x0406);break;//I
			case 0x05:pmath=mo;pmt(0x0404);break;//Ukrainian IE
			case 0x06:pmath=mo;pmt(0x0402);break;//DJE
			case 0x07:pmath=mo;pmt(0x040B);break;//TSHE
			case 0x08:pmath=mo;pmt(0x045A);break;//nje
			case 0x09:pmath=mo;pmt(0x0459);break;//lje
			case 0x0A:pmath=mo;pmt(0x045F);break;//dzhe
			case 0x0B:pmath=mo;pmt(0x044D);break;//e
			case 0x0C:pmath=mo;pmt(0x0456);break;//i
			case 0x0D:pmath=mo;pmt(0x0454);break;//ukrainian ie
			case 0x0E:pmath=mo;pmt(0x0452);break;//dje
			case 0x0F:pmath=mo;pmt(0x045B);break;//tshe

			case 0x10:pmath=mo;pmt(0x042E);break;//YU
			case 0x11:pmath=mo;pmt(0x0416);break;//ZHE
			case 0x12:pmath=mo;pmt(0x0419);break;//short I
			case 0x13:pmath=mo;pmt(0x0401);break;//IO
			case 0x14:pmath=mo;pmt(0x0474);break;//IZHITSA
			case 0x15:pmath=mo;pmt(0x0472);break;//FITA
			case 0x16:pmath=mo;pmt(0x0405);break;//DZE
			case 0x17:pmath=mo;pmt(0x042F);break;//YA
			case 0x18:pmath=mo;pmt(0x044E);break;//yu
			case 0x19:pmath=mo;pmt(0x0436);break;//zhe
			case 0x1A:pmath=mo;pmt(0x0439);break;//short i
			case 0x1B:pmath=mo;pmt(0x0451);break;//io
			case 0x1C:pmath=mo;pmt(0x0475);break;//izhitsa
			case 0x1D:pmath=mo;pmt(0x0473);break;//fita
			case 0x1E:pmath=mo;pmt(0x0455);break;//dze
			case 0x1F:pmath=mo;pmt(0x044F);break;//ya

			case 0x20:pmath=mo;pmt(0x00A8);break;//diaeresis
			case 0x21:pmath=mo;pmt(*temp);break;//!
			case 0x22:pmath=mo;pmt(0x201D);break;//right double quotation mark
			case 0x23:pmath=mo;pmt(0x0462);break;//YAT
			case 0x24:pmath=mo;pmt(0x02D8);break;//breve XXX should be breve1
			case 0x25:pmath=mo;pmt(*temp);break;//%
			case 0x26:pmath=mo;pmt(0x00B4);break;//acute 
			case 0x27:pmath=mo;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ld;pmt(*temp);break;//(
			case 0x29:pmath=rd;pmt(*temp);break;//)
			case 0x2A:pmath=mo;pmt(*temp);break;//*
			case 0x2B:pmath=mo;pmt(0x0463);break;//yat
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D://-
			case 0x2E://.
			case 0x2F:pmath=mo;pmt(*temp);break;//slash

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;//arabic numerals
			case 0x3A:pmath=mo;pmt(*temp);break;//:
			case 0x3B:pmath=mo;pmt(*temp);break;//;
			case 0x3C:pmath=mo;pmt(0x00AB);break;//guillemet left 
			case 0x3D:pmath=mo;pmt(0x0131);break;//imath
			case 0x3E:pmath=mo;pmt(0x00BB);break;//guillemet right 
			case 0x3F:pmath=mo;pmt(*temp);break;//?

			case 0x40:pmath=mo;pmt(0x02D8);break;//breve 
			case 0x41:pmath=mo;pmt(0x0410);break;//A
			case 0x42:pmath=mo;pmt(0x0411);break;//BE
			case 0x43:pmath=mo;pmt(0x0426);break;//TSE
			case 0x44:pmath=mo;pmt(0x0414);break;//DE
			case 0x45:pmath=mo;pmt(0x0415);break;//IE
			case 0x46:pmath=mo;pmt(0x0424);break;//EF
			case 0x47:pmath=mo;pmt(0x0413);break;//GHE
			case 0x48:pmath=mo;pmt(0x0425);break;//HA
			case 0x49:pmath=mo;pmt(0x0418);break;//I
			case 0x4A:pmath=mo;pmt(0x0408);break;//JE
			case 0x4B:pmath=mo;pmt(0x041A);break;//KA
			case 0x4C:pmath=mo;pmt(0x041B);break;//EL
			case 0x4D:pmath=mo;pmt(0x041C);break;//EM
			case 0x4E:pmath=mo;pmt(0x041D);break;//EN
			case 0x4F:pmath=mo;pmt(0x041E);break;//O

			case 0x50:pmath=mo;pmt(0x041F);break;//PE
			case 0x51:pmath=mo;pmt(0x0427);break;//CHE
			case 0x52:pmath=mo;pmt(0x0420);break;//ER
			case 0x53:pmath=mo;pmt(0x0421);break;//ES
			case 0x54:pmath=mo;pmt(0x0422);break;//TE
			case 0x55:pmath=mo;pmt(0x0423);break;//U
			case 0x56:pmath=mo;pmt(0x0412);break;//VE
			case 0x57:pmath=mo;pmt(0x0429);break;//SHCHA
			case 0x58:pmath=mo;pmt(0x0428);break;//SHA
			case 0x59:pmath=mo;pmt(0x042B);break;//YERU
			case 0x5A:pmath=mo;pmt(0x0417);break;//ZE
			
			case 0x5B:pmath=ld;pmt(*temp);break;//left bracket
			case 0x5C:pmath=ld;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rd;pmt(*temp);break;//right bracket
			case 0x5E:pmath=mo;pmt(0x044C);break;//soft sign
			case 0x5F:pmath=mo;pmt(0x044A);break;//hard sign

			case 0x60:pmath=mo;pmt(*temp);break;//`
			case 0x61:pmath=mo;pmt(0x0430);break;//a 
			case 0x62:pmath=mo;pmt(0x0431);break;//be
			case 0x63:pmath=mo;pmt(0x0446);break;//tse
			case 0x64:pmath=mo;pmt(0x0434);break;//de
			case 0x65:pmath=mo;pmt(0x0435);break;//ie
			case 0x66:pmath=mo;pmt(0x0444);break;//ef
			case 0x67:pmath=mo;pmt(0x0433);break;//ghe
			case 0x68:pmath=mo;pmt(0x0445);break;//ha
			case 0x69:pmath=mo;pmt(0x0438);break;//i
			case 0x6A:pmath=mo;pmt(0x0458);break;//je
			case 0x6B:pmath=mo;pmt(0x043A);break;//ka
			case 0x6C:pmath=mo;pmt(0x043B);break;//el
			case 0x6D:pmath=mo;pmt(0x043C);break;//em
			case 0x6E:pmath=mo;pmt(0x043D);break;//en
			case 0x6F:pmath=mo;pmt(0x043E);break;//o
			case 0x70:pmath=mo;pmt(0x043F);break;//pe
			case 0x71:pmath=mo;pmt(0x0447);break;//che
			case 0x72:pmath=mo;pmt(0x0440);break;//er
			case 0x73:pmath=mo;pmt(0x0441);break;//es
			case 0x74:pmath=mo;pmt(0x0442);break;//te
			case 0x75:pmath=mo;pmt(0x0443);break;//u
			case 0x76:pmath=mo;pmt(0x0432);break;//ve
			case 0x77:pmath=mo;pmt(0x0449);break;//shcha
			case 0x78:pmath=mo;pmt(0x0448);break;//sha
			case 0x79:pmath=mo;pmt(0x044B);break;//yeru
			case 0x7A:pmath=mo;pmt(0x0437);break;//ze
			
			case 0x7B:pmath=mo;pmt(0x2013);break;//en dash
			case 0x7C:pmath=mo;pmt(0x2014);break;//em dash
			case 0x7D:pmath=mo;pmt(0x2116);break;//numero sign
			case 0x7E:pmath=mo;pmt(0x044C);break;//soft
			case 0x7F:pmath=mo;pmt(0x044A);break;//hard
			default:pmath=mo;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if (strstr(currentFont,"wncyi")){//cyrillic
		do{
			switch(*temp){
			case 0x00:pmath=mi;pmt(0x040A);break;//NJE
			case 0x01:pmath=mi;pmt(0x0409);break;//LJE
			case 0x02:pmath=mi;pmt(0x040F);break;//DZHE
			case 0x03:pmath=mi;pmt(0x042D);break;//E
			case 0x04:pmath=mi;pmt(0x0406);break;//I
			case 0x05:pmath=mi;pmt(0x0404);break;//Ukrainian IE
			case 0x06:pmath=mi;pmt(0x0402);break;//DJE
			case 0x07:pmath=mi;pmt(0x040B);break;//TSHE
			case 0x08:pmath=mi;pmt(0x045A);break;//nje
			case 0x09:pmath=mi;pmt(0x0459);break;//lje
			case 0x0A:pmath=mi;pmt(0x045F);break;//dzhe
			case 0x0B:pmath=mi;pmt(0x044D);break;//e
			case 0x0C:pmath=mi;pmt(0x0456);break;//i
			case 0x0D:pmath=mi;pmt(0x0454);break;//ukrainian ie
			case 0x0E:pmath=mi;pmt(0x0452);break;//dje
			case 0x0F:pmath=mi;pmt(0x045B);break;//tshe

			case 0x10:pmath=mi;pmt(0x042E);break;//YU
			case 0x11:pmath=mi;pmt(0x0416);break;//ZHE
			case 0x12:pmath=mi;pmt(0x0419);break;//short I
			case 0x13:pmath=mi;pmt(0x0401);break;//IO
			case 0x14:pmath=mi;pmt(0x0474);break;//IZHITSA
			case 0x15:pmath=mi;pmt(0x0472);break;//FITA
			case 0x16:pmath=mi;pmt(0x0405);break;//DZE
			case 0x17:pmath=mi;pmt(0x042F);break;//YA
			case 0x18:pmath=mi;pmt(0x044E);break;//yu
			case 0x19:pmath=mi;pmt(0x0436);break;//zhe
			case 0x1A:pmath=mi;pmt(0x0439);break;//short i
			case 0x1B:pmath=mi;pmt(0x0451);break;//io
			case 0x1C:pmath=mi;pmt(0x0475);break;//izhitsa
			case 0x1D:pmath=mi;pmt(0x0473);break;//fita
			case 0x1E:pmath=mi;pmt(0x0455);break;//dze
			case 0x1F:pmath=mi;pmt(0x044F);break;//ya

			case 0x20:pmath=moi;pmt(0x00A8);break;//diaeresis
			case 0x21:pmath=moi;pmt(*temp);break;//!
			case 0x22:pmath=moi;pmt(0x201D);break;//right double quotation mark
			case 0x23:pmath=mi;pmt(0x0462);break;//YAT
			case 0x24:pmath=moi;pmt(0x02D8);break;//breve XXX should be breve1
			case 0x25:pmath=moi;pmt(*temp);break;//%
			case 0x26:pmath=moi;pmt(0x00B4);break;//acute 
			case 0x27:pmath=moi;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldi;pmt(*temp);break;//(
			case 0x29:pmath=rdi;pmt(*temp);break;//)
			case 0x2A:pmath=moi;pmt(*temp);break;//*
			case 0x2B:pmath=mi;pmt(0x0463);break;//yat
			case 0x2C:inhibitspace=0;pmath=moi;pmt(*temp);break;
			case 0x2D://-
			case 0x2E://.
			case 0x2F:pmath=moi;pmt(*temp);break;//slash

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mni;pmt(*temp);break;//arabic numerals
			case 0x3A:pmath=moi;pmt(*temp);break;//:
			case 0x3B:pmath=moi;pmt(*temp);break;//;
			case 0x3C:pmath=moi;pmt(0x00AB);break;//guillemet left 
			case 0x3D:pmath=moi;pmt(0x0131);break;//imath
			case 0x3E:pmath=moi;pmt(0x00BB);break;//guillemet right 
			case 0x3F:pmath=moi;pmt(*temp);break;//?

			case 0x40:pmath=moi;pmt(0x02D8);break;//breve 
			case 0x41:pmath=mi;pmt(0x0410);break;//A
			case 0x42:pmath=mi;pmt(0x0411);break;//BE
			case 0x43:pmath=mi;pmt(0x0426);break;//TSE
			case 0x44:pmath=mi;pmt(0x0414);break;//DE
			case 0x45:pmath=mi;pmt(0x0415);break;//IE
			case 0x46:pmath=mi;pmt(0x0424);break;//EF
			case 0x47:pmath=mi;pmt(0x0413);break;//GHE
			case 0x48:pmath=mi;pmt(0x0425);break;//HA
			case 0x49:pmath=mi;pmt(0x0418);break;//I
			case 0x4A:pmath=mi;pmt(0x0408);break;//JE
			case 0x4B:pmath=mi;pmt(0x041A);break;//KA
			case 0x4C:pmath=mi;pmt(0x041B);break;//EL
			case 0x4D:pmath=mi;pmt(0x041C);break;//EM
			case 0x4E:pmath=mi;pmt(0x041D);break;//EN
			case 0x4F:pmath=mi;pmt(0x041E);break;//O

			case 0x50:pmath=mi;pmt(0x041F);break;//PE
			case 0x51:pmath=mi;pmt(0x0427);break;//CHE
			case 0x52:pmath=mi;pmt(0x0420);break;//ER
			case 0x53:pmath=mi;pmt(0x0421);break;//ES
			case 0x54:pmath=mi;pmt(0x0422);break;//TE
			case 0x55:pmath=mi;pmt(0x0423);break;//U
			case 0x56:pmath=mi;pmt(0x0412);break;//VE
			case 0x57:pmath=mi;pmt(0x0429);break;//SHCHA
			case 0x58:pmath=mi;pmt(0x0428);break;//SHA
			case 0x59:pmath=mi;pmt(0x042B);break;//YERU
			case 0x5A:pmath=mi;pmt(0x0417);break;//ZE
			
			case 0x5B:pmath=ldi;pmt(*temp);break;//left bracket
			case 0x5C:pmath=ldi;pmt(0x201C);break;//left double quotation mark
			case 0x5D:pmath=rdi;pmt(*temp);break;//right bracket
			case 0x5E:pmath=moi;pmt(0x044C);break;//soft sign
			case 0x5F:pmath=moi;pmt(0x044A);break;//hard sign

			case 0x60:pmath=moi;pmt(*temp);break;//`
			case 0x61:pmath=mi;pmt(0x0430);break;//a 
			case 0x62:pmath=mi;pmt(0x0431);break;//be
			case 0x63:pmath=mi;pmt(0x0446);break;//tse
			case 0x64:pmath=mi;pmt(0x0434);break;//de
			case 0x65:pmath=mi;pmt(0x0435);break;//ie
			case 0x66:pmath=mi;pmt(0x0444);break;//ef
			case 0x67:pmath=mi;pmt(0x0433);break;//ghe
			case 0x68:pmath=mi;pmt(0x0445);break;//ha
			case 0x69:pmath=mi;pmt(0x0438);break;//i
			case 0x6A:pmath=mi;pmt(0x0458);break;//je
			case 0x6B:pmath=mi;pmt(0x043A);break;//ka
			case 0x6C:pmath=mi;pmt(0x043B);break;//el
			case 0x6D:pmath=mi;pmt(0x043C);break;//em
			case 0x6E:pmath=mi;pmt(0x043D);break;//en
			case 0x6F:pmath=mi;pmt(0x043E);break;//o
			case 0x70:pmath=mi;pmt(0x043F);break;//pe
			case 0x71:pmath=mi;pmt(0x0447);break;//che
			case 0x72:pmath=mi;pmt(0x0440);break;//er
			case 0x73:pmath=mi;pmt(0x0441);break;//es
			case 0x74:pmath=mi;pmt(0x0442);break;//te
			case 0x75:pmath=mi;pmt(0x0443);break;//u
			case 0x76:pmath=mi;pmt(0x0432);break;//ve
			case 0x77:pmath=mi;pmt(0x0449);break;//shcha
			case 0x78:pmath=mi;pmt(0x0448);break;//sha
			case 0x79:pmath=mi;pmt(0x044B);break;//yeru
			case 0x7A:pmath=mi;pmt(0x0437);break;//ze
			
			case 0x7B:pmath=moi;pmt(0x2013);break;//en dash
			case 0x7C:pmath=moi;pmt(0x2014);break;//em dash
			case 0x7D:pmath=moi;pmt(0x2116);break;//numero sign
			case 0x7E:pmath=moi;pmt(0x044C);break;//soft
			case 0x7F:pmath=moi;pmt(0x044A);break;//hard
			default:pmath=mi;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
			
	if (strstr(currentFont,"eusm")){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt('-');break;//-
			//nothing
			case 0x18:pmath=mo;pmt(0x223C);break;//\sim
			//nothing
			case 0x3A:pmath=mo;pmt(0x00AC);break;//\neg
			//nothing
			case 0x3C:pmath=mo;pmt(0x211C);break;//real part
			case 0x3D:pmath=mo;pmt(0x2111);break;//image part
			//nothing
			case 0x40:pmath=mo;pmt(0x2135);break;//\aleph transfinite
			case 0x41:
			case 0x42:
			case 0x43:
			case 0x44:
			case 0x45:
			case 0x46:
			case 0x47:
			case 0x48:
			case 0x49:
			case 0x4A:
			case 0x4B:
			case 0x4C:
			case 0x4D:
			case 0x4E:
			case 0x4F:
			
			case 0x50:
			case 0x51:
			case 0x52:
			case 0x53:
			case 0x54:
			case 0x55:
			case 0x56:
			case 0x57:
			case 0x58:
			case 0x59:
			case 0x5A:pmath=mos;pmt(*temp);break;//A-Z script, straight
			//nothing
			case 0x5E:pmath=mos;pmt(0x2227);break;//and
			case 0x5F:pmath=mos;pmt(0x2228);break;//or
			
			//nothing
			case 0x66:pmath=lds;pmt('{');break;//{
			case 0x67:pmath=rds;pmt('}');break;//}
			//nothing
			case 0x6A:pmath=mos;pmt('|');break;//
			//nothing
			case 0x6E:pmath=mos;pmt('\\');break;//
			//nothing
			case 0x78:pmath=mos;pmt(0x00A7);break;//section sign
			
			}
			temp++;
		}while(*temp);
		return;
	}

	if (strstr(currentFont,"euex")){
		do{
			switch(*temp){
			//nothing
			case 0x08:pmath=ld;pmt('{');break;//
			case 0x09:pmath=rd;pmt('}');break;//
			case 0x0A:pmath=ld;pmt('{');break;//
			case 0x0B:pmath=rd;pmt('}');break;//
			case 0x0C:pmath=ld;pmt('{');break;//
			case 0x0D:pmath=rd;pmt('}');break;//
			case 0x0E:pmath=ld;pmt('{');break;//
			case 0x0F:pmath=rd;pmt('}');break;//
			//nothing
			case 0x18:pmath=mo;pmt(0x21BC);break;//left harpoon barb up
			case 0x19:pmath=mo;pmt(0x21BD);break;//left harpoon barb down
			case 0x1A:pmath=mo;pmt(0x21C0);break;//right harpoon barb up
			case 0x1B:pmath=mo;pmt(0x21C1);break;//right harpoon barb down
			//nothing
			case 0x20:pmath=mo;pmt(0x2190);break;//left arrow
			case 0x21:pmath=mo;pmt(0x2192);break;//right arrow
			case 0x22:pmath=mo;pmt(0x2191);break;//up arrow
			case 0x23:pmath=mo;pmt(0x2193);break;//down arrow
			case 0x24:pmath=mo;pmt(0x2194);break;//left right arrow
			case 0x25:pmath=mo;pmt(0x2197);break;//N-E arrow
			case 0x26:pmath=mo;pmt(0x2198);break;//S-E arrow
			//nothing
			case 0x28:pmath=mo;pmt(0x21D0);break;//left double arrow
			case 0x29:pmath=mo;pmt(0x21D2);break;//right double arrow
			case 0x2A:pmath=mo;pmt(0x21D1);break;//up double arrow
			case 0x2B:pmath=mo;pmt(0x21D3);break;//down double arrow
			case 0x2C:pmath=mo;pmt(0x21D4);break;//left right double arrow
			case 0x2D:pmath=mo;pmt(0x2196);break;//N-W arrow
			case 0x2E:pmath=mo;pmt(0x2199);break;//S-W arrow
			//nothing
			case 0x31:pmath=mo;pmt(0x221E);break;//infinity
			
			case 0x38:pmath=ld;pmt('{');break;//infinity
			//XXX, let the extensions out and mark only the margins
			//XXX, scaling is done by the mathplayer
			case 0x3B:pmath=rd;pmt('{');break;//infinity
			
			//nothing
			
			case 0x48:
			case 0x49:pmath=mo;pmt(0x222E);break;//\oint
			//nothing
			
			case 0x50:pmath=mo;pmt(0x2211);break;//sum
			case 0x51:pmath=mo;pmt(0x220F);break;//product
			case 0x52:pmath=mo;pmt(0x222B);break;//\int
			//nothing
			case 0x58:pmath=mo;pmt(0x2211);break;//sum
			case 0x59:pmath=mo;pmt(0x220F);break;//product
			case 0x5A:pmath=mo;pmt(0x222B);break;//\int
			//nothing
			case 0x60:
			case 0x61:pmath=mo;pmt(0x220F);break;//n-ary coproduct
			//nothing
			//nothing
			case 0x6C:pmath=mo;pmt(0x2195);break;//up down arrow
			case 0x6D:pmath=mo;pmt(0x21D5);break;//up down double arrow
			
			//nothing, XXX, brace extensions, let the player do it
			
			}
			temp++;
		}while(*temp);
		return;
	}
		
	if (strstr(currentFont,"rsfs")){
		do{
			switch(*temp){
			
			case 0x7F:pmath=mo;pmt(0x2040);break;//tie
			
			default: pmath=mis;pmt('Z');break;//pmath=mi;pmt(0x1D4B5);break;//A-Z script; 
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if (strstr(currentFont,"lasy")){
		do{
			switch(*temp){
			//nothing here
			case 0x01:pmath=mo;pmt(0x22B2);break;//normal subgroup of
			case 0x02:pmath=mo;pmt(0x22B4);break;//normal subgroup of or equal to
			case 0x03:pmath=mo;pmt(0x22B3);break;//contains as normal subgroup
			case 0x04:pmath=mo;pmt(0x22B5);break;//contains as normal subgroup or equal to
			//nothing here
			case 0x28:pmath=mo;pmt(0x227A);break;//precedes
			case 0x29:pmath=mo;pmt(0x227B);break;//succeeds
			case 0x2A:pmath=mo;pmt(0x22CF);break;//curly logical and
			case 0x2B:pmath=mo;pmt(0x22CE);break;//curly logical or
			//nothing here
			
			case 0x30:pmath=mo;pmt(0x2127);break;//inverted ohm greek omega
			case 0x31:pmath=mo;pmt(0x22C8);break;//bowtie
			case 0x32:pmath=mo;pmt(0x25A1);break;//white square
			case 0x33:pmath=mo;pmt(0x25C7);break;//white diamond
			//nothing here
			
			case 0x3A:break;//XXX,extension to a squiggle arrow
			case 0x3B:pmath=mo;pmt(0x21DD);break;//right squiggle arrow
			case 0x3C:pmath=mo;pmt(0x228F);break;//square image of
			case 0x3D:pmath=mo;pmt(0x2290);break;//square original of
			}
			temp++;
		}while(*temp);
		return;
	}

		
	if (strstr(currentFont,"lassdc")){
		do{
			switch(*temp){
			case 0x00:pmath=mobss;pmt(0x0060);break;//grave accent
			case 0x01:pmath=mobss;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=mobss;pmt(0x005E);break;//hat
			case 0x03:pmath=mobss;pmt(0x007E);break;//tilde
			case 0x04:pmath=mobss;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=mobss;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=mobss;pmt(0x02DA);break;//ring above
			case 0x07:pmath=mobss;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=mobss;pmt(0x02D8);break;//breve
			case 0x09:pmath=mobss;pmt(0x00AF);break;//macron
			case 0x0A:pmath=mobss;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=mobss;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=mobss;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=mobss;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=mobss;pmt(0x2329);break;//left angle
			case 0x0F:pmath=mobss;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ldb;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=ldb;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=mobss;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=mobss;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=mobss;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=mobss;pmt(0x2013);break;//en dash
			case 0x16:pmath=mobss;pmt(0x2014);break;//em dash
			case 0x17:pmath=mobss;pmt(0xE003F);break;//XXX, error mark: I chose TAG question mark
			case 0x18:pmath=mobss;pmt('0');break;//XXX, pmzero???
			case 0x19:pmath=mobss;pmt(0x0131);break;//imath
			case 0x1A:pmath=mobss;pmt(0x006A);break;//jmath,pmt(0x0237);break;//jmath
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=mobss;pmt(0x2423);break;//graphic for space
			case 0x21:pmath=mobss;pmt(*temp);break;//!
			case 0x22:pmath=mobss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mobss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold-sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mobss;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mo;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mobss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mnb;pmt(*temp);break;
			case 0x3A:pmath=mobss;pmt(*temp);break;//:
			case 0x3B:pmath=mobss;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold-sans-serif\">&lt;</mo>");
				break;
			case 0x3D:pmath=mobss;pmt(0x002F);break;//division
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold-sans-serif\">&gt;</mo>");
				break;
			case 0x3F:pmath=mobss;pmt(*temp);break;//?

			case 0x40:pmath=mobss;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mobss;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			
			case 0x5E:pmath=mobss;pmt(*temp);break;//^
			case 0x5F:pmath=mobss;pmt(*temp);break;//_
			case 0x60:pmath=mobss;pmt(*temp);break;//`
			case 0x61:
			case 0x7A:break;//ascii small letters

			case 0x7B:pmath=ldb;pmt(*temp);break;//left brace
			case 0x7C:pmath=mobss;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdb;pmt(*temp);break;//right brace
			case 0x7E:pmath=mobss;pmt(*temp);break;//tilde
			case 0x7F:pmath=mobss;pmt(0x2012);break;//figure dash
			
			//cyrillic
			case 0x80:pmath=mobss;pmt(0x0490);break;//GHE with upturn
			case 0x81:pmath=mobss;pmt(0x0492);break;//GHE with stroke
			case 0x82:pmath=mobss;pmt(0x0494);break;//GHE with midhook
			case 0x83:pmath=mobss;pmt(0x040B);break;//TSHE
			case 0x84:pmath=mobss;pmt(0x04BA);break;//SHHA
			case 0x85:pmath=mobss;pmt(0x0496);break;//ZHE with descender
			case 0x86:pmath=mobss;pmt(0x0498);break;//ZE with descender
			case 0x87:pmath=mobss;pmt(0x0409);break;//LJE
			case 0x88:pmath=mobss;pmt(0x0407);break;//YI
			case 0x89:pmath=mobss;pmt(0x049A);break;//KA with descender
			case 0x8A:pmath=mobss;pmt(0x04A1);break;//KA bashkir
			case 0x8B:pmath=mobss;pmt(0x049C);break;//KA with vertical stroke
			case 0x8C:pmath=mobss;pmt(0x04D4);break;//ligature A IE
			case 0x8D:pmath=mobss;pmt(0x04A2);break;//EN with descender
			case 0x8E:pmath=mobss;pmt(0x04A4);break;//ligature EN GHE
			case 0x8F:pmath=mobss;pmt(0x0405);break;//DZE

			case 0x90:pmath=mobss;pmt(0x0472);break;//FITA
			case 0x91:pmath=mobss;pmt(0x04AA);break;//ES with descendent
			case 0x92:pmath=mobss;pmt(0x040E);break;//short U
			case 0x93:pmath=mobss;pmt(0x04AE);break;//straight U
			case 0x94:pmath=mobss;pmt(0x04B0);break;//straight U with stroke
			case 0x95:pmath=mobss;pmt(0x04B2);break;//HA with descender
			case 0x96:pmath=mobss;pmt(0x040F);break;//DZHE
			case 0x97:pmath=mobss;pmt(0x04B8);break;//CHE with vertical stroke
			case 0x98:pmath=mobss;pmt(0x04B6);break;//CHE with descender
			case 0x99:pmath=mobss;pmt(0x0404);break;//ukrainian IE
			case 0x9A:pmath=mobss;pmt(0x04D8);break;//SCHWA
			case 0x9B:pmath=mobss;pmt(0x040A);break;//NJE
			case 0x9C:pmath=mobss;pmt(0x0451);break;//IO
			case 0x9D:pmath=mobss;pmt(0x2116);break;//numero sign
			case 0x9E:pmath=mobss;pmt(0x00A4);break;//currency sign
			case 0x9F:pmath=mobss;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=mobss;pmt(0x0491);break;//ghe with upturn
			case 0xA1:pmath=mobss;pmt(0x0493);break;//ghe with stroke
			case 0xA2:pmath=mobss;pmt(0x0495);break;//ghe with midhook
			case 0xA3:pmath=mobss;pmt(0x045B);break;//tshe
			case 0xA4:pmath=mobss;pmt(0x04BB);break;//shha
			case 0xA5:pmath=mobss;pmt(0x0497);break;//zhe with descender
			case 0xA6:pmath=mobss;pmt(0x0499);break;//ze with descender
			case 0xA7:pmath=mobss;pmt(0x0459);break;//lje
			case 0xA8:pmath=mobss;pmt(0x0457);break;//yi
			case 0xA9:pmath=mobss;pmt(0x0498);break;//ka with descender
			case 0xAA:pmath=mobss;pmt(0x04A1);break;//ka bashkir
			case 0xAB:pmath=mobss;pmt(0x049D);break;//ka with vertical stroke
			case 0xAC:pmath=mobss;pmt(0x04D5);break;//ligature A IE
			case 0xAD:pmath=mobss;pmt(0x04A3);break;//en with descender
			case 0xAE:pmath=mobss;pmt(0x04A5);break;//ligature en ghe
			case 0xAF:pmath=mobss;pmt(0x0455);break;//dze
			
			case 0xB0:pmath=mobss;pmt(0x0473);break;//fita
			case 0xB1:pmath=mobss;pmt(0x04AB);break;//es with descendent
			case 0xB2:pmath=mobss;pmt(0x045E);break;//short u
			case 0xB3:pmath=mobss;pmt(0x04AF);break;//straight u
			case 0xB4:pmath=mobss;pmt(0x04B1);break;//straight u with stroke
			case 0xB5:pmath=mobss;pmt(0x04B3);break;//ha with descender
			case 0xB6:pmath=mobss;pmt(0x045F);break;//dzhe
			case 0xB7:pmath=mobss;pmt(0x04B9);break;//che with vertical stroke
			case 0xB8:pmath=mobss;pmt(0x04B7);break;//che with descender
			case 0xB9:pmath=mobss;pmt(0x0454);break;//ukrainian IE
			case 0xBA:pmath=mobss;pmt(0x04D9);break;//schwa
			case 0xBB:pmath=mobss;pmt(0x045A);break;//nje
			case 0xBC:pmath=mobss;pmt(0x0451);break;//io
			case 0xBD:pmath=moss;pmt(0x201E);break;//low double comma quot-mark
			case 0xBE:pmath=moss;pmt(0x00AB);break;//guillemet left 
			case 0xBF:pmath=mobss;pmt(0x00BB);break;//guillemet right

			case 0xC0:pmath=mobss;pmt(0x0410);break;//A
			case 0xC1:pmath=mobss;pmt(0x0411);break;//BE
			case 0xC2:pmath=mobss;pmt(0x0412);break;//VE
			case 0xC3:pmath=mobss;pmt(0x0413);break;//GHE
			case 0xC4:pmath=mobss;pmt(0x0414);break;//DE
			case 0xC5:pmath=mobss;pmt(0x0415);break;//IE
			case 0xC6:pmath=mobss;pmt(0x0416);break;//ZHE
			case 0xC7:pmath=mobss;pmt(0x0417);break;//ZE
			case 0xC8:pmath=mobss;pmt(0x0418);break;//I
			case 0xC9:pmath=mobss;pmt(0x0419);break;//short I
			case 0xCA:pmath=mobss;pmt(0x041A);break;//KA
			case 0xCB:pmath=mobss;pmt(0x041B);break;//EL
			case 0xCC:pmath=mobss;pmt(0x041C);break;//EM
			case 0xCD:pmath=mobss;pmt(0x041D);break;//EN
			case 0xCE:pmath=mobss;pmt(0x041E);break;//O
			case 0xCF:pmath=mobss;pmt(0x041F);break;//PE

			case 0xD0:pmath=mobss;pmt(0x0420);break;//ER
			case 0xD1:pmath=mobss;pmt(0x0421);break;//ES
			case 0xD2:pmath=mobss;pmt(0x0422);break;//TE
			case 0xD3:pmath=mobss;pmt(0x0423);break;//U
			case 0xD4:pmath=mobss;pmt(0x0424);break;//EF
			case 0xD5:pmath=mobss;pmt(0x0425);break;//HA
			case 0xD6:pmath=mobss;pmt(0x0426);break;//TSE
			case 0xD7:pmath=mobss;pmt(0x0427);break;//CHE
			case 0xD8:pmath=mobss;pmt(0x0428);break;//SHA
			case 0xD9:pmath=mobss;pmt(0x0429);break;//SHCHA
			case 0xDA:pmath=mobss;pmt(0x042A);break;//HARD sign
			case 0xDB:pmath=mobss;pmt(0x042B);break;//YERU
			case 0xDC:pmath=mobss;pmt(0x042C);break;//SOFT sign
			case 0xDD:pmath=mobss;pmt(0x042D);break;//E
			case 0xDE:pmath=mobss;pmt(0x042E);break;//YU
			case 0xDF:pmath=mobss;pmt(0x042F);break;//YA
			
			case 0xE0:pmath=mobss;pmt(0x0430);break;//a
			case 0xE1:pmath=mobss;pmt(0x0431);break;//be
			case 0xE2:pmath=mobss;pmt(0x0432);break;//ve
			case 0xE3:pmath=mobss;pmt(0x0433);break;//ghe
			case 0xE4:pmath=mobss;pmt(0x0434);break;//de
			case 0xE5:pmath=mobss;pmt(0x0435);break;//ie
			case 0xE6:pmath=mobss;pmt(0x0436);break;//zhe
			case 0xE7:pmath=mobss;pmt(0x0437);break;//ze
			case 0xE8:pmath=mobss;pmt(0x0438);break;//i
			case 0xE9:pmath=mobss;pmt(0x0439);break;//short i
			case 0xEA:pmath=mobss;pmt(0x043A);break;//ka
			case 0xEB:pmath=mobss;pmt(0x043B);break;//el
			case 0xEC:pmath=mobss;pmt(0x043C);break;//em
			case 0xED:pmath=mobss;pmt(0x043D);break;//en
			case 0xEE:pmath=mobss;pmt(0x043E);break;//o
			case 0xEF:pmath=mobss;pmt(0x043F);break;//pe

			case 0xF0:pmath=mobss;pmt(0x0440);break;//er
			case 0xF1:pmath=mobss;pmt(0x0441);break;//es
			case 0xF2:pmath=mobss;pmt(0x0442);break;//te
			case 0xF3:pmath=mobss;pmt(0x0443);break;//u
			case 0xF4:pmath=mobss;pmt(0x0444);break;//ef
			case 0xF5:pmath=mobss;pmt(0x0445);break;//ha
			case 0xF6:pmath=mobss;pmt(0x0446);break;//tse
			case 0xF7:pmath=mobss;pmt(0x0447);break;//che
			case 0xF8:pmath=mobss;pmt(0x0448);break;//sha
			case 0xF9:pmath=mobss;pmt(0x0449);break;//shcha
			case 0xFA:pmath=mobss;pmt(0x044A);break;//hard sign
			case 0xFB:pmath=mobss;pmt(0x044B);break;//yeru
			case 0xFC:pmath=mobss;pmt(0x044C);break;//soft sign
			case 0xFD:pmath=mobss;pmt(0x044D);break;//e
			case 0xFE:pmath=mobss;pmt(0x044E);break;//yu
			case 0xFF:pmath=mobss;pmt(0x044F);break;//ya
			
			default:pmath=mobss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}

	if (strstr(currentFont,"pplr8t")){
		do{
			switch(*temp){
			case 0x00:pmath=moss;pmt(0x0060);break;//grave accent
			case 0x01:pmath=moss;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=moss;pmt(0x005E);break;//hat
			case 0x03:pmath=moss;pmt(0x007E);break;//tilde
			case 0x04:pmath=moss;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=moss;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=moss;pmt(0x02DA);break;//ring above
			case 0x07:pmath=moss;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=moss;pmt(0x02D8);break;//breve
			case 0x09:pmath=moss;pmt(0x00AF);break;//macron
			case 0x0A:pmath=moss;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=moss;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=moss;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=moss;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=moss;pmt(0x2329);break;//left angle
			case 0x0F:pmath=moss;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ldss;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=ldss;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=moss;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=moss;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=moss;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=moss;pmt(0x2013);break;//en dash
			case 0x16:pmath=moss;pmt(0x2014);break;//em dash
			//nothing here
			case 0x18:pmath=moss;pmt(0x2030);break; //per mille
			case 0x19:pmath=moss;pmt(0x0131);break;//imath
			case 0x1A:pmath=moss;pmt(0x0237);break; //dotless j
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=moss;pmt(0x2423);break;//graphic for space
			
			case 0x21:pmath=moss;pmt(*temp);break;//!
			case 0x22:pmath=moss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moss;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldss;pmt(*temp);break;//(
			case 0x29:pmath=rdss;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moss;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=moss;pmt(*temp);break;//:
			case 0x3B:pmath=moss;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&lt;</mo>");
				break;
			case 0x3D:pmath=moss;pmt(0x002F);break;//slash
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"sans-serif\">&gt;</mo>");
				break;
			case 0x3F:pmath=moss;pmt(*temp);break;//?

			case 0x40:pmath=moss;pmt(*temp);break;//@

			case 0x5B:pmath=ldss;pmt(*temp);break;//[
			case 0x5C:pmath=moss;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdss;pmt(*temp);break;//]
			
			case 0x5E:pmath=moss;pmt(*temp);break;//^
			case 0x5F:pmath=moss;pmt(*temp);break;//_
			case 0x60:pmath=moss;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ldss;pmt(*temp);break;//left brace
			case 0x7C:pmath=moss;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdss;pmt(*temp);break;//right brace
			case 0x7E:pmath=moss;pmt(*temp);break;//tilde
			case 0x7F:pmath=moss;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=moss;pmt(0x0102);break;//A breve
			case 0x81:pmath=moss;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=moss;pmt(0x0106);break;//C acute
			case 0x83:pmath=moss;pmt(0x010C);break;//C caron
			case 0x84:pmath=moss;pmt(0x010E);break;//D caron
			case 0x85:pmath=moss;pmt(0x011A);break;//E caron
			case 0x86:pmath=moss;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=moss;pmt(0x011E);break;//G breve
			case 0x88:pmath=moss;pmt(0x0139);break;//L acute
			case 0x89:pmath=moss;pmt(0x013D);break;//L caron
			case 0x8A:pmath=moss;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=moss;pmt(0x0143);break;//N acute
			case 0x8C:pmath=moss;pmt(0x0147);break;//N caron
			case 0x8D:pmath=moss;pmt(0x014A);break;//ENG
			case 0x8E:pmath=moss;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=moss;pmt(0x0154);break;//R acute

			case 0x90:pmath=moss;pmt(0x0158);break;//R caron
			case 0x91:pmath=moss;pmt(0x015A);break;//S acute
			case 0x92:pmath=moss;pmt(0x0160);break;//S caron
			case 0x93:pmath=moss;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=moss;pmt(0x0164);break;//T caron
			case 0x95:pmath=moss;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=moss;pmt(0x0170);break;//U double acute
			case 0x97:pmath=moss;pmt(0x016E);break;//U ring above
			case 0x98:pmath=moss;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=moss;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=moss;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=moss;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=moss;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=moss;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=moss;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=moss;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=moss;pmt(0x0103);break;//a breve
			case 0xA1:pmath=moss;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=moss;pmt(0x0107);break;//c acute
			case 0xA3:pmath=moss;pmt(0x010D);break;//c caron
			case 0xA4:pmath=moss;pmt(0x010F);break;//d caron
			case 0xA5:pmath=moss;pmt(0x011B);break;//e caron
			case 0xA6:pmath=moss;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=moss;pmt(0x011F);break;//g breve
			case 0xA8:pmath=moss;pmt(0x013A);break;//l acute
			case 0xA9:pmath=moss;pmt(0x013E);break;//l caron
			case 0xAA:pmath=moss;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=moss;pmt(0x0144);break;//n acute
			case 0xAC:pmath=moss;pmt(0x0148);break;//n caron
			case 0xAD:pmath=moss;pmt(0x014B);break;//eng
			case 0xAE:pmath=moss;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=moss;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=moss;pmt(0x0159);break;//r caron
			case 0xB1:pmath=moss;pmt(0x015B);break;//s acute
			case 0xB2:pmath=moss;pmt(0x0161);break;//s caron
			case 0xB3:pmath=moss;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=moss;pmt(0x0165);break;//t caron
			case 0xB5:pmath=moss;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=moss;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=moss;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=moss;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=moss;pmt(0x017A);break;//z acute
			case 0xBA:pmath=moss;pmt(0x017E);break;//z caron
			case 0xBB:pmath=moss;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=moss;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=moss;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=moss;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=moss;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=moss;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=moss;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=moss;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=moss;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=moss;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=moss;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=moss;pmt(*temp);break;//thorn
			case 0xFF:pmath=moss;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=moss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if (strstr(currentFont,"pplb8t")){
		do{
			switch(*temp){
			case 0x00:pmath=mobss;pmt(0x0060);break;//grave accent
			case 0x01:pmath=mobss;pmt(0x00B4);break;//acute accent
			case 0x02:pmath=mobss;pmt(0x005E);break;//hat
			case 0x03:pmath=mobss;pmt(0x007E);break;//tilde
			case 0x04:pmath=mobss;pmt(0x0308);break;//XXX, it is combining, should be put in combineAccent
			case 0x05:pmath=mobss;pmt(0x02DD);break;//double acute accent
			case 0x06:pmath=mobss;pmt(0x02DA);break;//ring above
			case 0x07:pmath=mobss;pmt(0x02C7);break;//caron, hacek
			case 0x08:pmath=mobss;pmt(0x02D8);break;//breve
			case 0x09:pmath=mobss;pmt(0x00AF);break;//macron
			case 0x0A:pmath=mobss;pmt(0x02D9);break;//dot above
			case 0x0B:pmath=mobss;pmt(0x00B8);break;//cedilla
			case 0x0C:pmath=mobss;pmt(0x02DB);break;//ogonek
			case 0x0D:pmath=mobss;pmt(0x04C0);break;//cyrillic palochka
			case 0x0E:pmath=mobss;pmt(0x2329);break;//left angle
			case 0x0F:pmath=mobss;pmt(0x232A);break;//right angle
			

			case 0x10:pmath=ldb;pmt(0x201C);break;//left double quotation mark
			case 0x11:pmath=ldb;pmt(0x201D);break;//right double quotation mark
			case 0x12:pmath=mobss;pmt(0x0311);break;//frown, combining inverted breve
			case 0x13:pmath=mobss;pmt(0x030F);break;//combining double breve
			case 0x14:pmath=mobss;pmt(0x0306);break;//combining breve, XXX should be cyrillic breve
			case 0x15:pmath=mobss;pmt(0x2013);break;//en dash
			case 0x16:pmath=mobss;pmt(0x2014);break;//em dash
			case 0x17:pmath=mobss;pmt(0xE003F);break;//XXX, error mark: I chose TAG question mark
			case 0x18:pmath=mobss;pmt(0x220E);break; //end of proof
			case 0x19:pmath=mobss;pmt(0x0131);break;//imath
			case 0x1A:pmath=mobss;pmt(0x25AE);break; //black vertical rectangle
			case 0x1B:p("ff");break;//p(ul2utf8(0xFB00));break;//ligature ff
			case 0x1C:p("fi");break;//p(ul2utf8(0xFB01));break;//ligature fi
			case 0x1D:p("fl");break;//p(ul2utf8(0xFB02));break;//ligature fl
			case 0x1E:p("ffi");break;//p(ul2utf8(0xFB03));break;//ligature ffi
			case 0x1F:p("ffl");break;//p(ul2utf8(0xFB04));break;//ligature ffl

			case 0x20:pmath=mobss;pmt(0x2423);break;//graphic for space
			case 0x21:pmath=mobss;pmt(*temp);break;//!
			case 0x22:pmath=mobss;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=mobss;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"bold-sans-serif\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=mobss;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=mobss;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=mobss;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=mobss;pmt(*temp);break;//:
			case 0x3B:pmath=mobss;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold-sans-serif\">&lt;</mo>");
				break;
			case 0x3D:pmath=mobss;pmt(0x002F);break;//division
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"bold-sans-serif\">&gt;</mo>");
				break;
			case 0x3F:pmath=mobss;pmt(*temp);break;//?

			case 0x40:pmath=mobss;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=mobss;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			
			case 0x5E:pmath=mobss;pmt(*temp);break;//^
			case 0x5F:pmath=mobss;pmt(*temp);break;//_
			case 0x60:pmath=mobss;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ldb;pmt(*temp);break;//left brace
			case 0x7C:pmath=mobss;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdb;pmt(*temp);break;//right brace
			case 0x7E:pmath=mobss;pmt(*temp);break;//tilde
			case 0x7F:pmath=mobss;pmt(0x2012);break;//figure dash
			
			//combined accented 
			case 0x80:pmath=mobss;pmt(0x0102);break;//A breve
			case 0x81:pmath=mobss;pmt(0x0104);break;//A ogonek
			case 0x82:pmath=mobss;pmt(0x0106);break;//C acute
			case 0x83:pmath=mobss;pmt(0x010C);break;//C caron
			case 0x84:pmath=mobss;pmt(0x010E);break;//D caron
			case 0x85:pmath=mobss;pmt(0x011A);break;//E caron
			case 0x86:pmath=mobss;pmt(0x0118);break;//E ogonek
			case 0x87:pmath=mobss;pmt(0x011E);break;//G breve
			case 0x88:pmath=mobss;pmt(0x0139);break;//L acute
			case 0x89:pmath=mobss;pmt(0x013D);break;//L caron
			case 0x8A:pmath=mobss;pmt(0x0141);break;//L stroke
			case 0x8B:pmath=mobss;pmt(0x0143);break;//N acute
			case 0x8C:pmath=mobss;pmt(0x0147);break;//N caron
			case 0x8D:pmath=mobss;pmt(0x014A);break;//ENG
			case 0x8E:pmath=mobss;pmt(0x0150);break;//O double acute
			case 0x8F:pmath=mobss;pmt(0x0154);break;//R acute

			case 0x90:pmath=mobss;pmt(0x0158);break;//R caron
			case 0x91:pmath=mobss;pmt(0x015A);break;//S acute
			case 0x92:pmath=mobss;pmt(0x0160);break;//S caron
			case 0x93:pmath=mobss;pmt(0x015E);break;//S cedilla
			case 0x94:pmath=mobss;pmt(0x0164);break;//T caron
			case 0x95:pmath=mobss;pmt(0x0162);break;//T cedilla
			case 0x96:pmath=mobss;pmt(0x0170);break;//U double acute
			case 0x97:pmath=mobss;pmt(0x016E);break;//U ring above
			case 0x98:pmath=mobss;pmt(0x0178);break;//Y diaeresis
			case 0x99:pmath=mobss;pmt(0x0179);break;//Z acute
			case 0x9A:pmath=mobss;pmt(0x017D);break;//Z caron
			case 0x9B:pmath=mobss;pmt(0x017B);break;//Z dot above
			case 0x9C:pmath=mobss;pmt(0x0132);break;//ligature IJ
			case 0x9D:pmath=mobss;pmt(0x0130);break;//I dot above
			case 0x9E:pmath=mobss;pmt(0x0111);break;//d stroke
			case 0x9F:pmath=mobss;pmt(0x00A7);break;//section sign

			case 0xA0:pmath=mobss;pmt(0x0103);break;//a breve
			case 0xA1:pmath=mobss;pmt(0x0104);break;//a ogonek
			case 0xA2:pmath=mobss;pmt(0x0107);break;//c acute
			case 0xA3:pmath=mobss;pmt(0x010D);break;//c caron
			case 0xA4:pmath=mobss;pmt(0x010F);break;//d caron
			case 0xA5:pmath=mobss;pmt(0x011B);break;//e caron
			case 0xA6:pmath=mobss;pmt(0x0119);break;//e ogonek
			case 0xA7:pmath=mobss;pmt(0x011F);break;//g breve
			case 0xA8:pmath=mobss;pmt(0x013A);break;//l acute
			case 0xA9:pmath=mobss;pmt(0x013E);break;//l caron
			case 0xAA:pmath=mobss;pmt(0x0142);break;//l stroke
			case 0xAB:pmath=mobss;pmt(0x0144);break;//n acute
			case 0xAC:pmath=mobss;pmt(0x0148);break;//n caron
			case 0xAD:pmath=mobss;pmt(0x014B);break;//eng
			case 0xAE:pmath=mobss;pmt(0x0151);break;//o double acute
			case 0xAF:pmath=mobss;pmt(0x0155);break;//r acute
			
			case 0xB0:pmath=mobss;pmt(0x0159);break;//r caron
			case 0xB1:pmath=mobss;pmt(0x015B);break;//s acute
			case 0xB2:pmath=mobss;pmt(0x0161);break;//s caron
			case 0xB3:pmath=mobss;pmt(0x015F);break;//s cedilla
			case 0xB4:pmath=mobss;pmt(0x0165);break;//t caron
			case 0xB5:pmath=mobss;pmt(0x0163);break;//t cedilla
			case 0xB6:pmath=mobss;pmt(0x0171);break;//u double acute
			case 0xB7:pmath=mobss;pmt(0x016F);break;//u ring above
			case 0xB8:pmath=mobss;pmt(0x00FF);break;//y diaeresis
			case 0xB9:pmath=mobss;pmt(0x017A);break;//z acute
			case 0xBA:pmath=mobss;pmt(0x017E);break;//z caron
			case 0xBB:pmath=mobss;pmt(0x017C);break;//z dot above
			case 0xBC:pmath=mobss;pmt(0x0133);break;//ligature ij
			case 0xBD:pmath=mobss;pmt(0x00A1);break;//inverted exclamation sign
			case 0xBE:pmath=mobss;pmt(0x00BF);break;//inverted question sign
			case 0xBF:pmath=miss;pmt(0x00A3);break;//pound sterling

			case 0xC0://A grave
			case 0xC1://A acute
			case 0xC2://A circumflex
			case 0xC3://A tilde
			case 0xC4://A diaeresis
			case 0xC5://A ring above
			case 0xC6://AE ligature
			case 0xC7://C cedilla
			case 0xC8://E grave
			case 0xC9://E acute
			case 0xCA://E circumflex
			case 0xCB://E diaeresis
			case 0xCC://I grave
			case 0xCD://I acute
			case 0xCE://I circumflex
			case 0xCF:pmath=mobss;pmt(*temp);break;//I diaeresis

			case 0xD0://ETH
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			case 0xD7://C cedilla
			case 0xD8://E grave
			case 0xD9://E acute
			case 0xDA://E circumflex
			case 0xDB://E diaeresis
			case 0xDC://I grave
			case 0xDD://I acute
			case 0xDE:pmath=mobss;pmt(*temp);break;//I circumflex
			case 0xDF:pmath=mobss;pmt(0x0152);break;//ligature OE
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2://a circumflex
			case 0xE3://a tilde
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			case 0xE6://ligature ae
			case 0xE7://c cedilla
			case 0xE8://e grave
			case 0xE9://e acute
			case 0xEA://e circumflex
			case 0xEB://e diaeresis
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=mobss;pmt(*temp);break;//i diaeresis
			
			case 0xF0://eth
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=mobss;pmt(*temp);break;//o diaeresis
			case 0xF7:pmath=mobss;pmt(0x0153);break;//ligature oe
			case 0xF8://o stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE:pmath=mobss;pmt(*temp);break;//thorn
			case 0xFF:pmath=mobss;pmt(0x00DF);break;//sharp s, german eszett
			
			default:pmath=mobss;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
	
	if (strstr(currentFont,"pplri8t")){
		do{
			switch(*temp){
			case 0x00:
			case 0x01:
			case 0x02:
			case 0x03:
			case 0x04:
			case 0x05:
			case 0x06:
			case 0x07:
			case 0x08:
			case 0x09:
			case 0x0A:
			case 0x0B:
			case 0x0C:pmath=moi;pmt(0xE003F);break;//error mark: nothing in TeX 
			case 0x0D:pmath=moi;pmt(0x2032);break;//prime
			case 0x0E:pmath=moi;pmt(0x00A1);break;//inverted exclamation mark
			case 0x0F:pmath=moi;pmt(0x00BF);break;//inverted question mark
			

			case 0x10:pmath=moi;pmt(0x0131);break;//imath
			case 0x11:pmath=moi;pmt(0xE003F);break;//error mark: nothing in TeX 
			case 0x12:pmath=moi;pmt(0x0060);break;//grave accent
			case 0x13:pmath=moi;pmt(0x00B4);break;//acute accent
			case 0x14:pmath=moi;pmt(0x02C7);break;//caron, hacek
			case 0x15:pmath=moi;pmt(0x02D8);break;//breve
			case 0x16:pmath=moi;pmt(0x00AF);break;//macron
			case 0x17:pmath=moi;pmt(0x02DA);break;//ring above
			case 0x18:pmath=moi;pmt(0x00B8);break;//cedilla
			case 0x19:pmath=mi;pmt(0x00DF);break;//german SS
			case 0x1A:pmath=mi;pmt(0x00E6);break;//latin ae
			case 0x1B:pmath=mi;pmt(0x0153);break;//latin oe
			case 0x1C:pmath=mi;pmt(0x00F8);break;//o slash
			case 0x1D:pmath=mi;pmt(0x00C6);break;//latin AE
			case 0x1E:pmath=mi;pmt(0x0152);break;//latin OE
			case 0x1F:pmath=mi;pmt(0x00D8);break;//O slash

			case 0x20:pmath=moi;pmt(0xE003F);break;//error mark: nothing in TeX 
			
			case 0x21:pmath=moi;pmt(*temp);break;//!
			case 0x22:pmath=moi;pmt(0x201D);break;//right double quotation mark
			case 0x23:
			case 0x24:
			case 0x25:pmath=moi;pmt(*temp);break;
			case 0x26:
				if (mathmode && !mathText){
					p("<mo mathvariant=\"italic\">&amp;</mo>");
				}else 
					p("&amp;");
				break;//ampersand
			case 0x27:pmath=moi;pmt(0x2019);break;//quoteright
			case 0x28:pmath=ldb;pmt(*temp);break;//(
			case 0x29:pmath=rdb;pmt(*temp);break;//)
			case 0x2A:
			case 0x2B:
			case 0x2C:inhibitspace=0;pmath=moi;pmt(*temp);break;
			case 0x2D:
			case 0x2E:
			case 0x2F:pmath=moi;pmt(*temp);break;

			case 0x30:
			case 0x31:
			case 0x32:
			case 0x33:
			case 0x34:
			case 0x35:
			case 0x36:
			case 0x37:
			case 0x38:
			case 0x39:pmath=mn;pmt(*temp);break;
			case 0x3A:pmath=moi;pmt(*temp);break;//:
			case 0x3B:pmath=moi;pmt(*temp);break;//;
			case 0x3C://less than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"italic\">&lt;</mo>");
				break;
			case 0x3D:pmath=moi;pmt(0x002F);break;//division
			case 0x3E: //greater than
				if(combiningUnicode==0x0338) { 
					combiningUnicode=0;
					pmt(0x226F);
				}	else	p("<mo mathvariant=\"italic\">&gt;</mo>");
				break;
			case 0x3F:pmath=moi;pmt(*temp);break;//?
			case 0x40:pmath=moi;pmt(*temp);break;//@

			case 0x5B:pmath=ldb;pmt(*temp);break;//[
			case 0x5C:pmath=moi;pmt(*temp);break;//backslash
			case 0x5D:pmath=rdb;pmt(*temp);break;//]
			
			case 0x5E:pmath=moi;pmt(*temp);break;//^
			case 0x5F:pmath=moi;pmt(*temp);break;//_
			case 0x60:pmath=moi;pmt(*temp);break;//`
			
			//ascii small letters

			case 0x7B:pmath=ldb;pmt(*temp);break;//left brace
			case 0x7C:pmath=moi;pmt(*temp);break;//vertical bar
			case 0x7D:pmath=rdb;pmt(*temp);break;//right brace
			case 0x7E:pmath=moi;pmt(*temp);break;//tilde
			case 0x7F:pmath=moi;pmt(0x00A8);break;//diaeresis
			
			//accents, combined accented 
			case 0x80:pmath=moi;pmt(0x005E);break;//circumflex
			case 0x81:pmath=moi;pmt(0x007E);break;//tilde
			case 0x82:pmath=mi;pmt(0x00C7);break;//C cedilla
			case 0x83:pmath=mi;pmt(0x00CD);break;//I acute
			case 0x84:pmath=mi;pmt(0x00CE);break;//I circumflex
			case 0x85:pmath=mi;pmt(0x00E3);break;//a tilde
			case 0x86:pmath=mi;pmt(0x00EB);break;//e diaeresis
			case 0x87:pmath=mi;pmt(0x00E8);break;//e grave
			case 0x88:pmath=mi;pmt(0x0161);break;//s caron
			case 0x89:pmath=mi;pmt(0x017E);break;//z caron
			case 0x8A:pmath=mi;pmt(0x00D0);break;//ETH

			//nothing in the font here
			
			case 0x92:pmath=moi;pmt(0x0160);break;//S caron
			//nothing in the font here
			case 0x98:pmath=moi;pmt(0x0178);break;//Y diaeresis
			//nothing in the font here
			case 0x9A:pmath=moi;pmt(0x017D);break;//Z caron

			//nothing in the font here
			
			case 0xA2:pmath=moi;pmt(0x00A2);break;//cent
			case 0xA3:pmath=moi;pmt(0x00A3);break;//pound
			case 0xA4:pmath=moi;pmt(0x002F);break;//slash
			case 0xA5:pmath=moi;pmt(0x00A5);break;//yen
			case 0xA6:pmath=moi;pmt(0x0192);break;//f script
			case 0xA7:pmath=moi;pmt(0x00A7);break;//section sign
			case 0xA8:pmath=moi;pmt(0x00A4);break;//currency
			case 0xA9:pmath=moi;pmt(0x00A9);break;//copyright
			case 0xAA:pmath=moi;pmt(0x201C);break;//left double quote
			case 0xAB:pmath=moi;pmt(*temp);break;//left guillemet
			case 0xAC:pmath=moi;pmt(0x2039);break;//single left quote
			case 0xAD:pmath=moi;pmt(0x203A);break;//single right quote
			case 0xAE:p("fi");break;//ligature fi
			case 0xAF:p("fl");break;//ligature fl
			
			case 0xB0:pmath=moi;pmt(*temp);break;//degree sign
			case 0xB1:pmath=moi;pmt(0x2010);break;//hyphen
			case 0xB2:pmath=moi;pmt(0x2020);break;//dagger
			case 0xB3:pmath=moi;pmt(0x2021);break;//double dagger
			case 0xB4:pmath=moi;pmt(0x2024);break;//one dot leader
			//nothing here 
			case 0xB6:pmath=moi;pmt(0x00B6);break;//pilcrow
			case 0xB7:pmath=moi;pmt(0x2022);break;//bullet
			case 0xB8:pmath=moi;pmt(0x201A);break;//single low quote
			case 0xB9:pmath=moi;pmt(0x201E);break;//double low quote
			case 0xBA:pmath=moi;pmt(0x201D);break;//right double quote
			case 0xBB:pmath=moi;pmt(0x00BB);break;//right guillemet
			case 0xBC:pmath=moi;pmt(0x2026);break;//horizontal ellipsis
			case 0xBD:pmath=moi;pmt(0x2030);break;//per mille
			//nothing here 

			case 0xC0:pmath=moi;pmt(0x00C0);break;//A grave
			case 0xC1:pmath=moi;pmt(0x00C1);break;//A acute
			case 0xC2:pmath=moi;pmt(0x00C2);break;//A circumflex
			case 0xC3:pmath=moi;pmt(0x00C3);break;//A tilde
			case 0xC4:pmath=moi;pmt(0x00C4);break;//A diaeresis
			case 0xC5:pmath=moi;pmt(0x00C5);break;//A ring above
			//nothing here 
			case 0xC7:pmath=moi;pmt(0x02D9);break;//dot above
			case 0xC8:pmath=moi;pmt(0x00C8);break;//E grave
			case 0xC9:pmath=moi;pmt(0x00C9);break;//E acute
			case 0xCA:pmath=moi;pmt(0x00CA);break;//E circumflex
			case 0xCB:pmath=moi;pmt(0x00CB);break;//E diaeresis
			case 0xCC:pmath=moi;pmt(0x00CC);break;//I grave
			case 0xCD:pmath=moi;pmt(0x2033);break;//double prime
			case 0xCE:pmath=moi;pmt(0x02DB);break;//ogonek
			case 0xCF:pmath=moi;pmt(0x00CF);break;//I diaeresis

			case 0xD0:pmath=mi;pmt(0x2013);break;//en dash
			case 0xD1://N tilde
			case 0xD2://O grave
			case 0xD3://O acute
			case 0xD4://O circumflex
			case 0xD5://O tilde
			case 0xD6://O diaeresis
			//nothing here
			case 0xD9://U acute
			case 0xDA://U circumflex
			case 0xDB://U diaeresis
			case 0xDC://U grave
			case 0xDD://Y acute
			case 0xDE:pmath=mi;pmt(*temp);break;//Thorn
			//nothing here
			
			case 0xE0://a grave
			case 0xE1://a acute
			case 0xE2:pmath=mi;pmt(*temp);break;//a circumflex
			case 0xE3:pmath=mi;pmt(0x00AA);break;//feminine ordinal indicator
			case 0xE4://a diaeresis
			case 0xE5://a ring above
			//nothing here
			case 0xE7:pmath=mi;pmt(*temp);break;//c cedilla
			case 0xE8:pmath=mi;pmt(0x0141);break;//L stroke
			case 0xE9://e acute
			case 0xEA:pmath=mi;pmt(*temp);break;//e circumflex
			case 0xEB:pmath=mi;pmt(0x0141);break;//masculine ordinal indicator
			case 0xEC://i grave
			case 0xED://i acute
			case 0xEE://i circumflex
			case 0xEF:pmath=mi;pmt(*temp);break;//i diaeresis
			
			//nothing here
			case 0xF1://n tilde
			case 0xF2://o grave
			case 0xF3://o acute
			case 0xF4://o circumflex
			case 0xF5://o tilde
			case 0xF6:pmath=mi;pmt(*temp);break;//o diaeresis
			//nothing here
			case 0xF8:pmath=mi;pmt(0x0142);break;//l stroke
			case 0xF9://u grave
			case 0xFA://u acute
			case 0xFB://u circumflex
			case 0xFC://u diaeresis
			case 0xFD://y acute
			case 0xFE://thorn
			case 0xFF:pmath=mi;pmt(*temp);break;//y diaeresis
			
			default:pmath=mi;pmt(*temp);
			}
			temp++;
		}while(*temp);
		return;
	}
			

	if (strstr(currentFont,"wasy")){
		do{
			switch(*temp){
			case 0x00:pmath=mo;pmt(0x25B3);break;//up-triangle white
			case 0x01:pmath=mo;pmt(0x22B2);break;//normal subgroup of
			case 0x02:pmath=mo;pmt(0x22B4);break;//normal subgroup of or equal to
			case 0x03:pmath=mo;pmt(0x22B3);break;//contains as normal subgroup
			case 0x04:pmath=mo;pmt(0x22B5);break;//contains as normal subgroup or equal to
			case 0x05:pmath=mo;pmt(0x2234);break;//therefore
			case 0x06:pmath=mo;pmt(0x2315);break;//recorder
			case 0x07:pmath=mo;pmt(0x260E);break;//black telephone
			case 0x08:pmath=mo;pmt(0x2713);break;//check mark
			case 0x09:pmath=mo;pmt(0x27AA);break;//right \pointer
			case 0x0A:pmath=mo;pmt(0x237E);break;//\bell
			case 0x0B:pmath=mo;pmt(0x266A);break;//\eighthnote
			case 0x0C:pmath=mo;pmt(0x2669);break;//\quarternote
			case 0x0D:pmath=mo;pmt(0x1D15E);break;//\halfnote
			case 0x0E:pmath=mo;pmt(0x1D15D);break;//\fullnote musical
			case 0x0F:pmath=mo;pmt(0x266B);break;//\twonotes, beamed eigththnotes
			
			case 0x10:pmath=mo;pmt(0x25C0);break;//left-triangle black
			case 0x11:pmath=mo;pmt(0x25B6);break;//right-triangle black
			case 0x12:pmath=mo;pmt(0x2607);break;//lightning
			case 0x13:pmath=mo;pmt(0x260A);break;//ascending note
			case 0x14:pmath=mo;pmt(0x260B);break;//descending note
			case 0x15:pmath=mo;pmt(0x2349);break;//APL\invdiameter
			case 0x16:pmath=mo;pmt(0x235F);break;//XXX?,circle star, \APLlog
			case 0x17:pmath=mo;pmt(0x2648);break;//\vernal, XXX is it \aries?
			case 0x18:pmath=mo;pmt(0x2310);break;//reversed not, \invneg
			case 0x19:pmath=mo;pmt(0x2640);break;//\venus
			case 0x1A:pmath=mo;pmt(0x2642);break;//male sign, \mars
			case 0x1B:pmath=mo;pmt(0x00A4);break;//\currency
			case 0x1C:pmath=mo;pmt(0x231A);break;//\clock
			case 0x1D:pmath=mo;pmt(0x221D);break;//\propto
			case 0x1E:pmath=mo;pmt(0x2222);break;//\varangle
			case 0x1F:pmath=mo;pmt(0x2300);break;//\diameter
			
			case 0x20:pmath=mo;pmt(0x26AB);break;//black circle
			case 0x21:pmath=mo;pmt(0x27F3);break;//\rightturn
			case 0x22:pmath=mo;pmt(0x27F2);break;//\leftturn
			case 0x23:pmath=mo;pmt(0x26AC);break;//white circle
			case 0x24:pmath=mo;pmt(0x263E);break;//\leftmoon
			case 0x25:pmath=mo;pmt(0x263D);break;//\rightmoon
			case 0x26:pmath=mo;pmt(0x2641);break;//\earth
			case 0x27:pmath=mo;pmt(0x263F);break;//\mercury
			case 0x28:pmath=mo;pmt(0x2039);break;//left quot angle
			case 0x29:pmath=mo;pmt(0x203A);break;//right quot angle
			case 0x2A:pmath=mo;pmt(0x2303);break;//up arrowhead
			case 0x2B:pmath=mo;pmt(0x2304);break;//down arrowhead
			case 0x2C:pmath=mo;pmt(0x263A);break;//\whitesmiley
			case 0x2D:pmath=mo;pmt(0x263B);break;//\blacksmiley
			case 0x2E:pmath=mo;pmt(0x263C);break;//\sun
			case 0x2F:pmath=mo;pmt(0x2639);break;//\frownie
			
			case 0x30:pmath=mo;pmt(0x2127);break;//inverted ohm sign
			case 0x31:pmath=mo;pmt(0x22C8);break;//\Bowtie
			case 0x32:pmath=mo;pmt(0x2395);break;//\APLbox
			case 0x33:pmath=mo;pmt(0x25C7);break;//\Diamond
			case 0x34:pmath=mo;pmt(0x2612);break;//\XBox
			case 0x35:pmath=mo;pmt(0x25CA);break;//\lozenge
			case 0x36:pmath=mo;pmt(0x2720);break;//maltese cross, \kreuz
			case 0x37:pmath=mo;pmt(0x2394);break;//software function, \hexagon
			case 0x38:pmath=mo;pmt(0x2639);break;//XXX :( not found in Unicode 4.1,\octagon
			case 0x39:pmath=mo;pmt(0x232C);break;//XXX?,benzene,\varhexagon
			case 0x3A:pmath=mo;pmt(0x223C);break;//APL tilde,\APLnot
			case 0x3B:pmath=mo;pmt(0x219D);break;//rightwards wave arrow
			case 0x3C:pmath=mo;pmt(0x228F);break;//square image of
			case 0x3D:pmath=mo;pmt(0x2290);break;//square original of
			case 0x3E:pmath=mo;pmt(0x2272);break;//less-than or equivalent to
			case 0x3F:pmath=mo;pmt(0x2273);break;//greater-than or equivalent to
			
			case 0x40:pmath=mo;pmt(0x224B);break;//triple tilde
			case 0x41:pmath=mo;pmt(0x2217);break;//XXX,asterisk operator,\hexstar
			case 0x42:pmath=mo;pmt(0x2217);break;//XXX not in Unicode4.1,asterisk operator,\varhexstar
			case 0x43:pmath=mo;pmt(0x2721);break;//\davidsstar
			case 0x44:pmath=mo;pmt(0x2639);break;//XXX :( not found in Unicode 4.1,\pentagon
			case 0x45:pmath=mo;pmt(0x2639);break;//XXX :( not found in Unicode 4.1,\APLstar
			case 0x46:pmath=mo;pmt(0x25BD);break;//\APL down, white triangle down 
			case 0x47:pmath=mo;pmt(0x25D6);break;//left half black circle,\leftcircle
			case 0x48:pmath=mo;pmt(0x25D7);break;//right half black circle,\rightcircle
			case 0x49:pmath=mo;pmt(0x25D6);break;//XXX: should be white, left half black circle,\leftcircle
			case 0x4A:pmath=mo;pmt(0x25D7);break;//XXX: should be white, right half black circle,\rightcircle
			case 0x4B:pmath=mo;pmt(0x25B2);break;//black up triangle, \UParrow
			case 0x4C:pmath=mo;pmt(0x25BC);break;//black down triangle, \DOWNarrow
			case 0x4D:
			case 0x4E:
			case 0x4F:break;//nothing

			case 0x50:pmath=mo;pmt(0x2639);break;//XXX:not found in U4.1,\gluonelement
			case 0x51:pmath=mo;pmt(0x2639);break;//XXX:not found in U4.1,\gluonbelement
			case 0x52:pmath=mo;pmt(0x2639);break;//XXX:not found in U4.1,\gluoneelement
			case 0x53:
			case 0x54:break;//nothing
			case 0x55:pmath=mo;pmt(0x01DD);break;//small letter turned e, \inve
			case 0x56:pmath=mo;pmt(0x260C);break;//conjunction
			case 0x57:pmath=mo;pmt(0x260D);break;//opposition
			case 0x58:pmath=mo;pmt(0x2643);break;//jupiter
			case 0x59:pmath=mo;pmt(0x2644);break;//saturn
			case 0x5A:pmath=mo;pmt(0x2645);break;//uranus
			case 0x5B:pmath=mo;pmt(0x2646);break;//neptune
			case 0x5C:pmath=mo;pmt(0x2647);break;//pluto
			case 0x5D:pmath=mo;pmt(0x2649);break;//taurus
			case 0x5E:pmath=mo;pmt(0x264A);break;//gemini
			case 0x5F:pmath=mo;pmt(0x264B);break;//cancer

			case 0x60:pmath=mo;pmt(0x264D);break;//virgo
			case 0x61:pmath=mo;pmt(0x264E);break;//libra
			case 0x62:pmath=mo;pmt(0x264F);break;//scorpius
			case 0x63:pmath=mo;pmt(0x2650);break;//saggitarius
			case 0x64:pmath=mo;pmt(0x2651);break;//capricorn
			case 0x65:pmath=mo;pmt(0x2652);break;//aquarius
			case 0x66:pmath=mo;pmt(0x2653);break;//pisces
			case 0x67:pmath=mo;pmt(0x00A2);break;//cent sign
			case 0x68:pmath=mo;pmt(0x2030);break;//\permil
			case 0x69:pmath=mo;pmt(0x00FE);break;//\thorn
			case 0x6A:pmath=mo;pmt(0x00DE);break;//\THORN
			case 0x6B:pmath=mo;pmt(0x00F0);break;//eth, \dh
			case 0x6C:pmath=mo;pmt(0x0254);break;//\openo
			case 0x6D:pmath=mo;pmt(0x2639);break;//XXX:not found in U4.1,\ataribox
			case 0x6E:pmath=mo;pmt(0x2350);break;//\APLuparrowbox
			case 0x6F:pmath=mo;pmt(0x2357);break;//\APLdownarrowbox

			case 0x70:pmath=mo;pmt(0x2347);break;//\APLleftarrowbox
			case 0x71:pmath=mo;pmt(0x2348);break;//\APLrightarrowbox
			case 0x72:pmath=mo;pmt(0x222B);break;//integral, \int
			case 0x73:pmath=mo;pmt(0x222C);break;//\iint
			case 0x74:pmath=mo;pmt(0x222D);break;//\iiint
			case 0x75:pmath=mo;pmt(0x222E);break;//\oint
			case 0x76:pmath=mo;pmt(0x222F);break;//\oiint
			case 0x77:pmath=mo;pmt(0x222B);break;//integral, \int
			case 0x78:pmath=mo;pmt(0x222C);break;//\iint
			case 0x79:pmath=mo;pmt(0x222D);break;//\iiint
			case 0x7A:pmath=mo;pmt(0x222E);break;//\oint
			case 0x7B:pmath=mo;pmt(0x222F);break;//\oiint
			case 0x7C:pmath=mo;pmt('|');break;//|
			case 0x7D:pmath=mo;pmt(0x235E);break;//XXX:?, APL quote,\APLinput
			case 0x7E:pmath=mo;pmt(0x2395);break;//APL quad,\APLbox
			case 0x7F:pmath=mo;pmt(0x2639);break;//XXX:not found in U4.1,\APLcomment

			}
			temp++;
		}while(*temp);
		return;
	}
			
	fprintf(stderr,"\nerror: font %s not mapped yet\n",currentFont);
	die("dying...");
}

char* ul2utf8(unsigned long unicode){
	unsigned long mask=0x3F;
	unsigned char u1,u2=0x80,u3=0x80,u4=0x80,u5=0x80,u6=0x80;
	static char s[7];
	if (unicode>=0x04000000) u1=126;
		else if (unicode>=0x00200000) u1=62;
			else if (unicode>=0x00010000) u1=30;
				else if (unicode>=0x00000800) u1=14;
					else if (unicode>=0x00000080) u1=6;
						else u1=0;
	switch(u1){
		case 0:
			u1=unicode;
			sprintf(s,"%c",u1);
			break;
		case 6:
			u2+=unicode & mask;
			u1=(u1<<5)+(unicode>>6 & mask>>1);
			sprintf(s,"%c%c",u1,u2);
			break;
		case 14:
			u3+=unicode & mask;
			u2+=unicode>>6 & mask;
			u1=(u1<<4)+(unicode>>12 & mask>>2);
			sprintf(s,"%c%c%c",u1,u2,u3);
			break;
		case 30:
			u4+=unicode & mask;
			u3+=unicode>>6 & mask;
			u2+=unicode>>12 & mask;
			u1=(u1<<3)+(unicode>>18 & mask>>3);
			sprintf(s,"%c%c%c%c",u1,u2,u3,u4);
			break;
		case 62:
			u5+=unicode & mask;
			u4+=unicode>>6 & mask;
			u3+=unicode>>12 & mask;
			u2+=unicode>>18 & mask;
			u1=(u1<<2)+(unicode>>24 & mask>>4);
			sprintf(s,"%c%c%c%c%c",u1,u2,u3,u4,u5);
			break;
		case 126:
			u6+=unicode & mask;
			u5+=unicode>>6 & mask;
			u4+=unicode>>12 & mask;
			u3+=unicode>>18 & mask;
			u2+=unicode>>24 & mask;
			u1=(u1<<1)+(unicode>>30 & mask>>5);
			sprintf(s,"%c%c%c%c%c%c",u1,u2,u3,u4,u5,u6);
			break;
	}
	return s;
}

void pmt(unsigned long unicode){
	if (mathmode && !mathText && !mathOp){
		if (unicode!=blockthis) blockthis=0;
		else return;
		switch(pmath){
			case mi:
				p("<mi>");
				break;
			case mo:
				p("<mo>");
				break;
			case mib:
				p("<mi mathvariant=\"bold\">");
				break;
			case mibi:
				p("<mi mathvariant=\"bold-italic\">");
				break;
			case mif:
				p("<mi mathvariant=\"fraktur\">");
				break;
			case mis:
				p("<mi mathvariant=\"script\">");
				break;
			case mitt:
				p("<mi mathvariant=\"monospace\">");
				break;
			case miss:
				p("<mi mathvariant=\"sans-serif\">");
				break;
			case missi:
				p("<mi mathvariant=\"sans-serif-italic\">");
				break;
			case mibs:
				p("<mi mathvariant=\"bold-script\">");
				break;
			case mids:
				p("<mi mathvariant=\"double-struck\">");
				break;
			case mibss:
				p("<mi mathvariant=\"bold-sans-serif\">");
				break;
			case mob:
				p("<mo mathvariant=\"bold\">");
				break;
			case moi:
				p("<mo mathvariant=\"italic\">");
				break;
			case mobi:
				p("<mo mathvariant=\"bold-italic\">");
				break;
			case mof:
				p("<mo mathvariant=\"fraktur\">");
				break;
			case mos:
				p("<mo mathvariant=\"script\">");
				break;
			case mott:
				p("<mo mathvariant=\"monospace\">");
				break;
			case moss:
				p("<mo mathvariant=\"sans-serif\">");
				break;
			case mossi:
				p("<mo mathvariant=\"sans-serif-italic\">");
				break;
			case mobs:
				p("<mo mathvariant=\"bold-script\">");
				break;
			case mods:
				p("<mo mathvariant=\"double-struck\">");
				break;
			case mobss:
				p("<mo mathvariant=\"bold-sans-serif\">");
				break;
			case mn:
			case mnb:
			case mni:
			case mnbi:
			case mnf:
			case mns:
			case mnbs:
			case mnds:
			case mntt:
			case mnss:
			case mnbss:
			case mnssi:
				fixDigits();//XXX needs fixing, currently ignores number formatting
				break;
			case ld:
				p("<mrow><mo>");
				break;
			case ldb:
				p("<mrow><mo mathvariant=\"bold\">");
				break;
			case ldi:
				p("<mrow><mo mathvariant=\"bold\">");
				break;
			case lds:
				p("<mrow><mo mathvariant=\"script\">");
				break;
			case ldbi:
				p("<mrow><mo mathvariant=\"bold-italic\">");
				break;
			case ldtt:
				p("<mrow><mo mathvariant=\"monospace\">");
				break;
			case ldss:
				p("<mrow><mo mathvariant=\"sans-serif\">");
				break;
			case ldssi:
				p("<mrow><mo mathvariant=\"sans-serif-italic\">");
				break;
			case rd:
				p("</mrow><mo>");
				break;
			case rdb:
				p("</mrow><mo mathvariant=\"bold\">");
				break;
			case rdi:
				p("</mrow><mo mathvariant=\"italic\">");
				break;
			case rds:
				p("</mrow><mo mathvariant=\"script\">");
				break;
			case rdbi:
				p("</mrow><mo mathvariant=\"bold-italic\">");
				break;
			case rdtt:
				p("</mrow><mo mathvariant=\"monospace\">");
				break;
			case rdss:
				p("</mrow><mo mathvariant=\"sans-serif\">");
				break;
			case rdssi:
				p("</mrow><mo mathvariant=\"sans-serif-italic\">");
				break;
			case ld_b:
			case rd_b:
				p("<mrow><mo>");
				break;
			case ld_x:
			case rd_x:
			case ld_e:
			case rd_e:
				break;
		}

		p(ul2utf8(unicode));
		if (combiningUnicode) {
			p(ul2utf8(combiningUnicode));
			combiningUnicode=0;
		}

		switch(pmath){
			case mi:
			case mib:
			case mibi:
			case mif:
			case mis:
			case mitt:
			case miss:
			case missi:
			case mibs:
			case mids:
			case mibss:
				p("</mi>");
				break;
			case mo:
			case mob:
			case moi:
			case mobi:
			case mof:
			case mos:
			case mott:
			case moss:
			case mossi:
			case mobs:
			case mods:
			case mobss:
				p("</mo>");
				break;
			case mn:
			case mnb:
			case mni:
			case mnbi:
			case mnf:
			case mns:
			case mnbs:
			case mnds:
			case mntt:
			case mnss:
			case mnbss:
			case mnssi:
				p("</mn>");
				break;
			case ld:
			case ldb:
			case ldi:
			case lds:
			case ldbi:
			case ldtt:
			case ldss:
			case ldssi:
				p("</mo><mrow>"); 
				break;
			case rd:
			case rdb:
			case rdi:
			case rds:
			case rdbi:
			case rdtt:
			case rdss:
			case rdssi:
				p("</mo></mrow>");
				break;
			case ld_b:
			case rd_b:
			case ld_x:
			case rd_x:
				break;
			case ld_e:
			case rd_e:
				p("</mo></mrow>");
				break;
		}
	}else {
		p(ul2utf8(unicode));
		if (combiningUnicode) {
			contractTextAccent();			
			combiningUnicode=0;
		}
	}
	return;
}

void saveAccent(char accent){
	if (strstr(currentFont,"cmr")|| strstr(currentFont,"cmbx")|| strstr(currentFont,"pplr")){
			switch(accent){
			case 0x12:combiningUnicode=0x0300;break;//grave accent
			case 0x13:combiningUnicode=0x0301;break;//acute accent
			case 0x14:combiningUnicode=0x030C;break;//caron, hacek
			case 0x15:combiningUnicode=0x0306;break;//breve
			case 0x16:combiningUnicode=0x0304;break;//macron
			case 0x17:combiningUnicode=0x030A;break;//ring above
			case 0x18:combiningUnicode=0x0327;break;//cedilla below 
			case 0x20:combiningUnicode=0x0337;break;//short solidus overlay
			case 0x5E:combiningUnicode=0x0302;break;//circumflex
			case 0x5F:combiningUnicode=0x0307;break;//dot above
			case 0x63:combiningUnicode=0x0063;break;//special case 'c' from copyright
			case 0x7D:combiningUnicode=0x030B;break;//long hungarian umlaut, combining double acute accent
			case 0x7E:combiningUnicode=0x0342;break;//tilde
			case 0x7F:combiningUnicode=0x0308;break;//diaeresis
			}
	}
	if (strstr(currentFont,"cmmi")){
		switch(accent){
			case 0x7F:combiningUnicode=0x2040;break;//tie
		}
	}
	return;
}

void saveAccentUnder(char accent){
	if (strstr(currentFont,"cmr")||strstr(currentFont,"cmbx")){
			switch(accent){
			case 0x16:combiningUnicode=0x0331;break;//macron below
			case 0x18:combiningUnicode=0x0327;break;//cedilla below
			case 0x2E:combiningUnicode=0x0323;break;//dot below
			}
	}
	return;
}

void InferContent(){
	char*from,utf8Operator[100];

	//divide
	from=doc_math;
	do{
	from=content(from,">/<","<apply><divide/><ci>","</ci></apply>");
	}while(from);

	//plus
	from=doc_math;
	do{
	from=content(from,">+<","<apply><plus/><ci>","</ci></apply>");
	}while(from);

	//minus
	from=doc_math;
	strcpy(utf8Operator,">");
	strcat(utf8Operator,ul2utf8(0x2212));
	strcat(utf8Operator,"<");
	do{
	from=content(from,utf8Operator,"<apply><minus/><ci>","</ci></apply>");
	}while(from);
	
	//begin relations 
	//equal
	from=doc_math;
	do{
	from=content(from,">=<","<apply><eq/><ci>","</ci></apply>");
	}while(from);
	
	//not equal
	from=doc_math;
	strcpy(utf8Operator,">");
	strcat(utf8Operator,ul2utf8(0x2260));
	strcat(utf8Operator,"<");
	do{
	from=content(from,utf8Operator,"<apply><neq/><ci>","</ci></apply>");
	}while(from);
	
	//greater than
	from=doc_math;
	do{
	from=content(from,">&gt;<","<apply><gt/><ci>","</ci></apply>");
	}while(from);

	//less than
	from=doc_math;
	do{
	from=content(from,">&lt;<","<apply><lt/><ci>","</ci></apply>");
	}while(from);
	
	//greater than or equal
	from=doc_math;
	strcpy(utf8Operator,">");
	strcat(utf8Operator,ul2utf8(0x2265));
	strcat(utf8Operator,"<");
	do{
	from=content(from,utf8Operator,"<apply><geq/><ci>","</ci></apply>");
	}while(from);
	
	//less than or equal
	from=doc_math;
	strcpy(utf8Operator,">");
	strcat(utf8Operator,ul2utf8(0x2264));
	strcat(utf8Operator,"<");
	do{
	from=content(from,utf8Operator,"<apply><leq/><ci>","</ci></apply>");
	}while(from);
	
	//equivalent
	from=doc_math;
	strcpy(utf8Operator,">");
	strcat(utf8Operator,ul2utf8(0x224D));
	strcat(utf8Operator,"<");
	do{
	from=content(from,utf8Operator,"<apply><equivalent/><ci>","</ci></apply>");
	}while(from);
	
	//approx
	from=doc_math;
	strcpy(utf8Operator,">");
	strcat(utf8Operator,ul2utf8(0x224A));
	strcat(utf8Operator,"<");
	do{
	from=content(from,utf8Operator,"<apply><approx/><ci>","</ci></apply>");
	}while(from);
	
	//end relations 
}

char* content(char*from,char*what, char*bas, char*eas){
	/* look for 'what' in 'from',
	find the previous argument and insert 'bas', then '</ci><ci>',
	then find the next argument and insert and 'eas'
	*/

	char *temp,*tail,*lock,*check;
	temp=lock=check=strstr(from,what);
	if (temp==NULL) return NULL;

	//ensure we're not at the end of a container
	check=strstr(++check,">");
	if (check==strstr(check,"><")){
		if (IsMMLContainerEnd(++check)) return ++lock;
	}else
		return ++lock;

	//ensure we're not at the beginning of a container
	while(*temp--!='<'){if (temp==from) return(++lock);};
	while(*temp--!='<'){if (temp==from) return(++lock);};
	if (IsMMLContainerStart(++temp)) return ++lock;

	lock=strstr(temp,what);
	lock=strstr(++lock,">");
	tail=(char*)malloc(strlen(++lock)+1);
	strcpy(tail,lock);
	lock=strstr(temp,"><");
	*++lock=0;
	lock=(char*)malloc(strlen(temp)+1);
	strcpy(lock,"<");
	strcat(lock,temp+2);
	temp=MatchTagLeft(temp,lock);
	free(lock);
	Insert(temp,bas);
	strcat(temp,"</ci><ci>");
	lock=strrchr(temp,0);
	strcat(temp,tail);
	free(tail);

	//'lock' points now to the beginning of the second argument
	temp=lock;
	temp=MatchTagRight(strstr(temp,"<"));
	Insert(temp,eas);
	return ++lock;
}

void beginSuperScript(){
	char*temp=strrchr(doc_math,0),*tail,*lock;
	lock=temp;
	//go to last closing tag
	while (strstr(temp,"</")!=temp) {
		if (temp==doc_math) {
			Insert(temp,"<msup><mrow><mi> </mi></mrow><mrow>");
			return; //the author used $^
		}
		if (strstr(temp,"<mrow")==temp || strstr(temp,"<mtd")==temp) {
			temp=strstr(temp,">");temp++;
			Insert(temp,"<msup><mrow><mi> </mi></mrow><mrow>");
			return; //the author used {}^ 
		}
		temp--;
	}
	
	
	if ((tail=strstr(temp," RD "))){
		temp=SkipBracketsLeft(tail);
	}else{
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,"<");
		strcat(tail,strstr(temp,"/")+1);
		*strstr(tail,">")=0;
		temp=MatchTagLeft(temp,tail);
		free(tail);
	}
	
	if (hbrace && temp==strstr(temp,"<munder")){
		Insert(temp,"<munder accentunder=\"true\">");
		p("<mrow>");
	}else{
		if (hbrace && temp==strstr(temp,"<mover")){
			Insert(temp,"<mover accent=\"true\">");
			p("<mrow>");
		}else{
			Insert(temp,"<msup><mrow>");
			p("</mrow><mrow>");
		}
	}
}

void beginSubScript(){
	char*temp=strrchr(doc_math,0),*tail,*lock;
	while (strstr(temp,"</")!=temp) {
		if (temp==doc_math) {
			Insert(temp,"<msub><mrow><mi> </mi></mrow><mrow>");
			return; //the author used $_
		}
		if (strstr(temp,"<mrow")==temp || strstr(temp,"<mtd")==temp) {
			temp=strstr(temp,">");temp++;
			Insert(temp,"<msub><mrow><mi> </mi></mrow><mrow>");
			return; //the author used {}_ 
		}
		temp--;
	}
	
	if ((tail=strstr(temp," RD "))){
		temp=SkipBracketsLeft(tail);
	}else{
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,"<");
		strcat(tail,strstr(temp,"/")+1);
		*strstr(tail,">")=0;
		lock=temp=MatchTagLeft(temp,tail);
		free(tail);
	}
	if (temp==strstr(temp,"<msup")){
		lock=MatchTagRight(temp);
		while (lock!=strstr(lock,"</")) lock--;
		*lock=0;
		temp++;temp++;
		Insert(temp,"sub");//make it a <msubsup> tag
		p("<mrow>");
	}else{
		if (hbrace && temp==strstr(temp,"<munder")){
			Insert(temp,"<munder accentunder=\"true\">");
			p("<mrow>");
		}else{
			if (hbrace && temp==strstr(temp,"<mover")){
				Insert(temp,"<mover accent=\"true\">");
				p("<mrow>");
			}else{
				Insert(temp,"<msub><mrow>");
				p("</mrow><mrow>");
			}
		}
	}
}

void endSubScript(){
	char*temp=strrchr(doc_math,0),*tail,*lock;
	p("</mrow>");
	while (strstr(temp,"</mrow")!=temp) temp--;
	temp=MatchTagLeft(temp,"<mrow");

	while (strstr(temp,"</mrow")!=temp) {
		if (temp!=doc_math) temp--;
		else die("error:\n can't reach first argument of 'subscript'\n");
	}
	temp=MatchTagLeft(temp,"<mrow");

	if (temp!=doc_math) {
		temp--;
		while (strstr(temp,"<")!=temp) temp--;
	}
	if (temp==strstr(temp,"</mrow>")){
		temp=MatchTagLeft(temp,"<mrow");
		if (temp!=doc_math) temp--;
		while (strstr(temp,"<")!=temp) {
			if (temp!=doc_math) temp--;
			else die("error:\n can't delimit first argument of 'subscript'\n");
		}
	}

	if (temp==strstr(temp,"<msubsup")){
		temp=strstr(temp,"<mrow>");
		temp=MatchTagRight(temp);
		lock=temp;
		temp=MatchTagRight(temp);
		tail=(char*)malloc(strlen(temp)+1);
		strcpy(tail,temp);
		*temp=0;
		Insert(lock,tail);
		free(tail);
		p("</msubsup>");
	}
	else
		if (temp==strstr(temp,"<munder")) p("</munder>");
		else {
			if (temp==strstr(temp,"<mover")) p("</mover>");
			else	p("</msub>");
		}
}


void endSuperScript()
{
	char*temp=strrchr(doc_math,0);
	p("</mrow>");

	while (strstr(temp,"</mrow")!=temp) temp--;
	temp=MatchTagLeft(temp,"<mrow");

	while (strstr(temp,"</mrow")!=temp) {
		if (temp!=doc_math) temp--;
		else die("error:\n can't reach first argument of 'superscript'\n");
	}
	temp=MatchTagLeft(temp,"<mrow");

	if (temp!=doc_math) {
		temp--;
		while (strstr(temp,"<")!=temp) temp--;
	}
	if (temp==strstr(temp,"</mrow>")){
		temp=MatchTagLeft(temp,"<mrow");
		if (temp!=doc_math) temp--;
		while (strstr(temp,"<")!=temp) {
			if (temp!=doc_math) temp--;
			else die("error:\n can't delimit first argument of 'superscript'\n");
		}
	}
	
	if (temp==strstr(temp,"<munder")) p("</munder>");
	else {
		if (temp==strstr(temp,"<mover")) p("</mover>");
		else	p("</msup>");
	}
}

void endMAccent(){
	char*temp=strrchr(doc_math,0),*tail;
	while (strstr(temp,"</mrow")!=temp) temp--;
	temp=MatchTagLeft(temp,"<mrow");
	tail=(char*)malloc(strlen(temp)+1);
	strcpy(tail,temp);*temp=0;
	while (strstr(temp,"</mrow")!=temp) {
		if (temp!=doc_math) temp--;
		else die("error in MAccent\n");
	}
	temp=MatchTagLeft(temp,"<mrow");
	Insert(temp,tail);
	free(tail);
}

void fixDigits(){
	char*temp=strrchr(doc_math,0);
	char dsep;
	//if there are previous digits don't put any <mn
	if (temp==doc_math){p("<mn>");return ;}
	while(*temp!='<'){
		temp--;
		if (temp==doc_math){p("<mn>");return ;}
	}
	if (temp==strstr(temp,"</mn>")) {
		*temp=0;return;
	}
	//if noninteger, unwrap the separator
	if (temp==strstr(temp,"</mo>")) {
		temp--;
		if (*temp=='.'){ //noninteger number, XXX localize separator
			dsep=*temp;
			temp=MatchTagLeft(temp,"<mo");
			temp--;
			if (temp==doc_math){p("<mn>");return ;}
			while(*temp!='<'){
				temp--;
				if (temp==doc_math){p("<mn>");return ;}
			}
		}
		if (temp==strstr(temp,"</mn")) {
			*temp++=dsep;
			*temp=0;
			return;			
		}
	}
	p("<mn>");
}

void precomposedNegative(unsigned long single, unsigned long composed){
//choose the precomposed negated operators where available
		if(combiningUnicode==0x0338) { 
				combiningUnicode=0;
				pmt(composed);
			}
		else	pmt(single);
}

void contractTextAccent(){
//mapping a character-accent combining pair into a single
//unicode character, if the accented character 
//is already available in the Unicode spec

	unsigned char*temp=(unsigned char*)strrchr(doc_text,0);
	unsigned char test=*(--temp);
	switch (test){
		case 'a':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xE0));//a with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xE1));//a with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x01CE));//a with caron
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x0103));//a with breve
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x0101));//a with macron
				break;
				case 0x030A:
					*temp=0;
					p(ul2utf8(0x00E5));//a with ring above
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xE2));//a with circumflex
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x0227));//a with dot above
				break;
				case 0x0342:
					*temp=0;
					p(ul2utf8(0x00E3));//a with tilde
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x00E4));//a with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'A':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xC0));//A with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xC1));//A with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x01CD));//A with caron
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x0102));//A with breve
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x0100));//A with macron
				break;
				case 0x030A:
					*temp=0;
					p(ul2utf8(0x00C5));//A with ring above
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xC2));//A with circumflex
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x0226));//A with dot above
				break;
				case 0x0342:
					*temp=0;
					p(ul2utf8(0x00C3));//A with tilde
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x00C4));//A with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'e':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xE8));//a with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xE9));//e with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x011B));//e with caron
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x0115));//e with breve
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x0113));//e with macron
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xEA));//e with circumflex
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x0117));//e with dot above
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0xEB));//e with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'E':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xC8));//E with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xC9));//E with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x011A));//E with caron
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x0114));//E with breve
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x0112));//E with macron
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xCA));//E with circumflex
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x0116));//E with dot above
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x00CB));//E with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 177://the dotless i case
			temp--;
			if (*(unsigned char*)temp==196){
				switch (combiningUnicode){
					case 0x0300:
						*temp=0;
						p(ul2utf8(0xEC));//i with grave
					break;
					case 0x0301:
						*temp=0;
						p(ul2utf8(0xED));//i with acute
					break;
					case 0x0302:
						*temp=0;
						p(ul2utf8(0xEE));//i with circumflex
					break;
					case 0x0304:
						*temp=0;
						p(ul2utf8(0x012B));//i with macron
					break;
					case 0x0306:
						*temp=0;
						p(ul2utf8(0x012D));//i with breve
					break;
					case 0x0307:
						*temp=0;
						p(ul2utf8(0x0131));//i with_out_ dot above
					break;
					case 0x0308:
						*temp=0;
						p(ul2utf8(0x00EF));//i with diaeresis
					break;
					case 0x030C:
						*temp=0;
						p(ul2utf8(0x01D0));//i with caron
					break;
					case 0x0342:
						*temp=0;
						p(ul2utf8(0x0129));//i with tilde
					break;
					default:
						p(ul2utf8(combiningUnicode)); //leave them combined 
				};
			}
			break;
		case 'I':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xCC));//I with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xCD));//I with acute
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xCE));//I with circumflex
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x012A));//I with macron
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x012C));//I with breve
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x0130));//I with dot above
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x01CF));//I with caron
				break;
				case 0x0342:
					*temp=0;
					p(ul2utf8(0x0129));//I with tilde
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x00CF));//I with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'o':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xF2));//o with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xF3));//o with acute
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xF4));//o with circumflex
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x014F));//o with breve
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x014D));//o with macron
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x022F));//o with dot above
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x00F6));//o with diaeresis
				break;
				case 0x030B:
					*temp=0;
					p(ul2utf8(0x0151));//o with Hungarian umlaut
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x01D2));//o with caron
				break;
				case 0x0342:
					*temp=0;
					p(ul2utf8(0x00F5));//o with tilde
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'O':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xD2));//O with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xD3));//O with acute
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xD4));//O with circumflex
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x014C));//O with macron
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x014E));//O with breve
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x022E));//O with dot above
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x00D6));//O with diaeresis
				break;
				case 0x030B:
					*temp=0;
					p(ul2utf8(0x0150));//O with Hungarian umlaut
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x01D1));//O with caron
				break;
				case 0x0342:
					*temp=0;
					p(ul2utf8(0x00D5));//O with tilde
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'u':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xF9));//u with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xFA));//u with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x01D4));//u with caron
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x016D));//u with breve
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x016B));//u with macron
				break;
				case 0x030A:
					*temp=0;
					p(ul2utf8(0x016F));//u with ring above
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xFB));//u with circumflex
				break;
				case 0x030B:
					*temp=0;
					p(ul2utf8(0x0171));//u with Hungarian umlaut
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x00FC));//u with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'U':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0xD9));//u with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0xDA));//u with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x01D3));//u with caron
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x016C));//u with breve
				break;
				case 0x0304:
					*temp=0;
					p(ul2utf8(0x016A));//u with macron
				break;
				case 0x030A:
					*temp=0;
					p(ul2utf8(0x016E));//u with ring above
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0xDB));//u with circumflex
				break;
				case 0x030B:
					*temp=0;
					p(ul2utf8(0x0170));//u with Hungarian umlaut
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0xDC));//u with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'c':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x0107));//c with acute
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x109));//c with circumflex
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x010B));//c with dot above
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x010D));//c with caron
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'C':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x0106));//C with acute
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x108));//C with circumflex
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x010A));//C with dot above
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x010C));//C with caron
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'd':
			switch (combiningUnicode){
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x010F));//d with caron
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'D':
			switch (combiningUnicode){
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x010E));//D with caron
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'g':
			switch (combiningUnicode){
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x011D));//g with circumflex
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x011F));//g with breve
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x0121));//g with dot above
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0122));//g with cedilla
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'G':
			switch (combiningUnicode){
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x011C));//G with circumflex
				break;
				case 0x0306:
					*temp=0;
					p(ul2utf8(0x011D));//G with breve
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x0120));//G with dot above
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0122));//G with cedilla
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'h':
			switch (combiningUnicode){
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x0125));//h with circumflex
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'H':
			switch (combiningUnicode){
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x0124));//H with circumflex
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'k':
			switch (combiningUnicode){
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0137));//l with cedilla
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'K':
			switch (combiningUnicode){
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0136));//L with cedilla
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'l':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x013A));//l with acute
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x013C));//l with cedilla
				break;
				case 0x0337:
					*temp=0;
					p(ul2utf8(0x0142));//l with stroke
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'L':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x0139));//L with acute
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x013B));//L with cedilla
				break;
				case 0x0337:
					*temp=0;
					p(ul2utf8(0x0141));//L with stroke
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'n':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0x01F9));//n with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x0144));//n with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x0148));//n with caron
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0146));//n with cedilla
				break;
				case 0x0342:
					*temp=0;
					p(ul2utf8(0x00F1));//n with tilde
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'N':
			switch (combiningUnicode){
				case 0x0300:
					*temp=0;
					p(ul2utf8(0x01F8));//N with grave
				break;
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x0143));//N with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x0147));//N with caron
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0145));//N with cedilla
				break;
				case 0x0342:
					*temp=0;
					p(ul2utf8(0x00D1));//n with tilde
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'r':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x0155));//r with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x0159));//r with caron
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0157));//r with cedilla
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'R':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x0154));//R with acute
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x0158));//R with caron
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0156));//R with cedilla
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 's':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x15B));//s with acute
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x15D));//s with circumflex
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x0161));//s with caron
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x015F));//S with cedilla
					//p(ul2utf8(0x0219));//S with comma
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'S':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x15A));//S with acute
				break;
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x15C));//S with circumflex
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x0160));//S with caron
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x015E));//S with cedilla
					//p(ul2utf8(0x0218));//S with comma
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 't':
			switch (combiningUnicode){
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x0165));//t with caron
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0163));//t with cedilla 
					//p(ul2utf8(0x021B));//t with comma
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'T':
			switch (combiningUnicode){
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x0164));//T with caron
				break;
				case 0x0327:
					*temp=0;
					p(ul2utf8(0x0162));//T with cedilla
					//p(ul2utf8(0x021A));//T with comma
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'w':
			switch (combiningUnicode){
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x0175));//w with circumflex
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'W':
			switch (combiningUnicode){
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x0174));//w with circumflex
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'y':
			switch (combiningUnicode){
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x0177));//y with circumflex
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x00FF));//y with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'Y':
			switch (combiningUnicode){
				case 0x0302:
					*temp=0;
					p(ul2utf8(0x0176));//Y with circumflex
				break;
				case 0x0308:
					*temp=0;
					p(ul2utf8(0x0178));//Y with diaeresis
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'z':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x017A));//z with acute
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x017C));//z with dot above
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x017E));//z with caron
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 'Z':
			switch (combiningUnicode){
				case 0x0301:
					*temp=0;
					p(ul2utf8(0x0179));//Z with acute
				break;
				case 0x0307:
					*temp=0;
					p(ul2utf8(0x017B));//z with dot above
				break;
				case 0x030C:
					*temp=0;
					p(ul2utf8(0x017D));//z with caron
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		case 0x01://holder for big circle in cmsy, this is for the copyright symbol
			switch (combiningUnicode){//this should be 'c'
				case 'c':
					*temp=0;
					p(ul2utf8(0x00A9));//copyright sign
				break;
				default:
					p(ul2utf8(combiningUnicode)); //leave them combined 
			};
			break;
		default:
			p(ul2utf8(combiningUnicode)); //leave them combined 
	}
	combiningUnicode=0;
}

void AddPHint(int start){
	if (!fakesp){strcat(doc_text," ");fakesp=1;}
	if (!pHints || (mathmode && !mathText)) return;
//	if (*currentFont==0) return;
	if (start){
		strcat(doc_text,"<ph f=\""); strcat(doc_text,currentFont);strcat(doc_text,"\">");
	}	else
		strcat(doc_text,"</ph>");
}

void printFigureFileName(){
	char*filename=(char*)malloc(strlen(yytext)+1), *temp;
	temp=strstr(yytext," figFileName: ")+strlen(" figFileName: ");
	if (temp==NULL) die("\nin epsffile, expected ' figFileName: '\n");
	strcpy(filename,temp);
	temp=strrchr(filename,'.');
	if (temp) 
		*temp=0;
	else
		*strstr(filename," :figFileName ")=0;
	AddPHint(0);
	p("<source>");
	p(filename);
	p("</source>");
	free(filename);
	AddPHint(1);
}

void printEPSFigureFileName(){
	char*filename=(char*)malloc(strlen(yytext)+1), *temp;
	temp=strstr(yytext,"file=")+strlen("file=");
	if (temp==NULL) die("\nin epsfig, expected 'file='\n");
	strcpy(filename,temp);
	temp=strrchr(filename,'.');
	if (temp) 
		*temp=0;
	else
		*strstr(filename," :epsfigFileName ")=0;
	AddPHint(0);
	p("<source>");
	p(filename);
	p("</source>");
	AddPHint(1);
	free(filename);
}

void printRef(){
	char*ref=(char*)malloc(strlen(yytext)+1);
	strcpy(ref,strstr(yytext," Sref:@")+strlen(" Sref:@"));
	*strstr(ref,"@:Sref ")=0;
	p("<sref>");
	p(ref);
	p("</sref>");
	free(ref);
}

void printId(){
	char*label=(char*)malloc(strlen(yytext)+1);
	strcpy(label,strstr(yytext," Id:@")+strlen(" Id:@"));
	*strstr(label,"@:Id ")=0;
	if (mathmode){
		p("<id>");
		p(label);
		p("</id>");
	}else{
		AddPHint(0);
		p("<id>");
		p(label);
		p("</id>");
		AddPHint(1);
	}
	free(label);
}

void printEnvType(){
	char*type=(char*)malloc(strlen(yytext)+1);
	strcpy(type,strstr(yytext," env:@")+strlen(" env:@"));
	*strchr(type,'@')=0;
	if (mathmode){
		p("<type>");
		p(type);
		p("</type>");
	}else{
		AddPHint(0);
		p("<type>");
		p(type);
		p("</type>");
		AddPHint(1);
	}
	free(type);
}

void printSectType(){
	char*ref=(char*)malloc(strlen(yytext)+1);
	strcpy(ref,strstr(yytext," sectType:")+strlen(" sectType:"));
	*strstr(ref,":sectType ")=0;
	p("<type>");
	p(ref);
	p("</type>");
	free(ref);
}

void printCiteSRef(){
	char* peek,*temp,*ref;
	int commas=0;
	peek=yytext;
	while((peek=strchr(peek,','))){
		commas++;peek++;
	}
	ref=(char*)malloc(strlen(yytext)+commas*strlen("</sref><sref>")+1);
	p("<sref>");
	peek=strchr(yytext,'@')+1;
	temp=ref;
	while (*peek!='@'){
		if (*peek==' '){ 
			peek++; continue;
		}
		if (*peek==','){
			strcpy(temp,"</sref><sref>");
			temp=strrchr(temp,0);
		}else
			*temp++=*peek;
		peek++;
	}
	*temp=0;
	p(ref);
	p("</sref>");
	free(ref);
}
